json = {
    "components": [
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central arc radius.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Angle",
                    "name": "angle",
                    "tooltip": "Arc coverage angle.",
                    "defaults": 90.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": -360, "max": 360},
                    "type": "number",
                    "suffix": "°",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bend that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "label": "Port Bends",
                    "name": "port_bends",
                    "tooltip": "Flag controllig whether to set a bend radius for the ports. Not used when ``euler_factor > 0``.",
                    "type": "checkbox",
                    "defaults": False,
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.bend",
            "label": "Bend",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.462500 -8.462500 10.175000 10.175000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}.reference{fill:none;stroke:#221f20;stroke-width:0.035612;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.407000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.050875;}.dashed{stroke-dasharray:0.254375,0.152625;}.port{fill:none;stroke:#805080;stroke-width:0.101750;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.076313;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.203500 L 0.305250,0 0,0.203500" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.152625 C 0.203500,-0.152625 0.203500,0.152625 0,0.152625" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.091575" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.106838" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 0.346000,-1.244000 0.691000,-1.224000 1.036000,-1.192000 1.379000,-1.147000 1.720000,-1.089000 2.058000,-1.018000 2.394000,-0.935000 2.726000,-0.839000 3.055000,-0.731000 3.379000,-0.611000 3.699000,-0.478000 4.013000,-0.334000 4.322000,-0.178000 4.625000,-0.011000 4.921000,0.168000 5.211000,0.357000 5.493000,0.557000 5.767000,0.768000 6.034000,0.989000 6.292000,1.219000 6.541000,1.459000 6.781000,1.708000 7.011000,1.966000 7.232000,2.233000 7.443000,2.507000 7.643000,2.789000 7.832000,3.079000 8.011000,3.375000 8.178000,3.678000 8.334000,3.987000 8.478000,4.301000 8.611000,4.621000 8.731000,4.945000 8.839000,5.274000 8.935000,5.606000 9.018000,5.942000 9.089000,6.280000 9.147000,6.621000 9.192000,6.964000 9.224000,7.309000 9.244000,7.654000 9.250000,8.000000 6.750000,8.000000 6.745000,7.748000 6.708000,7.244000 6.675000,6.994000 6.581000,6.498000 6.450000,6.010000 6.283000,5.534000 6.082000,5.071000 5.846000,4.625000 5.577000,4.198000 5.277000,3.791000 4.948000,3.409000 4.591000,3.052000 4.209000,2.723000 3.802000,2.423000 3.375000,2.154000 2.929000,1.918000 2.466000,1.717000 1.990000,1.550000 1.502000,1.419000 1.006000,1.325000 0.756000,1.292000 0.504000,1.269000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.308000,-0.244000 0.617000,-0.227000 0.924000,-0.198000 1.230000,-0.158000 1.534000,-0.106000 1.836000,-0.043000 2.135000,0.031000 2.432000,0.117000 2.725000,0.213000 3.014000,0.320000 3.299000,0.438000 3.580000,0.567000 3.855000,0.706000 4.125000,0.855000 4.389000,1.015000 4.647000,1.184000 4.899000,1.362000 5.144000,1.550000 5.381000,1.747000 5.611000,1.952000 5.834000,2.166000 6.048000,2.389000 6.253000,2.619000 6.450000,2.856000 6.638000,3.101000 6.816000,3.353000 6.985000,3.611000 7.145000,3.875000 7.294000,4.145000 7.433000,4.420000 7.562000,4.701000 7.680000,4.986000 7.787000,5.275000 7.883000,5.568000 7.969000,5.865000 8.043000,6.164000 8.106000,6.466000 8.158000,6.770000 8.198000,7.076000 8.227000,7.383000 8.244000,7.692000 8.250000,8.000000 7.750000,8.000000 7.745000,7.710000 7.728000,7.421000 7.701000,7.132000 7.663000,6.845000 7.615000,6.559000 7.556000,6.275000 7.486000,5.994000 7.406000,5.716000 7.315000,5.440000 7.214000,5.169000 6.983000,4.637000 6.712000,4.125000 6.562000,3.877000 6.403000,3.634000 6.236000,3.398000 6.059000,3.168000 5.874000,2.945000 5.681000,2.729000 5.480000,2.520000 5.271000,2.319000 5.055000,2.126000 4.832000,1.941000 4.602000,1.764000 4.366000,1.597000 4.123000,1.438000 3.875000,1.288000 3.363000,1.017000 2.831000,0.786000 2.560000,0.685000 2.284000,0.594000 2.006000,0.514000 1.725000,0.444000 1.441000,0.385000 1.155000,0.337000 0.868000,0.299000 0.290000,0.255000 0.000000,0.250000 z" /><g transform="translate(8.000000 8.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Turns",
                    "name": "turns",
                    "tooltip": "Number of turns in each of the 2 spiral arms. Does not need to be an integer.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "required": False,
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Bend radius for the internal spiral turns.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Separation",
                    "name": "separation",
                    "tooltip": "Distance between waveguide centers in parallel sections.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Full Length",
                    "name": "full_length",
                    "tooltip": "Desired spiral length. If set to a positive value, 'turns' is calculated automatically.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                    "required": False,
                },
                {
                    "label": "Align Ports",
                    "name": "align_ports",
                    "tooltip": "Optionally align ports on the same side of the spiral.",
                    "defaults": False,
                    "type": "checkbox",
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.circular_spiral",
            "label": "Circular Spiral",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.753000 -101.125000 105.007000 107.250000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.536250;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.536250;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.536250;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.536250;}.reference{fill:none;stroke:#221f20;stroke-width:0.375375;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:4.290000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.536250;}.dashed{stroke-dasharray:2.681250,1.608750;}.port{fill:none;stroke:#805080;stroke-width:1.072500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.804375;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-2.145000 L 3.217500,0 0,2.145000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-1.608750 C 2.145000,-1.608750 2.145000,1.608750 0,1.608750" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.965250" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="1.126125" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 41.769000,-1.250000 42.815000,-1.223000 43.861000,-1.173000 44.905000,-1.101000 45.946000,-1.007000 46.985000,-0.891000 48.021000,-0.752000 49.054000,-0.591000 50.082000,-0.408000 51.106000,-0.203000 52.125000,0.024000 53.138000,0.273000 54.146000,0.543000 55.147000,0.835000 56.142000,1.148000 57.129000,1.483000 58.108000,1.838000 59.080000,2.214000 60.042000,2.611000 60.996000,3.028000 61.940000,3.466000 62.874000,3.923000 63.798000,4.401000 64.711000,4.898000 65.613000,5.414000 66.504000,5.949000 67.382000,6.503000 68.248000,7.076000 69.101000,7.667000 69.941000,8.276000 70.768000,8.903000 71.581000,9.547000 72.379000,10.208000 73.163000,10.886000 73.932000,11.581000 74.685000,12.291000 75.423000,13.018000 76.144000,13.760000 76.850000,14.517000 77.539000,15.288000 78.210000,16.074000 78.865000,16.874000 79.502000,17.688000 80.121000,18.515000 80.722000,19.354000 81.305000,20.207000 81.869000,21.071000 82.415000,21.947000 82.941000,22.834000 83.448000,23.731000 83.935000,24.640000 84.402000,25.558000 84.850000,26.486000 85.277000,27.422000 85.684000,28.368000 86.071000,29.322000 86.437000,30.283000 86.782000,31.252000 87.105000,32.228000 87.408000,33.210000 87.690000,34.198000 87.950000,35.191000 88.189000,36.190000 88.406000,37.193000 88.601000,38.200000 88.775000,39.211000 88.927000,40.225000 89.057000,41.242000 89.165000,42.261000 89.252000,43.282000 89.316000,44.304000 89.358000,45.327000 89.379000,46.350000 89.377000,47.373000 89.353000,48.396000 89.308000,49.417000 89.240000,50.437000 89.151000,51.455000 89.040000,52.470000 88.907000,53.483000 88.752000,54.492000 88.576000,55.497000 88.378000,56.498000 88.159000,57.494000 87.919000,58.484000 87.658000,59.469000 87.375000,60.448000 87.072000,61.421000 86.748000,62.386000 86.404000,63.344000 86.039000,64.293000 85.654000,65.235000 85.248000,66.167000 84.824000,67.091000 84.379000,68.005000 83.915000,68.908000 83.432000,69.802000 82.930000,70.684000 82.410000,71.555000 81.871000,72.415000 81.313000,73.262000 80.738000,74.097000 80.146000,74.919000 79.536000,75.728000 78.909000,76.524000 78.265000,77.305000 77.605000,78.073000 76.929000,78.825000 76.236000,79.563000 75.529000,80.285000 74.806000,80.992000 74.069000,81.683000 73.317000,82.358000 72.551000,83.016000 71.772000,83.658000 70.979000,84.282000 70.173000,84.889000 69.354000,85.478000 68.523000,86.050000 67.681000,86.603000 66.827000,87.138000 65.962000,87.654000 65.087000,88.151000 64.201000,88.629000 63.305000,89.088000 62.401000,89.528000 61.487000,89.948000 60.565000,90.348000 59.634000,90.728000 58.696000,91.087000 57.751000,91.427000 56.799000,91.746000 55.841000,92.044000 54.877000,92.322000 53.907000,92.578000 52.933000,92.814000 51.954000,93.029000 50.971000,93.222000 49.984000,93.395000 48.994000,93.546000 48.001000,93.675000 47.007000,93.784000 46.010000,93.870000 45.012000,93.936000 44.014000,93.980000 43.015000,94.002000 42.016000,94.003000 41.017000,93.983000 40.020000,93.941000 39.024000,93.878000 38.030000,93.793000 37.038000,93.688000 36.049000,93.560000 35.063000,93.412000 34.082000,93.243000 33.104000,93.053000 32.131000,92.841000 31.163000,92.609000 30.201000,92.357000 29.244000,92.084000 28.294000,91.790000 27.351000,91.476000 26.415000,91.142000 25.487000,90.789000 24.567000,90.415000 23.655000,90.022000 22.752000,89.610000 21.859000,89.178000 20.976000,88.728000 20.102000,88.258000 19.239000,87.771000 18.388000,87.265000 17.547000,86.741000 16.718000,86.199000 15.902000,85.640000 15.098000,85.063000 14.306000,84.470000 13.528000,83.860000 12.764000,83.234000 12.013000,82.591000 11.276000,81.933000 10.554000,81.259000 9.847000,80.571000 9.155000,79.867000 8.479000,79.149000 7.818000,78.417000 7.174000,77.671000 6.546000,76.912000 5.934000,76.139000 5.340000,75.354000 4.762000,74.557000 4.202000,73.747000 3.660000,72.927000 3.136000,72.095000 2.630000,71.252000 2.142000,70.398000 1.673000,69.535000 1.223000,68.662000 0.791000,67.780000 0.379000,66.890000 -0.013000,65.990000 -0.387000,65.083000 -0.740000,64.169000 -1.074000,63.247000 -1.388000,62.319000 -1.681000,61.385000 -1.955000,60.444000 -2.208000,59.499000 -2.440000,58.548000 -2.652000,57.593000 -2.844000,56.634000 -3.015000,55.672000 -3.165000,54.706000 -3.294000,53.738000 -3.402000,52.768000 -3.490000,51.795000 -3.556000,50.822000 -3.601000,49.847000 -3.626000,48.872000 -3.630000,47.897000 -3.612000,46.923000 -3.574000,45.950000 -3.515000,44.977000 -3.435000,44.007000 -3.334000,43.039000 -3.213000,42.074000 -3.071000,41.112000 -2.908000,40.153000 -2.725000,39.199000 -2.521000,38.249000 -2.297000,37.304000 -2.053000,36.364000 -1.789000,35.430000 -1.505000,34.502000 -1.202000,33.581000 -0.878000,32.667000 -0.536000,31.760000 -0.174000,30.861000 0.208000,29.971000 0.608000,29.089000 1.026000,28.217000 1.464000,27.353000 1.919000,26.500000 2.393000,25.657000 2.884000,24.825000 3.393000,24.003000 3.920000,23.193000 4.463000,22.395000 5.023000,21.609000 5.600000,20.836000 6.193000,20.075000 6.802000,19.327000 7.427000,18.593000 8.067000,17.873000 8.723000,17.167000 9.393000,16.475000 10.077000,15.798000 10.776000,15.137000 11.489000,14.490000 12.215000,13.860000 12.954000,13.245000 13.706000,12.646000 14.470000,12.064000 15.246000,11.499000 16.034000,10.951000 16.834000,10.420000 17.644000,9.906000 18.465000,9.410000 19.296000,8.932000 20.137000,8.473000 20.987000,8.031000 21.846000,7.608000 22.714000,7.204000 23.590000,6.818000 24.474000,6.452000 25.365000,6.105000 26.263000,5.777000 27.168000,5.468000 28.078000,5.180000 28.995000,4.910000 29.916000,4.661000 30.843000,4.432000 31.774000,4.223000 32.708000,4.033000 33.647000,3.864000 34.588000,3.716000 35.532000,3.587000 36.479000,3.479000 37.427000,3.391000 38.376000,3.324000 39.326000,3.277000 40.277000,3.251000 41.228000,3.244000 42.178000,3.259000 43.128000,3.294000 44.076000,3.349000 45.022000,3.424000 45.966000,3.520000 46.908000,3.636000 47.847000,3.772000 48.782000,3.928000 49.713000,4.104000 50.640000,4.300000 51.562000,4.516000 52.479000,4.752000 53.391000,5.007000 54.296000,5.282000 55.195000,5.575000 56.088000,5.888000 56.972000,6.220000 57.850000,6.571000 58.719000,6.940000 59.580000,7.328000 60.432000,7.734000 61.275000,8.158000 62.108000,8.600000 62.931000,9.060000 63.744000,9.537000 64.546000,10.031000 65.337000,10.542000 66.117000,11.070000 66.885000,11.614000 67.641000,12.175000 68.384000,12.751000 69.114000,13.343000 69.832000,13.950000 70.535000,14.573000 71.226000,15.210000 71.902000,15.861000 72.563000,16.527000 73.210000,17.207000 73.842000,17.900000 74.459000,18.606000 75.060000,19.325000 75.645000,20.056000 76.215000,20.800000 76.768000,21.555000 77.304000,22.322000 77.824000,23.100000 78.327000,23.889000 78.812000,24.688000 79.280000,25.497000 79.731000,26.315000 80.163000,27.143000 80.578000,27.979000 80.974000,28.824000 81.352000,29.677000 81.712000,30.538000 82.053000,31.406000 82.374000,32.280000 82.677000,33.161000 82.961000,34.048000 83.226000,34.941000 83.471000,35.838000 83.697000,36.741000 83.904000,37.648000 84.090000,38.558000 84.257000,39.472000 84.405000,40.390000 84.533000,41.309000 84.640000,42.231000 84.728000,43.155000 84.796000,44.080000 84.844000,45.007000 84.873000,45.933000 84.881000,46.860000 84.869000,47.786000 84.838000,48.711000 84.787000,49.636000 84.716000,50.558000 84.625000,51.479000 84.514000,52.397000 84.384000,53.312000 84.234000,54.224000 84.065000,55.132000 83.876000,56.036000 83.668000,56.935000 83.441000,57.829000 83.194000,58.718000 82.929000,59.601000 82.645000,60.478000 82.343000,61.348000 82.021000,62.212000 81.682000,63.067000 81.324000,63.915000 80.948000,64.755000 80.555000,65.587000 80.144000,66.409000 79.715000,67.222000 79.269000,68.025000 78.807000,68.819000 78.327000,69.601000 77.831000,70.374000 77.319000,71.135000 76.790000,71.884000 76.246000,72.622000 75.687000,73.348000 75.112000,74.061000 74.522000,74.761000 73.917000,75.449000 73.298000,76.123000 72.665000,76.783000 72.018000,77.429000 71.358000,78.061000 70.684000,78.679000 69.998000,79.282000 69.299000,79.869000 68.588000,80.441000 67.864000,80.998000 67.130000,81.539000 66.384000,82.063000 65.628000,82.572000 64.861000,83.063000 64.083000,83.538000 63.297000,83.996000 62.500000,84.437000 61.695000,84.861000 60.881000,85.267000 60.059000,85.655000 59.229000,86.025000 58.392000,86.378000 57.547000,86.712000 56.696000,87.028000 55.839000,87.325000 54.976000,87.604000 54.107000,87.864000 53.233000,88.105000 52.354000,88.327000 51.472000,88.531000 50.585000,88.715000 49.695000,88.880000 48.802000,89.026000 47.906000,89.153000 47.009000,89.260000 46.109000,89.348000 45.208000,89.417000 44.306000,89.466000 43.404000,89.496000 42.501000,89.506000 41.599000,89.497000 40.698000,89.469000 39.797000,89.421000 38.899000,89.354000 38.002000,89.268000 37.108000,89.163000 36.216000,89.038000 35.328000,88.895000 34.443000,88.732000 33.562000,88.551000 32.686000,88.350000 31.814000,88.131000 30.948000,87.894000 30.087000,87.638000 29.233000,87.363000 28.384000,87.071000 27.543000,86.760000 26.709000,86.432000 25.882000,86.085000 25.063000,85.722000 24.253000,85.340000 23.451000,84.942000 22.658000,84.527000 21.875000,84.095000 21.101000,83.646000 20.338000,83.181000 19.584000,82.700000 18.842000,82.203000 18.111000,81.691000 17.391000,81.163000 16.683000,80.620000 15.987000,80.062000 15.304000,79.489000 14.633000,78.902000 13.975000,78.301000 13.331000,77.686000 12.700000,77.058000 12.083000,76.417000 11.480000,75.762000 10.891000,75.096000 10.318000,74.417000 9.759000,73.726000 9.215000,73.023000 8.687000,72.309000 8.174000,71.585000 7.677000,70.849000 7.197000,70.104000 6.732000,69.349000 6.284000,68.584000 5.853000,67.810000 5.439000,67.027000 5.042000,66.236000 4.662000,65.436000 4.299000,64.629000 3.954000,63.815000 3.626000,62.994000 3.317000,62.166000 3.025000,61.332000 2.752000,60.492000 2.496000,59.647000 2.259000,58.797000 2.041000,57.943000 1.841000,57.084000 1.659000,56.222000 1.496000,55.356000 1.352000,54.487000 1.226000,53.615000 1.120000,52.742000 1.032000,51.866000 0.963000,50.990000 0.913000,50.112000 0.881000,49.234000 0.869000,48.356000 0.875000,47.477000 0.900000,46.600000 0.945000,45.724000 1.008000,44.849000 1.089000,43.976000 1.190000,43.105000 1.309000,42.237000 1.446000,41.372000 1.602000,40.511000 1.777000,39.653000 1.969000,38.800000 2.180000,37.951000 2.409000,37.108000 2.656000,36.269000 2.921000,35.437000 3.204000,34.611000 3.504000,33.791000 3.822000,32.979000 4.156000,32.173000 4.508000,31.376000 4.877000,30.586000 5.263000,29.805000 5.665000,29.032000 6.083000,28.269000 6.518000,27.515000 6.968000,26.771000 7.435000,26.037000 7.916000,25.313000 8.413000,24.601000 8.925000,23.899000 9.452000,23.209000 9.993000,22.530000 10.548000,21.864000 11.118000,21.210000 11.701000,20.568000 12.297000,19.940000 12.907000,19.324000 13.529000,18.722000 14.164000,18.134000 14.812000,17.560000 15.471000,17.000000 16.142000,16.455000 16.824000,15.924000 17.517000,15.408000 18.221000,14.908000 18.935000,14.423000 19.659000,13.953000 20.392000,13.500000 21.135000,13.062000 21.887000,12.641000 22.648000,12.236000 23.417000,11.847000 24.193000,11.476000 24.977000,11.121000 25.769000,10.783000 26.567000,10.463000 27.371000,10.159000 28.181000,9.874000 28.997000,9.606000 29.819000,9.355000 30.645000,9.123000 31.475000,8.908000 32.310000,8.711000 33.149000,8.532000 33.990000,8.372000 34.835000,8.229000 35.682000,8.105000 36.532000,7.999000 37.383000,7.911000 38.236000,7.842000 39.089000,7.791000 39.943000,7.758000 40.797000,7.744000 41.651000,7.748000 42.505000,7.771000 43.357000,7.811000 44.208000,7.870000 45.057000,7.948000 45.904000,8.043000 46.749000,8.157000 47.590000,8.288000 48.428000,8.438000 49.263000,8.605000 50.093000,8.791000 50.919000,8.994000 51.740000,9.214000 52.555000,9.453000 53.365000,9.708000 54.169000,9.981000 54.967000,10.271000 55.758000,10.577000 56.542000,10.901000 57.318000,11.241000 58.087000,11.598000 58.848000,11.971000 59.600000,12.360000 60.343000,12.765000 61.077000,13.186000 61.802000,13.622000 62.516000,14.073000 63.221000,14.540000 63.915000,15.021000 64.599000,15.517000 65.271000,16.028000 65.932000,16.552000 66.581000,17.090000 67.219000,17.642000 67.844000,18.208000 68.456000,18.786000 69.056000,19.377000 69.643000,19.981000 70.216000,20.597000 70.776000,21.225000 71.322000,21.864000 71.853000,22.515000 72.371000,23.177000 72.874000,23.849000 73.362000,24.532000 73.836000,25.225000 74.294000,25.928000 74.737000,26.640000 75.164000,27.361000 75.575000,28.091000 75.971000,28.829000 76.350000,29.575000 76.713000,30.329000 77.060000,31.090000 77.390000,31.858000 77.704000,32.633000 78.000000,33.414000 78.280000,34.201000 78.542000,34.994000 78.788000,35.791000 79.016000,36.594000 79.227000,37.401000 79.420000,38.211000 79.596000,39.026000 79.754000,39.844000 79.895000,40.664000 80.017000,41.487000 80.122000,42.313000 80.210000,43.139000 80.279000,43.968000 80.331000,44.797000 80.365000,45.627000 80.380000,46.457000 80.379000,47.287000 80.359000,48.116000 80.321000,48.945000 80.266000,49.772000 80.193000,50.597000 80.102000,51.420000 79.994000,52.241000 79.868000,53.059000 79.725000,53.874000 79.564000,54.685000 79.386000,55.492000 79.191000,56.295000 78.978000,57.093000 78.749000,57.886000 78.503000,58.674000 78.240000,59.456000 77.960000,60.232000 77.664000,61.001000 77.351000,61.763000 77.023000,62.518000 76.678000,63.266000 76.318000,64.006000 75.941000,64.738000 75.550000,65.461000 75.143000,66.175000 74.721000,66.880000 74.284000,67.575000 73.832000,68.261000 73.366000,68.936000 72.886000,69.602000 72.392000,70.256000 71.884000,70.899000 71.363000,71.531000 70.828000,72.152000 70.281000,72.760000 69.720000,73.357000 69.148000,73.941000 68.563000,74.512000 67.966000,75.071000 67.357000,75.616000 66.737000,76.148000 66.107000,76.666000 65.465000,77.170000 64.813000,77.660000 64.151000,78.136000 63.479000,78.598000 62.798000,79.044000 62.107000,79.476000 61.408000,79.893000 60.700000,80.294000 59.984000,80.680000 59.260000,81.050000 58.529000,81.405000 57.790000,81.743000 57.045000,82.066000 56.293000,82.372000 55.536000,82.662000 54.772000,82.936000 54.003000,83.192000 53.229000,83.433000 52.450000,83.656000 51.667000,83.863000 50.881000,84.052000 50.090000,84.225000 49.296000,84.381000 48.500000,84.519000 47.701000,84.640000 46.900000,84.744000 46.097000,84.831000 45.293000,84.900000 44.488000,84.953000 43.682000,84.987000 42.876000,85.005000 42.071000,85.005000 41.265000,84.988000 40.461000,84.953000 39.658000,84.902000 38.856000,84.833000 38.057000,84.747000 37.259000,84.644000 36.465000,84.523000 35.674000,84.386000 34.886000,84.232000 34.102000,84.061000 33.322000,83.873000 32.546000,83.669000 31.776000,83.448000 31.011000,83.211000 30.251000,82.958000 29.497000,82.688000 28.750000,82.402000 28.009000,82.101000 27.275000,81.784000 26.549000,81.451000 25.830000,81.103000 25.119000,80.739000 24.416000,80.361000 23.722000,79.968000 23.036000,79.560000 22.360000,79.137000 21.693000,78.701000 21.037000,78.250000 20.390000,77.786000 19.754000,77.307000 19.128000,76.816000 18.513000,76.312000 17.910000,75.794000 17.318000,75.264000 16.738000,74.722000 16.170000,74.167000 15.614000,73.601000 15.070000,73.023000 14.540000,72.434000 14.022000,71.833000 13.518000,71.223000 13.027000,70.601000 12.550000,69.970000 12.086000,69.328000 11.637000,68.677000 11.202000,68.017000 10.781000,67.348000 10.375000,66.671000 9.984000,65.985000 9.608000,65.291000 9.247000,64.589000 8.901000,63.880000 8.571000,63.165000 8.256000,62.442000 7.957000,61.714000 7.674000,60.979000 7.407000,60.239000 7.156000,59.493000 6.921000,58.743000 6.702000,57.988000 6.500000,57.229000 6.314000,56.466000 6.145000,55.699000 5.992000,54.930000 5.856000,54.157000 5.736000,53.382000 5.633000,52.605000 5.547000,51.827000 5.478000,51.047000 5.425000,50.266000 5.390000,49.484000 5.371000,48.703000 5.369000,47.921000 5.384000,47.140000 5.415000,46.359000 5.463000,45.580000 5.528000,44.803000 5.610000,44.027000 5.708000,43.253000 5.823000,42.482000 5.954000,41.714000 6.102000,40.950000 6.266000,40.189000 6.446000,39.432000 6.642000,38.680000 6.854000,37.932000 7.083000,37.189000 7.327000,36.452000 7.587000,35.720000 7.862000,34.994000 8.152000,34.275000 8.458000,33.563000 8.779000,32.857000 9.115000,32.159000 9.466000,31.469000 9.832000,30.786000 10.211000,30.112000 10.605000,29.446000 11.013000,28.790000 11.435000,28.142000 11.871000,27.504000 12.320000,26.876000 12.782000,26.258000 13.257000,25.650000 13.744000,25.053000 14.245000,24.466000 14.757000,23.891000 15.282000,23.327000 15.818000,22.775000 16.366000,22.235000 16.925000,21.707000 17.495000,21.191000 18.076000,20.688000 18.667000,20.197000 19.268000,19.720000 19.880000,19.255000 20.500000,18.805000 21.130000,18.367000 21.769000,17.944000 22.417000,17.535000 23.073000,17.140000 23.737000,16.759000 24.409000,16.392000 25.088000,16.041000 25.774000,15.704000 26.468000,15.382000 27.167000,15.075000 27.873000,14.784000 28.584000,14.508000 29.301000,14.247000 30.023000,14.002000 30.750000,13.772000 31.481000,13.559000 32.217000,13.361000 32.956000,13.179000 33.698000,13.013000 34.444000,12.863000 35.192000,12.729000 35.943000,12.612000 36.696000,12.510000 37.450000,12.425000 38.206000,12.356000 38.963000,12.303000 39.720000,12.267000 40.478000,12.247000 41.235000,12.243000 41.993000,12.256000 42.749000,12.284000 43.504000,12.329000 44.258000,12.390000 45.010000,12.468000 45.760000,12.561000 46.507000,12.670000 47.252000,12.796000 47.993000,12.937000 48.731000,13.094000 49.464000,13.267000 50.194000,13.455000 50.919000,13.659000 51.639000,13.879000 52.355000,14.114000 53.064000,14.364000 53.768000,14.629000 54.465000,14.909000 55.156000,15.204000 55.841000,15.513000 56.518000,15.837000 57.188000,16.175000 57.850000,16.527000 58.504000,16.894000 59.149000,17.274000 59.786000,17.668000 60.415000,18.075000 61.034000,18.495000 61.643000,18.929000 62.243000,19.375000 62.833000,19.834000 63.413000,20.305000 63.982000,20.788000 64.541000,21.284000 65.088000,21.790000 65.624000,22.309000 66.149000,22.838000 66.662000,23.378000 67.163000,23.929000 67.651000,24.491000 68.128000,25.062000 68.592000,25.644000 69.043000,26.235000 69.481000,26.835000 69.906000,27.444000 70.317000,28.062000 70.715000,28.688000 71.099000,29.323000 71.470000,29.965000 71.826000,30.615000 72.168000,31.272000 72.496000,31.936000 72.809000,32.606000 73.108000,33.283000 73.392000,33.966000 73.661000,34.654000 73.915000,35.348000 74.154000,36.046000 74.378000,36.750000 74.586000,37.457000 74.780000,38.169000 74.958000,38.884000 75.120000,39.603000 75.267000,40.325000 75.398000,41.049000 75.514000,41.776000 75.614000,42.504000 75.698000,43.235000 75.766000,43.966000 75.819000,44.699000 75.856000,45.432000 75.877000,46.165000 75.883000,46.899000 75.872000,47.632000 75.846000,48.364000 75.804000,49.096000 75.747000,49.825000 75.674000,50.554000 75.585000,51.280000 75.481000,52.003000 75.361000,52.724000 75.226000,53.442000 75.076000,54.157000 74.910000,54.868000 74.729000,55.574000 74.533000,56.277000 74.323000,56.974000 74.097000,57.667000 73.857000,58.354000 73.602000,59.036000 73.332000,59.712000 73.048000,60.382000 72.751000,61.045000 72.439000,61.701000 72.113000,62.350000 71.773000,62.991000 71.420000,63.625000 71.054000,64.251000 70.674000,64.868000 70.281000,65.477000 69.876000,66.077000 69.458000,66.668000 69.027000,67.250000 68.584000,67.822000 68.130000,68.384000 67.663000,68.936000 67.185000,69.477000 66.696000,70.008000 66.196000,70.528000 65.685000,71.037000 65.163000,71.535000 64.631000,72.021000 64.089000,72.495000 63.537000,72.957000 62.976000,73.407000 62.405000,73.845000 61.825000,74.270000 61.237000,74.683000 60.640000,75.082000 60.035000,75.468000 59.422000,75.842000 58.801000,76.201000 58.173000,76.548000 57.538000,76.880000 56.897000,77.199000 56.249000,77.503000 55.595000,77.794000 54.935000,78.070000 54.270000,78.332000 53.599000,78.579000 52.924000,78.812000 52.244000,79.030000 51.560000,79.233000 50.872000,79.422000 50.180000,79.596000 49.486000,79.754000 48.788000,79.898000 48.088000,80.026000 47.385000,80.140000 46.681000,80.238000 45.974000,80.321000 45.267000,80.389000 44.559000,80.442000 43.849000,80.479000 43.140000,80.501000 42.431000,80.508000 41.722000,80.500000 41.014000,80.476000 40.306000,80.437000 39.600000,80.383000 38.896000,80.314000 38.193000,80.230000 37.493000,80.131000 36.796000,80.017000 36.101000,79.888000 35.410000,79.744000 34.723000,79.585000 34.039000,79.412000 33.359000,79.224000 32.684000,79.022000 32.014000,78.805000 31.349000,78.574000 30.689000,78.329000 30.035000,78.070000 29.387000,77.797000 28.745000,77.511000 28.110000,77.211000 27.482000,76.897000 26.861000,76.570000 26.247000,76.230000 25.642000,75.877000 25.044000,75.512000 24.454000,75.133000 23.873000,74.743000 23.301000,74.340000 22.738000,73.925000 22.184000,73.498000 21.640000,73.060000 21.105000,72.610000 20.581000,72.150000 20.067000,71.678000 19.563000,71.195000 19.070000,70.703000 18.588000,70.199000 18.117000,69.686000 17.657000,69.163000 17.209000,68.631000 16.773000,68.089000 16.349000,67.539000 15.937000,66.979000 15.537000,66.411000 15.149000,65.835000 14.775000,65.251000 14.413000,64.660000 14.064000,64.061000 13.728000,63.455000 13.405000,62.842000 13.096000,62.223000 12.800000,61.597000 12.518000,60.966000 12.250000,60.329000 11.995000,59.687000 11.755000,59.039000 11.528000,58.387000 11.316000,57.731000 11.118000,57.070000 10.934000,56.406000 10.765000,55.738000 10.610000,55.067000 10.470000,54.394000 10.344000,53.717000 10.233000,53.039000 10.137000,52.358000 10.055000,51.676000 9.988000,50.993000 9.935000,50.309000 9.898000,49.624000 9.875000,48.939000 9.867000,48.253000 9.873000,47.569000 9.894000,46.884000 9.930000,46.201000 9.981000,45.519000 10.046000,44.838000 10.126000,44.160000 10.220000,43.483000 10.329000,42.809000 10.452000,42.138000 10.590000,41.470000 10.741000,40.806000 10.907000,40.145000 11.087000,39.488000 11.281000,38.836000 11.489000,38.188000 11.710000,37.545000 11.946000,36.908000 12.194000,36.275000 12.456000,35.649000 12.732000,35.029000 13.020000,34.415000 13.322000,33.808000 13.636000,33.207000 13.963000,32.614000 14.303000,32.028000 14.654000,31.450000 15.018000,30.880000 15.394000,30.318000 15.782000,29.765000 16.181000,29.220000 16.592000,28.685000 17.014000,28.158000 17.447000,27.641000 17.891000,27.134000 18.345000,26.637000 18.810000,26.149000 19.285000,25.672000 19.770000,25.206000 20.264000,24.750000 20.768000,24.305000 21.281000,23.872000 21.803000,23.449000 22.333000,23.039000 22.872000,22.640000 23.420000,22.252000 23.975000,21.877000 24.538000,21.514000 25.108000,21.163000 25.685000,20.825000 26.270000,20.500000 26.860000,20.187000 27.457000,19.887000 28.060000,19.601000 28.669000,19.327000 29.283000,19.067000 29.903000,18.820000 30.527000,18.586000 31.156000,18.366000 31.789000,18.160000 32.426000,17.968000 33.066000,17.789000 33.711000,17.624000 34.358000,17.473000 35.008000,17.337000 35.660000,17.214000 36.314000,17.105000 36.971000,17.011000 37.629000,16.930000 38.288000,16.864000 38.948000,16.812000 39.609000,16.774000 40.270000,16.751000 40.931000,16.741000 41.592000,16.746000 42.252000,16.765000 42.911000,16.799000 43.569000,16.846000 44.226000,16.908000 44.881000,16.983000 45.534000,17.073000 46.184000,17.176000 46.831000,17.293000 47.476000,17.425000 48.117000,17.570000 48.755000,17.728000 49.389000,17.900000 50.019000,18.086000 50.644000,18.285000 51.265000,18.498000 51.880000,18.723000 52.490000,18.962000 53.095000,19.213000 53.694000,19.477000 54.287000,19.754000 54.873000,20.044000 55.453000,20.346000 56.025000,20.660000 56.591000,20.986000 57.149000,21.324000 57.700000,21.674000 58.242000,22.035000 58.777000,22.408000 59.303000,22.792000 59.820000,23.187000 60.329000,23.593000 60.828000,24.009000 61.318000,24.436000 61.799000,24.873000 62.270000,25.320000 62.730000,25.777000 63.181000,26.244000 63.622000,26.719000 64.051000,27.204000 64.471000,27.698000 64.879000,28.200000 65.276000,28.711000 65.662000,29.230000 66.036000,29.757000 66.399000,30.291000 66.750000,30.833000 67.089000,31.382000 67.416000,31.938000 67.731000,32.500000 68.034000,33.069000 68.324000,33.644000 68.602000,34.225000 68.867000,34.811000 69.119000,35.402000 69.358000,35.999000 69.585000,36.600000 69.798000,37.206000 69.998000,37.815000 70.185000,38.429000 70.358000,39.046000 70.518000,39.666000 70.665000,40.290000 70.798000,40.916000 70.918000,41.544000 71.024000,42.174000 71.116000,42.807000 71.195000,43.441000 71.260000,44.076000 71.312000,44.712000 71.349000,45.348000 71.373000,45.985000 71.384000,46.622000 71.380000,47.259000 71.363000,47.895000 71.333000,48.530000 71.288000,49.164000 71.230000,49.797000 71.159000,50.428000 71.074000,51.057000 70.976000,51.684000 70.864000,52.308000 70.739000,52.930000 70.600000,53.548000 70.449000,54.162000 70.284000,54.773000 70.107000,55.380000 69.916000,55.983000 69.713000,56.581000 69.497000,57.175000 69.268000,57.763000 69.027000,58.346000 68.774000,58.923000 68.508000,59.494000 68.231000,60.060000 67.941000,60.619000 67.640000,61.171000 67.327000,61.716000 67.002000,62.254000 66.666000,62.785000 66.320000,63.309000 65.962000,63.824000 65.593000,64.331000 65.214000,64.830000 64.824000,65.321000 64.424000,65.802000 64.014000,66.275000 63.594000,66.739000 63.164000,67.193000 62.725000,67.638000 62.277000,68.073000 61.820000,68.498000 61.354000,68.913000 60.880000,69.317000 60.397000,69.711000 59.906000,70.094000 59.407000,70.467000 58.901000,70.828000 58.387000,71.179000 57.866000,71.518000 57.338000,71.845000 56.804000,72.161000 56.263000,72.466000 55.716000,72.758000 55.163000,73.039000 54.605000,73.307000 54.041000,73.563000 53.472000,73.807000 52.899000,74.039000 52.321000,74.258000 51.738000,74.464000 51.152000,74.658000 50.562000,74.839000 49.968000,75.007000 49.371000,75.162000 48.772000,75.305000 48.170000,75.434000 47.565000,75.550000 46.959000,75.654000 46.350000,75.744000 45.741000,75.821000 45.130000,75.885000 44.518000,75.936000 43.905000,75.973000 43.292000,75.997000 42.680000,76.009000 42.067000,76.007000 41.455000,75.991000 40.844000,75.963000 40.233000,75.922000 39.625000,75.867000 39.017000,75.800000 38.412000,75.719000 37.809000,75.626000 37.208000,75.520000 36.610000,75.400000 36.015000,75.269000 35.424000,75.124000 34.836000,74.967000 34.252000,74.797000 33.672000,74.615000 33.096000,74.421000 32.525000,74.214000 31.958000,73.996000 31.397000,73.765000 30.842000,73.522000 30.292000,73.268000 29.747000,73.002000 29.209000,72.725000 28.678000,72.436000 28.153000,72.136000 27.634000,71.825000 27.123000,71.503000 26.619000,71.170000 26.123000,70.827000 25.635000,70.474000 25.154000,70.110000 24.682000,69.736000 24.218000,69.352000 23.762000,68.959000 23.316000,68.556000 22.878000,68.144000 22.450000,67.723000 22.031000,67.293000 21.621000,66.854000 21.222000,66.407000 20.832000,65.952000 20.452000,65.488000 20.083000,65.017000 19.724000,64.538000 19.375000,64.052000 19.038000,63.559000 18.711000,63.059000 18.395000,62.552000 18.090000,62.039000 17.797000,61.520000 17.514000,60.995000 17.244000,60.464000 16.985000,59.928000 16.738000,59.387000 16.502000,58.840000 16.279000,58.290000 16.067000,57.734000 15.868000,57.175000 15.680000,56.612000 15.505000,56.045000 15.342000,55.475000 15.192000,54.902000 15.054000,54.326000 14.929000,53.748000 14.816000,53.167000 14.715000,52.585000 14.628000,52.000000 14.552000,51.415000 14.490000,50.828000 14.440000,50.240000 14.403000,49.652000 14.378000,49.063000 14.366000,48.474000 14.367000,47.886000 14.381000,47.298000 14.407000,46.711000 14.445000,46.124000 14.496000,45.539000 14.560000,44.956000 14.636000,44.374000 14.725000,43.795000 14.826000,43.218000 14.939000,42.643000 15.065000,42.072000 15.203000,41.503000 15.352000,40.938000 15.514000,40.377000 15.688000,39.819000 15.874000,39.266000 16.071000,38.717000 16.280000,38.173000 16.500000,37.634000 16.732000,37.100000 16.976000,36.571000 17.230000,36.048000 17.495000,35.531000 17.772000,35.020000 18.059000,34.515000 18.356000,34.017000 18.664000,33.526000 18.983000,33.042000 19.311000,32.565000 19.650000,32.095000 19.998000,31.633000 20.356000,31.179000 20.724000,30.733000 21.100000,30.295000 21.486000,29.865000 21.881000,29.445000 22.285000,29.033000 22.697000,28.630000 23.117000,28.236000 23.545000,27.852000 23.982000,27.477000 24.426000,27.111000 24.877000,26.756000 25.336000,26.411000 25.802000,26.075000 26.275000,25.750000 26.754000,25.436000 27.240000,25.132000 27.732000,24.838000 28.229000,24.556000 28.733000,24.284000 29.241000,24.023000 29.755000,23.774000 30.274000,23.536000 30.798000,23.309000 31.326000,23.093000 31.858000,22.889000 32.395000,22.697000 32.935000,22.516000 33.478000,22.347000 34.025000,22.190000 34.574000,22.045000 35.126000,21.912000 35.681000,21.790000 36.238000,21.681000 36.796000,21.583000 37.357000,21.498000 37.918000,21.425000 38.481000,21.364000 39.045000,21.315000 39.609000,21.278000 40.173000,21.254000 40.738000,21.241000 41.302000,21.241000 41.866000,21.253000 42.430000,21.277000 42.992000,21.313000 43.553000,21.361000 44.112000,21.421000 44.670000,21.493000 45.226000,21.577000 45.780000,21.673000 46.331000,21.780000 46.879000,21.900000 47.424000,22.031000 47.966000,22.174000 48.505000,22.328000 49.039000,22.493000 49.570000,22.670000 50.097000,22.859000 50.619000,23.058000 51.136000,23.268000 51.648000,23.490000 52.155000,23.722000 52.657000,23.965000 53.153000,24.218000 53.644000,24.482000 54.128000,24.757000 54.606000,25.041000 55.077000,25.335000 55.542000,25.640000 56.000000,25.954000 56.450000,26.278000 56.894000,26.611000 57.330000,26.953000 57.758000,27.304000 58.178000,27.665000 58.590000,28.034000 58.994000,28.411000 59.389000,28.797000 59.776000,29.191000 60.154000,29.593000 60.523000,30.003000 60.883000,30.421000 61.234000,30.845000 61.575000,31.277000 61.907000,31.716000 62.229000,32.162000 62.541000,32.614000 62.843000,33.073000 63.135000,33.538000 63.417000,34.008000 63.689000,34.485000 63.950000,34.966000 64.200000,35.453000 64.440000,35.945000 64.669000,36.442000 64.887000,36.943000 65.095000,37.448000 65.291000,37.958000 65.476000,38.471000 65.650000,38.988000 65.813000,39.508000 65.964000,40.031000 66.104000,40.557000 66.233000,41.086000 66.350000,41.616000 66.456000,42.149000 66.550000,42.684000 66.632000,43.220000 66.703000,43.758000 66.762000,44.297000 66.810000,44.836000 66.846000,45.376000 66.871000,45.917000 66.884000,46.457000 66.885000,46.998000 66.874000,47.537000 66.852000,48.077000 66.819000,48.615000 66.774000,49.152000 66.717000,49.688000 66.649000,50.222000 66.570000,50.754000 66.479000,51.284000 66.377000,51.811000 66.264000,52.336000 66.139000,52.858000 66.003000,53.377000 65.857000,53.893000 65.699000,54.405000 65.531000,54.913000 65.351000,55.417000 65.161000,55.917000 64.961000,56.412000 64.750000,56.903000 64.297000,57.869000 64.055000,58.344000 63.803000,58.814000 63.542000,59.277000 63.270000,59.735000 62.990000,60.186000 62.699000,60.631000 62.399000,61.070000 62.091000,61.502000 61.773000,61.926000 61.446000,62.344000 61.111000,62.754000 60.767000,63.156000 60.414000,63.551000 60.054000,63.938000 59.685000,64.317000 59.309000,64.687000 58.925000,65.049000 58.534000,65.403000 58.135000,65.748000 57.730000,66.084000 57.317000,66.411000 56.898000,66.729000 56.472000,67.037000 56.040000,67.336000 55.602000,67.626000 55.158000,67.906000 54.709000,68.176000 54.254000,68.437000 53.794000,68.687000 53.329000,68.927000 52.859000,69.157000 52.384000,69.377000 51.906000,69.586000 51.423000,69.785000 50.936000,69.974000 50.446000,70.151000 49.952000,70.318000 49.455000,70.475000 48.956000,70.620000 48.453000,70.755000 47.948000,70.878000 47.441000,70.991000 46.932000,71.093000 46.421000,71.184000 45.909000,71.264000 45.395000,71.332000 44.880000,71.390000 44.365000,71.436000 43.333000,71.496000 42.816000,71.509000 42.300000,71.511000 41.784000,71.502000 41.269000,71.481000 40.755000,71.450000 40.242000,71.408000 39.730000,71.355000 39.220000,71.291000 38.711000,71.215000 38.205000,71.129000 37.701000,71.033000 37.199000,70.925000 36.701000,70.807000 36.205000,70.678000 35.712000,70.539000 35.223000,70.389000 34.737000,70.229000 34.256000,70.059000 33.778000,69.878000 32.836000,69.487000 32.372000,69.276000 31.913000,69.055000 31.459000,68.825000 31.010000,68.586000 30.567000,68.337000 29.699000,67.811000 29.273000,67.534000 28.854000,67.249000 28.442000,66.955000 28.036000,66.652000 27.245000,66.021000 26.860000,65.693000 26.483000,65.358000 26.113000,65.014000 25.751000,64.663000 25.051000,63.939000 24.713000,63.566000 24.383000,63.186000 23.749000,62.406000 23.151000,61.600000 22.864000,61.189000 22.587000,60.771000 22.061000,59.920000 21.812000,59.486000 21.343000,58.604000 21.123000,58.156000 20.712000,57.248000 20.341000,56.324000 20.171000,55.856000 20.011000,55.386000 19.861000,54.912000 19.593000,53.957000 19.474000,53.475000 19.366000,52.992000 19.268000,52.506000 19.181000,52.019000 19.104000,51.531000 18.982000,50.551000 18.937000,50.059000 18.879000,49.075000 18.863000,48.091000 18.871000,47.599000 18.890000,47.108000 18.919000,46.618000 18.959000,46.128000 19.069000,45.154000 19.140000,44.669000 19.221000,44.187000 19.313000,43.706000 19.415000,43.228000 19.526000,42.753000 19.781000,41.810000 19.923000,41.344000 20.236000,40.422000 20.589000,39.516000 20.980000,38.626000 21.189000,38.189000 21.635000,37.328000 21.872000,36.906000 22.372000,36.077000 22.906000,35.273000 23.186000,34.879000 23.769000,34.112000 24.073000,33.738000 24.704000,33.012000 25.364000,32.314000 26.053000,31.646000 26.769000,31.010000 27.137000,30.703000 27.891000,30.115000 28.668000,29.561000 29.468000,29.042000 29.875000,28.795000 30.705000,28.329000 31.553000,27.900000 31.983000,27.699000 32.855000,27.326000 33.740000,26.991000 34.188000,26.838000 34.638000,26.695000 35.091000,26.562000 36.005000,26.325000 36.926000,26.128000 37.389000,26.044000 38.320000,25.907000 39.254000,25.810000 39.721000,25.777000 40.658000,25.741000 41.126000,25.738000 41.593000,25.745000 42.527000,25.789000 42.992000,25.826000 43.456000,25.873000 43.918000,25.930000 44.838000,26.073000 45.750000,26.256000 46.652000,26.477000 47.098000,26.602000 47.982000,26.881000 48.851000,27.196000 49.705000,27.549000 50.126000,27.738000 50.954000,28.144000 51.762000,28.584000 52.550000,29.058000 52.935000,29.307000 53.689000,29.830000 54.057000,30.103000 54.774000,30.672000 55.465000,31.270000 56.128000,31.897000 56.763000,32.550000 57.368000,33.230000 57.660000,33.579000 58.219000,34.294000 58.487000,34.660000 58.997000,35.408000 59.475000,36.177000 59.701000,36.568000 60.127000,37.364000 60.327000,37.768000 60.699000,38.588000 60.872000,39.003000 61.191000,39.843000 61.337000,40.268000 61.600000,41.125000 61.826000,41.992000 62.014000,42.866000 62.164000,43.746000 62.276000,44.630000 62.349000,45.517000 62.385000,46.405000 62.382000,47.293000 62.341000,48.178000 62.262000,49.060000 62.209000,49.498000 62.074000,50.371000 61.901000,51.235000 61.692000,52.090000 61.447000,52.934000 61.166000,53.766000 61.013000,54.176000 60.680000,54.986000 60.313000,55.780000 60.117000,56.170000 59.700000,56.936000 59.252000,57.683000 58.772000,58.409000 58.263000,59.112000 57.725000,59.791000 57.159000,60.446000 56.566000,61.075000 56.260000,61.380000 55.629000,61.968000 54.974000,62.528000 54.297000,63.058000 53.599000,63.557000 53.243000,63.796000 52.516000,64.248000 52.146000,64.463000 51.393000,64.866000 50.624000,65.237000 49.842000,65.574000 49.047000,65.876000 48.241000,66.143000 47.834000,66.264000 47.014000,66.478000 46.187000,66.657000 45.772000,66.733000 44.937000,66.857000 44.099000,66.946000 43.260000,66.998000 42.420000,67.014000 41.581000,66.994000 40.746000,66.938000 40.330000,66.897000 39.502000,66.787000 38.680000,66.642000 37.867000,66.463000 37.064000,66.249000 36.272000,66.001000 35.492000,65.719000 34.727000,65.405000 33.977000,65.059000 33.243000,64.681000 32.528000,64.273000 31.832000,63.835000 31.157000,63.369000 30.503000,62.874000 29.873000,62.353000 29.266000,61.806000 28.684000,61.234000 28.129000,60.639000 27.600000,60.022000 27.099000,59.383000 26.627000,58.725000 26.184000,58.047000 25.772000,57.353000 25.390000,56.643000 25.040000,55.918000 24.722000,55.180000 24.437000,54.430000 24.184000,53.670000 23.965000,52.901000 23.779000,52.124000 23.627000,51.342000 23.509000,50.555000 23.425000,49.765000 23.376000,48.973000 23.360000,48.182000 23.379000,47.391000 23.400000,46.997000 23.470000,46.212000 23.572000,45.431000 23.708000,44.657000 23.877000,43.891000 24.079000,43.134000 24.312000,42.388000 24.577000,41.654000 24.872000,40.933000 25.198000,40.226000 25.553000,39.536000 25.937000,38.862000 26.349000,38.207000 26.788000,37.571000 27.253000,36.956000 27.744000,36.362000 28.258000,35.791000 28.796000,35.243000 29.356000,34.720000 29.937000,34.223000 30.537000,33.752000 31.156000,33.307000 31.793000,32.891000 32.446000,32.503000 33.114000,32.144000 33.795000,31.815000 34.489000,31.515000 35.194000,31.247000 35.908000,31.009000 36.631000,30.803000 37.360000,30.628000 38.095000,30.485000 38.835000,30.374000 39.577000,30.296000 40.320000,30.249000 41.051000,30.234000 41.780000,30.250000 42.118000,30.257000 42.455000,30.277000 42.791000,30.309000 43.126000,30.353000 43.460000,30.409000 43.790000,30.478000 44.119000,30.558000 44.444000,30.651000 44.765000,30.755000 45.082000,30.871000 45.395000,30.999000 45.703000,31.137000 46.006000,31.287000 46.303000,31.448000 46.594000,31.620000 46.879000,31.802000 47.157000,31.995000 47.427000,32.197000 47.690000,32.409000 47.945000,32.631000 48.192000,32.862000 48.430000,33.101000 48.659000,33.350000 48.879000,33.606000 49.090000,33.870000 49.290000,34.142000 49.481000,34.421000 49.661000,34.707000 49.831000,34.999000 49.990000,35.297000 50.138000,35.601000 50.275000,35.910000 50.400000,36.224000 50.514000,36.542000 50.616000,36.864000 50.707000,37.189000 50.785000,37.518000 50.852000,37.849000 50.906000,38.183000 50.948000,38.518000 50.977000,38.855000 50.995000,39.192000 51.000000,39.530000 50.993000,39.868000 50.973000,40.205000 50.941000,40.541000 50.897000,40.876000 50.841000,41.210000 50.772000,41.540000 50.692000,41.869000 50.599000,42.194000 50.495000,42.515000 50.379000,42.832000 50.251000,43.145000 50.113000,43.453000 49.963000,43.756000 49.802000,44.053000 49.630000,44.344000 49.448000,44.629000 49.255000,44.907000 49.053000,45.177000 48.841000,45.440000 48.619000,45.695000 48.388000,45.942000 48.149000,46.180000 47.900000,46.409000 47.644000,46.629000 47.380000,46.840000 47.108000,47.040000 46.829000,47.231000 46.543000,47.411000 46.251000,47.581000 45.953000,47.740000 45.649000,47.888000 45.340000,48.025000 45.026000,48.150000 44.708000,48.264000 44.386000,48.366000 44.061000,48.457000 43.732000,48.535000 43.401000,48.602000 43.067000,48.656000 42.732000,48.698000 42.395000,48.727000 42.073000,48.744000 41.750000,48.750000 41.257000,48.768000 40.767000,48.822000 40.282000,48.911000 39.805000,49.036000 39.339000,49.195000 38.885000,49.388000 38.446000,49.614000 38.026000,49.871000 37.822000,50.010000 37.432000,50.312000 37.065000,50.641000 36.723000,50.996000 36.407000,51.375000 36.260000,51.572000 35.988000,51.984000 35.747000,52.414000 35.538000,52.860000 35.445000,53.089000 35.286000,53.555000 35.161000,54.032000 35.072000,54.517000 35.018000,55.007000 35.000000,55.500000 35.018000,55.993000 35.072000,56.483000 35.161000,56.968000 35.286000,57.445000 35.445000,57.911000 35.638000,58.365000 35.864000,58.804000 36.121000,59.224000 36.260000,59.428000 36.562000,59.818000 36.891000,60.185000 37.246000,60.527000 37.625000,60.843000 37.822000,60.990000 38.234000,61.262000 38.664000,61.503000 39.110000,61.712000 39.339000,61.805000 39.805000,61.964000 40.282000,62.089000 40.767000,62.178000 41.257000,62.232000 41.503000,62.246000 41.784000,62.250000 42.420000,62.266000 43.056000,62.254000 43.692000,62.215000 44.327000,62.148000 44.960000,62.054000 45.590000,61.933000 46.215000,61.784000 46.834000,61.608000 47.447000,61.405000 48.051000,61.176000 48.647000,60.920000 49.232000,60.639000 49.805000,60.331000 50.366000,59.999000 50.913000,59.642000 51.445000,59.262000 51.962000,58.858000 52.461000,58.431000 52.943000,57.982000 53.406000,57.512000 53.849000,57.021000 54.272000,56.511000 54.673000,55.982000 55.051000,55.435000 55.407000,54.872000 55.738000,54.292000 56.045000,53.698000 56.327000,53.089000 56.582000,52.468000 56.811000,51.836000 57.014000,51.192000 57.188000,50.540000 57.335000,49.879000 57.453000,49.211000 57.543000,48.537000 57.604000,47.859000 57.635000,47.178000 57.637000,46.494000 57.610000,45.810000 57.553000,45.126000 57.467000,44.444000 57.351000,43.765000 57.206000,43.090000 57.032000,42.421000 56.828000,41.759000 56.596000,41.105000 56.336000,40.460000 56.047000,39.826000 55.731000,39.203000 55.388000,38.594000 55.018000,37.999000 54.622000,37.419000 54.201000,36.856000 53.755000,36.310000 53.285000,35.783000 52.792000,35.276000 52.277000,34.790000 51.740000,34.325000 51.183000,33.883000 50.606000,33.465000 50.011000,33.071000 49.398000,32.702000 48.768000,32.359000 48.124000,32.044000 47.465000,31.755000 46.793000,31.495000 46.109000,31.264000 45.415000,31.062000 44.711000,30.889000 43.999000,30.747000 43.281000,30.635000 42.557000,30.554000 41.829000,30.505000 41.098000,30.486000 40.366000,30.499000 39.634000,30.544000 38.902000,30.620000 38.174000,30.728000 37.450000,30.867000 36.731000,31.037000 36.018000,31.239000 35.314000,31.471000 34.619000,31.734000 33.935000,32.028000 33.263000,32.351000 32.604000,32.703000 31.960000,33.084000 31.332000,33.492000 30.721000,33.929000 30.128000,34.392000 29.555000,34.881000 29.002000,35.394000 28.471000,35.933000 27.962000,36.494000 27.478000,37.078000 27.018000,37.683000 26.584000,38.309000 26.176000,38.954000 25.796000,39.617000 25.444000,40.296000 25.121000,40.992000 24.828000,41.702000 24.565000,42.425000 24.334000,43.160000 24.133000,43.905000 23.965000,44.660000 23.829000,45.422000 23.725000,46.192000 23.655000,46.966000 23.618000,47.743000 23.614000,48.523000 23.644000,49.304000 23.708000,50.084000 23.805000,50.862000 23.936000,51.636000 24.101000,52.405000 24.298000,53.168000 24.529000,53.923000 24.792000,54.668000 25.088000,55.402000 25.415000,56.125000 25.774000,56.834000 26.163000,57.528000 26.583000,58.205000 27.032000,58.865000 27.510000,59.506000 28.016000,60.128000 28.549000,60.727000 29.109000,61.304000 29.693000,61.858000 30.302000,62.387000 30.934000,62.890000 31.588000,63.366000 32.263000,63.814000 32.958000,64.233000 33.671000,64.623000 34.402000,64.983000 35.148000,65.311000 35.910000,65.607000 36.684000,65.871000 37.471000,66.101000 38.268000,66.298000 39.074000,66.461000 39.887000,66.589000 40.707000,66.682000 41.531000,66.740000 42.358000,66.762000 43.187000,66.749000 44.015000,66.700000 44.842000,66.616000 45.666000,66.495000 46.077000,66.422000 46.893000,66.248000 47.703000,66.039000 48.504000,65.796000 49.295000,65.517000 50.075000,65.205000 50.841000,64.858000 51.594000,64.478000 52.330000,64.066000 53.049000,63.622000 53.749000,63.146000 54.430000,62.640000 55.089000,62.105000 55.725000,61.540000 56.035000,61.248000 56.635000,60.642000 57.209000,60.010000 57.757000,59.353000 58.276000,58.672000 58.767000,57.969000 59.228000,57.244000 59.657000,56.498000 60.055000,55.734000 60.242000,55.345000 60.590000,54.554000 60.905000,53.748000 61.050000,53.340000 61.312000,52.514000 61.540000,51.676000 61.731000,50.827000 61.886000,49.970000 61.950000,49.539000 62.049000,48.672000 62.112000,47.799000 62.129000,47.362000 62.135000,46.486000 62.124000,46.047000 62.073000,45.170000 61.985000,44.295000 61.858000,43.423000 61.695000,42.556000 61.494000,41.696000 61.255000,40.844000 60.980000,40.001000 60.669000,39.170000 60.321000,38.352000 60.134000,37.948000 59.734000,37.153000 59.299000,36.373000 58.830000,35.613000 58.584000,35.240000 58.066000,34.509000 57.516000,33.800000 56.936000,33.115000 56.326000,32.454000 55.687000,31.819000 55.020000,31.212000 54.677000,30.918000 53.971000,30.354000 53.608000,30.082000 52.866000,29.563000 52.486000,29.315000 51.710000,28.844000 50.913000,28.406000 50.097000,28.002000 49.263000,27.633000 48.413000,27.299000 47.548000,27.002000 46.670000,26.742000 46.226000,26.626000 45.331000,26.423000 44.426000,26.258000 43.515000,26.132000 42.597000,26.046000 42.136000,26.017000 41.675000,25.998000 41.213000,25.989000 40.288000,26.002000 39.825000,26.023000 38.901000,26.095000 37.979000,26.206000 37.519000,26.277000 37.061000,26.358000 36.150000,26.549000 35.697000,26.659000 34.798000,26.909000 33.910000,27.198000 33.033000,27.525000 32.170000,27.890000 31.322000,28.293000 30.904000,28.508000 30.491000,28.732000 29.679000,29.207000 29.280000,29.457000 28.498000,29.985000 28.116000,30.261000 27.368000,30.839000 26.645000,31.450000 26.293000,31.767000 25.609000,32.424000 24.954000,33.111000 24.327000,33.826000 24.025000,34.194000 23.445000,34.950000 22.897000,35.731000 22.635000,36.131000 22.382000,36.536000 21.902000,37.364000 21.675000,37.786000 21.457000,38.213000 21.248000,38.645000 20.858000,39.522000 20.677000,39.967000 20.506000,40.416000 20.344000,40.870000 20.049000,41.787000 19.794000,42.717000 19.681000,43.187000 19.486000,44.134000 19.404000,44.611000 19.332000,45.090000 19.270000,45.570000 19.218000,46.052000 19.146000,47.020000 19.125000,47.506000 19.115000,47.992000 19.116000,48.479000 19.148000,49.452000 19.180000,49.939000 19.222000,50.425000 19.275000,50.910000 19.338000,51.394000 19.412000,51.878000 19.496000,52.360000 19.695000,53.318000 19.936000,54.269000 20.072000,54.741000 20.218000,55.210000 20.374000,55.676000 20.540000,56.139000 20.903000,57.054000 21.099000,57.506000 21.305000,57.954000 21.746000,58.838000 21.981000,59.273000 22.225000,59.702000 22.479000,60.127000 22.742000,60.547000 23.014000,60.961000 23.295000,61.369000 23.585000,61.772000 23.883000,62.169000 24.507000,62.943000 24.831000,63.320000 25.504000,64.054000 26.209000,64.759000 26.573000,65.100000 26.945000,65.434000 27.324000,65.760000 28.103000,66.387000 28.503000,66.688000 28.910000,66.981000 29.742000,67.541000 30.168000,67.807000 30.599000,68.065000 31.036000,68.313000 31.479000,68.552000 31.927000,68.782000 32.380000,69.002000 32.838000,69.213000 33.301000,69.413000 33.768000,69.604000 34.240000,69.785000 34.715000,69.956000 35.195000,70.117000 35.678000,70.267000 36.164000,70.407000 36.654000,70.537000 37.147000,70.656000 37.643000,70.765000 38.141000,70.863000 38.641000,70.950000 39.144000,71.027000 39.648000,71.092000 40.154000,71.147000 40.662000,71.192000 41.170000,71.225000 42.190000,71.259000 43.212000,71.249000 44.233000,71.195000 44.743000,71.151000 45.253000,71.096000 45.761000,71.031000 46.268000,70.955000 46.774000,70.867000 47.278000,70.769000 47.780000,70.660000 48.281000,70.540000 48.778000,70.409000 49.273000,70.267000 49.766000,70.115000 50.255000,69.952000 50.741000,69.778000 51.223000,69.594000 51.702000,69.400000 52.176000,69.195000 52.647000,68.980000 53.113000,68.754000 53.574000,68.519000 54.030000,68.274000 54.482000,68.018000 54.928000,67.753000 55.368000,67.478000 56.232000,66.900000 57.071000,66.284000 57.481000,65.962000 57.884000,65.632000 58.280000,65.292000 58.669000,64.944000 59.050000,64.588000 59.424000,64.223000 59.791000,63.850000 60.149000,63.469000 60.500000,63.080000 60.842000,62.683000 61.176000,62.279000 61.501000,61.868000 61.818000,61.449000 62.424000,60.591000 62.714000,60.152000 62.994000,59.707000 63.526000,58.797000 63.777000,58.334000 64.018000,57.865000 64.250000,57.391000 64.471000,56.911000 64.682000,56.427000 64.883000,55.937000 65.074000,55.444000 65.254000,54.946000 65.423000,54.444000 65.581000,53.938000 65.729000,53.428000 65.866000,52.915000 65.992000,52.399000 66.106000,51.880000 66.210000,51.359000 66.302000,50.835000 66.384000,50.309000 66.454000,49.780000 66.512000,49.251000 66.559000,48.719000 66.595000,48.187000 66.620000,47.653000 66.633000,47.119000 66.634000,46.584000 66.624000,46.049000 66.602000,45.514000 66.569000,44.979000 66.525000,44.445000 66.469000,43.912000 66.401000,43.379000 66.322000,42.848000 66.232000,42.318000 66.130000,41.790000 66.016000,41.264000 65.892000,40.740000 65.756000,40.219000 65.608000,39.701000 65.450000,39.185000 65.280000,38.673000 65.100000,38.164000 64.908000,37.658000 64.705000,37.157000 64.492000,36.660000 64.267000,36.167000 64.032000,35.679000 63.787000,35.196000 63.531000,34.718000 63.265000,34.245000 62.988000,33.778000 62.701000,33.316000 62.404000,32.861000 62.097000,32.411000 61.781000,31.969000 61.455000,31.532000 61.119000,31.103000 60.774000,30.681000 60.420000,30.266000 60.057000,29.858000 59.684000,29.458000 59.303000,29.066000 58.914000,28.682000 58.516000,28.306000 58.110000,27.939000 57.696000,27.580000 57.274000,27.230000 56.844000,26.889000 56.407000,26.557000 55.962000,26.234000 55.510000,25.921000 55.052000,25.617000 54.587000,25.324000 54.115000,25.040000 53.637000,24.766000 53.153000,24.502000 52.663000,24.248000 52.167000,24.005000 51.666000,23.773000 51.160000,23.551000 50.649000,23.340000 50.133000,23.140000 49.613000,22.951000 49.089000,22.773000 48.560000,22.606000 48.028000,22.451000 47.492000,22.307000 46.952000,22.174000 46.410000,22.053000 45.865000,21.944000 45.318000,21.846000 44.768000,21.760000 44.216000,21.686000 43.662000,21.624000 43.107000,21.573000 42.550000,21.535000 41.993000,21.508000 41.434000,21.494000 40.875000,21.491000 40.316000,21.501000 39.757000,21.522000 39.198000,21.555000 38.640000,21.601000 38.082000,21.658000 37.526000,21.728000 36.971000,21.810000 36.417000,21.903000 35.865000,22.008000 35.315000,22.126000 34.768000,22.255000 34.223000,22.396000 33.681000,22.549000 33.142000,22.713000 32.606000,22.889000 32.074000,23.077000 31.546000,23.276000 31.022000,23.487000 30.502000,23.709000 29.987000,23.942000 29.477000,24.187000 28.972000,24.442000 28.472000,24.708000 27.977000,24.986000 27.489000,25.274000 27.006000,25.572000 26.530000,25.881000 26.060000,26.201000 25.597000,26.530000 25.141000,26.870000 24.692000,27.220000 24.250000,27.579000 23.816000,27.948000 23.390000,28.327000 22.971000,28.714000 22.561000,29.111000 22.159000,29.517000 21.766000,29.932000 21.382000,30.355000 21.006000,30.787000 20.640000,31.227000 20.283000,31.675000 19.936000,32.130000 19.598000,32.594000 19.270000,33.064000 18.952000,33.542000 18.644000,34.027000 18.347000,34.519000 18.060000,35.018000 17.784000,35.522000 17.518000,36.033000 17.264000,36.550000 17.020000,37.072000 16.787000,37.600000 16.566000,38.133000 16.356000,38.671000 16.158000,39.213000 15.971000,39.760000 15.796000,40.312000 15.633000,40.867000 15.481000,41.426000 15.342000,41.988000 15.215000,42.553000 15.099000,43.122000 14.996000,43.693000 14.905000,44.266000 14.827000,44.842000 14.761000,45.420000 14.707000,45.999000 14.665000,46.579000 14.636000,47.161000 14.620000,47.743000 14.616000,48.326000 14.625000,48.910000 14.646000,49.493000 14.680000,50.076000 14.726000,50.658000 14.785000,51.240000 14.856000,51.821000 14.940000,52.400000 15.036000,52.977000 15.145000,53.553000 15.266000,54.127000 15.400000,54.698000 15.546000,55.267000 15.704000,55.832000 15.874000,56.395000 16.057000,56.953000 16.251000,57.509000 16.458000,58.060000 16.677000,58.607000 16.907000,59.149000 17.149000,59.687000 17.403000,60.219000 17.668000,60.746000 17.945000,61.268000 18.233000,61.784000 18.532000,62.294000 18.842000,62.798000 19.163000,63.295000 19.495000,63.785000 19.838000,64.269000 20.191000,64.745000 20.554000,65.214000 20.928000,65.675000 21.312000,66.128000 21.705000,66.574000 22.109000,67.010000 22.521000,67.439000 22.943000,67.858000 23.375000,68.269000 23.815000,68.671000 24.264000,69.063000 24.722000,69.445000 25.188000,69.818000 25.662000,70.181000 26.144000,70.534000 26.634000,70.877000 27.131000,71.209000 27.636000,71.531000 28.148000,71.842000 28.666000,72.142000 29.192000,72.431000 29.723000,72.709000 30.261000,72.975000 30.805000,73.230000 31.354000,73.474000 31.909000,73.705000 32.468000,73.925000 33.033000,74.133000 33.603000,74.329000 34.176000,74.512000 34.754000,74.683000 35.336000,74.842000 35.922000,74.989000 36.510000,75.123000 37.102000,75.244000 37.697000,75.353000 38.294000,75.449000 38.893000,75.532000 39.495000,75.602000 40.098000,75.659000 40.702000,75.704000 41.308000,75.735000 41.914000,75.753000 42.521000,75.759000 43.129000,75.751000 43.736000,75.730000 44.343000,75.696000 44.950000,75.649000 45.556000,75.589000 46.160000,75.516000 46.764000,75.430000 47.365000,75.331000 47.965000,75.219000 48.562000,75.095000 49.157000,74.957000 49.750000,74.806000 50.339000,74.643000 50.924000,74.467000 51.507000,74.278000 52.085000,74.076000 52.659000,73.863000 53.229000,73.636000 53.794000,73.398000 54.354000,73.147000 54.909000,72.884000 55.458000,72.609000 56.002000,72.322000 56.540000,72.024000 57.071000,71.714000 57.596000,71.392000 58.114000,71.059000 58.625000,70.714000 59.129000,70.359000 59.626000,69.992000 60.114000,69.615000 60.595000,69.227000 61.068000,68.829000 61.532000,68.421000 61.987000,68.002000 62.434000,67.573000 62.871000,67.135000 63.300000,66.687000 63.718000,66.230000 64.127000,65.764000 64.526000,65.288000 64.916000,64.804000 65.294000,64.312000 65.663000,63.811000 66.020000,63.302000 66.367000,62.786000 66.703000,62.261000 67.027000,61.730000 67.341000,61.191000 67.642000,60.645000 67.933000,60.093000 68.211000,59.534000 68.477000,58.969000 68.732000,58.398000 68.974000,57.822000 69.204000,57.240000 69.421000,56.653000 69.626000,56.061000 69.818000,55.465000 69.998000,54.864000 70.164000,54.260000 70.318000,53.651000 70.459000,53.039000 70.586000,52.424000 70.700000,51.806000 70.801000,51.185000 70.889000,50.562000 70.964000,49.937000 71.025000,49.310000 71.072000,48.682000 71.106000,48.052000 71.126000,47.422000 71.133000,46.791000 71.127000,46.159000 71.107000,45.527000 71.073000,44.896000 71.025000,44.265000 70.964000,43.636000 70.890000,43.007000 70.802000,42.379000 70.700000,41.754000 70.585000,41.130000 70.457000,40.509000 70.315000,39.890000 70.160000,39.274000 69.991000,38.661000 69.809000,38.052000 69.614000,37.447000 69.407000,36.845000 69.186000,36.248000 68.952000,35.655000 68.705000,35.067000 68.446000,34.485000 68.174000,33.907000 67.889000,33.336000 67.593000,32.770000 67.283000,32.211000 66.962000,31.658000 66.629000,31.112000 66.284000,30.572000 65.927000,30.040000 65.559000,29.516000 65.180000,28.999000 64.789000,28.491000 64.387000,27.990000 63.974000,27.498000 63.551000,27.015000 63.117000,26.541000 62.673000,26.076000 62.218000,25.621000 61.754000,25.175000 61.280000,24.739000 60.797000,24.313000 60.304000,23.897000 59.802000,23.492000 59.291000,23.097000 58.772000,22.713000 58.244000,22.341000 57.708000,21.979000 57.164000,21.629000 56.613000,21.291000 56.054000,20.964000 55.488000,20.649000 54.915000,20.347000 54.335000,20.056000 53.749000,19.778000 53.157000,19.513000 52.559000,19.260000 51.955000,19.020000 51.346000,18.793000 50.732000,18.579000 50.113000,18.378000 49.490000,18.190000 48.862000,18.016000 48.231000,17.855000 47.596000,17.707000 46.957000,17.573000 46.316000,17.453000 45.671000,17.347000 45.025000,17.254000 44.376000,17.176000 43.725000,17.111000 43.073000,17.060000 42.419000,17.023000 41.764000,17.001000 41.109000,16.992000 40.454000,16.997000 39.798000,17.017000 39.142000,17.051000 38.488000,17.098000 37.834000,17.160000 37.181000,17.236000 36.529000,17.326000 35.880000,17.430000 35.232000,17.548000 34.587000,17.680000 33.944000,17.826000 33.304000,17.985000 32.668000,18.159000 32.035000,18.346000 31.406000,18.547000 30.781000,18.761000 30.161000,18.989000 29.545000,19.230000 28.935000,19.485000 28.329000,19.753000 27.730000,20.034000 27.136000,20.328000 26.548000,20.634000 25.967000,20.954000 25.392000,21.286000 24.825000,21.630000 24.265000,21.987000 23.712000,22.356000 23.167000,22.736000 22.630000,23.129000 22.101000,23.533000 21.581000,23.949000 21.070000,24.376000 20.567000,24.814000 20.075000,25.263000 19.591000,25.723000 19.117000,26.194000 18.654000,26.674000 18.200000,27.165000 17.757000,27.665000 17.325000,28.176000 16.903000,28.695000 16.492000,29.224000 16.093000,29.762000 15.705000,30.309000 15.329000,30.864000 14.965000,31.427000 14.613000,31.998000 14.272000,32.577000 13.945000,33.164000 13.629000,33.757000 13.327000,34.358000 13.037000,34.965000 12.760000,35.579000 12.497000,36.198000 12.246000,36.824000 12.009000,37.455000 11.786000,38.091000 11.576000,38.732000 11.380000,39.378000 11.197000,40.029000 11.029000,40.683000 10.875000,41.342000 10.734000,42.003000 10.608000,42.668000 10.496000,43.336000 10.399000,44.006000 10.316000,44.679000 10.247000,45.354000 10.193000,46.030000 10.153000,46.707000 10.128000,47.386000 10.118000,48.065000 10.122000,48.745000 10.140000,49.425000 10.174000,50.105000 10.222000,50.784000 10.284000,51.462000 10.361000,52.139000 10.453000,52.814000 10.559000,53.488000 10.680000,54.160000 10.815000,54.829000 10.965000,55.495000 11.129000,56.159000 11.307000,56.819000 11.499000,57.475000 11.706000,58.128000 11.927000,58.776000 12.162000,59.419000 12.410000,60.058000 12.673000,60.691000 12.949000,61.319000 13.238000,61.942000 13.541000,62.558000 13.858000,63.167000 14.188000,63.771000 14.530000,64.367000 14.886000,64.956000 15.254000,65.537000 15.635000,66.111000 16.028000,66.677000 16.434000,67.234000 16.852000,67.783000 17.281000,68.323000 17.722000,68.854000 18.175000,69.375000 18.639000,69.887000 19.115000,70.389000 19.601000,70.881000 20.098000,71.363000 20.605000,71.834000 21.122000,72.294000 21.650000,72.743000 22.187000,73.181000 22.734000,73.608000 23.291000,74.023000 23.856000,74.426000 24.430000,74.817000 25.012000,75.196000 25.603000,75.562000 26.202000,75.916000 26.809000,76.257000 27.423000,76.585000 28.044000,76.900000 28.673000,77.201000 29.308000,77.489000 29.949000,77.764000 30.596000,78.025000 31.249000,78.272000 31.908000,78.505000 32.572000,78.724000 33.240000,78.929000 33.913000,79.119000 34.591000,79.295000 35.272000,79.456000 35.957000,79.603000 36.645000,79.736000 37.337000,79.853000 38.031000,79.956000 38.727000,80.043000 39.425000,80.116000 40.125000,80.174000 40.827000,80.217000 41.530000,80.244000 42.233000,80.257000 42.937000,80.254000 43.641000,80.236000 44.345000,80.204000 45.048000,80.156000 45.750000,80.093000 46.451000,80.014000 47.151000,79.921000 47.849000,79.813000 48.544000,79.689000 49.238000,79.551000 49.928000,79.398000 50.615000,79.230000 51.299000,79.047000 51.979000,78.849000 52.655000,78.637000 53.326000,78.410000 53.993000,78.168000 54.655000,77.913000 55.311000,77.642000 55.962000,77.358000 56.607000,77.060000 57.245000,76.748000 57.877000,76.422000 58.502000,76.082000 59.120000,75.729000 59.731000,75.362000 60.333000,74.982000 60.928000,74.589000 61.515000,74.184000 62.092000,73.765000 62.661000,73.334000 63.221000,72.891000 63.772000,72.436000 64.313000,71.968000 64.843000,71.489000 65.364000,70.999000 65.874000,70.497000 66.374000,69.984000 66.863000,69.460000 67.340000,68.926000 67.807000,68.381000 68.261000,67.826000 68.704000,67.261000 69.135000,66.686000 69.553000,66.103000 69.959000,65.510000 70.352000,64.908000 70.733000,64.297000 71.100000,63.678000 71.455000,63.051000 71.796000,62.417000 72.123000,61.775000 72.436000,61.126000 72.736000,60.469000 73.022000,59.807000 73.293000,59.138000 73.550000,58.463000 73.793000,57.782000 74.021000,57.096000 74.235000,56.405000 74.433000,55.709000 74.617000,55.009000 74.786000,54.304000 74.939000,53.596000 75.078000,52.884000 75.201000,52.170000 75.309000,51.452000 75.401000,50.732000 75.478000,50.010000 75.540000,49.286000 75.586000,48.560000 75.616000,47.834000 75.631000,47.106000 75.630000,46.378000 75.613000,45.650000 75.581000,44.922000 75.533000,44.195000 75.470000,43.468000 75.391000,42.743000 75.296000,42.019000 75.186000,41.297000 75.060000,40.578000 74.918000,39.860000 74.762000,39.146000 74.589000,38.435000 74.402000,37.728000 74.199000,37.024000 73.981000,36.325000 73.748000,35.630000 73.500000,34.940000 73.238000,34.255000 72.960000,33.575000 72.668000,32.902000 72.361000,32.235000 72.040000,31.574000 71.704000,30.919000 71.354000,30.272000 70.991000,29.632000 70.613000,29.000000 70.222000,28.376000 69.817000,27.760000 69.400000,27.153000 68.968000,26.555000 68.524000,25.966000 68.068000,25.386000 67.598000,24.815000 67.116000,24.255000 66.623000,23.705000 66.117000,23.166000 65.599000,22.637000 65.070000,22.119000 64.530000,21.613000 63.979000,21.118000 63.417000,20.635000 62.844000,20.163000 62.262000,19.704000 61.669000,19.258000 61.066000,18.824000 60.454000,18.403000 59.833000,17.995000 59.203000,17.600000 58.565000,17.219000 57.918000,16.851000 57.263000,16.497000 56.600000,16.157000 55.930000,15.831000 55.253000,15.520000 54.568000,15.223000 53.878000,14.941000 53.181000,14.674000 52.478000,14.421000 51.770000,14.184000 51.056000,13.961000 50.338000,13.754000 49.614000,13.563000 48.887000,13.387000 48.156000,13.226000 47.421000,13.081000 46.682000,12.952000 45.941000,12.839000 45.198000,12.742000 44.452000,12.660000 43.704000,12.595000 42.954000,12.546000 42.204000,12.512000 41.452000,12.495000 40.700000,12.495000 39.948000,12.510000 39.196000,12.541000 38.444000,12.589000 37.693000,12.653000 36.944000,12.732000 36.196000,12.829000 35.450000,12.941000 34.706000,13.069000 33.965000,13.213000 33.227000,13.373000 32.492000,13.549000 31.761000,13.741000 31.034000,13.949000 30.311000,14.172000 29.592000,14.411000 28.879000,14.665000 28.171000,14.935000 27.468000,15.220000 26.772000,15.520000 26.082000,15.836000 25.399000,16.166000 24.722000,16.511000 24.053000,16.870000 23.391000,17.244000 22.737000,17.632000 22.092000,18.035000 21.455000,18.451000 20.827000,18.881000 20.208000,19.325000 19.598000,19.782000 18.998000,20.252000 18.408000,20.735000 17.828000,21.231000 17.259000,21.740000 16.701000,22.261000 16.154000,22.794000 15.618000,23.339000 15.093000,23.895000 14.581000,24.463000 14.081000,25.042000 13.592000,25.632000 13.117000,26.233000 12.654000,26.843000 12.205000,27.464000 11.769000,28.095000 11.346000,28.735000 10.936000,29.385000 10.541000,30.043000 10.160000,30.710000 9.793000,31.385000 9.440000,32.069000 9.102000,32.760000 8.779000,33.458000 8.471000,34.164000 8.178000,34.876000 7.900000,35.595000 7.638000,36.319000 7.391000,37.050000 7.159000,37.786000 6.944000,38.527000 6.744000,39.273000 6.561000,40.024000 6.393000,40.778000 6.242000,41.536000 6.107000,42.298000 5.988000,43.063000 5.886000,43.830000 5.800000,44.600000 5.730000,45.372000 5.678000,46.145000 5.641000,46.920000 5.622000,47.695000 5.619000,48.471000 5.633000,49.248000 5.663000,50.024000 5.711000,50.800000 5.774000,51.575000 5.855000,52.348000 5.952000,53.120000 6.066000,53.890000 6.196000,54.658000 6.343000,55.423000 6.507000,56.186000 6.686000,56.944000 6.883000,57.699000 7.095000,58.450000 7.324000,59.197000 7.568000,59.939000 7.829000,60.676000 8.105000,61.407000 8.398000,62.132000 8.706000,62.852000 9.029000,63.564000 9.368000,64.270000 9.722000,64.969000 10.091000,65.661000 10.475000,66.344000 10.874000,67.020000 11.288000,67.687000 11.715000,68.345000 12.158000,68.994000 12.614000,69.634000 13.084000,70.264000 13.567000,70.884000 14.064000,71.494000 14.574000,72.093000 15.098000,72.682000 15.634000,73.259000 16.182000,73.825000 16.743000,74.379000 17.315000,74.921000 17.900000,75.452000 18.496000,75.969000 19.103000,76.474000 19.721000,76.966000 20.350000,77.445000 20.990000,77.910000 21.639000,78.362000 22.298000,78.800000 22.967000,79.223000 23.645000,79.633000 24.332000,80.028000 25.027000,80.408000 25.731000,80.773000 26.443000,81.124000 27.162000,81.459000 27.889000,81.778000 28.623000,82.082000 29.364000,82.371000 30.110000,82.643000 30.863000,82.900000 31.622000,83.140000 32.385000,83.364000 33.154000,83.572000 33.928000,83.764000 34.705000,83.938000 35.487000,84.096000 36.272000,84.238000 37.060000,84.362000 37.851000,84.469000 38.644000,84.560000 39.440000,84.633000 40.237000,84.690000 41.036000,84.729000 41.836000,84.751000 42.636000,84.756000 43.436000,84.744000 44.237000,84.715000 45.037000,84.668000 45.836000,84.604000 46.633000,84.523000 47.430000,84.425000 48.224000,84.309000 49.016000,84.177000 49.805000,84.028000 50.591000,83.861000 51.374000,83.678000 52.153000,83.478000 52.928000,83.261000 53.698000,83.027000 54.463000,82.777000 55.223000,82.510000 55.978000,82.227000 56.726000,81.927000 57.469000,81.612000 58.204000,81.280000 58.933000,80.933000 59.654000,80.569000 60.368000,80.191000 61.073000,79.797000 61.771000,79.387000 62.459000,78.963000 63.139000,78.524000 63.809000,78.070000 64.470000,77.601000 65.120000,77.118000 65.761000,76.622000 66.391000,76.111000 67.010000,75.587000 67.617000,75.049000 68.214000,74.498000 68.798000,73.934000 69.371000,73.358000 69.931000,72.769000 70.479000,72.168000 71.014000,71.555000 71.536000,70.931000 72.045000,70.295000 72.540000,69.648000 73.021000,68.991000 73.488000,68.323000 73.941000,67.645000 74.379000,66.957000 74.803000,66.259000 75.212000,65.552000 75.605000,64.836000 75.983000,64.112000 76.346000,63.380000 76.693000,62.639000 77.025000,61.891000 77.340000,61.136000 77.639000,60.374000 77.922000,59.605000 78.188000,58.830000 78.438000,58.049000 78.671000,57.263000 78.887000,56.471000 79.086000,55.675000 79.268000,54.874000 79.433000,54.070000 79.580000,53.261000 79.711000,52.450000 79.823000,51.635000 79.919000,50.818000 79.997000,49.999000 80.057000,49.177000 80.099000,48.355000 80.124000,47.531000 80.131000,46.707000 80.121000,45.882000 80.093000,45.057000 80.047000,44.233000 79.983000,43.410000 79.902000,42.588000 79.803000,41.768000 79.686000,40.949000 79.551000,40.133000 79.400000,39.320000 79.230000,38.510000 79.043000,37.703000 78.839000,36.900000 78.618000,36.102000 78.379000,35.308000 78.123000,34.519000 77.851000,33.735000 77.561000,32.957000 77.254000,32.186000 76.931000,31.420000 76.592000,30.662000 76.236000,29.911000 75.864000,29.167000 75.476000,28.431000 75.072000,27.703000 74.652000,26.984000 74.217000,26.274000 73.766000,25.573000 73.300000,24.882000 72.820000,24.200000 72.324000,23.529000 71.814000,22.868000 71.290000,22.218000 70.752000,21.579000 70.200000,20.952000 69.634000,20.337000 69.055000,19.733000 68.463000,19.142000 67.859000,18.564000 67.241000,17.998000 66.612000,17.445000 65.970000,16.906000 65.317000,16.381000 64.652000,15.870000 63.976000,15.373000 63.290000,14.890000 62.593000,14.422000 61.886000,13.969000 61.169000,13.531000 60.442000,13.108000 59.706000,12.701000 58.962000,12.310000 58.208000,11.934000 57.447000,11.575000 56.678000,11.232000 55.901000,10.905000 55.117000,10.595000 54.327000,10.302000 53.530000,10.026000 52.726000,9.767000 51.918000,9.525000 51.104000,9.301000 50.284000,9.094000 49.461000,8.904000 48.633000,8.732000 47.801000,8.578000 46.966000,8.442000 46.128000,8.324000 45.287000,8.223000 44.444000,8.141000 43.599000,8.077000 42.752000,8.031000 41.904000,8.003000 41.056000,7.994000 40.207000,8.002000 39.358000,8.029000 38.510000,8.074000 37.663000,8.138000 36.816000,8.219000 35.972000,8.319000 35.129000,8.437000 34.289000,8.573000 33.452000,8.727000 32.617000,8.899000 31.787000,9.090000 30.960000,9.298000 30.138000,9.523000 29.320000,9.767000 28.508000,10.028000 27.701000,10.307000 26.899000,10.603000 26.104000,10.916000 25.316000,11.246000 24.535000,11.594000 23.761000,11.958000 22.994000,12.339000 22.236000,12.736000 21.486000,13.150000 20.745000,13.580000 20.013000,14.026000 19.291000,14.488000 18.578000,14.965000 17.876000,15.458000 17.184000,15.966000 16.503000,16.489000 15.832000,17.026000 15.174000,17.578000 14.527000,18.145000 13.892000,18.725000 13.270000,19.319000 12.660000,19.926000 12.063000,20.547000 11.480000,21.181000 10.910000,21.827000 10.354000,22.486000 9.811000,23.156000 9.284000,23.839000 8.770000,24.532000 8.272000,25.237000 7.789000,25.953000 7.321000,26.680000 6.868000,27.416000 6.431000,28.162000 6.011000,28.918000 5.606000,29.683000 5.218000,30.457000 4.846000,31.239000 4.491000,32.029000 4.153000,32.827000 3.833000,33.633000 3.529000,34.445000 3.243000,35.264000 2.974000,36.090000 2.723000,36.921000 2.490000,37.758000 2.275000,38.600000 2.078000,39.446000 1.899000,40.297000 1.738000,41.152000 1.596000,42.011000 1.472000,42.873000 1.367000,43.737000 1.280000,44.604000 1.212000,45.473000 1.162000,46.344000 1.131000,47.215000 1.119000,48.088000 1.126000,48.961000 1.151000,49.834000 1.195000,50.706000 1.258000,51.578000 1.340000,52.448000 1.440000,53.317000 1.559000,54.184000 1.697000,55.048000 1.853000,55.910000 2.028000,56.768000 2.221000,57.623000 2.433000,58.473000 2.663000,59.320000 2.911000,60.161000 3.177000,60.997000 3.462000,61.828000 3.764000,62.652000 4.084000,63.471000 4.421000,64.282000 4.777000,65.086000 5.149000,65.883000 5.539000,66.672000 5.945000,67.453000 6.369000,68.225000 6.809000,68.988000 7.265000,69.741000 7.738000,70.485000 8.227000,71.219000 8.732000,71.943000 9.252000,72.656000 9.788000,73.357000 10.339000,74.048000 10.904000,74.726000 11.485000,75.393000 12.080000,76.047000 12.689000,76.688000 13.312000,77.317000 13.948000,77.932000 14.598000,78.534000 15.261000,79.121000 15.936000,79.695000 16.624000,80.254000 17.324000,80.798000 18.036000,81.328000 18.759000,81.842000 19.494000,82.341000 20.239000,82.824000 20.995000,83.291000 21.761000,83.742000 22.536000,84.176000 23.322000,84.594000 24.116000,84.995000 24.919000,85.379000 25.730000,85.746000 26.550000,86.096000 27.377000,86.428000 28.211000,86.742000 29.052000,87.038000 29.899000,87.317000 30.753000,87.577000 31.612000,87.818000 32.477000,88.042000 33.347000,88.247000 34.221000,88.433000 35.099000,88.600000 35.981000,88.749000 36.866000,88.879000 37.755000,88.989000 38.645000,89.081000 39.538000,89.153000 40.433000,89.206000 41.328000,89.240000 42.225000,89.255000 43.122000,89.251000 44.019000,89.227000 44.916000,89.184000 45.812000,89.122000 46.706000,89.040000 47.599000,88.939000 48.490000,88.819000 49.379000,88.680000 50.264000,88.522000 51.147000,88.345000 52.026000,88.148000 52.900000,87.933000 53.770000,87.699000 54.635000,87.447000 55.495000,87.175000 56.349000,86.885000 57.197000,86.577000 58.039000,86.250000 58.874000,85.906000 59.701000,85.543000 60.521000,85.163000 61.332000,84.764000 62.135000,84.349000 62.930000,83.916000 63.715000,83.466000 64.490000,82.999000 65.256000,82.515000 66.011000,82.015000 66.756000,81.498000 67.490000,80.966000 68.212000,80.417000 68.923000,79.853000 69.621000,79.274000 70.307000,78.679000 70.981000,78.070000 71.642000,77.446000 72.289000,76.808000 72.923000,76.156000 73.542000,75.490000 74.148000,74.811000 74.739000,74.118000 75.315000,73.413000 75.876000,72.696000 76.422000,71.966000 76.952000,71.224000 77.466000,70.471000 77.964000,69.707000 78.446000,68.932000 78.911000,68.147000 79.360000,67.351000 79.791000,66.546000 80.205000,65.731000 80.602000,64.907000 80.981000,64.075000 81.342000,63.234000 81.685000,62.386000 82.010000,61.530000 82.317000,60.667000 82.605000,59.797000 82.874000,58.921000 83.125000,58.039000 83.357000,57.152000 83.569000,56.259000 83.763000,55.362000 83.937000,54.461000 84.092000,53.555000 84.228000,52.647000 84.344000,51.735000 84.440000,50.820000 84.517000,49.904000 84.574000,48.985000 84.612000,48.066000 84.629000,47.145000 84.627000,46.224000 84.605000,45.303000 84.563000,44.382000 84.502000,43.462000 84.421000,42.543000 84.320000,41.625000 84.199000,40.710000 84.058000,39.798000 83.898000,38.888000 83.719000,37.981000 83.519000,37.078000 83.301000,36.180000 83.063000,35.286000 82.806000,34.397000 82.530000,33.513000 82.234000,32.635000 81.920000,31.764000 81.587000,30.899000 81.235000,30.041000 80.865000,29.191000 80.477000,28.348000 80.070000,27.514000 79.646000,26.688000 79.204000,25.872000 78.744000,25.064000 78.266000,24.267000 77.772000,23.480000 77.260000,22.703000 76.732000,21.937000 76.187000,21.182000 75.626000,20.439000 75.049000,19.708000 74.456000,18.989000 73.848000,18.283000 73.224000,17.590000 72.586000,16.910000 71.932000,16.244000 71.265000,15.592000 70.583000,14.954000 69.887000,14.331000 69.178000,13.722000 68.456000,13.129000 67.721000,12.551000 66.973000,11.989000 66.213000,11.443000 65.442000,10.913000 64.659000,10.399000 63.865000,9.903000 63.060000,9.423000 62.244000,8.961000 61.419000,8.516000 60.584000,8.088000 59.740000,7.679000 58.886000,7.288000 58.025000,6.915000 57.155000,6.560000 56.277000,6.224000 55.392000,5.907000 54.501000,5.609000 53.602000,5.330000 52.698000,5.071000 51.788000,4.830000 50.872000,4.610000 49.952000,4.409000 49.027000,4.227000 48.099000,4.066000 47.166000,3.924000 46.231000,3.803000 45.293000,3.701000 44.352000,3.620000 43.410000,3.559000 42.466000,3.518000 41.522000,3.497000 40.576000,3.497000 39.631000,3.517000 38.686000,3.557000 37.742000,3.618000 36.799000,3.699000 35.857000,3.800000 34.918000,3.921000 33.981000,4.063000 33.047000,4.225000 32.116000,4.406000 31.189000,4.608000 30.267000,4.830000 29.349000,5.072000 28.436000,5.333000 27.528000,5.614000 26.627000,5.915000 25.732000,6.235000 24.844000,6.574000 23.962000,6.933000 23.089000,7.310000 22.223000,7.706000 21.366000,8.121000 20.518000,8.554000 19.679000,9.006000 18.850000,9.475000 18.030000,9.963000 17.221000,10.468000 16.423000,10.991000 15.635000,11.531000 14.860000,12.087000 14.096000,12.661000 13.344000,13.251000 12.605000,13.857000 11.879000,14.479000 11.167000,15.117000 10.468000,15.771000 9.782000,16.439000 9.111000,17.122000 8.455000,17.820000 7.814000,18.532000 7.188000,19.257000 6.577000,19.996000 5.982000,20.749000 5.404000,21.514000 4.841000,22.292000 4.296000,23.082000 3.767000,23.884000 3.255000,24.697000 2.761000,25.521000 2.284000,26.356000 1.826000,27.202000 1.385000,28.057000 0.963000,28.922000 0.559000,29.796000 0.174000,30.679000 -0.192000,31.570000 -0.538000,32.469000 -0.866000,33.376000 -1.174000,34.290000 -1.463000,35.210000 -1.732000,36.137000 -1.981000,37.070000 -2.209000,38.008000 -2.418000,38.952000 -2.607000,39.899000 -2.775000,40.851000 -2.923000,41.807000 -3.050000,42.766000 -3.157000,43.728000 -3.243000,44.692000 -3.308000,45.658000 -3.352000,46.626000 -3.376000,47.595000 -3.379000,48.564000 -3.361000,49.534000 -3.323000,50.503000 -3.263000,51.471000 -3.183000,52.439000 -3.081000,53.405000 -2.960000,54.368000 -2.817000,55.329000 -2.654000,56.288000 -2.470000,57.242000 -2.265000,58.193000 -2.040000,59.140000 -1.795000,60.082000 -1.529000,61.019000 -1.244000,61.950000 -0.938000,62.875000 -0.612000,63.794000 -0.267000,64.705000 0.098000,65.610000 0.483000,66.506000 0.886000,67.395000 1.309000,68.275000 1.751000,69.146000 2.212000,70.007000 2.691000,70.859000 3.189000,71.701000 3.705000,72.532000 4.238000,73.352000 4.789000,74.160000 5.358000,74.957000 5.944000,75.742000 6.547000,76.514000 7.166000,77.273000 7.802000,78.019000 8.454000,78.752000 9.122000,79.470000 9.805000,80.174000 10.504000,80.864000 11.217000,81.539000 11.945000,82.198000 12.687000,82.842000 13.444000,83.470000 14.213000,84.082000 14.996000,84.677000 15.792000,85.256000 16.600000,85.818000 17.421000,86.362000 18.253000,86.889000 19.097000,87.397000 19.951000,87.888000 20.817000,88.361000 21.692000,88.815000 22.578000,89.250000 23.472000,89.666000 24.376000,90.063000 25.289000,90.441000 26.209000,90.799000 27.138000,91.137000 28.074000,91.455000 29.017000,91.754000 29.966000,92.032000 30.921000,92.290000 31.882000,92.527000 32.848000,92.743000 33.819000,92.939000 34.795000,93.114000 35.774000,93.268000 36.756000,93.401000 37.742000,93.513000 38.730000,93.604000 39.720000,93.674000 40.711000,93.722000 41.769000,93.750000 83.500000,93.750000 83.500000,96.250000 41.731000,96.250000 40.720000,96.224000 39.709000,96.177000 38.666000,96.107000 37.624000,96.014000 36.585000,95.899000 35.548000,95.762000 34.516000,95.602000 33.487000,95.421000 32.463000,95.217000 31.444000,94.992000 30.430000,94.744000 29.422000,94.476000 28.420000,94.185000 27.425000,93.873000 26.437000,93.541000 25.457000,93.187000 24.485000,92.812000 23.522000,92.416000 22.568000,92.000000 21.623000,91.564000 20.688000,91.108000 19.764000,90.632000 18.850000,90.136000 17.947000,89.621000 17.056000,89.087000 16.177000,88.534000 15.310000,87.963000 14.456000,87.373000 13.615000,86.765000 12.787000,86.140000 11.973000,85.497000 11.174000,84.837000 10.389000,84.160000 9.620000,83.466000 8.865000,82.757000 8.126000,82.031000 7.404000,81.291000 6.697000,80.535000 6.007000,79.764000 5.334000,78.979000 4.678000,78.180000 4.040000,77.367000 3.420000,76.541000 2.817000,75.702000 2.233000,74.851000 1.668000,73.988000 1.121000,73.113000 0.594000,72.226000 0.086000,71.329000 -0.403000,70.422000 -0.872000,69.504000 -1.320000,68.577000 -1.749000,67.641000 -2.158000,66.696000 -2.545000,65.743000 -2.913000,64.782000 -3.259000,63.813000 -3.584000,62.838000 -3.889000,61.857000 -4.172000,60.869000 -4.433000,59.876000 -4.673000,58.877000 -4.892000,57.875000 -5.089000,56.868000 -5.264000,55.857000 -5.418000,54.843000 -5.549000,53.826000 -5.659000,52.807000 -5.747000,51.787000 -5.812000,50.765000 -5.856000,49.742000 -5.878000,48.719000 -5.878000,47.696000 -5.856000,46.673000 -5.811000,45.652000 -5.745000,44.632000 -5.658000,43.613000 -5.548000,42.598000 -5.416000,41.585000 -5.263000,40.576000 -5.089000,39.571000 -4.892000,38.569000 -4.675000,37.573000 -4.436000,36.582000 -4.176000,35.597000 -3.895000,34.617000 -3.593000,33.645000 -3.270000,32.679000 -2.927000,31.721000 -2.564000,30.770000 -2.180000,29.828000 -1.776000,28.895000 -1.353000,27.971000 -0.910000,27.056000 -0.447000,26.152000 0.035000,25.258000 0.535000,24.375000 1.055000,23.503000 1.593000,22.643000 2.149000,21.794000 2.722000,20.959000 3.314000,20.136000 3.923000,19.326000 4.549000,18.529000 5.191000,17.747000 5.850000,16.979000 6.526000,16.225000 7.217000,15.486000 7.923000,14.763000 8.645000,14.055000 9.381000,13.363000 10.132000,12.687000 10.897000,12.028000 11.676000,11.385000 12.468000,10.759000 13.273000,10.151000 14.090000,9.561000 14.920000,8.988000 15.762000,8.434000 16.615000,7.898000 17.479000,7.380000 18.354000,6.882000 19.239000,6.402000 20.134000,5.942000 21.038000,5.501000 21.952000,5.080000 22.873000,4.679000 23.803000,4.297000 24.741000,3.936000 25.685000,3.595000 26.637000,3.275000 27.595000,2.975000 28.558000,2.696000 29.528000,2.438000 30.502000,2.201000 31.480000,1.985000 32.463000,1.790000 33.450000,1.616000 34.439000,1.464000 35.432000,1.333000 36.426000,1.223000 37.423000,1.135000 38.421000,1.068000 39.419000,1.022000 40.418000,0.998000 41.417000,0.996000 42.416000,1.015000 43.413000,1.055000 44.409000,1.117000 45.404000,1.200000 46.396000,1.305000 47.385000,1.430000 48.370000,1.577000 49.353000,1.745000 50.331000,1.934000 51.304000,2.144000 52.272000,2.374000 53.235000,2.626000 54.192000,2.898000 55.142000,3.190000 56.086000,3.502000 57.022000,3.835000 57.951000,4.187000 58.872000,4.559000 59.784000,4.951000 60.687000,5.362000 61.581000,5.792000 62.465000,6.242000 63.339000,6.710000 64.203000,7.196000 65.055000,7.701000 65.897000,8.224000 66.726000,8.764000 67.544000,9.322000 68.349000,9.897000 69.141000,10.490000 69.920000,11.098000 70.686000,11.724000 71.437000,12.365000 72.175000,13.022000 72.898000,13.695000 73.606000,14.383000 74.299000,15.085000 74.976000,15.802000 75.638000,16.533000 76.283000,17.278000 76.913000,18.037000 77.525000,18.808000 78.121000,19.593000 78.699000,20.389000 79.260000,21.198000 79.804000,22.018000 80.329000,22.849000 80.837000,23.691000 81.326000,24.544000 81.796000,25.407000 82.248000,26.279000 82.680000,27.160000 83.094000,28.050000 83.488000,28.949000 83.862000,29.855000 84.217000,30.769000 84.552000,31.691000 84.867000,32.618000 85.162000,33.552000 85.437000,34.492000 85.691000,35.438000 85.925000,36.388000 86.139000,37.342000 86.332000,38.301000 86.504000,39.263000 86.655000,40.229000 86.786000,41.197000 86.895000,42.167000 86.984000,43.139000 87.052000,44.113000 87.099000,45.087000 87.125000,46.062000 87.130000,47.037000 87.114000,48.012000 87.077000,48.985000 87.020000,49.957000 86.941000,50.928000 86.842000,51.896000 86.722000,52.861000 86.581000,53.824000 86.420000,54.782000 86.238000,55.737000 86.036000,56.688000 85.813000,57.633000 85.570000,58.573000 85.308000,59.508000 85.025000,60.436000 84.723000,61.357000 84.401000,62.272000 84.059000,63.179000 83.698000,64.078000 83.319000,64.969000 82.920000,65.852000 82.502000,66.725000 82.066000,67.589000 81.612000,68.443000 81.140000,69.287000 80.649000,70.120000 80.142000,70.942000 79.616000,71.753000 79.074000,72.552000 78.515000,73.338000 77.939000,74.113000 77.347000,74.875000 76.739000,75.623000 76.115000,76.358000 75.476000,77.079000 74.822000,77.786000 74.153000,78.479000 73.469000,79.157000 72.771000,79.819000 72.060000,80.467000 71.335000,81.098000 70.596000,81.714000 69.845000,82.314000 69.082000,82.897000 68.306000,83.463000 67.519000,84.013000 66.720000,84.545000 65.911000,85.060000 65.091000,85.557000 64.260000,86.036000 63.420000,86.497000 62.570000,86.940000 61.712000,87.364000 60.844000,87.770000 59.969000,88.156000 59.086000,88.524000 58.195000,88.873000 57.297000,89.202000 56.393000,89.512000 55.483000,89.802000 54.567000,90.072000 53.646000,90.323000 52.720000,90.553000 51.789000,90.764000 50.854000,90.955000 49.916000,91.125000 48.975000,91.275000 48.031000,91.405000 47.085000,91.514000 46.137000,91.604000 45.188000,91.672000 44.238000,91.721000 43.287000,91.748000 42.336000,91.756000 41.386000,91.743000 40.436000,91.709000 39.488000,91.656000 38.541000,91.582000 37.597000,91.487000 36.655000,91.373000 35.716000,91.238000 34.781000,91.083000 33.849000,90.908000 32.922000,90.713000 31.999000,90.499000 31.082000,90.265000 30.170000,90.011000 29.264000,89.738000 28.365000,89.445000 27.472000,89.133000 26.587000,88.803000 25.709000,88.453000 24.839000,88.085000 23.978000,87.699000 23.125000,87.294000 22.282000,86.871000 21.448000,86.430000 20.624000,85.972000 19.810000,85.496000 19.007000,85.003000 18.215000,84.493000 17.435000,83.966000 16.666000,83.423000 15.910000,82.863000 15.166000,82.288000 14.434000,81.697000 13.716000,81.091000 13.011000,80.470000 12.320000,79.833000 11.643000,79.183000 10.981000,78.518000 10.333000,77.840000 9.700000,77.147000 9.082000,76.442000 8.480000,75.724000 7.893000,74.993000 7.323000,74.250000 6.769000,73.496000 6.231000,72.730000 5.710000,71.953000 5.206000,71.165000 4.720000,70.366000 4.250000,69.558000 3.799000,68.740000 3.365000,67.913000 2.949000,67.077000 2.552000,66.233000 2.173000,65.380000 1.812000,64.520000 1.470000,63.653000 1.147000,62.779000 0.842000,61.898000 0.557000,61.012000 0.291000,60.120000 0.045000,59.222000 -0.183000,58.320000 -0.390000,57.413000 -0.578000,56.503000 -0.747000,55.589000 -0.896000,54.672000 -1.025000,53.752000 -1.134000,52.831000 -1.223000,51.907000 -1.292000,50.982000 -1.342000,50.056000 -1.371000,49.129000 -1.381000,48.203000 -1.371000,47.276000 -1.341000,46.351000 -1.291000,45.426000 -1.221000,44.504000 -1.131000,43.583000 -1.022000,42.665000 -0.893000,41.749000 -0.745000,40.837000 -0.577000,39.929000 -0.389000,39.025000 -0.182000,38.125000 0.043000,37.231000 0.288000,36.341000 0.552000,35.458000 0.835000,34.581000 1.137000,33.710000 1.457000,32.846000 1.795000,31.990000 2.151000,31.141000 2.526000,30.301000 2.918000,29.469000 3.328000,28.646000 3.756000,27.832000 4.200000,27.028000 4.662000,26.234000 5.140000,25.451000 5.635000,24.678000 6.146000,23.916000 6.674000,23.166000 7.217000,22.427000 7.775000,21.701000 8.349000,20.987000 8.938000,20.285000 9.542000,19.597000 10.160000,18.922000 10.792000,18.261000 11.438000,17.614000 12.098000,16.981000 12.770000,16.362000 13.456000,15.758000 14.154000,15.170000 14.864000,14.597000 15.587000,14.039000 16.320000,13.497000 17.065000,12.971000 17.821000,12.462000 18.588000,11.969000 19.364000,11.493000 20.150000,11.034000 20.946000,10.592000 21.751000,10.167000 22.564000,9.760000 23.385000,9.370000 24.215000,8.999000 25.052000,8.645000 25.896000,8.310000 26.746000,7.993000 27.603000,7.694000 28.466000,7.414000 29.335000,7.153000 30.208000,6.910000 31.086000,6.687000 31.969000,6.482000 32.855000,6.297000 33.745000,6.130000 34.638000,5.983000 35.533000,5.855000 36.431000,5.747000 37.330000,5.657000 38.231000,5.587000 39.133000,5.537000 40.035000,5.506000 40.938000,5.494000 41.840000,5.501000 42.742000,5.528000 43.642000,5.575000 44.541000,5.640000 45.438000,5.725000 46.332000,5.829000 47.224000,5.953000 48.113000,6.095000 48.998000,6.256000 49.879000,6.437000 50.756000,6.636000 51.627000,6.853000 52.494000,7.090000 53.355000,7.345000 54.210000,7.618000 55.059000,7.909000 55.901000,8.219000 56.735000,8.546000 57.563000,8.891000 58.382000,9.253000 59.193000,9.633000 59.995000,10.031000 60.789000,10.445000 61.573000,10.876000 62.347000,11.323000 63.111000,11.787000 63.865000,12.267000 64.608000,12.763000 65.340000,13.274000 66.061000,13.801000 66.770000,14.343000 67.466000,14.900000 68.151000,15.472000 68.822000,16.058000 69.481000,16.658000 70.126000,17.272000 70.758000,17.899000 71.376000,18.540000 71.980000,19.193000 72.570000,19.859000 73.144000,20.537000 73.704000,21.228000 74.249000,21.929000 74.778000,22.642000 75.292000,23.366000 75.790000,24.101000 76.272000,24.846000 76.737000,25.600000 77.186000,26.365000 77.618000,27.138000 78.034000,27.920000 78.432000,28.711000 78.813000,29.510000 79.177000,30.316000 79.524000,31.130000 79.852000,31.951000 80.163000,32.778000 80.456000,33.612000 80.730000,34.451000 80.987000,35.296000 81.225000,36.145000 81.445000,37.000000 81.646000,37.858000 81.829000,38.720000 81.993000,39.586000 82.139000,40.455000 82.266000,41.326000 82.374000,42.199000 82.463000,43.075000 82.533000,43.951000 82.585000,44.829000 82.617000,45.707000 82.631000,46.585000 82.626000,47.464000 82.602000,48.341000 82.559000,49.218000 82.497000,50.092000 82.417000,50.966000 82.318000,51.836000 82.200000,52.705000 82.064000,53.570000 81.909000,54.432000 81.736000,55.289000 81.544000,56.143000 81.335000,56.992000 81.107000,57.836000 80.861000,58.675000 80.597000,59.507000 80.316000,60.334000 80.017000,61.154000 79.700000,61.967000 79.367000,62.773000 79.016000,63.571000 78.648000,64.361000 78.264000,65.143000 77.863000,65.916000 77.445000,66.680000 77.012000,67.435000 76.562000,68.179000 76.097000,68.914000 75.617000,69.638000 75.121000,70.352000 74.610000,71.054000 74.084000,71.745000 73.544000,72.424000 72.989000,73.092000 72.421000,73.747000 71.839000,74.389000 71.243000,75.018000 70.634000,75.635000 70.013000,76.238000 69.379000,76.827000 68.732000,77.402000 68.074000,77.963000 67.404000,78.509000 66.722000,79.041000 66.030000,79.558000 65.327000,80.059000 64.614000,80.545000 63.890000,81.016000 63.157000,81.470000 62.415000,81.909000 61.663000,82.332000 60.904000,82.738000 60.135000,83.127000 59.359000,83.500000 58.576000,83.856000 57.785000,84.195000 56.987000,84.516000 56.183000,84.821000 55.373000,85.108000 54.558000,85.377000 53.737000,85.629000 52.911000,85.862000 52.080000,86.078000 51.246000,86.276000 50.408000,86.456000 49.566000,86.618000 48.722000,86.762000 47.875000,86.887000 47.025000,86.995000 46.174000,87.083000 45.322000,87.154000 44.468000,87.206000 43.614000,87.240000 42.760000,87.256000 41.906000,87.253000 41.053000,87.232000 40.200000,87.192000 39.349000,87.134000 38.500000,87.058000 37.653000,86.964000 36.808000,86.852000 35.966000,86.721000 35.128000,86.573000 34.293000,86.406000 33.463000,86.222000 32.637000,86.020000 31.815000,85.801000 30.999000,85.564000 30.189000,85.310000 29.385000,85.038000 28.586000,84.749000 27.795000,84.444000 27.011000,84.121000 26.234000,83.782000 25.464000,83.427000 24.703000,83.055000 23.951000,82.667000 23.207000,82.263000 22.472000,81.843000 21.747000,81.408000 21.031000,80.958000 20.326000,80.492000 19.631000,80.012000 18.947000,79.517000 18.274000,79.007000 17.612000,78.484000 16.962000,77.946000 16.324000,77.395000 15.698000,76.831000 15.085000,76.253000 14.484000,75.663000 13.896000,75.060000 13.322000,74.445000 12.762000,73.818000 12.215000,73.179000 11.682000,72.529000 11.163000,71.868000 10.659000,71.196000 10.170000,70.514000 9.696000,69.822000 9.237000,69.120000 8.793000,68.409000 8.365000,67.688000 7.952000,66.959000 7.555000,66.221000 7.175000,65.475000 6.811000,64.722000 6.463000,63.961000 6.132000,63.193000 5.817000,62.419000 5.519000,61.638000 5.238000,60.852000 4.975000,60.060000 4.728000,59.262000 4.499000,58.460000 4.287000,57.654000 4.092000,56.843000 3.915000,56.029000 3.756000,55.211000 3.614000,54.391000 3.490000,53.568000 3.384000,52.743000 3.296000,51.916000 3.225000,51.088000 3.172000,50.259000 3.137000,49.429000 3.120000,48.599000 3.121000,47.769000 3.139000,46.939000 3.176000,46.111000 3.230000,45.284000 3.301000,44.458000 3.391000,43.635000 3.498000,42.814000 3.623000,41.996000 3.765000,41.181000 3.924000,40.369000 4.101000,39.562000 4.295000,38.759000 4.507000,37.960000 4.735000,37.167000 4.980000,36.379000 5.242000,35.596000 5.521000,34.820000 5.816000,34.051000 6.127000,33.288000 6.455000,32.532000 6.798000,31.784000 7.158000,31.044000 7.533000,30.311000 7.923000,29.588000 8.329000,28.873000 8.750000,28.167000 9.186000,27.471000 9.637000,26.785000 10.102000,26.109000 10.581000,25.443000 11.074000,24.788000 11.581000,24.144000 12.102000,23.511000 12.635000,22.890000 13.182000,22.280000 13.742000,21.683000 14.314000,21.098000 14.898000,20.526000 15.494000,19.967000 16.101000,19.420000 16.721000,18.888000 17.351000,18.369000 17.991000,17.863000 18.643000,17.372000 19.304000,16.895000 19.975000,16.433000 20.656000,15.985000 21.346000,15.553000 22.045000,15.135000 22.752000,14.732000 23.468000,14.346000 24.191000,13.974000 24.922000,13.619000 25.660000,13.279000 26.405000,12.955000 27.156000,12.648000 27.913000,12.357000 28.676000,12.082000 29.445000,11.824000 30.219000,11.583000 30.997000,11.358000 31.780000,11.151000 32.566000,10.960000 33.357000,10.786000 34.150000,10.629000 34.946000,10.490000 35.745000,10.367000 36.546000,10.262000 37.349000,10.174000 38.153000,10.104000 38.958000,10.050000 39.764000,10.014000 40.570000,9.996000 41.375000,9.994000 42.181000,10.010000 42.985000,10.044000 43.788000,10.094000 44.590000,10.162000 45.390000,10.247000 46.187000,10.349000 46.982000,10.468000 47.773000,10.604000 48.561000,10.757000 49.346000,10.927000 50.126000,11.113000 50.902000,11.317000 51.672000,11.536000 52.438000,11.772000 53.198000,12.025000 53.952000,12.293000 54.700000,12.578000 55.441000,12.878000 56.176000,13.195000 56.903000,13.526000 57.622000,13.873000 58.334000,14.236000 59.037000,14.613000 59.732000,15.006000 60.418000,15.412000 61.095000,15.834000 61.762000,16.270000 62.420000,16.719000 63.067000,17.183000 63.704000,17.660000 64.330000,18.150000 64.946000,18.654000 65.550000,19.171000 66.143000,19.700000 66.724000,20.241000 67.293000,20.795000 67.849000,21.361000 68.394000,21.938000 68.925000,22.526000 69.444000,23.126000 69.949000,23.736000 70.441000,24.357000 70.919000,24.988000 71.383000,25.628000 71.833000,26.279000 72.270000,26.938000 72.691000,27.607000 73.098000,28.284000 73.490000,28.969000 73.867000,29.662000 74.229000,30.363000 74.576000,31.072000 74.908000,31.787000 75.223000,32.509000 75.523000,33.237000 75.807000,33.971000 76.076000,34.711000 76.328000,35.456000 76.564000,36.207000 76.784000,36.961000 76.987000,37.720000 77.174000,38.483000 77.345000,39.249000 77.499000,40.019000 77.636000,40.791000 77.756000,41.565000 77.860000,42.342000 77.948000,43.121000 78.018000,43.901000 78.072000,44.681000 78.108000,45.463000 78.128000,46.245000 78.131000,47.026000 78.118000,47.808000 78.088000,48.588000 78.040000,49.367000 77.977000,50.145000 77.896000,50.921000 77.799000,51.695000 77.685000,52.466000 77.555000,53.234000 77.409000,53.999000 77.246000,54.760000 77.067000,55.517000 76.872000,56.270000 76.660000,57.018000 76.433000,57.761000 76.190000,58.499000 75.931000,59.231000 75.657000,59.957000 75.368000,60.677000 75.063000,61.390000 74.743000,62.096000 74.408000,62.794000 74.058000,63.485000 73.693000,64.168000 73.315000,64.843000 72.922000,65.509000 72.515000,66.166000 72.094000,66.815000 71.659000,67.453000 71.211000,68.082000 70.750000,68.701000 70.276000,69.309000 69.789000,69.907000 69.289000,70.495000 68.778000,71.071000 68.254000,71.635000 67.718000,72.188000 67.171000,72.729000 66.613000,73.258000 66.043000,73.775000 65.463000,74.279000 64.873000,74.770000 64.272000,75.249000 63.662000,75.714000 63.042000,76.166000 62.412000,76.604000 61.774000,77.028000 61.127000,77.438000 60.471000,77.834000 59.808000,78.216000 59.136000,78.583000 58.458000,78.936000 57.772000,79.274000 57.079000,79.597000 56.380000,79.904000 55.675000,80.197000 54.964000,80.474000 54.247000,80.736000 53.525000,80.982000 52.799000,81.213000 52.068000,81.427000 51.333000,81.626000 50.594000,81.809000 49.852000,81.976000 49.106000,82.127000 48.358000,82.262000 47.607000,82.381000 46.855000,82.484000 46.100000,82.570000 45.345000,82.640000 44.588000,82.694000 43.831000,82.731000 43.073000,82.752000 42.315000,82.757000 41.558000,82.746000 40.802000,82.718000 40.047000,82.674000 39.293000,82.614000 38.541000,82.538000 37.791000,82.446000 37.043000,82.338000 36.298000,82.213000 35.557000,82.073000 34.819000,81.917000 34.085000,81.745000 33.355000,81.558000 32.629000,81.355000 31.909000,81.136000 31.193000,80.903000 30.483000,80.654000 29.779000,80.390000 29.081000,80.111000 28.390000,79.817000 27.705000,79.508000 27.027000,79.185000 26.357000,78.848000 25.695000,78.497000 25.040000,78.131000 24.394000,77.752000 23.756000,77.359000 23.127000,76.953000 22.508000,76.533000 21.897000,76.101000 21.297000,75.655000 20.706000,75.197000 20.126000,74.727000 19.556000,74.245000 18.997000,73.750000 18.449000,73.244000 17.912000,72.727000 17.386000,72.198000 16.872000,71.658000 16.371000,71.108000 15.881000,70.547000 15.404000,69.976000 14.939000,69.396000 14.487000,68.805000 14.048000,68.206000 13.622000,67.597000 13.210000,66.980000 12.811000,66.354000 12.426000,65.720000 12.055000,65.078000 11.698000,64.429000 11.354000,63.773000 11.026000,63.109000 10.712000,62.439000 10.412000,61.763000 10.127000,61.080000 9.857000,60.392000 9.602000,59.699000 9.362000,59.001000 9.137000,58.298000 8.927000,57.590000 8.733000,56.879000 8.554000,56.164000 8.390000,55.445000 8.243000,54.724000 8.110000,54.000000 7.994000,53.273000 7.893000,52.545000 7.807000,51.815000 7.738000,51.083000 7.684000,50.351000 7.646000,49.617000 7.624000,48.884000 7.617000,48.150000 7.627000,47.417000 7.652000,46.685000 7.692000,45.954000 7.749000,45.224000 7.821000,44.495000 7.908000,43.769000 8.012000,43.045000 8.130000,42.324000 8.264000,41.606000 8.414000,40.891000 8.578000,40.180000 8.758000,39.473000 8.953000,38.770000 9.163000,38.072000 9.387000,37.379000 9.627000,36.692000 9.881000,36.009000 10.149000,35.333000 10.432000,34.663000 10.729000,34.000000 11.040000,33.343000 11.365000,32.694000 11.704000,32.052000 12.056000,31.417000 12.421000,30.791000 12.800000,30.173000 13.192000,29.563000 13.597000,28.963000 14.014000,28.371000 14.444000,27.789000 14.885000,27.216000 15.339000,26.654000 15.805000,26.101000 16.282000,25.559000 16.771000,25.027000 17.270000,24.506000 17.781000,23.997000 18.302000,23.499000 18.833000,23.012000 19.374000,22.537000 19.926000,22.074000 20.486000,21.623000 21.057000,21.184000 21.636000,20.758000 22.224000,20.345000 22.820000,19.944000 23.425000,19.557000 24.037000,19.183000 24.657000,18.822000 25.284000,18.475000 25.919000,18.142000 26.560000,17.822000 27.207000,17.517000 27.861000,17.226000 28.521000,16.948000 29.186000,16.686000 29.856000,16.437000 30.531000,16.203000 31.210000,15.984000 31.894000,15.780000 32.582000,15.590000 33.273000,15.416000 33.968000,15.256000 34.665000,15.111000 35.365000,14.982000 36.068000,14.867000 36.772000,14.768000 37.478000,14.684000 38.185000,14.615000 38.894000,14.561000 39.603000,14.523000 40.312000,14.500000 41.022000,14.492000 41.731000,14.499000 42.439000,14.522000 43.146000,14.560000 43.852000,14.613000 44.557000,14.681000 45.259000,14.764000 45.960000,14.862000 46.657000,14.975000 47.352000,15.103000 48.043000,15.246000 48.731000,15.404000 49.415000,15.576000 50.095000,15.763000 50.771000,15.964000 51.441000,16.180000 52.107000,16.410000 52.767000,16.654000 53.421000,16.912000 54.070000,17.184000 54.712000,17.469000 55.347000,17.769000 55.976000,18.081000 56.597000,18.407000 57.212000,18.746000 57.818000,19.099000 58.416000,19.463000 59.006000,19.841000 59.588000,20.231000 60.161000,20.633000 60.724000,21.047000 61.279000,21.473000 61.824000,21.910000 62.359000,22.359000 62.884000,22.819000 63.399000,23.290000 63.904000,23.772000 64.397000,24.264000 64.880000,24.767000 65.352000,25.279000 65.812000,25.801000 66.261000,26.333000 66.698000,26.874000 67.123000,27.424000 67.536000,27.983000 67.937000,28.550000 68.325000,29.126000 68.701000,29.709000 69.063000,30.300000 69.413000,30.899000 69.750000,31.504000 70.074000,32.116000 70.384000,32.735000 70.680000,33.360000 70.963000,33.991000 71.233000,34.628000 71.488000,35.270000 71.730000,35.917000 71.957000,36.569000 72.170000,37.225000 72.369000,37.885000 72.554000,38.549000 72.724000,39.217000 72.880000,39.887000 73.021000,40.561000 73.148000,41.237000 73.260000,41.916000 73.357000,42.596000 73.440000,43.278000 73.508000,43.961000 73.562000,44.645000 73.600000,45.330000 73.624000,46.015000 73.633000,46.700000 73.628000,47.385000 73.607000,48.070000 73.572000,48.753000 73.523000,49.435000 73.459000,50.116000 73.380000,50.795000 73.287000,51.471000 73.179000,52.145000 73.057000,52.817000 72.920000,53.485000 72.769000,54.150000 72.604000,54.811000 72.425000,55.468000 72.232000,56.120000 72.026000,56.769000 71.805000,57.412000 71.571000,58.050000 71.323000,58.682000 71.062000,59.309000 70.787000,59.930000 70.500000,60.544000 70.199000,61.152000 69.885000,61.753000 69.559000,62.346000 69.221000,62.933000 68.870000,63.511000 68.507000,64.082000 68.131000,64.644000 67.744000,65.198000 67.346000,65.743000 66.936000,66.280000 66.515000,66.807000 66.082000,67.324000 65.639000,67.832000 65.186000,68.330000 64.722000,68.818000 64.247000,69.296000 63.763000,69.763000 63.270000,70.220000 62.766000,70.665000 62.254000,71.100000 61.733000,71.523000 61.203000,71.934000 60.664000,72.334000 60.117000,72.722000 59.563000,73.098000 59.000000,73.462000 58.431000,73.813000 57.854000,74.152000 57.270000,74.479000 56.680000,74.792000 56.083000,75.093000 55.480000,75.381000 54.872000,75.655000 54.258000,75.916000 53.639000,76.164000 53.015000,76.399000 52.387000,76.619000 51.754000,76.826000 51.117000,77.020000 50.477000,77.199000 49.833000,77.365000 49.186000,77.517000 48.536000,77.655000 47.884000,77.778000 47.230000,77.888000 46.573000,77.983000 45.916000,78.065000 45.257000,78.132000 44.596000,78.185000 43.936000,78.224000 43.275000,78.248000 42.614000,78.258000 41.953000,78.254000 41.292000,78.236000 40.633000,78.204000 39.975000,78.158000 39.318000,78.097000 38.663000,78.022000 38.010000,77.934000 37.360000,77.831000 36.712000,77.715000 36.067000,77.585000 35.426000,77.441000 34.787000,77.283000 34.153000,77.112000 33.523000,76.927000 32.898000,76.729000 32.277000,76.517000 31.661000,76.293000 31.050000,76.055000 30.445000,75.804000 29.846000,75.541000 29.253000,75.265000 28.666000,74.976000 28.086000,74.675000 27.513000,74.362000 26.947000,74.036000 26.388000,73.699000 25.837000,73.350000 25.294000,72.989000 24.759000,72.617000 24.232000,72.234000 23.714000,71.840000 23.205000,71.435000 22.705000,71.019000 22.215000,70.593000 21.733000,70.156000 21.262000,69.710000 20.800000,69.254000 20.349000,68.788000 19.908000,68.313000 19.477000,67.829000 19.057000,67.336000 18.648000,66.834000 18.251000,66.324000 17.864000,65.805000 17.489000,65.279000 17.125000,64.745000 16.773000,64.204000 16.433000,63.655000 16.105000,63.100000 15.789000,62.538000 15.486000,61.969000 15.195000,61.395000 14.916000,60.815000 14.651000,60.229000 14.398000,59.638000 14.157000,59.041000 13.930000,58.441000 13.716000,57.835000 13.515000,57.226000 13.328000,56.613000 13.153000,55.996000 12.992000,55.376000 12.845000,54.752000 12.710000,54.127000 12.590000,53.498000 12.483000,52.868000 12.390000,52.236000 12.310000,51.602000 12.244000,50.967000 12.192000,50.331000 12.153000,49.695000 12.128000,49.058000 12.117000,48.421000 12.119000,47.784000 12.135000,47.148000 12.165000,46.512000 12.208000,45.878000 12.265000,45.245000 12.336000,44.614000 12.420000,43.985000 12.517000,43.358000 12.628000,42.734000 12.752000,42.112000 12.890000,41.494000 13.041000,40.879000 13.204000,40.268000 13.381000,39.660000 13.571000,39.057000 13.773000,38.459000 13.988000,37.865000 14.216000,37.277000 14.456000,36.693000 14.709000,36.116000 14.973000,35.544000 15.250000,34.978000 15.539000,34.419000 15.840000,33.866000 16.152000,33.320000 16.476000,32.782000 16.811000,32.250000 17.157000,31.726000 17.514000,31.210000 17.882000,30.703000 18.261000,30.203000 18.650000,29.712000 19.049000,29.230000 19.458000,28.756000 19.878000,28.292000 20.306000,27.837000 20.745000,27.392000 21.192000,26.956000 21.649000,26.531000 22.114000,26.115000 22.588000,25.710000 23.071000,25.315000 23.561000,24.931000 24.059000,24.558000 24.565000,24.196000 25.078000,23.844000 25.599000,23.505000 26.126000,23.176000 26.660000,22.859000 27.201000,22.554000 27.747000,22.261000 28.299000,21.980000 28.857000,21.711000 29.421000,21.454000 29.989000,21.209000 30.563000,20.977000 31.141000,20.757000 31.723000,20.549000 32.309000,20.355000 32.899000,20.173000 33.492000,20.004000 34.088000,19.848000 34.688000,19.705000 35.290000,19.574000 35.894000,19.457000 36.501000,19.353000 37.109000,19.262000 37.718000,19.184000 38.329000,19.119000 38.941000,19.067000 39.554000,19.029000 40.166000,19.004000 40.779000,18.992000 41.392000,18.993000 42.004000,19.007000 42.615000,19.035000 43.226000,19.075000 43.835000,19.129000 44.442000,19.195000 45.047000,19.275000 45.651000,19.367000 46.252000,19.473000 46.850000,19.591000 47.445000,19.722000 48.037000,19.866000 48.625000,20.022000 49.209000,20.191000 49.790000,20.372000 50.366000,20.566000 50.937000,20.772000 51.504000,20.989000 52.065000,21.219000 52.621000,21.461000 53.172000,21.715000 53.716000,21.980000 54.255000,22.256000 54.787000,22.544000 55.312000,22.844000 55.831000,23.154000 56.343000,23.475000 56.847000,23.807000 57.344000,24.149000 57.833000,24.502000 58.314000,24.865000 58.787000,25.239000 59.251000,25.622000 59.707000,26.014000 60.154000,26.416000 60.593000,26.828000 61.022000,27.248000 61.441000,27.678000 61.851000,28.116000 62.252000,28.563000 62.642000,29.017000 63.022000,29.480000 63.393000,29.951000 63.752000,30.429000 64.102000,30.915000 64.440000,31.408000 64.768000,31.907000 65.084000,32.414000 65.390000,32.926000 65.684000,33.445000 65.967000,33.970000 66.238000,34.500000 66.498000,35.036000 66.746000,35.577000 66.982000,36.123000 67.207000,36.673000 67.419000,37.228000 67.619000,37.787000 67.808000,38.350000 67.983000,38.917000 68.147000,39.486000 68.298000,40.059000 68.437000,40.635000 68.563000,41.213000 68.677000,41.794000 68.778000,42.376000 68.867000,42.960000 68.943000,43.546000 69.006000,44.133000 69.057000,44.720000 69.095000,45.309000 69.120000,45.897000 69.133000,46.486000 69.133000,47.075000 69.121000,47.663000 69.096000,48.250000 69.058000,48.836000 69.007000,49.421000 68.945000,50.005000 68.869000,50.587000 68.781000,51.166000 68.681000,51.744000 68.569000,52.318000 68.444000,52.890000 68.307000,53.459000 68.158000,54.024000 67.997000,54.586000 67.824000,55.143000 67.639000,55.697000 67.443000,56.246000 67.234000,56.790000 67.015000,57.330000 66.784000,57.864000 66.541000,58.393000 66.288000,58.917000 66.023000,59.434000 65.747000,59.946000 65.461000,60.451000 65.164000,60.950000 64.857000,61.441000 64.539000,61.926000 64.211000,62.404000 63.873000,62.874000 63.526000,63.336000 63.168000,63.791000 62.801000,64.238000 62.425000,64.676000 62.040000,65.106000 61.646000,65.527000 61.243000,65.940000 60.831000,66.343000 60.412000,66.738000 59.984000,67.123000 59.548000,67.498000 59.104000,67.864000 58.653000,68.220000 58.195000,68.567000 57.729000,68.903000 57.257000,69.228000 56.778000,69.544000 56.293000,69.848000 55.802000,70.142000 55.304000,70.426000 54.801000,70.698000 54.293000,70.960000 53.779000,71.210000 53.261000,71.449000 52.737000,71.676000 52.209000,71.893000 51.677000,72.097000 51.141000,72.291000 50.602000,72.472000 50.059000,72.642000 49.512000,72.800000 48.963000,72.946000 48.411000,73.080000 47.856000,73.202000 47.300000,73.312000 46.741000,73.410000 46.181000,73.496000 45.620000,73.570000 45.057000,73.632000 44.493000,73.682000 43.929000,73.719000 43.365000,73.745000 42.800000,73.758000 42.236000,73.759000 41.672000,73.748000 41.108000,73.725000 40.546000,73.690000 39.985000,73.643000 39.425000,73.583000 38.867000,73.512000 38.311000,73.429000 37.758000,73.334000 37.206000,73.227000 36.658000,73.109000 36.112000,72.978000 35.570000,72.836000 35.031000,72.683000 34.496000,72.518000 33.965000,72.342000 33.439000,72.154000 32.916000,71.956000 32.399000,71.746000 31.886000,71.525000 31.378000,71.294000 30.876000,71.052000 30.380000,70.799000 29.889000,70.536000 29.404000,70.262000 28.926000,69.978000 28.454000,69.685000 27.989000,69.381000 27.531000,69.068000 27.080000,68.745000 26.636000,68.412000 26.199000,68.070000 25.771000,67.720000 25.350000,67.360000 24.937000,66.992000 24.533000,66.615000 24.137000,66.229000 23.749000,65.836000 23.371000,65.434000 23.001000,65.025000 22.641000,64.608000 22.289000,64.183000 21.947000,63.752000 21.615000,63.313000 21.292000,62.868000 20.980000,62.416000 20.677000,61.958000 20.384000,61.494000 20.101000,61.023000 19.829000,60.548000 19.567000,60.066000 19.316000,59.580000 19.076000,59.088000 18.846000,58.592000 18.627000,58.091000 18.419000,57.586000 18.222000,57.077000 18.036000,56.564000 17.861000,56.047000 17.698000,55.527000 17.546000,55.004000 17.405000,54.478000 17.276000,53.950000 17.158000,53.419000 17.051000,52.887000 16.956000,52.352000 16.873000,51.816000 16.801000,51.278000 16.741000,50.740000 16.693000,50.200000 16.656000,49.660000 16.631000,49.120000 16.617000,48.579000 16.615000,48.039000 16.625000,47.499000 16.646000,46.960000 16.678000,46.421000 16.723000,45.884000 16.779000,45.348000 16.846000,44.814000 16.925000,44.282000 17.015000,43.752000 17.116000,43.224000 17.229000,42.699000 17.352000,42.177000 17.487000,41.658000 17.633000,41.142000 17.790000,40.629000 17.958000,40.121000 18.136000,39.617000 18.525000,38.621000 18.736000,38.130000 18.956000,37.644000 19.187000,37.163000 19.428000,36.688000 19.679000,36.218000 19.940000,35.754000 20.211000,35.296000 20.491000,34.844000 20.781000,34.398000 21.080000,33.959000 21.388000,33.527000 21.706000,33.102000 22.032000,32.684000 22.367000,32.274000 22.710000,31.871000 23.062000,31.475000 23.422000,31.088000 23.790000,30.709000 24.165000,30.338000 24.549000,29.975000 24.940000,29.621000 25.338000,29.275000 25.743000,28.939000 26.155000,28.611000 26.574000,28.292000 26.999000,27.983000 27.431000,27.683000 27.868000,27.393000 28.312000,27.113000 28.761000,26.842000 29.215000,26.581000 29.675000,26.330000 30.140000,26.089000 30.610000,25.858000 31.562000,25.427000 32.045000,25.228000 32.531000,25.039000 33.021000,24.860000 33.515000,24.693000 34.011000,24.536000 34.511000,24.389000 35.013000,24.254000 35.518000,24.129000 36.025000,24.016000 36.534000,23.913000 37.044000,23.822000 38.070000,23.672000 38.585000,23.614000 39.100000,23.567000 39.616000,23.531000 40.133000,23.506000 40.649000,23.492000 41.165000,23.489000 41.681000,23.497000 42.711000,23.547000 43.224000,23.589000 43.736000,23.641000 44.246000,23.705000 44.755000,23.779000 45.261000,23.864000 45.765000,23.960000 46.267000,24.067000 46.766000,24.185000 47.262000,24.313000 47.755000,24.451000 48.244000,24.600000 48.730000,24.760000 49.212000,24.930000 49.690000,25.110000 50.163000,25.300000 50.633000,25.500000 51.097000,25.710000 51.556000,25.929000 52.011000,26.159000 52.460000,26.398000 52.903000,26.646000 53.341000,26.904000 53.773000,27.171000 54.198000,27.447000 54.618000,27.732000 55.031000,28.025000 55.836000,28.638000 56.229000,28.957000 56.614000,29.284000 56.992000,29.620000 57.725000,30.313000 58.079000,30.671000 58.426000,31.037000 58.764000,31.409000 59.095000,31.789000 59.417000,32.175000 59.730000,32.568000 60.330000,33.372000 60.617000,33.783000 61.163000,34.623000 61.422000,35.051000 61.911000,35.923000 62.142000,36.366000 62.363000,36.814000 62.574000,37.265000 62.775000,37.722000 62.966000,38.182000 63.147000,38.645000 63.318000,39.112000 63.629000,40.056000 63.769000,40.532000 63.899000,41.011000 64.018000,41.492000 64.226000,42.461000 64.314000,42.948000 64.391000,43.436000 64.458000,43.926000 64.514000,44.416000 64.560000,44.908000 64.595000,45.400000 64.619000,45.892000 64.637000,46.876000 64.612000,47.859000 64.544000,48.839000 64.495000,49.327000 64.435000,49.813000 64.365000,50.298000 64.285000,50.781000 64.194000,51.262000 64.093000,51.740000 63.860000,52.688000 63.729000,53.158000 63.436000,54.088000 63.275000,54.547000 63.104000,55.003000 62.733000,55.901000 62.534000,56.344000 62.325000,56.782000 62.107000,57.215000 61.880000,57.643000 61.644000,58.066000 61.146000,58.895000 60.612000,59.701000 60.046000,60.482000 59.751000,60.863000 59.447000,61.237000 58.818000,61.964000 58.492000,62.317000 57.818000,63.001000 57.470000,63.332000 57.116000,63.654000 56.388000,64.276000 56.014000,64.575000 55.635000,64.865000 54.858000,65.421000 54.059000,65.942000 53.652000,66.189000 53.240000,66.427000 52.402000,66.876000 51.546000,67.288000 51.112000,67.480000 50.234000,67.835000 49.342000,68.152000 48.439000,68.429000 47.526000,68.668000 46.605000,68.866000 45.677000,69.025000 45.212000,69.089000 44.278000,69.187000 43.810000,69.221000 42.874000,69.259000 41.938000,69.256000 41.471000,69.240000 40.539000,69.177000 40.075000,69.131000 39.152000,69.008000 38.692000,68.932000 37.780000,68.751000 37.328000,68.646000 36.878000,68.531000 35.988000,68.273000 35.111000,67.977000 34.248000,67.644000 33.402000,67.275000 32.986000,67.077000 32.167000,66.655000 31.368000,66.199000 30.976000,65.958000 30.210000,65.453000 29.468000,64.915000 28.750000,64.348000 28.401000,64.053000 27.723000,63.441000 27.072000,62.802000 26.758000,62.472000 26.151000,61.793000 25.576000,61.091000 25.031000,60.365000 24.519000,59.617000 24.041000,58.849000 23.596000,58.063000 23.387000,57.663000 22.995000,56.852000 22.812000,56.440000 22.474000,55.607000 22.173000,54.761000 21.908000,53.904000 21.681000,53.037000 21.492000,52.164000 21.412000,51.724000 21.279000,50.842000 21.185000,49.956000 21.129000,49.068000 21.112000,48.180000 21.132000,47.294000 21.157000,46.852000 21.234000,45.970000 21.287000,45.531000 21.421000,44.659000 21.592000,43.794000 21.800000,42.938000 21.918000,42.515000 22.179000,41.676000 22.324000,41.262000 22.638000,40.444000 22.987000,39.642000 23.370000,38.856000 23.785000,38.089000 24.233000,37.342000 24.711000,36.616000 25.219000,35.911000 25.757000,35.231000 26.322000,34.575000 26.914000,33.945000 27.532000,33.342000 28.174000,32.767000 28.839000,32.222000 29.526000,31.705000 30.233000,31.220000 30.959000,30.766000 31.329000,30.552000 32.082000,30.147000 32.850000,29.775000 33.632000,29.437000 34.426000,29.134000 35.232000,28.865000 36.047000,28.632000 36.871000,28.434000 37.700000,28.272000 38.117000,28.205000 38.953000,28.097000 39.792000,28.026000 40.632000,27.990000 41.472000,27.991000 42.309000,28.028000 43.142000,28.100000 43.557000,28.150000 44.382000,28.276000 45.200000,28.437000 46.009000,28.633000 46.807000,28.863000 47.594000,29.126000 48.367000,29.423000 49.125000,29.753000 49.867000,30.114000 50.592000,30.505000 51.299000,30.928000 51.985000,31.379000 52.651000,31.859000 53.294000,32.366000 53.913000,32.899000 54.508000,33.458000 55.078000,34.040000 55.621000,34.646000 56.137000,35.274000 56.625000,35.922000 57.083000,36.589000 57.512000,37.274000 57.910000,37.976000 58.277000,38.694000 58.612000,39.425000 58.915000,40.169000 59.185000,40.923000 59.422000,41.688000 59.626000,42.461000 59.796000,43.240000 59.932000,44.025000 60.034000,44.813000 60.102000,45.604000 60.136000,46.396000 60.136000,47.187000 60.101000,47.976000 60.033000,48.762000 59.932000,49.543000 59.797000,50.317000 59.629000,51.083000 59.429000,51.840000 59.196000,52.587000 58.933000,53.322000 58.638000,54.043000 58.313000,54.750000 57.959000,55.441000 57.576000,56.115000 57.165000,56.771000 56.727000,57.408000 56.263000,58.024000 55.773000,58.618000 55.259000,59.190000 54.722000,59.739000 54.163000,60.262000 53.583000,60.761000 52.983000,61.233000 52.365000,61.678000 51.729000,62.096000 51.076000,62.485000 50.409000,62.844000 49.728000,63.175000 49.035000,63.475000 48.330000,63.745000 47.616000,63.983000 46.894000,64.191000 46.164000,64.366000 45.429000,64.510000 44.690000,64.622000 43.948000,64.702000 43.205000,64.750000 42.461000,64.766000 41.719000,64.750000 41.397000,64.743000 41.075000,64.725000 40.738000,64.695000 40.403000,64.651000 40.070000,64.596000 39.739000,64.529000 39.410000,64.449000 39.085000,64.358000 38.763000,64.255000 38.446000,64.140000 38.132000,64.013000 37.824000,63.875000 37.521000,63.726000 37.223000,63.566000 36.931000,63.396000 36.646000,63.214000 36.368000,63.023000 36.097000,62.821000 35.833000,62.610000 35.577000,62.389000 35.330000,62.159000 35.091000,61.920000 34.861000,61.673000 34.640000,61.417000 34.429000,61.153000 34.227000,60.882000 34.036000,60.604000 33.854000,60.319000 33.684000,60.027000 33.524000,59.729000 33.375000,59.426000 33.237000,59.118000 33.110000,58.804000 32.995000,58.487000 32.892000,58.165000 32.801000,57.840000 32.721000,57.511000 32.654000,57.180000 32.599000,56.847000 32.555000,56.512000 32.525000,56.175000 32.506000,55.838000 32.500000,55.500000 32.506000,55.162000 32.525000,54.825000 32.555000,54.488000 32.599000,54.153000 32.654000,53.820000 32.721000,53.489000 32.801000,53.160000 32.892000,52.835000 32.995000,52.513000 33.110000,52.196000 33.237000,51.882000 33.375000,51.574000 33.524000,51.271000 33.684000,50.973000 33.854000,50.681000 34.036000,50.396000 34.227000,50.118000 34.429000,49.847000 34.640000,49.583000 34.861000,49.327000 35.091000,49.080000 35.330000,48.841000 35.577000,48.611000 35.833000,48.390000 36.097000,48.179000 36.368000,47.977000 36.646000,47.786000 36.931000,47.604000 37.223000,47.434000 37.521000,47.274000 37.824000,47.125000 38.132000,46.987000 38.446000,46.860000 38.763000,46.745000 39.085000,46.642000 39.410000,46.551000 39.739000,46.471000 40.070000,46.404000 40.403000,46.349000 40.738000,46.305000 41.075000,46.275000 41.412000,46.256000 41.750000,46.250000 41.778000,46.250000 42.271000,46.230000 42.516000,46.206000 43.004000,46.133000 43.245000,46.082000 43.722000,45.956000 44.188000,45.794000 44.641000,45.600000 45.078000,45.372000 45.498000,45.114000 45.898000,44.825000 46.276000,44.508000 46.629000,44.165000 46.956000,43.796000 47.256000,43.404000 47.527000,42.992000 47.766000,42.561000 47.973000,42.114000 48.148000,41.653000 48.288000,41.180000 48.393000,40.698000 48.463000,40.210000 48.484000,39.964000 48.500000,39.472000 48.480000,38.979000 48.456000,38.734000 48.383000,38.246000 48.332000,38.005000 48.206000,37.528000 48.044000,37.062000 47.850000,36.609000 47.622000,36.172000 47.364000,35.752000 47.075000,35.352000 46.758000,34.974000 46.415000,34.621000 46.046000,34.294000 45.654000,33.994000 45.242000,33.724000 44.811000,33.484000 44.364000,33.277000 43.903000,33.102000 43.430000,32.962000 42.948000,32.857000 42.460000,32.787000 42.214000,32.766000 41.716000,32.750000 41.229000,32.735000 40.742000,32.737000 40.106000,32.763000 39.470000,32.817000 38.836000,32.898000 38.204000,33.007000 37.577000,33.143000 36.955000,33.306000 36.339000,33.496000 35.730000,33.713000 35.130000,33.957000 34.541000,34.226000 33.962000,34.522000 33.395000,34.842000 32.841000,35.188000 32.302000,35.557000 31.778000,35.951000 31.270000,36.367000 30.780000,36.806000 30.308000,37.266000 29.855000,37.747000 29.423000,38.248000 29.012000,38.768000 28.623000,39.307000 28.257000,39.863000 27.914000,40.435000 27.595000,41.023000 27.302000,41.625000 27.034000,42.240000 26.792000,42.867000 26.577000,43.506000 26.390000,44.154000 26.230000,44.811000 26.099000,45.476000 25.996000,46.147000 25.921000,46.823000 25.876000,47.504000 25.860000,48.186000 25.874000,48.870000 25.916000,49.555000 25.989000,50.238000 26.091000,50.918000 26.222000,51.595000 26.383000,52.267000 26.573000,52.933000 26.792000,53.591000 27.039000,54.240000 27.314000,54.879000 27.618000,55.507000 27.948000,56.123000 28.306000,56.725000 28.690000,57.312000 29.099000,57.883000 29.534000,58.437000 29.992000,58.973000 30.475000,59.489000 30.980000,59.986000 31.506000,60.461000 32.054000,60.913000 32.622000,61.343000 33.209000,61.748000 33.814000,62.129000 34.436000,62.484000 35.073000,62.812000 35.726000,63.113000 36.392000,63.387000 37.070000,63.632000 37.759000,63.847000 38.459000,64.034000 39.167000,64.190000 39.882000,64.316000 40.604000,64.412000 41.330000,64.476000 42.060000,64.509000 42.792000,64.511000 43.524000,64.481000 44.256000,64.420000 44.986000,64.327000 45.712000,64.202000 46.434000,64.046000 47.150000,63.859000 47.858000,63.641000 48.557000,63.392000 49.247000,63.113000 49.924000,62.804000 50.589000,62.466000 51.241000,62.098000 51.876000,61.702000 52.496000,61.279000 53.097000,60.828000 53.680000,60.351000 54.242000,59.849000 54.784000,59.322000 55.303000,58.771000 55.799000,58.198000 56.270000,57.602000 56.716000,56.986000 57.137000,56.350000 57.530000,55.696000 57.895000,55.024000 58.231000,54.335000 58.538000,53.632000 58.816000,52.915000 59.062000,52.185000 59.277000,51.445000 59.461000,50.694000 59.612000,49.935000 59.731000,49.169000 59.816000,48.397000 59.869000,47.621000 59.888000,46.842000 59.874000,46.061000 59.826000,45.281000 59.744000,44.502000 59.629000,43.725000 59.480000,42.954000 59.298000,42.188000 59.083000,41.429000 58.835000,40.679000 58.554000,39.940000 58.242000,39.211000 57.898000,38.496000 57.522000,37.795000 57.117000,37.109000 56.681000,36.441000 56.217000,35.791000 55.724000,35.160000 55.203000,34.550000 54.656000,33.963000 54.083000,33.398000 53.486000,32.857000 52.864000,32.342000 52.221000,31.853000 51.555000,31.392000 50.869000,30.959000 50.165000,30.555000 49.442000,30.182000 48.703000,29.839000 47.948000,29.527000 47.179000,29.248000 46.398000,29.002000 45.606000,28.790000 44.804000,28.611000 43.994000,28.467000 43.177000,28.357000 42.355000,28.283000 41.529000,28.244000 40.701000,28.240000 39.872000,28.273000 39.044000,28.340000 38.218000,28.444000 37.397000,28.583000 36.580000,28.758000 35.771000,28.968000 34.970000,29.213000 34.180000,29.492000 33.400000,29.806000 32.634000,30.154000 31.882000,30.534000 31.146000,30.948000 30.428000,31.393000 30.076000,31.628000 29.386000,32.119000 28.716000,32.641000 28.069000,33.192000 27.445000,33.772000 26.846000,34.378000 26.273000,35.011000 25.726000,35.668000 25.207000,36.350000 24.718000,37.054000 24.258000,37.780000 23.829000,38.527000 23.433000,39.292000 23.068000,40.074000 22.899000,40.472000 22.585000,41.278000 22.306000,42.098000 22.062000,42.931000 21.954000,43.352000 21.763000,44.200000 21.682000,44.628000 21.547000,45.489000 21.448000,46.357000 21.387000,47.229000 21.363000,48.104000 21.366000,48.543000 21.399000,49.420000 21.469000,50.296000 21.519000,50.733000 21.646000,51.605000 21.811000,52.472000 22.014000,53.332000 22.253000,54.184000 22.529000,55.026000 22.681000,55.443000 23.012000,56.267000 23.378000,57.078000 23.575000,57.477000 23.993000,58.265000 24.216000,58.652000 24.685000,59.412000 25.188000,60.152000 25.452000,60.514000 26.002000,61.222000 26.583000,61.907000 27.195000,62.567000 27.835000,63.201000 28.502000,63.808000 29.196000,64.386000 29.915000,64.935000 30.659000,65.453000 31.425000,65.940000 31.816000,66.171000 32.613000,66.608000 33.430000,67.011000 34.264000,67.379000 35.115000,67.711000 35.981000,68.007000 36.859000,68.266000 37.750000,68.487000 38.199000,68.583000 38.650000,68.669000 39.558000,68.814000 40.015000,68.871000 40.933000,68.957000 41.855000,69.003000 42.317000,69.011000 42.780000,69.009000 43.705000,68.976000 44.168000,68.944000 45.091000,68.851000 46.010000,68.718000 46.925000,68.545000 47.832000,68.333000 48.731000,68.082000 49.176000,67.942000 50.059000,67.633000 50.495000,67.464000 50.929000,67.285000 51.784000,66.900000 52.205000,66.694000 53.036000,66.254000 53.444000,66.020000 54.246000,65.526000 54.639000,65.266000 55.027000,64.997000 55.785000,64.435000 56.520000,63.840000 56.878000,63.530000 57.574000,62.887000 58.243000,62.214000 58.884000,61.512000 59.494000,60.782000 59.788000,60.406000 60.351000,59.637000 60.620000,59.243000 61.134000,58.437000 61.378000,58.026000 61.613000,57.609000 62.057000,56.759000 62.464000,55.891000 62.654000,55.449000 62.834000,55.004000 63.005000,54.554000 63.318000,53.644000 63.460000,53.183000 63.592000,52.719000 63.714000,52.252000 63.826000,51.782000 63.928000,51.310000 64.020000,50.835000 64.173000,49.879000 64.234000,49.399000 64.326000,48.433000 64.376000,47.463000 64.384000,46.490000 64.350000,45.516000 64.318000,45.030000 64.275000,44.544000 64.221000,44.058000 64.157000,43.574000 64.083000,43.091000 63.998000,42.609000 63.903000,42.129000 63.681000,41.174000 63.555000,40.700000 63.419000,40.229000 63.272000,39.760000 63.115000,39.294000 62.772000,38.372000 62.585000,37.916000 62.388000,37.464000 61.965000,36.573000 61.504000,35.699000 61.005000,34.845000 60.741000,34.426000 60.187000,33.604000 59.597000,32.806000 59.289000,32.416000 58.973000,32.033000 58.648000,31.656000 58.315000,31.286000 57.624000,30.567000 56.903000,29.878000 56.151000,29.220000 55.764000,28.902000 55.371000,28.593000 54.971000,28.292000 54.150000,27.716000 53.304000,27.176000 52.873000,26.919000 52.435000,26.671000 51.992000,26.432000 51.544000,26.203000 50.632000,25.774000 50.169000,25.574000 49.702000,25.384000 48.754000,25.033000 48.274000,24.873000 47.304000,24.584000 46.814000,24.455000 46.321000,24.337000 45.825000,24.229000 45.327000,24.131000 44.826000,24.045000 44.323000,23.969000 43.819000,23.904000 43.313000,23.849000 42.297000,23.773000 41.277000,23.741000 40.766000,23.741000 39.744000,23.775000 39.234000,23.808000 38.724000,23.852000 38.214000,23.907000 37.706000,23.974000 37.199000,24.051000 36.693000,24.139000 36.189000,24.238000 35.687000,24.348000 35.187000,24.469000 34.689000,24.600000 34.195000,24.742000 33.702000,24.895000 33.213000,25.059000 32.728000,25.233000 32.246000,25.418000 31.767000,25.613000 30.823000,26.034000 30.357000,26.261000 29.896000,26.497000 29.440000,26.743000 28.989000,26.999000 28.543000,27.265000 28.103000,27.540000 27.669000,27.825000 27.241000,28.120000 26.818000,28.424000 26.402000,28.737000 25.993000,29.059000 25.590000,29.390000 25.195000,29.730000 24.806000,30.079000 24.425000,30.436000 24.052000,30.801000 23.686000,31.175000 23.328000,31.556000 22.978000,31.946000 22.636000,32.343000 22.303000,32.747000 21.978000,33.159000 21.662000,33.578000 21.355000,34.005000 21.057000,34.437000 20.768000,34.877000 20.488000,35.323000 20.218000,35.775000 19.958000,36.233000 19.707000,36.696000 19.466000,37.166000 19.235000,37.640000 19.015000,38.120000 18.804000,38.605000 18.604000,39.094000 18.414000,39.588000 18.235000,40.087000 18.067000,40.589000 17.909000,41.095000 17.762000,41.605000 17.626000,42.118000 17.501000,42.634000 17.387000,43.153000 17.284000,43.675000 17.192000,44.199000 17.112000,44.726000 17.042000,45.254000 16.984000,45.784000 16.938000,46.315000 16.903000,46.848000 16.879000,47.382000 16.867000,47.916000 16.866000,48.451000 16.877000,48.986000 16.899000,49.521000 16.933000,50.055000 16.979000,50.590000 17.035000,51.123000 17.104000,51.655000 17.184000,52.187000 17.275000,52.716000 17.377000,53.244000 17.492000,53.770000 17.617000,54.294000 17.754000,54.815000 17.902000,55.333000 18.061000,55.848000 18.231000,56.361000 18.413000,56.869000 18.605000,57.374000 18.808000,57.875000 19.023000,58.372000 19.248000,58.865000 19.483000,59.352000 19.729000,59.835000 19.986000,60.313000 20.253000,60.786000 20.530000,61.253000 20.818000,61.714000 21.115000,62.169000 21.423000,62.618000 21.740000,63.060000 22.067000,63.496000 22.403000,63.925000 22.749000,64.347000 23.104000,64.761000 23.467000,65.168000 23.840000,65.568000 24.222000,65.959000 24.612000,66.343000 25.010000,66.718000 25.417000,67.085000 25.832000,67.443000 26.254000,67.792000 26.684000,68.133000 27.122000,68.464000 27.567000,68.786000 28.019000,69.099000 28.478000,69.402000 28.944000,69.695000 29.416000,69.979000 29.894000,70.252000 30.379000,70.515000 30.869000,70.768000 31.365000,71.010000 31.866000,71.242000 32.373000,71.463000 32.884000,71.673000 33.400000,71.873000 33.921000,72.061000 34.446000,72.238000 34.975000,72.404000 35.507000,72.559000 36.043000,72.702000 36.583000,72.834000 37.125000,72.954000 37.670000,73.063000 38.218000,73.160000 38.768000,73.245000 39.320000,73.318000 39.874000,73.380000 40.429000,73.429000 40.986000,73.467000 41.544000,73.493000 42.102000,73.507000 42.661000,73.509000 43.220000,73.498000 43.779000,73.476000 44.338000,73.442000 44.896000,73.396000 45.454000,73.337000 46.010000,73.267000 46.565000,73.185000 47.119000,73.091000 47.671000,72.984000 48.220000,72.866000 48.768000,72.736000 49.312000,72.594000 49.854000,72.441000 50.393000,72.276000 50.928000,72.099000 51.460000,71.910000 51.988000,71.710000 52.512000,71.499000 53.031000,71.276000 53.546000,71.042000 54.056000,70.797000 54.561000,70.541000 55.061000,70.274000 55.554000,69.996000 56.043000,69.707000 56.525000,69.408000 57.001000,69.098000 57.470000,68.778000 57.933000,68.448000 58.389000,68.108000 58.837000,67.757000 59.278000,67.397000 59.712000,67.028000 60.138000,66.648000 60.556000,66.260000 60.965000,65.863000 61.366000,65.456000 61.759000,65.041000 62.143000,64.617000 62.518000,64.185000 62.883000,63.744000 63.240000,63.296000 63.586000,62.840000 63.924000,62.376000 64.251000,61.905000 64.568000,61.426000 64.875000,60.941000 65.172000,60.449000 65.458000,59.950000 65.734000,59.445000 65.999000,58.933000 66.253000,58.416000 66.496000,57.894000 66.727000,57.366000 66.948000,56.832000 67.157000,56.294000 67.355000,55.751000 67.541000,55.204000 67.715000,54.653000 67.877000,54.097000 68.028000,53.538000 68.167000,52.975000 68.293000,52.410000 68.408000,51.841000 68.510000,51.270000 68.600000,50.696000 68.678000,50.120000 68.743000,49.543000 68.796000,48.963000 68.837000,48.383000 68.865000,47.801000 68.881000,47.219000 68.884000,46.636000 68.874000,46.053000 68.852000,45.469000 68.818000,44.886000 68.771000,44.304000 68.711000,43.722000 68.639000,43.142000 68.554000,42.563000 68.457000,41.985000 68.347000,41.409000 68.225000,40.836000 68.091000,40.265000 67.944000,39.697000 67.785000,39.131000 67.614000,38.569000 67.431000,38.010000 67.236000,37.456000 67.028000,36.905000 66.809000,36.358000 66.578000,35.816000 66.335000,35.279000 66.080000,34.746000 65.814000,34.220000 65.537000,33.698000 65.248000,33.183000 64.948000,32.673000 64.637000,32.170000 64.316000,31.673000 63.983000,31.183000 63.640000,30.700000 63.286000,30.224000 62.922000,29.756000 62.547000,29.295000 62.163000,28.842000 61.769000,28.398000 61.365000,27.961000 60.951000,27.534000 60.529000,27.115000 60.097000,26.705000 59.656000,26.304000 59.206000,25.912000 58.748000,25.530000 58.282000,25.158000 57.807000,24.795000 57.324000,24.443000 56.834000,24.101000 56.336000,23.769000 55.831000,23.448000 55.319000,23.138000 54.800000,22.839000 54.274000,22.551000 53.742000,22.274000 53.204000,22.008000 52.660000,21.754000 52.110000,21.511000 51.555000,21.280000 50.995000,21.061000 50.430000,20.854000 49.860000,20.659000 49.286000,20.476000 48.708000,20.306000 48.126000,20.148000 47.540000,20.002000 46.951000,19.869000 46.359000,19.748000 45.764000,19.641000 45.167000,19.546000 44.568000,19.463000 43.966000,19.394000 43.363000,19.338000 42.759000,19.294000 42.153000,19.263000 41.546000,19.246000 40.939000,19.241000 40.332000,19.250000 39.724000,19.272000 39.117000,19.306000 38.511000,19.354000 37.905000,19.415000 37.300000,19.489000 36.697000,19.576000 36.096000,19.675000 35.496000,19.788000 34.899000,19.914000 34.304000,20.053000 33.712000,20.204000 33.123000,20.368000 32.538000,20.545000 31.956000,20.735000 31.378000,20.937000 30.804000,21.152000 30.234000,21.379000 29.669000,21.618000 29.110000,21.870000 28.555000,22.133000 28.006000,22.409000 27.463000,22.697000 26.926000,22.996000 26.395000,23.307000 25.870000,23.630000 25.352000,23.963000 24.842000,24.309000 24.338000,24.665000 23.842000,25.032000 23.354000,25.410000 22.874000,25.798000 22.402000,26.197000 21.938000,26.606000 21.484000,27.026000 21.038000,27.455000 20.601000,27.894000 20.173000,28.342000 19.755000,28.800000 19.346000,29.267000 18.948000,29.743000 18.560000,30.227000 18.181000,30.720000 17.814000,31.222000 17.457000,31.731000 17.111000,32.248000 16.776000,32.773000 16.452000,33.305000 16.139000,33.844000 15.838000,34.391000 15.549000,34.943000 15.271000,35.502000 15.006000,36.068000 14.752000,36.639000 14.511000,37.216000 14.282000,37.798000 14.065000,38.385000 13.861000,38.977000 13.670000,39.574000 13.491000,40.175000 13.325000,40.780000 13.172000,41.388000 13.033000,42.001000 12.906000,42.616000 12.793000,43.234000 12.692000,43.855000 12.606000,44.478000 12.532000,45.104000 12.472000,45.731000 12.425000,46.359000 12.392000,46.989000 12.373000,47.619000 12.367000,48.251000 12.374000,48.882000 12.395000,49.514000 12.430000,50.145000 12.478000,50.776000 12.540000,51.405000 12.615000,52.034000 12.704000,52.661000 12.807000,53.287000 12.923000,53.910000 13.052000,54.532000 13.195000,55.150000 13.351000,55.766000 13.520000,56.378000 13.703000,56.987000 13.899000,57.593000 14.107000,58.194000 14.329000,58.791000 14.564000,59.383000 14.811000,59.971000 15.072000,60.553000 15.344000,61.130000 15.630000,61.701000 15.927000,62.267000 16.237000,62.826000 16.559000,63.378000 16.893000,63.924000 17.239000,64.462000 17.596000,64.994000 17.965000,65.518000 18.345000,66.034000 18.737000,66.542000 19.140000,67.042000 19.553000,67.533000 19.977000,68.016000 20.412000,68.489000 20.857000,68.954000 21.312000,69.409000 21.776000,69.854000 22.251000,70.289000 22.735000,70.715000 23.229000,71.130000 23.731000,71.534000 24.242000,71.928000 24.762000,72.311000 25.290000,72.683000 25.827000,73.044000 26.371000,73.393000 26.923000,73.731000 27.483000,74.057000 28.049000,74.371000 28.623000,74.672000 29.203000,74.962000 29.789000,75.239000 30.382000,75.504000 30.980000,75.756000 31.584000,75.995000 32.194000,76.222000 32.808000,76.435000 33.427000,76.635000 34.051000,76.822000 34.679000,76.995000 35.311000,77.155000 35.946000,77.302000 36.585000,77.435000 37.226000,77.554000 37.871000,77.660000 38.518000,77.751000 39.167000,77.829000 39.817000,77.893000 40.470000,77.943000 41.124000,77.979000 41.778000,78.000000 42.433000,78.008000 43.089000,78.002000 43.745000,77.981000 44.400000,77.947000 45.055000,77.898000 45.709000,77.835000 46.362000,77.759000 47.013000,77.668000 47.663000,77.563000 48.310000,77.444000 48.955000,77.311000 49.598000,77.164000 50.237000,77.004000 50.873000,76.829000 51.506000,76.641000 52.134000,76.440000 52.759000,76.224000 53.379000,75.996000 53.994000,75.753000 54.605000,75.498000 55.210000,75.229000 55.809000,74.948000 56.402000,74.653000 56.990000,74.345000 57.571000,74.025000 58.145000,73.692000 58.712000,73.347000 59.272000,72.990000 59.824000,72.620000 60.368000,72.238000 60.905000,71.845000 61.433000,71.440000 61.952000,71.023000 62.463000,70.596000 62.965000,70.157000 63.457000,69.707000 63.940000,69.246000 64.413000,68.776000 64.876000,68.294000 65.329000,67.803000 65.771000,67.302000 66.203000,66.791000 66.624000,66.271000 67.034000,65.741000 67.432000,65.203000 67.819000,64.656000 68.195000,64.100000 68.558000,63.536000 68.910000,62.964000 69.249000,62.385000 69.576000,61.798000 69.891000,61.204000 70.192000,60.603000 70.481000,59.995000 70.757000,59.381000 71.020000,58.761000 71.270000,58.135000 71.506000,57.504000 71.728000,56.867000 71.937000,56.226000 72.133000,55.579000 72.314000,54.929000 72.482000,54.274000 72.635000,53.616000 72.774000,52.954000 72.900000,52.288000 73.010000,51.621000 73.107000,50.950000 73.189000,50.277000 73.257000,49.602000 73.310000,48.926000 73.349000,48.248000 73.373000,47.570000 73.383000,46.890000 73.378000,46.211000 73.358000,45.531000 73.324000,44.851000 73.275000,44.172000 73.211000,43.494000 73.133000,42.817000 73.041000,42.142000 72.934000,41.468000 72.812000,40.797000 72.676000,40.128000 72.525000,39.462000 72.360000,38.798000 72.181000,38.139000 71.988000,37.482000 71.780000,36.830000 71.558000,36.182000 71.323000,35.539000 71.073000,34.901000 70.810000,34.268000 70.533000,33.640000 70.242000,33.018000 69.938000,32.402000 69.621000,31.793000 69.291000,31.190000 68.947000,30.595000 68.591000,30.006000 68.222000,29.425000 67.840000,28.852000 67.446000,28.287000 67.039000,27.730000 66.621000,27.182000 66.191000,26.642000 65.749000,26.112000 65.295000,25.591000 64.830000,25.080000 64.354000,24.579000 63.867000,24.087000 63.370000,23.606000 62.862000,23.136000 62.344000,22.676000 61.815000,22.228000 61.277000,21.791000 60.730000,21.365000 60.173000,20.951000 59.607000,20.548000 59.033000,20.158000 58.449000,19.780000 57.858000,19.415000 57.258000,19.062000 56.651000,18.722000 56.037000,18.394000 55.415000,18.080000 54.786000,17.780000 54.151000,17.492000 53.509000,17.219000 52.861000,16.959000 52.208000,16.713000 51.549000,16.480000 50.885000,16.262000 50.216000,16.059000 49.543000,15.869000 48.865000,15.694000 48.184000,15.534000 47.498000,15.388000 46.810000,15.256000 46.118000,15.140000 45.424000,15.038000 44.728000,14.952000 44.029000,14.880000 43.329000,14.823000 42.627000,14.781000 41.925000,14.755000 41.221000,14.743000 40.517000,14.747000 39.813000,14.765000 39.110000,14.799000 38.406000,14.848000 37.704000,14.912000 37.003000,14.991000 36.304000,15.085000 35.606000,15.195000 34.910000,15.319000 34.217000,15.458000 33.527000,15.613000 32.840000,15.782000 32.157000,15.966000 31.477000,16.164000 30.801000,16.378000 30.130000,16.606000 29.464000,16.848000 28.802000,17.105000 28.146000,17.376000 27.496000,17.661000 26.852000,17.960000 26.214000,18.273000 25.582000,18.600000 24.957000,18.941000 24.340000,19.295000 23.730000,19.662000 23.128000,20.043000 22.533000,20.437000 21.948000,20.843000 21.370000,21.262000 20.802000,21.694000 20.243000,22.138000 19.693000,22.594000 19.153000,23.062000 18.622000,23.542000 18.102000,24.034000 17.593000,24.536000 17.094000,25.050000 16.606000,25.574000 16.129000,26.109000 15.664000,26.655000 15.210000,27.211000 14.768000,27.776000 14.338000,28.351000 13.920000,28.936000 13.515000,29.529000 13.122000,30.132000 12.743000,30.743000 12.376000,31.362000 12.023000,31.990000 11.683000,32.625000 11.356000,33.267000 11.044000,33.917000 10.745000,34.574000 10.460000,35.237000 10.190000,35.906000 9.933000,36.581000 9.692000,37.263000 9.464000,37.949000 9.252000,38.640000 9.054000,39.337000 8.871000,40.037000 8.704000,40.742000 8.551000,41.450000 8.414000,42.162000 8.291000,42.877000 8.185000,43.595000 8.093000,44.315000 8.017000,45.037000 7.957000,45.761000 7.912000,46.487000 7.883000,47.214000 7.869000,47.941000 7.871000,48.669000 7.888000,49.397000 7.922000,50.125000 7.970000,50.853000 8.035000,51.579000 8.115000,52.304000 8.211000,53.028000 8.322000,53.750000 8.449000,54.469000 8.591000,55.186000 8.749000,55.900000 8.922000,56.611000 9.111000,57.318000 9.314000,58.022000 9.533000,58.721000 9.767000,59.415000 10.016000,60.105000 10.280000,60.790000 10.559000,61.469000 10.852000,62.142000 11.160000,62.809000 11.482000,63.469000 11.818000,64.123000 12.169000,64.770000 12.533000,65.409000 12.912000,66.040000 13.304000,66.664000 13.709000,67.279000 14.128000,67.886000 14.560000,68.484000 15.005000,69.072000 15.463000,69.652000 15.933000,70.221000 16.415000,70.781000 16.910000,71.330000 17.417000,71.869000 17.935000,72.397000 18.465000,72.914000 19.006000,73.420000 19.557000,73.914000 20.120000,74.396000 20.693000,74.867000 21.277000,75.325000 21.870000,75.771000 22.473000,76.204000 23.086000,76.624000 23.707000,77.031000 24.338000,77.425000 24.977000,77.806000 25.625000,78.173000 26.280000,78.526000 26.943000,78.864000 27.614000,79.189000 28.292000,79.500000 28.976000,79.796000 29.667000,80.077000 30.365000,80.343000 31.068000,80.595000 31.777000,80.831000 32.490000,81.053000 33.209000,81.259000 33.933000,81.449000 34.660000,81.624000 35.392000,81.784000 36.127000,81.928000 36.866000,82.056000 37.607000,82.168000 38.351000,82.264000 39.097000,82.344000 39.845000,82.409000 40.595000,82.457000 41.345000,82.489000 42.097000,82.505000 42.849000,82.505000 43.601000,82.489000 44.353000,82.456000 45.105000,82.408000 45.855000,82.343000 46.605000,82.262000 47.353000,82.165000 48.098000,82.052000 48.842000,81.922000 49.583000,81.777000 50.321000,81.616000 51.056000,81.439000 51.787000,81.246000 52.514000,81.037000 53.236000,80.813000 53.954000,80.573000 54.667000,80.318000 55.375000,80.047000 56.077000,79.761000 56.773000,79.460000 57.463000,79.143000 58.146000,78.812000 58.822000,78.467000 59.490000,78.106000 60.152000,77.731000 60.805000,77.342000 61.450000,76.939000 62.086000,76.522000 62.714000,76.091000 63.332000,75.646000 63.941000,75.188000 64.541000,74.717000 65.130000,74.233000 65.709000,73.736000 66.277000,73.227000 66.835000,72.705000 67.382000,72.171000 67.917000,71.626000 68.440000,71.068000 68.952000,70.500000 69.452000,69.920000 69.939000,69.329000 70.413000,68.728000 70.875000,68.117000 71.324000,67.495000 71.759000,66.864000 72.181000,66.223000 72.590000,65.573000 72.984000,64.914000 73.364000,64.246000 73.730000,63.571000 74.082000,62.887000 74.419000,62.195000 74.741000,61.496000 75.048000,60.790000 75.341000,60.078000 75.617000,59.359000 75.879000,58.633000 76.125000,57.902000 76.355000,57.166000 76.570000,56.424000 76.768000,55.678000 76.951000,54.927000 77.117000,54.173000 77.268000,53.414000 77.402000,52.652000 77.519000,51.888000 77.621000,51.120000 77.705000,50.350000 77.774000,49.578000 77.825000,48.805000 77.860000,48.030000 77.879000,47.254000 77.881000,46.478000 77.866000,45.702000 77.834000,44.926000 77.786000,44.150000 77.721000,43.375000 77.639000,42.602000 77.541000,41.830000 77.426000,41.060000 77.295000,40.292000 77.147000,39.527000 76.982000,38.765000 76.801000,38.006000 76.604000,37.252000 76.391000,36.501000 76.161000,35.755000 75.915000,35.013000 75.654000,34.277000 75.376000,33.546000 75.083000,32.821000 74.774000,32.102000 74.449000,31.390000 74.110000,30.684000 73.754000,29.986000 73.384000,29.295000 72.999000,28.612000 72.599000,27.937000 72.185000,27.270000 71.756000,26.613000 71.313000,25.964000 70.856000,25.325000 70.385000,24.695000 69.901000,24.076000 69.403000,23.467000 68.892000,22.868000 68.368000,22.280000 67.831000,21.704000 67.282000,21.139000 66.720000,20.585000 66.147000,20.044000 65.562000,19.514000 64.965000,18.998000 64.357000,18.494000 63.738000,18.003000 63.109000,17.525000 62.469000,17.060000 61.819000,16.609000 61.159000,16.172000 60.489000,15.750000 59.811000,15.341000 59.123000,14.947000 58.427000,14.568000 57.723000,14.204000 57.010000,13.854000 56.290000,13.520000 55.563000,13.201000 54.829000,12.898000 54.088000,12.611000 53.341000,12.340000 52.588000,12.084000 51.829000,11.845000 51.065000,11.622000 50.296000,11.415000 49.522000,11.225000 48.744000,11.051000 47.962000,10.894000 47.177000,10.754000 46.389000,10.631000 45.598000,10.524000 44.804000,10.435000 44.008000,10.362000 43.211000,10.307000 42.412000,10.269000 41.612000,10.248000 40.812000,10.244000 40.012000,10.257000 39.211000,10.288000 38.411000,10.336000 37.612000,10.401000 36.815000,10.483000 36.019000,10.582000 35.224000,10.699000 34.433000,10.832000 33.644000,10.983000 32.858000,11.150000 32.075000,11.335000 31.297000,11.536000 30.522000,11.754000 29.752000,11.989000 28.987000,12.240000 28.227000,12.508000 27.473000,12.792000 26.725000,13.093000 25.983000,13.409000 25.248000,13.742000 24.520000,14.091000 23.799000,14.455000 23.086000,14.834000 22.381000,15.230000 21.684000,15.640000 20.996000,16.065000 20.317000,16.506000 19.648000,16.960000 18.988000,17.430000 18.338000,17.914000 17.698000,18.411000 17.069000,18.923000 16.451000,19.448000 15.843000,19.987000 15.248000,20.538000 14.664000,21.103000 14.092000,21.680000 13.533000,22.270000 12.986000,22.871000 12.452000,23.485000 11.930000,24.110000 11.423000,24.747000 10.929000,25.394000 10.448000,26.052000 9.982000,26.721000 9.530000,27.400000 9.093000,28.089000 8.670000,28.787000 8.262000,29.494000 7.870000,30.210000 7.492000,30.935000 7.131000,31.668000 6.785000,32.409000 6.454000,33.158000 6.140000,33.913000 5.842000,34.676000 5.560000,35.445000 5.295000,36.221000 5.047000,37.002000 4.815000,37.788000 4.600000,38.580000 4.402000,39.377000 4.221000,40.178000 4.057000,40.983000 3.911000,41.791000 3.782000,42.603000 3.670000,43.418000 3.576000,44.235000 3.499000,45.055000 3.440000,45.876000 3.399000,46.699000 3.375000,47.523000 3.369000,48.347000 3.380000,49.172000 3.410000,49.996000 3.457000,50.820000 3.522000,51.643000 3.604000,52.465000 3.705000,53.286000 3.822000,54.104000 3.958000,54.920000 4.111000,55.733000 4.281000,56.543000 4.469000,57.349000 4.675000,58.152000 4.897000,58.950000 5.137000,59.744000 5.394000,60.532000 5.668000,61.315000 5.959000,62.093000 6.266000,62.864000 6.590000,63.629000 6.931000,64.387000 7.288000,65.138000 7.661000,65.881000 8.050000,66.616000 8.455000,67.344000 8.876000,68.062000 9.312000,68.772000 9.764000,69.472000 10.230000,70.163000 10.712000,70.844000 11.208000,71.514000 11.719000,72.174000 12.244000,72.824000 12.784000,73.462000 13.336000,74.088000 13.903000,74.703000 14.483000,75.306000 15.076000,75.896000 15.681000,76.474000 16.299000,77.038000 16.930000,77.590000 17.572000,78.128000 18.226000,78.653000 18.891000,79.163000 19.568000,79.659000 20.255000,80.141000 20.953000,80.608000 21.661000,81.060000 22.378000,81.497000 23.106000,81.919000 23.842000,82.325000 24.587000,82.715000 25.341000,83.090000 26.103000,83.448000 26.872000,83.790000 27.650000,84.115000 28.434000,84.424000 29.225000,84.716000 30.022000,84.991000 30.826000,85.249000 31.635000,85.490000 32.450000,85.713000 33.269000,85.919000 34.093000,86.108000 34.921000,86.278000 35.753000,86.431000 36.588000,86.566000 37.427000,86.683000 38.268000,86.782000 39.111000,86.864000 39.956000,86.926000 40.803000,86.971000 41.651000,86.998000 42.499000,87.006000 43.348000,86.996000 44.197000,86.968000 45.045000,86.922000 45.892000,86.858000 46.739000,86.775000 47.583000,86.674000 48.425000,86.555000 49.266000,86.417000 50.103000,86.262000 50.937000,86.089000 51.767000,85.897000 52.594000,85.688000 53.416000,85.461000 54.233000,85.217000 55.045000,84.954000 55.852000,84.675000 56.653000,84.378000 57.447000,84.063000 58.235000,83.732000 59.016000,83.383000 59.789000,83.018000 60.555000,82.636000 61.313000,82.237000 62.062000,81.822000 62.803000,81.391000 63.534000,80.944000 64.256000,80.482000 64.968000,80.003000 65.670000,79.510000 66.361000,79.001000 67.041000,78.477000 67.711000,77.938000 68.369000,77.385000 69.015000,76.818000 69.649000,76.237000 70.270000,75.642000 70.879000,75.034000 71.475000,74.412000 72.058000,73.778000 72.627000,73.131000 73.182000,72.471000 73.723000,71.800000 74.250000,71.117000 74.763000,70.422000 75.260000,69.716000 75.742000,69.000000 76.209000,68.273000 76.661000,67.536000 77.096000,66.789000 77.516000,66.032000 77.920000,65.267000 78.307000,64.493000 78.677000,63.710000 79.031000,62.919000 79.368000,62.121000 79.688000,61.315000 79.990000,60.502000 80.275000,59.682000 80.543000,58.856000 80.793000,58.025000 81.024000,57.188000 81.238000,56.345000 81.434000,55.498000 81.612000,54.647000 81.772000,53.792000 81.913000,52.933000 82.035000,52.071000 82.140000,51.206000 82.225000,50.339000 82.292000,49.470000 82.341000,48.600000 82.370000,47.728000 82.381000,46.855000 82.373000,45.982000 82.347000,45.110000 82.301000,44.237000 82.237000,43.365000 82.154000,42.495000 82.053000,41.626000 81.932000,40.760000 81.794000,39.896000 81.636000,39.034000 81.460000,38.176000 81.266000,37.322000 81.053000,36.471000 80.822000,35.626000 80.572000,34.784000 80.305000,33.949000 80.019000,33.118000 79.716000,32.294000 79.395000,31.477000 79.056000,30.666000 78.700000,29.862000 78.326000,29.065000 77.935000,28.277000 77.528000,27.497000 77.103000,26.725000 76.662000,25.963000 76.204000,25.210000 75.731000,24.467000 75.241000,23.733000 74.735000,23.010000 74.214000,22.298000 73.677000,21.597000 73.125000,20.908000 72.558000,20.230000 71.977000,19.564000 71.381000,18.911000 70.771000,18.270000 70.147000,17.643000 69.510000,17.028000 68.859000,16.428000 68.196000,15.841000 67.520000,15.268000 66.831000,14.710000 66.130000,14.167000 65.417000,13.638000 64.693000,13.125000 63.958000,12.627000 63.212000,12.145000 62.456000,11.679000 61.689000,11.229000 60.913000,10.796000 60.127000,10.379000 59.332000,9.979000 58.529000,9.596000 57.717000,9.231000 56.897000,8.882000 56.069000,8.551000 55.235000,8.238000 54.393000,7.943000 53.545000,7.666000 52.691000,7.407000 51.831000,7.166000 50.966000,6.944000 50.097000,6.741000 49.222000,6.556000 48.344000,6.389000 47.461000,6.242000 46.576000,6.114000 45.688000,6.004000 44.797000,5.914000 43.904000,5.843000 43.009000,5.791000 42.113000,5.758000 41.217000,5.744000 40.320000,5.750000 39.423000,5.775000 38.526000,5.819000 37.630000,5.883000 36.736000,5.966000 35.843000,6.068000 34.952000,6.189000 34.064000,6.329000 33.178000,6.489000 32.296000,6.667000 31.417000,6.865000 30.543000,7.081000 29.673000,7.317000 28.809000,7.571000 27.949000,7.843000 27.095000,8.134000 26.248000,8.444000 25.407000,8.771000 24.572000,9.117000 23.746000,9.481000 22.926000,9.863000 22.115000,10.262000 21.313000,10.679000 20.519000,11.113000 19.735000,11.564000 18.960000,12.032000 18.195000,12.517000 17.440000,13.018000 16.696000,13.536000 15.963000,14.070000 15.242000,14.619000 14.532000,15.184000 13.834000,15.764000 13.148000,16.360000 12.476000,16.970000 11.816000,17.595000 11.170000,18.234000 10.537000,18.887000 9.918000,19.554000 9.313000,20.234000 8.723000,20.927000 8.148000,21.633000 7.588000,22.351000 7.043000,23.082000 6.514000,23.824000 6.001000,24.578000 5.504000,25.343000 5.023000,26.119000 4.559000,26.905000 4.112000,27.701000 3.682000,28.507000 3.269000,29.322000 2.873000,30.147000 2.495000,30.979000 2.135000,31.820000 1.793000,32.669000 1.469000,33.526000 1.164000,34.389000 0.877000,35.259000 0.609000,36.136000 0.359000,37.018000 0.129000,37.906000 -0.083000,38.799000 -0.275000,39.696000 -0.448000,40.598000 -0.602000,41.504000 -0.736000,42.413000 -0.851000,43.325000 -0.946000,44.239000 -1.021000,45.156000 -1.077000,46.074000 -1.113000,46.994000 -1.130000,47.915000 -1.126000,48.836000 -1.103000,49.757000 -1.060000,50.678000 -0.997000,51.598000 -0.915000,52.517000 -0.812000,53.434000 -0.690000,54.349000 -0.549000,55.262000 -0.387000,56.171000 -0.206000,57.078000 -0.006000,57.980000 0.214000,58.878000 0.453000,59.772000 0.712000,60.661000 0.989000,61.544000 1.286000,62.421000 1.601000,63.292000 1.935000,64.157000 2.288000,65.014000 2.659000,65.864000 3.049000,66.706000 3.457000,67.540000 3.882000,68.365000 4.326000,69.181000 4.787000,69.988000 5.265000,70.785000 5.761000,71.571000 6.274000,72.347000 6.803000,73.113000 7.349000,73.866000 7.911000,74.609000 8.489000,75.339000 9.083000,76.057000 9.692000,76.762000 10.317000,77.454000 10.957000,78.133000 11.611000,78.799000 12.279000,79.450000 12.962000,80.087000 13.659000,80.709000 14.368000,81.317000 15.092000,81.909000 15.827000,82.486000 16.576000,83.047000 17.336000,83.592000 18.109000,84.121000 18.892000,84.634000 19.687000,85.129000 20.493000,85.608000 21.309000,86.069000 22.135000,86.513000 22.971000,86.939000 23.816000,87.347000 24.669000,87.737000 25.532000,88.109000 26.402000,88.462000 27.280000,88.797000 28.165000,89.113000 29.058000,89.409000 29.956000,89.687000 30.861000,89.946000 31.772000,90.185000 32.687000,90.404000 33.608000,90.604000 34.533000,90.784000 35.462000,90.944000 36.394000,91.084000 37.330000,91.205000 38.268000,91.305000 39.209000,91.385000 40.151000,91.445000 41.095000,91.484000 42.040000,91.504000 42.985000,91.503000 43.930000,91.481000 44.875000,91.440000 45.820000,91.378000 46.763000,91.296000 47.704000,91.193000 48.643000,91.070000 49.580000,90.927000 50.514000,90.764000 51.444000,90.581000 52.371000,90.378000 53.293000,90.155000 54.211000,89.912000 55.123000,89.649000 56.030000,89.367000 56.931000,89.065000 57.826000,88.744000 58.714000,88.403000 59.595000,88.044000 60.468000,87.665000 61.333000,87.268000 62.189000,86.852000 63.037000,86.417000 63.875000,85.964000 64.704000,85.493000 65.523000,85.005000 66.331000,84.498000 67.129000,83.975000 67.915000,83.434000 68.690000,82.876000 69.453000,82.301000 70.204000,81.710000 70.942000,81.103000 71.667000,80.480000 72.379000,79.841000 73.077000,79.186000 73.762000,78.517000 74.432000,77.833000 75.087000,77.134000 75.727000,76.422000 76.352000,75.695000 76.962000,74.955000 77.556000,74.202000 78.134000,73.436000 78.695000,72.657000 79.239000,71.866000 79.767000,71.064000 80.278000,70.250000 80.771000,69.425000 81.246000,68.589000 81.703000,67.743000 82.143000,66.887000 82.564000,66.021000 82.966000,65.147000 83.350000,64.263000 83.715000,63.372000 84.060000,62.472000 84.387000,61.565000 84.694000,60.651000 84.981000,59.730000 85.248000,58.802000 85.496000,57.869000 85.724000,56.931000 85.931000,55.987000 86.118000,55.039000 86.285000,54.087000 86.432000,53.131000 86.558000,52.172000 86.663000,51.210000 86.748000,50.245000 86.811000,49.279000 86.855000,48.311000 86.877000,47.342000 86.879000,46.373000 86.859000,45.403000 86.819000,44.434000 86.758000,43.466000 86.677000,42.498000 86.574000,41.533000 86.451000,40.569000 86.307000,39.608000 86.142000,38.650000 85.957000,37.696000 85.751000,36.745000 85.525000,35.799000 85.278000,34.857000 85.012000,33.921000 84.725000,32.990000 84.417000,32.065000 84.091000,31.147000 83.744000,30.236000 83.378000,29.332000 82.992000,28.435000 82.587000,27.548000 82.162000,26.668000 81.719000,25.798000 81.257000,24.937000 80.777000,24.086000 80.278000,23.245000 79.761000,22.415000 79.227000,21.596000 78.674000,20.788000 78.104000,19.992000 77.517000,19.208000 76.913000,18.437000 76.293000,17.678000 75.656000,16.933000 75.003000,16.201000 74.334000,15.484000 73.650000,14.780000 72.950000,14.092000 72.236000,13.418000 71.507000,12.759000 70.764000,12.117000 70.007000,11.490000 69.236000,10.879000 68.452000,10.285000 67.656000,9.707000 66.847000,9.147000 66.026000,8.603000 65.193000,8.078000 64.348000,7.570000 63.493000,7.081000 62.627000,6.609000 61.751000,6.157000 60.865000,5.723000 59.969000,5.308000 59.065000,4.912000 58.152000,4.536000 57.230000,4.179000 56.301000,3.842000 55.365000,3.525000 54.422000,3.228000 53.472000,2.951000 52.516000,2.694000 51.555000,2.459000 50.589000,2.243000 49.617000,2.049000 48.642000,1.875000 47.662000,1.722000 46.680000,1.591000 45.694000,1.480000 44.706000,1.391000 43.716000,1.322000 42.724000,1.276000 41.731000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 41.754000,-0.250000 42.779000,-0.223000 43.803000,-0.175000 44.825000,-0.105000 45.845000,-0.012000 46.863000,0.102000 47.878000,0.238000 48.889000,0.396000 49.896000,0.575000 50.899000,0.776000 51.897000,0.998000 52.890000,1.242000 53.876000,1.506000 54.857000,1.792000 55.831000,2.099000 56.798000,2.426000 57.757000,2.774000 58.708000,3.143000 59.651000,3.531000 60.585000,3.940000 61.510000,4.369000 62.425000,4.817000 63.330000,5.284000 64.224000,5.771000 65.107000,6.276000 65.979000,6.801000 66.839000,7.343000 67.688000,7.904000 68.523000,8.483000 69.346000,9.080000 70.155000,9.693000 70.951000,10.324000 71.733000,10.972000 72.500000,11.636000 73.253000,12.316000 73.991000,13.012000 74.713000,13.723000 75.420000,14.449000 76.111000,15.190000 76.785000,15.946000 77.443000,16.716000 78.084000,17.499000 78.708000,18.296000 79.314000,19.105000 79.903000,19.928000 80.474000,20.762000 81.026000,21.608000 81.560000,22.466000 82.075000,23.334000 82.572000,24.214000 83.049000,25.103000 83.506000,26.002000 83.945000,26.910000 84.363000,27.828000 84.762000,28.753000 85.140000,29.687000 85.498000,30.629000 85.836000,31.577000 86.153000,32.532000 86.450000,33.494000 86.725000,34.461000 86.980000,35.434000 87.214000,36.412000 87.426000,37.394000 87.618000,38.380000 87.788000,39.370000 87.937000,40.363000 88.064000,41.358000 88.170000,42.356000 88.254000,43.355000 88.317000,44.356000 88.359000,45.357000 88.379000,46.359000 88.377000,47.361000 88.354000,48.362000 88.309000,49.362000 88.243000,50.360000 88.156000,51.357000 88.047000,52.351000 87.917000,53.342000 87.765000,54.330000 87.593000,55.314000 87.400000,56.293000 87.185000,57.268000 86.950000,58.238000 86.694000,59.203000 86.418000,60.161000 86.121000,61.113000 85.804000,62.057000 85.466000,62.995000 85.109000,63.925000 84.732000,64.846000 84.336000,65.759000 83.920000,66.663000 83.485000,67.558000 83.030000,68.442000 82.558000,69.317000 82.066000,70.180000 81.557000,71.033000 81.029000,71.874000 80.484000,72.704000 79.921000,73.521000 79.341000,74.326000 78.744000,75.118000 78.130000,75.896000 77.500000,76.661000 76.854000,77.412000 76.192000,78.149000 75.515000,78.871000 74.822000,79.578000 74.115000,80.270000 73.393000,80.946000 72.657000,81.607000 71.908000,82.251000 71.145000,82.879000 70.368000,83.490000 69.580000,84.084000 68.779000,84.660000 67.966000,85.220000 67.141000,85.761000 66.305000,86.284000 65.459000,86.790000 64.602000,87.276000 63.735000,87.744000 62.859000,88.194000 61.973000,88.624000 61.079000,89.035000 60.177000,89.426000 59.266000,89.798000 58.348000,90.150000 57.423000,90.482000 56.492000,90.794000 55.554000,91.086000 54.610000,91.358000 53.662000,91.609000 52.708000,91.840000 51.750000,92.050000 50.788000,92.239000 49.822000,92.408000 48.854000,92.555000 47.883000,92.682000 46.909000,92.788000 45.934000,92.873000 44.958000,92.937000 43.980000,92.980000 43.003000,93.003000 42.025000,93.004000 41.048000,92.984000 40.072000,92.943000 39.098000,92.881000 38.125000,92.798000 37.155000,92.694000 36.187000,92.570000 35.223000,92.425000 34.262000,92.259000 33.306000,92.073000 32.354000,91.866000 31.406000,91.639000 30.465000,91.392000 29.529000,91.125000 28.599000,90.838000 27.677000,90.531000 26.761000,90.204000 25.853000,89.858000 24.953000,89.493000 24.061000,89.108000 23.178000,88.705000 22.304000,88.282000 21.439000,87.842000 20.585000,87.383000 19.741000,86.905000 18.908000,86.410000 18.085000,85.898000 17.275000,85.368000 16.476000,84.821000 15.689000,84.257000 14.915000,83.676000 14.154000,83.080000 13.406000,82.467000 12.671000,81.838000 11.951000,81.195000 11.244000,80.536000 10.553000,79.862000 9.876000,79.174000 9.214000,78.471000 8.568000,77.755000 7.937000,77.025000 7.323000,76.283000 6.725000,75.527000 6.143000,74.759000 5.579000,73.979000 5.031000,73.187000 4.501000,72.384000 3.988000,71.571000 3.493000,70.746000 3.016000,69.911000 2.557000,69.067000 2.116000,68.213000 1.694000,67.351000 1.291000,66.479000 0.907000,65.600000 0.542000,64.713000 0.196000,63.818000 -0.130000,62.917000 -0.437000,62.009000 -0.724000,61.095000 -0.992000,60.175000 -1.239000,59.251000 -1.467000,58.321000 -1.674000,57.387000 -1.861000,56.449000 -2.028000,55.508000 -2.175000,54.563000 -2.301000,53.616000 -2.407000,52.667000 -2.493000,51.716000 -2.558000,50.764000 -2.602000,49.811000 -2.626000,48.858000 -2.630000,47.904000 -2.613000,46.952000 -2.575000,45.999000 -2.518000,45.049000 -2.439000,44.100000 -2.341000,43.153000 -2.222000,42.209000 -2.083000,41.268000 -1.924000,40.331000 -1.745000,39.398000 -1.546000,38.469000 -1.327000,37.545000 -1.088000,36.626000 -0.830000,35.712000 -0.552000,34.805000 -0.255000,33.904000 0.061000,33.010000 0.396000,32.124000 0.750000,31.245000 1.123000,30.374000 1.514000,29.512000 1.923000,28.659000 2.351000,27.815000 2.796000,26.980000 3.259000,26.156000 3.740000,25.342000 4.238000,24.539000 4.752000,23.747000 5.284000,22.967000 5.831000,22.198000 6.395000,21.442000 6.975000,20.698000 7.571000,19.967000 8.182000,19.249000 8.808000,18.545000 9.448000,17.855000 10.104000,17.179000 10.773000,16.517000 11.456000,15.870000 12.153000,15.238000 12.862000,14.622000 13.585000,14.021000 14.320000,13.435000 15.067000,12.866000 15.826000,12.314000 16.597000,11.778000 17.378000,11.259000 18.170000,10.757000 18.973000,10.272000 19.785000,9.805000 20.607000,9.355000 21.438000,8.923000 22.278000,8.510000 23.127000,8.115000 23.983000,7.738000 24.847000,7.380000 25.718000,7.040000 26.596000,6.720000 27.480000,6.418000 28.370000,6.136000 29.266000,5.873000 30.167000,5.629000 31.073000,5.405000 31.983000,5.201000 32.896000,5.016000 33.813000,4.850000 34.734000,4.705000 35.656000,4.579000 36.581000,4.474000 37.508000,4.388000 38.436000,4.322000 39.365000,4.276000 40.294000,4.250000 41.223000,4.244000 42.152000,4.259000 43.080000,4.292000 44.007000,4.346000 44.932000,4.420000 45.855000,4.514000 46.775000,4.627000 47.693000,4.760000 48.607000,4.913000 49.517000,5.085000 50.423000,5.277000 51.324000,5.488000 52.220000,5.718000 53.111000,5.967000 53.996000,6.235000 54.874000,6.522000 55.746000,6.828000 56.611000,7.153000 57.469000,7.495000 58.318000,7.856000 59.159000,8.235000 59.992000,8.632000 60.816000,9.047000 61.630000,9.479000 62.434000,9.928000 63.229000,10.394000 64.013000,10.877000 64.786000,11.376000 65.548000,11.892000 66.298000,12.424000 67.036000,12.972000 67.763000,13.535000 68.476000,14.113000 69.177000,14.707000 69.865000,15.315000 70.539000,15.937000 71.200000,16.574000 71.846000,17.224000 72.479000,17.888000 73.096000,18.565000 73.699000,19.255000 74.286000,19.958000 74.858000,20.673000 75.414000,21.399000 75.955000,22.137000 76.479000,22.887000 76.987000,23.647000 77.478000,24.417000 77.952000,25.198000 78.410000,25.988000 78.850000,26.788000 79.272000,27.597000 79.677000,28.414000 80.065000,29.239000 80.434000,30.073000 80.785000,30.913000 81.118000,31.761000 81.432000,32.615000 81.728000,33.476000 82.006000,34.343000 82.264000,35.215000 82.504000,36.092000 82.725000,36.973000 82.926000,37.859000 83.109000,38.749000 83.272000,39.642000 83.416000,40.538000 83.541000,41.436000 83.646000,42.337000 83.732000,43.239000 83.798000,44.143000 83.845000,45.048000 83.873000,45.953000 83.881000,46.858000 83.870000,47.763000 83.839000,48.667000 83.789000,49.570000 83.719000,50.471000 83.631000,51.370000 83.523000,52.267000 83.395000,53.160000 83.249000,54.051000 83.084000,54.938000 82.899000,55.821000 82.696000,56.699000 82.474000,57.573000 82.234000,58.441000 81.975000,59.303000 81.697000,60.160000 81.402000,61.010000 81.088000,61.853000 80.756000,62.689000 80.407000,63.517000 80.040000,64.337000 79.656000,65.149000 79.254000,65.952000 78.836000,66.746000 78.400000,67.531000 77.948000,68.305000 77.480000,69.070000 76.996000,69.824000 76.495000,70.567000 75.979000,71.299000 75.448000,72.020000 74.901000,72.729000 74.340000,73.425000 73.764000,74.109000 73.173000,74.780000 72.569000,75.438000 71.951000,76.083000 71.319000,76.714000 70.674000,77.332000 70.016000,77.935000 69.346000,78.523000 68.664000,79.097000 67.969000,79.656000 67.263000,80.199000 66.546000,80.727000 65.818000,81.239000 65.079000,81.736000 64.330000,82.216000 63.571000,82.680000 62.803000,83.127000 62.025000,83.557000 61.239000,83.971000 60.445000,84.367000 59.642000,84.746000 58.832000,85.108000 58.014000,85.452000 57.189000,85.778000 56.358000,86.087000 55.521000,86.377000 54.678000,86.649000 53.830000,86.903000 52.977000,87.138000 52.120000,87.355000 51.258000,87.554000 50.392000,87.734000 49.523000,87.895000 48.651000,88.038000 47.777000,88.161000 46.901000,88.266000 46.022000,88.352000 45.143000,88.419000 44.262000,88.467000 43.382000,88.496000 42.501000,88.506000 41.620000,88.498000 40.740000,88.470000 39.861000,88.423000 38.984000,88.358000 38.108000,88.274000 37.235000,88.171000 36.365000,88.049000 35.498000,87.909000 34.634000,87.751000 33.774000,87.573000 32.919000,87.378000 32.068000,87.164000 31.223000,86.932000 30.383000,86.682000 29.549000,86.414000 28.721000,86.129000 27.899000,85.826000 27.085000,85.505000 26.278000,85.167000 25.479000,84.812000 24.688000,84.440000 23.905000,84.051000 23.132000,83.646000 22.367000,83.224000 21.612000,82.787000 20.867000,82.333000 20.132000,81.863000 19.407000,81.378000 18.694000,80.878000 17.991000,80.363000 17.300000,79.833000 16.621000,79.288000 15.954000,78.729000 15.300000,78.157000 14.658000,77.570000 14.029000,76.970000 13.413000,76.357000 12.811000,75.731000 12.223000,75.093000 11.648000,74.442000 11.088000,73.779000 10.543000,73.105000 10.012000,72.420000 9.497000,71.723000 8.997000,71.016000 8.512000,70.298000 8.043000,69.571000 7.590000,68.834000 7.153000,68.088000 6.732000,67.332000 6.328000,66.569000 5.940000,65.796000 5.569000,65.017000 5.215000,64.229000 4.879000,63.435000 4.559000,62.633000 4.257000,61.826000 3.973000,61.012000 3.706000,60.193000 3.457000,59.368000 3.226000,58.539000 3.012000,57.705000 2.817000,56.868000 2.640000,56.026000 2.481000,55.181000 2.340000,54.334000 2.218000,53.484000 2.114000,52.631000 2.028000,51.777000 1.960000,50.922000 1.911000,50.066000 1.881000,49.209000 1.869000,48.352000 1.875000,47.495000 1.900000,46.640000 1.943000,45.785000 2.004000,44.931000 2.084000,44.080000 2.182000,43.230000 2.298000,42.384000 2.432000,41.540000 2.584000,40.699000 2.754000,39.863000 2.942000,39.031000 3.148000,38.203000 3.371000,37.380000 3.612000,36.562000 3.871000,35.750000 4.146000,34.945000 4.439000,34.145000 4.749000,33.353000 5.076000,32.567000 5.419000,31.789000 5.779000,31.019000 6.155000,30.257000 6.547000,29.503000 6.955000,28.759000 7.379000,28.024000 7.818000,27.298000 8.273000,26.582000 8.743000,25.876000 9.227000,25.181000 9.727000,24.497000 10.240000,23.824000 10.768000,23.162000 11.310000,22.512000 11.865000,21.874000 12.434000,21.249000 13.015000,20.636000 13.610000,20.036000 14.217000,19.449000 14.836000,18.875000 15.467000,18.315000 16.110000,17.769000 16.764000,17.237000 17.429000,16.720000 18.105000,16.217000 18.792000,15.729000 19.488000,15.256000 20.194000,14.798000 20.909000,14.356000 21.634000,13.929000 22.367000,13.518000 23.108000,13.123000 23.858000,12.745000 24.615000,12.382000 25.380000,12.036000 26.151000,11.707000 26.929000,11.394000 27.714000,11.099000 28.504000,10.820000 29.299000,10.559000 30.100000,10.315000 30.906000,10.088000 31.715000,9.879000 32.529000,9.687000 33.347000,9.512000 34.167000,9.356000 34.991000,9.217000 35.817000,9.096000 36.645000,8.992000 37.475000,8.907000 38.306000,8.839000 39.138000,8.790000 39.971000,8.758000 40.803000,8.744000 41.636000,8.748000 42.468000,8.770000 43.299000,8.810000 44.128000,8.867000 44.956000,8.942000 45.782000,9.035000 46.605000,9.146000 47.425000,9.274000 48.242000,9.420000 49.055000,9.584000 49.865000,9.764000 50.669000,9.962000 51.470000,10.177000 52.265000,10.409000 53.054000,10.658000 53.838000,10.924000 54.615000,11.207000 55.386000,11.506000 56.150000,11.821000 56.907000,12.153000 57.656000,12.500000 58.398000,12.864000 59.131000,13.243000 59.855000,13.638000 60.570000,14.048000 61.277000,14.473000 61.973000,14.913000 62.660000,15.368000 63.337000,15.837000 64.003000,16.320000 64.658000,16.818000 65.302000,17.329000 65.935000,17.853000 66.556000,18.391000 67.165000,18.942000 67.762000,19.506000 68.346000,20.082000 68.918000,20.670000 69.477000,21.270000 70.022000,21.882000 70.554000,22.505000 71.072000,23.139000 71.577000,23.784000 72.067000,24.439000 72.543000,25.105000 73.004000,25.780000 73.450000,26.465000 73.882000,27.158000 74.298000,27.861000 74.699000,28.572000 75.084000,29.292000 75.454000,30.019000 75.808000,30.753000 76.146000,31.495000 76.467000,32.243000 76.773000,32.998000 77.062000,33.759000 77.334000,34.526000 77.590000,35.298000 77.829000,36.075000 78.051000,36.857000 78.257000,37.643000 78.445000,38.433000 78.616000,39.226000 78.770000,40.023000 78.907000,40.822000 79.027000,41.624000 79.129000,42.428000 79.214000,43.234000 79.282000,44.041000 79.332000,44.848000 79.365000,45.657000 79.381000,46.465000 79.379000,47.274000 79.359000,48.082000 79.323000,48.889000 79.269000,49.694000 79.198000,50.498000 79.110000,51.300000 79.004000,52.100000 78.882000,52.896000 78.742000,53.690000 78.585000,54.480000 78.412000,55.266000 78.222000,56.048000 78.015000,56.826000 77.791000,57.598000 77.552000,58.365000 77.295000,59.127000 77.023000,59.882000 76.735000,60.632000 76.430000,61.374000 76.110000,62.110000 75.774000,62.838000 75.423000,63.558000 75.057000,64.271000 74.676000,64.975000 74.279000,65.670000 73.868000,66.357000 73.443000,67.034000 73.003000,67.702000 72.549000,68.360000 72.082000,69.008000 71.601000,69.645000 71.106000,70.271000 70.598000,70.887000 70.078000,71.491000 69.545000,72.084000 68.999000,72.664000 68.441000,73.233000 67.872000,73.789000 67.290000,74.333000 66.698000,74.864000 66.094000,75.382000 65.480000,75.886000 64.856000,76.377000 64.221000,76.855000 63.576000,77.318000 62.922000,77.767000 62.259000,78.202000 61.586000,78.622000 60.905000,79.028000 60.216000,79.419000 59.519000,79.795000 58.814000,80.155000 58.102000,80.500000 57.383000,80.830000 56.658000,81.144000 55.926000,81.442000 55.188000,81.724000 54.445000,81.991000 53.696000,82.241000 52.943000,82.474000 52.185000,82.692000 51.423000,82.893000 50.657000,83.078000 49.887000,83.246000 49.115000,83.397000 48.339000,83.532000 47.562000,83.650000 46.782000,83.751000 46.000000,83.836000 45.218000,83.903000 44.434000,83.954000 43.650000,83.988000 42.865000,84.005000 42.081000,84.005000 41.297000,83.988000 40.514000,83.955000 39.733000,83.905000 38.953000,83.837000 38.174000,83.754000 37.398000,83.653000 36.625000,83.536000 35.855000,83.403000 35.088000,83.253000 34.325000,83.086000 33.566000,82.904000 32.812000,82.705000 32.062000,82.490000 31.317000,82.259000 30.578000,82.013000 29.844000,81.750000 29.117000,81.472000 28.396000,81.179000 27.682000,80.870000 26.975000,80.546000 26.275000,80.207000 25.583000,79.854000 24.899000,79.486000 24.224000,79.103000 23.557000,78.706000 22.899000,78.295000 22.250000,77.870000 21.611000,77.432000 20.982000,76.980000 20.363000,76.514000 19.754000,76.036000 19.156000,75.545000 18.569000,75.042000 17.993000,74.526000 17.428000,73.999000 16.876000,73.459000 16.335000,72.908000 15.806000,72.346000 15.290000,71.773000 14.786000,71.189000 14.296000,70.594000 13.818000,69.990000 13.354000,69.375000 12.903000,68.751000 12.466000,68.118000 12.043000,67.476000 11.633000,66.825000 11.238000,66.166000 10.858000,65.499000 10.492000,64.824000 10.141000,64.141000 9.805000,63.452000 9.483000,62.755000 9.177000,62.053000 8.886000,61.344000 8.611000,60.629000 8.351000,59.909000 8.107000,59.184000 7.878000,58.454000 7.666000,57.720000 7.469000,56.982000 7.288000,56.240000 7.123000,55.494000 6.975000,54.745000 6.842000,53.994000 6.726000,53.241000 6.626000,52.485000 6.542000,51.728000 6.475000,50.969000 6.424000,50.210000 6.389000,49.450000 6.371000,48.689000 6.369000,47.929000 6.383000,47.169000 6.414000,46.410000 6.461000,45.653000 6.524000,44.896000 6.603000,44.142000 6.699000,43.390000 6.810000,42.640000 6.938000,41.894000 7.081000,41.150000 7.241000,40.410000 7.416000,39.674000 7.607000,38.942000 7.813000,38.215000 8.035000,37.493000 8.273000,36.776000 8.525000,36.065000 8.793000,35.359000 9.076000,34.660000 9.373000,33.967000 9.685000,33.281000 10.012000,32.602000 10.353000,31.931000 10.708000,31.267000 11.077000,30.612000 11.460000,29.965000 11.857000,29.327000 12.267000,28.697000 12.690000,28.077000 13.127000,27.466000 13.576000,26.865000 14.038000,26.274000 14.512000,25.694000 14.998000,25.124000 15.497000,24.564000 16.007000,24.016000 16.528000,23.480000 17.061000,22.954000 17.604000,22.441000 18.158000,21.939000 18.723000,21.450000 19.297000,20.973000 19.882000,20.509000 20.476000,20.058000 21.079000,19.620000 21.692000,19.195000 22.313000,18.784000 22.942000,18.386000 23.580000,18.002000 24.225000,17.632000 24.878000,17.276000 25.538000,16.934000 26.205000,16.606000 26.879000,16.294000 27.559000,15.996000 28.245000,15.712000 28.936000,15.444000 29.633000,15.190000 30.335000,14.952000 31.041000,14.729000 31.752000,14.521000 32.466000,14.329000 33.184000,14.152000 33.906000,13.991000 34.631000,13.845000 35.358000,13.715000 36.087000,13.601000 36.819000,13.503000 37.552000,13.420000 38.286000,13.353000 39.022000,13.302000 39.757000,13.266000 40.494000,13.247000 41.230000,13.243000 41.965000,13.255000 42.700000,13.283000 43.434000,13.327000 44.166000,13.386000 44.897000,13.461000 45.626000,13.552000 46.352000,13.658000 47.075000,13.780000 47.795000,13.917000 48.512000,14.070000 49.225000,14.238000 49.934000,14.421000 50.638000,14.619000 51.338000,14.832000 52.032000,15.060000 52.722000,15.303000 53.405000,15.561000 54.083000,15.833000 54.754000,16.119000 55.419000,16.420000 56.077000,16.734000 56.727000,17.063000 57.370000,17.405000 58.006000,17.761000 58.633000,18.130000 59.252000,18.513000 59.862000,18.908000 60.463000,19.317000 61.055000,19.738000 61.638000,20.171000 62.211000,20.617000 62.774000,21.074000 63.327000,21.544000 63.869000,22.025000 64.401000,22.517000 64.921000,23.020000 65.431000,23.534000 65.929000,24.059000 66.416000,24.594000 66.890000,25.139000 67.353000,25.694000 67.803000,26.259000 68.241000,26.833000 68.667000,27.416000 69.079000,28.007000 69.479000,28.607000 69.865000,29.215000 70.238000,29.831000 70.598000,30.455000 70.944000,31.086000 71.276000,31.724000 71.594000,32.369000 71.899000,33.020000 72.189000,33.677000 72.464000,34.340000 72.726000,35.008000 72.972000,35.682000 73.204000,36.360000 73.422000,37.043000 73.624000,37.730000 73.812000,38.421000 73.985000,39.115000 74.142000,39.813000 74.285000,40.514000 74.412000,41.217000 74.525000,41.922000 74.622000,42.629000 74.703000,43.338000 74.770000,44.049000 74.821000,44.760000 74.857000,45.471000 74.877000,46.184000 74.883000,46.895000 74.873000,47.607000 74.847000,48.318000 74.807000,49.028000 74.751000,49.736000 74.680000,50.443000 74.594000,51.148000 74.493000,51.850000 74.377000,52.550000 74.245000,53.247000 74.099000,53.940000 73.939000,54.630000 73.763000,55.316000 73.573000,55.998000 73.369000,56.675000 73.150000,57.347000 72.916000,58.014000 72.669000,58.676000 72.407000,59.332000 72.132000,59.982000 71.843000,60.625000 71.540000,61.262000 71.224000,61.891000 70.894000,62.514000 70.552000,63.129000 70.196000,63.736000 69.828000,64.336000 69.447000,64.926000 69.053000,65.509000 68.648000,66.082000 68.230000,66.646000 67.800000,67.201000 67.359000,67.747000 66.907000,68.282000 66.443000,68.808000 65.968000,69.323000 65.483000,69.827000 64.987000,70.321000 64.481000,70.804000 63.965000,71.275000 63.439000,71.735000 62.903000,72.184000 62.358000,72.620000 61.805000,73.045000 61.242000,73.457000 60.672000,73.858000 60.092000,74.245000 59.505000,74.620000 58.911000,74.982000 58.309000,75.331000 57.700000,75.667000 57.084000,75.989000 56.462000,76.298000 55.833000,76.594000 55.199000,76.875000 54.559000,77.143000 53.913000,77.397000 53.263000,77.637000 52.608000,77.863000 51.949000,78.075000 51.285000,78.272000 50.618000,78.455000 49.947000,78.623000 49.273000,78.777000 48.597000,78.916000 47.918000,79.041000 47.236000,79.151000 46.553000,79.246000 45.868000,79.327000 45.182000,79.393000 44.495000,79.444000 43.808000,79.480000 43.120000,79.501000 42.432000,79.508000 41.744000,79.500000 41.058000,79.477000 40.372000,79.439000 39.687000,79.387000 39.004000,79.320000 38.323000,79.239000 37.644000,79.142000 36.968000,79.032000 36.295000,78.907000 35.624000,78.767000 34.958000,78.613000 34.295000,78.445000 33.636000,78.263000 32.981000,78.067000 32.332000,77.857000 31.687000,77.633000 31.047000,77.396000 30.413000,77.145000 29.785000,76.880000 29.163000,76.602000 28.547000,76.311000 27.938000,76.007000 27.336000,75.690000 26.742000,75.361000 26.154000,75.019000 25.575000,74.664000 25.003000,74.298000 24.440000,73.919000 23.886000,73.528000 23.340000,73.126000 22.803000,72.713000 22.275000,72.288000 21.757000,71.852000 21.249000,71.406000 20.751000,70.948000 20.262000,70.481000 19.785000,70.003000 19.317000,69.515000 18.861000,69.018000 18.416000,68.511000 17.981000,67.995000 17.559000,67.470000 17.147000,66.937000 16.748000,66.395000 16.361000,65.844000 15.985000,65.286000 15.622000,64.720000 15.271000,64.147000 14.933000,63.567000 14.608000,62.980000 14.295000,62.386000 13.995000,61.786000 13.709000,61.180000 13.435000,60.568000 13.175000,59.951000 12.929000,59.328000 12.696000,58.701000 12.476000,58.070000 12.271000,57.434000 12.079000,56.794000 11.901000,56.150000 11.737000,55.503000 11.587000,54.853000 11.451000,54.200000 11.329000,53.545000 11.222000,52.888000 11.128000,52.229000 11.049000,51.568000 10.984000,50.906000 10.933000,50.243000 10.897000,49.580000 10.875000,48.916000 10.867000,48.252000 10.873000,47.589000 10.894000,46.926000 10.928000,46.264000 10.977000,45.604000 11.041000,44.944000 11.118000,44.287000 11.209000,43.632000 11.314000,42.979000 11.434000,42.329000 11.567000,41.683000 11.714000,41.039000 11.874000,40.399000 12.049000,39.763000 12.236000,39.131000 12.438000,38.504000 12.652000,37.881000 12.880000,37.264000 13.121000,36.652000 13.375000,36.045000 13.641000,35.444000 13.921000,34.850000 14.213000,34.262000 14.517000,33.681000 14.834000,33.106000 15.162000,32.539000 15.503000,31.979000 15.855000,31.427000 16.219000,30.883000 16.595000,30.348000 16.981000,29.820000 17.379000,29.302000 17.788000,28.792000 18.207000,28.292000 18.636000,27.800000 19.076000,27.319000 19.526000,26.847000 19.986000,26.385000 20.455000,25.934000 20.934000,25.493000 21.421000,25.062000 21.918000,24.642000 22.423000,24.233000 22.937000,23.836000 23.459000,23.450000 23.989000,23.075000 24.526000,22.712000 25.071000,22.360000 25.623000,22.021000 26.181000,21.694000 26.747000,21.379000 27.319000,21.076000 27.896000,20.786000 28.480000,20.508000 29.069000,20.243000 29.664000,19.992000 30.263000,19.753000 30.867000,19.527000 31.476000,19.314000 32.088000,19.114000 32.705000,18.928000 33.325000,18.755000 33.948000,18.596000 34.574000,18.450000 35.203000,18.317000 35.834000,18.198000 36.468000,18.093000 37.103000,18.002000 37.739000,17.924000 38.377000,17.860000 39.016000,17.810000 39.655000,17.773000 40.295000,17.751000 40.934000,17.741000 41.574000,17.746000 42.212000,17.765000 42.850000,17.797000 43.487000,17.843000 44.122000,17.902000 44.756000,17.975000 45.387000,18.062000 46.016000,18.162000 46.643000,18.275000 47.266000,18.402000 47.887000,18.543000 48.503000,18.696000 49.117000,18.863000 49.726000,19.042000 50.331000,19.235000 50.931000,19.440000 51.526000,19.658000 52.116000,19.889000 52.701000,20.132000 53.280000,20.388000 53.854000,20.656000 54.421000,20.936000 54.981000,21.228000 55.535000,21.532000 56.082000,21.847000 56.622000,22.174000 57.154000,22.512000 57.679000,22.862000 58.196000,23.222000 58.704000,23.593000 59.205000,23.975000 59.696000,24.368000 60.179000,24.770000 60.653000,25.183000 61.118000,25.606000 61.573000,26.038000 62.019000,26.480000 62.455000,26.931000 62.880000,27.391000 63.296000,27.859000 63.701000,28.337000 64.096000,28.822000 64.480000,29.316000 64.853000,29.818000 65.215000,30.327000 65.566000,30.844000 65.905000,31.368000 66.233000,31.898000 66.549000,32.436000 66.854000,32.979000 67.146000,33.529000 67.427000,34.085000 67.695000,34.646000 67.951000,35.213000 68.195000,35.785000 68.426000,36.361000 68.645000,36.942000 68.851000,37.527000 69.044000,38.117000 69.225000,38.710000 69.393000,39.306000 69.547000,39.906000 69.689000,40.508000 69.818000,41.113000 69.933000,41.720000 70.036000,42.330000 70.125000,42.941000 70.201000,43.553000 70.264000,44.167000 70.314000,44.781000 70.350000,45.397000 70.374000,46.012000 70.384000,46.628000 70.380000,47.243000 70.364000,47.857000 70.334000,48.471000 70.291000,49.084000 70.236000,49.695000 70.166000,50.305000 70.084000,50.913000 69.989000,51.518000 69.881000,52.121000 69.761000,52.722000 69.627000,53.319000 69.481000,53.913000 69.322000,54.503000 69.150000,55.089000 68.966000,55.671000 68.770000,56.249000 68.561000,56.822000 68.340000,57.391000 68.107000,57.954000 67.863000,58.511000 67.606000,59.063000 67.338000,59.609000 67.058000,60.149000 66.767000,60.682000 66.465000,61.209000 66.151000,61.729000 65.827000,62.242000 65.492000,62.747000 65.146000,63.245000 64.790000,63.735000 64.424000,64.217000 64.048000,64.690000 63.661000,65.155000 63.265000,65.612000 62.860000,66.060000 62.445000,66.498000 62.021000,66.928000 61.589000,67.348000 61.147000,67.758000 60.697000,68.159000 60.239000,68.549000 59.773000,68.930000 59.299000,69.300000 58.817000,69.659000 58.328000,70.008000 57.832000,70.347000 57.330000,70.674000 56.820000,70.990000 56.304000,71.295000 55.782000,71.589000 55.254000,71.871000 54.720000,72.142000 54.181000,72.401000 53.637000,72.648000 53.088000,72.884000 52.534000,73.107000 51.976000,73.319000 51.414000,73.518000 50.848000,73.705000 50.279000,73.880000 49.706000,74.042000 49.130000,74.192000 48.551000,74.329000 47.970000,74.454000 47.387000,74.566000 46.801000,74.666000 46.214000,74.753000 45.626000,74.828000 45.036000,74.889000 44.446000,74.938000 43.855000,74.974000 43.264000,74.998000 42.672000,75.009000 42.081000,75.007000 41.490000,74.992000 40.901000,74.965000 40.312000,74.925000 39.724000,74.872000 39.138000,74.807000 38.554000,74.730000 37.973000,74.639000 37.393000,74.537000 36.816000,74.422000 36.242000,74.295000 35.672000,74.155000 35.104000,74.004000 34.541000,73.840000 33.981000,73.664000 33.426000,73.477000 32.875000,73.278000 32.329000,73.067000 31.788000,72.844000 31.251000,72.610000 30.721000,72.365000 30.196000,72.108000 29.677000,71.841000 29.164000,71.562000 28.658000,71.273000 28.158000,70.973000 27.665000,70.663000 27.179000,70.342000 26.701000,70.011000 26.230000,69.670000 25.766000,69.319000 25.311000,68.959000 24.863000,68.589000 24.424000,68.209000 23.994000,67.821000 23.572000,67.424000 23.159000,67.017000 22.755000,66.603000 22.360000,66.180000 21.974000,65.749000 21.599000,65.310000 21.233000,64.863000 20.876000,64.409000 20.530000,63.947000 20.194000,63.478000 19.869000,63.003000 19.554000,62.521000 19.249000,62.032000 18.955000,61.538000 18.672000,61.037000 18.400000,60.531000 18.140000,60.019000 17.890000,59.503000 17.652000,58.981000 17.425000,58.454000 17.209000,57.923000 17.005000,57.388000 16.813000,56.849000 16.633000,56.307000 16.464000,55.760000 16.307000,55.211000 16.162000,54.659000 16.029000,54.104000 15.908000,53.546000 15.799000,52.987000 15.703000,52.425000 15.618000,51.862000 15.546000,51.298000 15.485000,50.733000 15.437000,50.166000 15.401000,49.599000 15.378000,49.032000 15.366000,48.465000 15.367000,47.898000 15.380000,47.331000 15.405000,46.766000 15.442000,46.201000 15.492000,45.637000 15.553000,45.075000 15.626000,44.515000 15.712000,43.957000 15.809000,43.401000 15.918000,42.847000 16.039000,42.297000 16.172000,41.749000 16.316000,41.205000 16.472000,40.664000 16.639000,40.127000 16.818000,39.594000 17.008000,39.066000 17.210000,38.542000 17.422000,38.022000 17.645000,37.508000 17.879000,36.999000 18.124000,36.495000 18.380000,35.997000 18.646000,35.505000 18.922000,35.019000 19.209000,34.539000 19.506000,34.066000 19.812000,33.600000 20.129000,33.141000 20.455000,32.688000 20.790000,32.243000 21.135000,31.806000 21.489000,31.377000 21.851000,30.955000 22.223000,30.542000 22.603000,30.137000 22.991000,29.740000 23.388000,29.352000 23.793000,28.973000 24.205000,28.603000 24.625000,28.242000 25.053000,27.890000 25.487000,27.548000 25.929000,27.216000 26.377000,26.893000 26.832000,26.580000 27.294000,26.277000 27.761000,25.985000 28.235000,25.702000 28.714000,25.430000 29.198000,25.169000 29.688000,24.918000 30.182000,24.678000 30.682000,24.449000 31.186000,24.230000 31.694000,24.023000 32.206000,23.827000 32.722000,23.642000 33.242000,23.468000 33.765000,23.305000 34.291000,23.154000 34.819000,23.014000 35.351000,22.886000 35.884000,22.769000 36.420000,22.664000 36.957000,22.570000 37.496000,22.488000 38.037000,22.418000 38.578000,22.359000 39.120000,22.312000 39.663000,22.277000 40.206000,22.253000 40.749000,22.241000 41.292000,22.241000 41.835000,22.252000 42.376000,22.275000 42.917000,22.310000 43.457000,22.356000 43.995000,22.414000 44.532000,22.483000 45.066000,22.564000 45.598000,22.656000 46.128000,22.760000 46.656000,22.875000 47.180000,23.001000 47.701000,23.138000 48.219000,23.286000 48.733000,23.445000 49.244000,23.616000 49.750000,23.797000 50.252000,23.988000 51.242000,24.403000 52.212000,24.860000 52.689000,25.104000 53.160000,25.358000 53.626000,25.621000 54.085000,25.895000 54.538000,26.178000 54.985000,26.470000 55.425000,26.772000 55.859000,27.083000 56.285000,27.404000 56.704000,27.733000 57.115000,28.070000 57.519000,28.417000 57.915000,28.771000 58.303000,29.134000 58.683000,29.505000 59.055000,29.884000 59.418000,30.270000 59.773000,30.664000 60.119000,31.065000 60.456000,31.474000 60.784000,31.889000 61.103000,32.311000 61.412000,32.739000 61.712000,33.174000 62.002000,33.614000 62.283000,34.061000 62.554000,34.513000 62.815000,34.971000 63.066000,35.433000 63.306000,35.901000 63.537000,36.374000 63.757000,36.851000 63.966000,37.332000 64.165000,37.818000 64.354000,38.307000 64.532000,38.800000 64.699000,39.297000 64.855000,39.796000 65.001000,40.299000 65.135000,40.804000 65.259000,41.312000 65.371000,41.821000 65.473000,42.333000 65.563000,42.847000 65.642000,43.362000 65.710000,43.878000 65.767000,44.396000 65.813000,44.914000 65.848000,45.432000 65.884000,46.470000 65.885000,46.989000 65.875000,47.508000 65.854000,48.025000 65.822000,48.542000 65.778000,49.058000 65.724000,49.572000 65.659000,50.085000 65.582000,50.596000 65.495000,51.104000 65.397000,51.611000 65.288000,52.115000 65.169000,52.616000 65.039000,53.114000 64.898000,53.609000 64.585000,54.588000 64.413000,55.072000 64.230000,55.552000 64.038000,56.027000 63.835000,56.498000 63.623000,56.964000 63.401000,57.425000 63.169000,57.881000 62.927000,58.332000 62.676000,58.777000 62.416000,59.216000 61.868000,60.076000 61.580000,60.497000 61.284000,60.911000 60.979000,61.318000 60.665000,61.719000 60.343000,62.112000 59.676000,62.877000 59.330000,63.248000 58.976000,63.612000 58.615000,63.967000 58.247000,64.314000 57.872000,64.654000 57.100000,65.307000 56.302000,65.925000 55.894000,66.221000 55.480000,66.508000 55.060000,66.786000 54.634000,67.055000 54.203000,67.314000 53.325000,67.803000 52.879000,68.034000 52.429000,68.254000 51.974000,68.465000 51.515000,68.666000 51.052000,68.857000 50.115000,69.208000 49.642000,69.368000 49.166000,69.518000 48.205000,69.786000 47.721000,69.905000 47.235000,70.013000 46.747000,70.110000 46.257000,70.197000 45.766000,70.274000 45.273000,70.340000 44.780000,70.395000 44.286000,70.439000 43.791000,70.473000 43.297000,70.496000 42.802000,70.509000 42.307000,70.511000 41.319000,70.483000 40.826000,70.453000 40.334000,70.412000 39.844000,70.361000 39.355000,70.300000 38.868000,70.228000 37.900000,70.053000 37.419000,69.950000 36.942000,69.837000 35.995000,69.580000 35.061000,69.283000 34.600000,69.120000 34.142000,68.947000 33.240000,68.572000 32.795000,68.370000 32.355000,68.159000 31.491000,67.709000 30.648000,67.223000 30.235000,66.967000 29.827000,66.702000 29.031000,66.147000 28.261000,65.559000 27.885000,65.253000 27.156000,64.618000 26.455000,63.953000 25.785000,63.259000 25.461000,62.902000 24.838000,62.168000 24.539000,61.792000 24.248000,61.409000 23.692000,60.627000 23.170000,59.822000 22.923000,59.412000 22.456000,58.578000 22.025000,57.725000 21.632000,56.855000 21.277000,55.971000 21.114000,55.524000 20.961000,55.074000 20.818000,54.621000 20.561000,53.707000 20.344000,52.784000 20.250000,52.319000 20.167000,51.854000 20.030000,50.918000 19.977000,50.449000 19.934000,49.979000 19.901000,49.508000 19.866000,48.567000 19.863000,48.096000 19.889000,47.156000 19.954000,46.220000 20.002000,45.753000 20.060000,45.288000 20.128000,44.825000 20.293000,43.904000 20.390000,43.447000 20.497000,42.992000 20.740000,42.092000 21.021000,41.203000 21.340000,40.329000 21.695000,39.471000 21.886000,39.048000 22.295000,38.216000 22.739000,37.404000 23.217000,36.612000 23.727000,35.843000 24.269000,35.098000 24.842000,34.378000 25.140000,34.027000 25.757000,33.347000 26.401000,32.695000 27.073000,32.071000 27.769000,31.479000 28.489000,30.917000 28.857000,30.648000 29.610000,30.135000 30.384000,29.656000 31.176000,29.211000 31.985000,28.801000 32.810000,28.427000 33.649000,28.089000 34.501000,27.788000 35.363000,27.524000 36.235000,27.298000 37.114000,27.110000 37.556000,27.030000 38.444000,26.899000 38.889000,26.848000 39.782000,26.775000 40.228000,26.753000 41.122000,26.738000 41.568000,26.744000 42.458000,26.786000 43.344000,26.867000 43.786000,26.921000 44.663000,27.058000 45.099000,27.140000 45.964000,27.333000 46.818000,27.562000 47.661000,27.828000 48.490000,28.129000 48.899000,28.292000 49.705000,28.645000 50.494000,29.032000 51.265000,29.452000 52.016000,29.904000 52.383000,30.141000 53.102000,30.639000 53.797000,31.167000 54.468000,31.723000 55.113000,32.307000 55.732000,32.917000 56.323000,33.552000 56.885000,34.211000 57.418000,34.893000 57.920000,35.595000 58.391000,36.318000 58.829000,37.059000 59.235000,37.817000 59.607000,38.590000 59.781000,38.982000 60.101000,39.776000 60.249000,40.178000 60.517000,40.989000 60.750000,41.810000 60.947000,42.638000 61.108000,43.473000 61.232000,44.313000 61.321000,45.156000 61.373000,46.001000 61.388000,46.846000 61.367000,47.690000 61.310000,48.530000 61.217000,49.366000 61.158000,49.782000 61.011000,50.609000 60.830000,51.427000 60.614000,52.235000 60.364000,53.032000 60.080000,53.816000 59.763000,54.586000 59.414000,55.340000 59.034000,56.078000 58.622000,56.797000 58.406000,57.150000 57.950000,57.839000 57.466000,58.508000 56.954000,59.154000 56.416000,59.776000 55.853000,60.374000 55.265000,60.946000 54.655000,61.491000 54.022000,62.009000 53.369000,62.498000 52.696000,62.958000 52.006000,63.388000 51.298000,63.787000 50.576000,64.155000 49.839000,64.491000 49.090000,64.794000 48.330000,65.065000 47.560000,65.302000 46.782000,65.505000 45.997000,65.675000 45.207000,65.810000 44.414000,65.911000 43.617000,65.978000 42.820000,66.011000 42.024000,66.009000 41.230000,65.973000 40.439000,65.903000 39.654000,65.799000 38.875000,65.662000 38.104000,65.491000 37.342000,65.288000 36.591000,65.053000 35.852000,64.786000 35.126000,64.488000 34.415000,64.160000 33.720000,63.802000 33.042000,63.415000 32.383000,63.000000 31.743000,62.558000 31.124000,62.090000 30.526000,61.596000 29.951000,61.078000 29.400000,60.536000 28.874000,59.973000 28.373000,59.388000 27.899000,58.783000 27.452000,58.159000 27.033000,57.518000 26.643000,56.861000 26.281000,56.189000 25.950000,55.502000 25.649000,54.804000 25.379000,54.094000 25.140000,53.375000 24.932000,52.647000 24.756000,51.913000 24.613000,51.172000 24.501000,50.428000 24.422000,49.681000 24.375000,48.932000 24.360000,48.184000 24.378000,47.436000 24.427000,46.692000 24.508000,45.951000 24.621000,45.217000 24.765000,44.489000 24.940000,43.769000 25.146000,43.058000 25.381000,42.359000 25.646000,41.671000 25.940000,40.996000 26.261000,40.336000 26.611000,39.692000 26.987000,39.064000 27.388000,38.455000 27.815000,37.864000 28.267000,37.293000 28.741000,36.743000 29.238000,36.215000 29.756000,35.710000 30.294000,35.228000 30.852000,34.771000 31.427000,34.339000 32.020000,33.932000 32.628000,33.553000 33.251000,33.201000 33.888000,32.876000 34.537000,32.579000 35.196000,32.312000 35.865000,32.073000 36.543000,31.864000 37.228000,31.684000 37.918000,31.534000 38.613000,31.415000 39.311000,31.325000 40.011000,31.266000 40.712000,31.237000 41.237000,31.235000 41.761000,31.250000 42.063000,31.256000 42.364000,31.273000 42.664000,31.301000 42.962000,31.340000 43.260000,31.389000 43.555000,31.450000 43.848000,31.521000 44.138000,31.603000 44.708000,31.798000 45.262000,32.035000 45.532000,32.168000 45.798000,32.311000 46.312000,32.626000 46.560000,32.797000 46.801000,32.977000 47.036000,33.166000 47.264000,33.363000 47.484000,33.569000 47.697000,33.782000 47.902000,34.003000 48.099000,34.231000 48.287000,34.467000 48.637000,34.957000 48.798000,35.212000 48.950000,35.472000 49.092000,35.738000 49.225000,36.009000 49.460000,36.563000 49.562000,36.847000 49.735000,37.424000 49.805000,37.717000 49.865000,38.013000 49.914000,38.310000 49.952000,38.609000 49.979000,38.909000 49.995000,39.210000 50.000000,39.511000 49.994000,39.813000 49.977000,40.114000 49.949000,40.414000 49.910000,40.712000 49.861000,41.010000 49.800000,41.305000 49.729000,41.598000 49.647000,41.888000 49.452000,42.458000 49.215000,43.012000 49.082000,43.282000 48.939000,43.548000 48.624000,44.062000 48.453000,44.310000 48.273000,44.551000 48.084000,44.786000 47.887000,45.014000 47.681000,45.234000 47.468000,45.447000 47.247000,45.652000 47.019000,45.849000 46.783000,46.037000 46.293000,46.387000 46.038000,46.548000 45.778000,46.700000 45.512000,46.842000 45.241000,46.975000 44.687000,47.210000 44.403000,47.312000 43.826000,47.485000 43.533000,47.555000 43.237000,47.615000 42.940000,47.664000 42.641000,47.702000 42.341000,47.729000 42.046000,47.745000 41.750000,47.750000 41.467000,47.755000 40.902000,47.796000 40.342000,47.879000 40.065000,47.935000 39.790000,48.002000 39.248000,48.165000 38.981000,48.261000 38.719000,48.367000 38.460000,48.483000 38.206000,48.608000 37.957000,48.742000 37.713000,48.885000 37.241000,49.197000 37.013000,49.366000 36.578000,49.728000 36.171000,50.121000 35.978000,50.328000 35.616000,50.763000 35.447000,50.991000 35.287000,51.224000 35.135000,51.463000 34.992000,51.707000 34.858000,51.956000 34.733000,52.210000 34.617000,52.469000 34.511000,52.731000 34.415000,52.998000 34.252000,53.540000 34.185000,53.815000 34.129000,54.092000 34.046000,54.652000 34.005000,55.217000 34.005000,55.783000 34.046000,56.348000 34.129000,56.908000 34.185000,57.185000 34.252000,57.460000 34.415000,58.002000 34.511000,58.269000 34.617000,58.531000 34.733000,58.790000 34.858000,59.044000 34.992000,59.293000 35.135000,59.537000 35.447000,60.009000 35.616000,60.237000 35.978000,60.672000 36.371000,61.079000 36.578000,61.272000 37.013000,61.634000 37.241000,61.803000 37.474000,61.963000 37.713000,62.115000 37.957000,62.258000 38.206000,62.392000 38.460000,62.517000 38.719000,62.633000 38.981000,62.739000 39.248000,62.835000 39.790000,62.998000 40.065000,63.065000 40.342000,63.121000 40.902000,63.204000 41.467000,63.245000 41.761000,63.250000 42.439000,63.266000 43.118000,63.253000 43.797000,63.210000 44.475000,63.138000 45.150000,63.036000 45.822000,62.906000 46.489000,62.746000 47.149000,62.558000 47.803000,62.340000 48.447000,62.095000 49.081000,61.821000 49.705000,61.520000 50.316000,61.191000 50.913000,60.836000 51.496000,60.455000 52.062000,60.049000 52.612000,59.617000 53.144000,59.162000 53.657000,58.683000 54.149000,58.181000 54.620000,57.658000 55.070000,57.114000 55.496000,56.550000 55.898000,55.968000 56.276000,55.367000 56.628000,54.750000 56.954000,54.116000 57.252000,53.469000 57.523000,52.807000 57.766000,52.134000 57.980000,51.449000 58.165000,50.754000 58.320000,50.051000 58.445000,49.341000 58.539000,48.624000 58.603000,47.903000 58.635000,47.179000 58.637000,46.452000 58.607000,45.725000 58.545000,44.998000 58.453000,44.273000 58.329000,43.552000 58.173000,42.836000 57.987000,42.125000 57.770000,41.422000 57.523000,40.728000 57.245000,40.043000 56.938000,39.370000 56.601000,38.710000 56.236000,38.064000 55.842000,37.433000 55.421000,36.818000 54.974000,36.221000 54.500000,35.642000 54.000000,35.084000 53.477000,34.547000 52.929000,34.031000 52.359000,33.539000 51.768000,33.071000 51.155000,32.629000 50.523000,32.212000 49.873000,31.822000 49.205000,31.460000 48.522000,31.126000 47.823000,30.821000 47.110000,30.547000 46.386000,30.303000 45.650000,30.089000 44.904000,29.908000 44.150000,29.758000 43.389000,29.641000 42.622000,29.556000 41.851000,29.504000 41.077000,29.486000 40.301000,29.501000 39.526000,29.549000 38.752000,29.631000 37.982000,29.746000 37.215000,29.894000 36.454000,30.076000 35.701000,30.290000 34.956000,30.537000 34.221000,30.817000 33.498000,31.128000 32.788000,31.470000 32.092000,31.844000 31.411000,32.247000 30.747000,32.681000 30.102000,33.143000 29.476000,33.633000 28.870000,34.151000 28.287000,34.695000 27.726000,35.265000 27.190000,35.859000 26.679000,36.477000 26.194000,37.117000 25.736000,37.778000 25.306000,38.460000 24.906000,39.161000 24.535000,39.879000 24.195000,40.614000 23.886000,41.364000 23.610000,42.128000 23.366000,42.905000 23.156000,43.692000 22.979000,44.489000 22.903000,44.891000 22.778000,45.700000 22.688000,46.514000 22.632000,47.333000 22.612000,48.155000 22.627000,48.979000 22.678000,49.802000 22.764000,50.624000 22.885000,51.443000 23.042000,52.257000 23.234000,53.064000 23.461000,53.864000 23.723000,54.655000 24.018000,55.435000 24.348000,56.203000 24.711000,56.957000 25.106000,57.696000 25.534000,58.418000 25.759000,58.773000 26.234000,59.468000 26.482000,59.808000 27.002000,60.472000 27.550000,61.115000 28.127000,61.734000 28.730000,62.329000 29.360000,62.899000 30.014000,63.441000 30.692000,63.956000 31.393000,64.442000 32.115000,64.898000 32.857000,65.323000 33.235000,65.524000 34.005000,65.901000 34.792000,66.245000 35.593000,66.556000 36.409000,66.833000 37.237000,67.074000 37.655000,67.182000 38.499000,67.370000 39.352000,67.521000 39.781000,67.584000 40.211000,67.637000 41.076000,67.715000 41.945000,67.756000 42.816000,67.759000 43.688000,67.726000 44.124000,67.695000 44.994000,67.604000 45.860000,67.477000 46.721000,67.312000 47.576000,67.109000 48.423000,66.870000 49.260000,66.595000 50.085000,66.283000 50.898000,65.935000 51.696000,65.552000 52.089000,65.348000 52.862000,64.913000 53.617000,64.445000 54.352000,63.945000 55.067000,63.412000 55.758000,62.848000 56.426000,62.254000 57.069000,61.631000 57.685000,60.981000 58.273000,60.303000 58.833000,59.599000 59.362000,58.871000 59.616000,58.499000 60.098000,57.736000 60.548000,56.953000 60.761000,56.554000 60.965000,56.150000 61.347000,55.328000 61.694000,54.490000 62.005000,53.636000 62.280000,52.768000 62.517000,51.888000 62.622000,51.444000 62.717000,50.997000 62.878000,50.098000 63.001000,49.190000 63.048000,48.735000 63.085000,48.278000 63.129000,47.361000 63.137000,46.901000 63.122000,45.981000 63.100000,45.521000 63.025000,44.602000 62.912000,43.686000 62.840000,43.229000 62.667000,42.320000 62.566000,41.868000 62.455000,41.418000 62.204000,40.525000 62.064000,40.082000 61.755000,39.205000 61.408000,38.341000 61.221000,37.914000 60.818000,37.072000 60.603000,36.657000 60.146000,35.841000 59.654000,35.045000 59.395000,34.654000 58.851000,33.889000 58.274000,33.147000 57.665000,32.430000 57.024000,31.738000 56.354000,31.074000 56.008000,30.752000 55.655000,30.438000 54.928000,29.832000 54.174000,29.257000 53.396000,28.714000 52.997000,28.455000 52.184000,27.963000 51.349000,27.505000 50.493000,27.083000 50.059000,26.886000 49.176000,26.519000 48.729000,26.350000 48.277000,26.190000 47.822000,26.040000 46.903000,25.769000 45.971000,25.538000 45.501000,25.437000 44.554000,25.266000 44.077000,25.196000 43.599000,25.136000 43.119000,25.086000 42.638000,25.046000 42.156000,25.017000 41.190000,24.989000 40.221000,25.003000 39.253000,25.059000 38.770000,25.103000 37.806000,25.221000 37.325000,25.296000 36.846000,25.381000 36.369000,25.476000 35.893000,25.582000 35.419000,25.698000 34.479000,25.961000 33.550000,26.264000 33.090000,26.431000 32.181000,26.794000 31.731000,26.991000 31.286000,27.197000 30.845000,27.413000 30.409000,27.638000 29.977000,27.873000 29.128000,28.371000 28.712000,28.634000 28.301000,28.906000 27.895000,29.187000 27.496000,29.476000 27.102000,29.775000 26.715000,30.082000 26.334000,30.397000 25.592000,31.053000 24.878000,31.741000 24.532000,32.097000 24.194000,32.460000 23.863000,32.831000 23.540000,33.209000 23.225000,33.594000 22.918000,33.986000 22.620000,34.384000 22.330000,34.790000 22.048000,35.202000 21.775000,35.620000 21.257000,36.474000 21.011000,36.909000 20.774000,37.350000 20.547000,37.797000 20.330000,38.248000 19.923000,39.166000 19.735000,39.631000 19.388000,40.574000 19.230000,41.052000 19.082000,41.533000 18.944000,42.018000 18.816000,42.505000 18.699000,42.996000 18.593000,43.489000 18.497000,43.985000 18.411000,44.484000 18.337000,44.984000 18.273000,45.486000 18.219000,45.989000 18.177000,46.494000 18.125000,47.508000 18.115000,48.015000 18.116000,48.523000 18.128000,49.031000 18.151000,49.540000 18.185000,50.048000 18.230000,50.555000 18.286000,51.062000 18.430000,52.072000 18.519000,52.575000 18.618000,53.076000 18.728000,53.575000 18.849000,54.073000 18.981000,54.567000 19.124000,55.060000 19.277000,55.549000 19.440000,56.035000 19.615000,56.518000 19.799000,56.997000 19.994000,57.473000 20.200000,57.945000 20.415000,58.412000 20.641000,58.875000 21.122000,59.787000 21.378000,60.235000 21.643000,60.678000 21.918000,61.115000 22.202000,61.547000 22.496000,61.973000 22.799000,62.392000 23.112000,62.806000 23.433000,63.212000 23.763000,63.612000 24.102000,64.005000 24.450000,64.391000 24.806000,64.770000 25.170000,65.141000 25.542000,65.504000 25.922000,65.860000 26.706000,66.547000 27.109000,66.878000 27.520000,67.200000 27.938000,67.514000 28.362000,67.818000 28.793000,68.114000 29.231000,68.401000 29.675000,68.678000 30.125000,68.946000 30.581000,69.205000 31.043000,69.453000 31.511000,69.692000 31.984000,69.921000 32.461000,70.140000 32.944000,70.348000 33.432000,70.547000 34.420000,70.912000 34.920000,71.079000 35.424000,71.235000 35.931000,71.380000 36.442000,71.514000 36.956000,71.638000 37.473000,71.751000 37.992000,71.852000 38.514000,71.942000 39.038000,72.021000 39.564000,72.089000 40.091000,72.146000 40.620000,72.191000 41.150000,72.225000 41.681000,72.248000 42.213000,72.259000 42.745000,72.259000 43.278000,72.247000 43.810000,72.224000 44.342000,72.189000 44.873000,72.143000 45.404000,72.086000 45.934000,72.017000 46.462000,71.936000 46.989000,71.844000 47.514000,71.741000 48.037000,71.627000 48.558000,71.501000 49.076000,71.364000 49.592000,71.216000 50.105000,71.056000 50.614000,70.886000 51.120000,70.704000 51.622000,70.512000 52.120000,70.309000 52.614000,70.095000 53.104000,69.870000 53.589000,69.634000 54.069000,69.388000 54.544000,69.132000 55.014000,68.865000 55.478000,68.589000 55.936000,68.302000 56.389000,68.005000 56.835000,67.698000 57.275000,67.381000 57.708000,67.055000 58.134000,66.720000 58.553000,66.375000 58.965000,66.021000 59.369000,65.658000 59.766000,65.287000 60.155000,64.906000 60.536000,64.517000 60.909000,64.120000 61.273000,63.715000 61.629000,63.301000 61.976000,62.880000 62.314000,62.451000 62.643000,62.015000 62.963000,61.571000 63.273000,61.121000 63.574000,60.664000 63.865000,60.200000 64.146000,59.729000 64.417000,59.252000 64.678000,58.770000 64.928000,58.281000 65.169000,57.787000 65.398000,57.288000 65.617000,56.783000 65.826000,56.274000 66.023000,55.760000 66.210000,55.241000 66.385000,54.719000 66.549000,54.192000 66.702000,53.662000 66.844000,53.128000 66.974000,52.591000 67.092000,52.051000 67.199000,51.508000 67.295000,50.962000 67.379000,50.415000 67.451000,49.865000 67.511000,49.314000 67.559000,48.761000 67.596000,48.207000 67.620000,47.652000 67.633000,47.096000 67.634000,46.540000 67.622000,45.983000 67.599000,45.427000 67.564000,44.871000 67.517000,44.315000 67.458000,43.760000 67.387000,43.207000 67.304000,42.654000 67.209000,42.103000 67.102000,41.554000 66.983000,41.008000 66.853000,40.463000 66.711000,39.921000 66.557000,39.382000 66.391000,38.846000 66.214000,38.314000 66.026000,37.785000 65.826000,37.260000 65.614000,36.739000 65.391000,36.222000 65.158000,35.710000 64.913000,35.203000 64.657000,34.701000 64.390000,34.204000 64.112000,33.713000 63.824000,33.228000 63.525000,32.748000 63.216000,32.275000 62.896000,31.809000 62.566000,31.349000 62.227000,30.896000 61.877000,30.450000 61.518000,30.011000 61.149000,29.581000 60.771000,29.157000 60.384000,28.742000 59.987000,28.335000 59.582000,27.937000 59.168000,27.547000 58.745000,27.166000 58.314000,26.793000 57.875000,26.430000 57.428000,26.076000 56.973000,25.732000 56.511000,25.397000 56.041000,25.072000 55.564000,24.758000 55.080000,24.453000 54.589000,24.159000 54.092000,23.875000 53.589000,23.601000 53.080000,23.339000 52.564000,23.087000 52.044000,22.846000 51.517000,22.616000 50.986000,22.398000 50.450000,22.191000 49.909000,21.995000 49.364000,21.811000 48.815000,21.639000 48.261000,21.478000 47.704000,21.329000 47.144000,21.192000 46.581000,21.067000 46.015000,20.955000 45.446000,20.854000 44.874000,20.765000 44.301000,20.689000 43.726000,20.625000 43.149000,20.574000 42.571000,20.534000 41.992000,20.508000 41.412000,20.493000 40.832000,20.491000 40.251000,20.502000 39.670000,20.525000 39.090000,20.561000 38.510000,20.609000 37.932000,20.669000 37.354000,20.742000 36.777000,20.828000 36.203000,20.926000 35.630000,21.036000 35.059000,21.158000 34.491000,21.293000 33.925000,21.441000 33.363000,21.600000 32.804000,21.771000 32.248000,21.955000 31.696000,22.151000 31.148000,22.358000 30.604000,22.578000 30.065000,22.809000 29.530000,23.052000 29.001000,23.306000 28.477000,23.572000 27.959000,23.849000 27.446000,24.138000 26.939000,24.438000 26.439000,24.748000 25.945000,25.070000 25.458000,25.402000 24.977000,25.745000 24.505000,26.098000 24.039000,26.461000 23.581000,26.835000 23.131000,27.218000 22.689000,27.612000 22.256000,28.015000 21.831000,28.427000 21.414000,28.849000 21.007000,29.280000 20.609000,29.720000 20.220000,30.168000 19.840000,30.625000 19.471000,31.090000 19.111000,31.564000 18.761000,32.045000 18.422000,32.534000 18.093000,33.030000 17.774000,33.534000 17.466000,34.044000 17.169000,34.562000 16.883000,35.086000 16.609000,35.616000 16.345000,36.152000 16.093000,36.695000 15.853000,37.242000 15.624000,37.795000 15.407000,38.354000 15.202000,38.917000 15.009000,39.484000 14.828000,40.056000 14.660000,40.632000 14.504000,41.212000 14.360000,41.796000 14.229000,42.382000 14.110000,42.972000 14.004000,43.564000 13.910000,44.159000 13.830000,44.756000 13.762000,45.355000 13.707000,45.956000 13.665000,46.558000 13.636000,47.161000 13.620000,47.765000 13.616000,48.370000 13.626000,48.974000 13.649000,49.579000 13.685000,50.184000 13.734000,50.787000 13.795000,51.390000 13.870000,51.992000 13.958000,52.593000 14.059000,53.191000 14.172000,53.788000 14.299000,54.383000 14.438000,54.975000 14.590000,55.564000 14.755000,56.150000 14.932000,56.732000 15.122000,57.312000 15.325000,57.887000 15.540000,58.458000 15.767000,59.024000 16.007000,59.586000 16.258000,60.143000 16.522000,60.695000 16.798000,61.241000 17.085000,61.781000 17.384000,62.315000 17.695000,62.843000 18.018000,63.365000 18.351000,63.880000 18.696000,64.388000 19.052000,64.888000 19.418000,65.381000 19.796000,65.866000 20.183000,66.344000 20.582000,66.813000 20.990000,67.274000 21.409000,67.726000 21.837000,68.169000 22.275000,68.603000 22.722000,69.028000 23.179000,69.443000 23.645000,69.849000 24.120000,70.245000 24.603000,70.630000 25.095000,71.006000 25.595000,71.371000 26.103000,71.725000 26.618000,72.069000 27.142000,72.401000 27.672000,72.723000 28.210000,73.033000 28.754000,73.331000 29.306000,73.618000 29.863000,73.894000 30.426000,74.157000 30.996000,74.408000 31.571000,74.647000 32.151000,74.874000 32.736000,75.089000 33.326000,75.291000 33.921000,75.480000 34.520000,75.656000 35.122000,75.820000 35.729000,75.971000 36.339000,76.109000 36.952000,76.234000 37.568000,76.345000 38.186000,76.444000 38.807000,76.529000 39.430000,76.601000 40.054000,76.659000 40.680000,76.704000 41.308000,76.736000 41.936000,76.754000 42.564000,76.759000 43.193000,76.750000 43.822000,76.727000 44.450000,76.691000 45.078000,76.642000 45.706000,76.579000 46.331000,76.503000 46.956000,76.413000 47.579000,76.309000 48.199000,76.192000 48.818000,76.062000 49.433000,75.919000 50.046000,75.762000 50.656000,75.592000 51.262000,75.409000 51.864000,75.213000 52.463000,75.003000 53.057000,74.781000 53.646000,74.546000 54.231000,74.298000 54.810000,74.038000 55.384000,73.765000 55.952000,73.480000 56.515000,73.182000 57.071000,72.872000 57.620000,72.550000 58.163000,72.217000 58.699000,71.871000 59.227000,71.514000 59.748000,71.145000 60.261000,70.765000 60.766000,70.374000 61.263000,69.972000 61.752000,69.560000 62.231000,69.136000 62.702000,68.702000 63.164000,68.258000 63.616000,67.804000 64.058000,67.340000 64.491000,66.866000 64.913000,66.383000 65.326000,65.891000 65.727000,65.390000 66.119000,64.880000 66.499000,64.361000 66.868000,63.834000 67.226000,63.299000 67.573000,62.756000 67.908000,62.206000 68.231000,61.648000 68.543000,61.083000 68.842000,60.511000 69.129000,59.933000 69.404000,59.348000 69.666000,58.757000 69.916000,58.160000 70.153000,57.558000 70.377000,56.951000 70.588000,56.338000 70.786000,55.721000 70.971000,55.100000 71.142000,54.474000 71.300000,53.845000 71.445000,53.211000 71.576000,52.575000 71.693000,51.936000 71.796000,51.294000 71.886000,50.649000 71.962000,50.003000 72.024000,49.354000 72.073000,48.704000 72.107000,48.053000 72.127000,47.401000 72.133000,46.748000 72.126000,46.095000 72.104000,45.442000 72.068000,44.790000 72.018000,44.137000 71.954000,43.486000 71.876000,42.836000 71.784000,42.188000 71.678000,41.541000 71.558000,40.896000 71.425000,40.254000 71.277000,39.615000 71.116000,38.978000 70.941000,38.345000 70.752000,37.715000 70.549000,37.089000 70.334000,36.468000 70.104000,35.851000 69.862000,35.238000 69.606000,34.631000 69.337000,34.029000 69.055000,33.433000 68.760000,32.842000 68.453000,32.258000 68.132000,31.680000 67.800000,31.109000 67.454000,30.545000 67.097000,29.988000 66.728000,29.439000 66.346000,28.898000 65.953000,28.364000 65.549000,27.839000 65.133000,27.323000 64.705000,26.815000 64.267000,26.316000 63.818000,25.827000 63.358000,25.347000 62.888000,24.877000 62.407000,24.416000 61.917000,23.966000 61.417000,23.527000 60.907000,23.098000 60.388000,22.680000 59.859000,22.273000 59.322000,21.877000 58.776000,21.493000 58.222000,21.120000 57.660000,20.759000 57.089000,20.411000 56.511000,20.074000 55.926000,19.750000 55.334000,19.438000 54.734000,19.138000 54.128000,18.852000 53.516000,18.579000 52.898000,18.318000 52.274000,18.071000 51.644000,17.837000 51.010000,17.617000 50.370000,17.410000 49.726000,17.217000 49.077000,17.038000 48.425000,16.873000 47.768000,16.721000 47.109000,16.584000 46.446000,16.461000 45.780000,16.352000 45.112000,16.257000 44.442000,16.177000 43.769000,16.111000 43.096000,16.059000 42.420000,16.022000 41.744000,16.000000 41.068000,15.992000 40.390000,15.999000 39.713000,16.020000 39.036000,16.055000 38.360000,16.106000 37.685000,16.170000 37.011000,16.250000 36.338000,16.343000 35.667000,16.452000 34.999000,16.574000 34.333000,16.712000 33.669000,16.863000 33.009000,17.029000 32.352000,17.209000 31.699000,17.403000 31.050000,17.611000 30.405000,17.834000 29.765000,18.070000 29.129000,18.320000 28.499000,18.584000 27.875000,18.861000 27.256000,19.152000 26.643000,19.456000 26.037000,19.774000 25.437000,20.104000 24.845000,20.448000 24.259000,20.804000 23.681000,21.173000 23.111000,21.555000 22.549000,21.949000 21.995000,22.355000 21.450000,22.773000 20.914000,23.203000 20.387000,23.645000 19.869000,24.098000 19.360000,24.562000 18.862000,25.037000 18.374000,25.523000 17.896000,26.020000 17.428000,26.527000 16.972000,27.045000 16.526000,27.572000 16.092000,28.109000 15.669000,28.655000 15.258000,29.211000 14.858000,29.776000 14.471000,30.349000 14.095000,30.931000 13.733000,31.521000 13.382000,32.119000 13.045000,32.725000 12.721000,33.338000 12.409000,33.958000 12.111000,34.585000 11.826000,35.219000 11.555000,35.858000 11.298000,36.504000 11.054000,37.156000 10.824000,37.813000 10.609000,38.475000 10.407000,39.142000 10.220000,39.813000 10.047000,40.489000 9.889000,41.168000 9.745000,41.851000 9.616000,42.537000 9.501000,43.226000 9.402000,43.918000 9.317000,44.612000 9.247000,45.308000 9.192000,46.006000 9.152000,46.705000 9.127000,47.405000 9.117000,48.106000 9.123000,48.807000 9.143000,49.509000 9.178000,50.210000 9.229000,50.910000 9.294000,51.610000 9.375000,52.308000 9.470000,53.005000 9.581000,53.699000 9.706000,54.392000 9.847000,55.082000 10.002000,55.769000 10.172000,56.453000 10.357000,57.134000 10.556000,57.811000 10.770000,58.483000 10.999000,59.151000 11.242000,59.815000 11.499000,60.473000 11.771000,61.126000 12.057000,61.774000 12.356000,62.415000 12.670000,63.050000 12.997000,63.678000 13.338000,64.300000 13.692000,64.914000 14.060000,65.521000 14.440000,66.120000 14.834000,66.711000 15.240000,67.294000 15.659000,67.868000 16.091000,68.433000 16.535000,68.990000 16.990000,69.536000 17.458000,70.073000 17.937000,70.601000 18.428000,71.118000 18.930000,71.624000 19.443000,72.120000 19.967000,72.605000 20.501000,73.079000 21.046000,73.541000 21.600000,73.992000 22.165000,74.431000 22.739000,74.858000 23.322000,75.273000 23.915000,75.675000 24.516000,76.065000 25.126000,76.442000 25.743000,76.805000 26.369000,77.156000 27.003000,77.493000 27.644000,77.817000 28.292000,78.127000 28.947000,78.423000 29.608000,78.705000 30.276000,78.973000 30.950000,79.227000 31.629000,79.466000 32.313000,79.691000 33.003000,79.901000 33.697000,80.096000 34.395000,80.277000 35.098000,80.442000 35.804000,80.593000 36.513000,80.728000 37.226000,80.848000 37.942000,80.953000 38.659000,81.042000 39.379000,81.116000 40.101000,81.175000 40.824000,81.218000 41.548000,81.245000 42.273000,81.257000 42.998000,81.253000 43.724000,81.234000 44.449000,81.199000 45.174000,81.149000 45.897000,81.083000 46.620000,81.001000 47.341000,80.904000 48.059000,80.791000 48.776000,80.663000 49.490000,80.520000 50.201000,80.361000 50.909000,80.187000 51.613000,79.997000 52.314000,79.792000 53.010000,79.573000 53.701000,79.338000 54.388000,79.088000 55.069000,78.824000 55.745000,78.544000 56.415000,78.251000 57.079000,77.942000 57.737000,77.620000 58.387000,77.283000 59.031000,76.932000 59.667000,76.567000 60.295000,76.189000 60.916000,75.797000 61.528000,75.391000 62.131000,74.972000 62.726000,74.540000 63.311000,74.096000 63.888000,73.638000 64.454000,73.168000 65.010000,72.686000 65.557000,72.192000 66.092000,71.686000 66.617000,71.168000 67.131000,70.639000 67.634000,70.099000 68.125000,69.548000 68.604000,68.986000 69.071000,68.414000 69.527000,67.831000 69.969000,67.239000 70.400000,66.637000 70.817000,66.026000 71.221000,65.405000 71.612000,64.776000 71.990000,64.138000 72.354000,63.492000 72.704000,62.838000 73.040000,62.176000 73.362000,61.507000 73.670000,60.831000 73.963000,60.148000 74.242000,59.459000 74.505000,58.763000 74.754000,58.062000 74.988000,57.355000 75.207000,56.643000 75.411000,55.926000 75.599000,55.205000 75.772000,54.479000 75.929000,53.750000 76.070000,53.017000 76.196000,52.281000 76.306000,51.542000 76.400000,50.800000 76.478000,50.057000 76.541000,49.311000 76.587000,48.564000 76.617000,47.816000 76.631000,47.067000 76.629000,46.317000 76.611000,45.568000 76.577000,44.818000 76.527000,44.070000 76.460000,43.322000 76.378000,42.575000 76.279000,41.830000 76.165000,41.087000 76.034000,40.347000 75.887000,39.609000 75.725000,38.874000 75.547000,38.142000 75.353000,37.414000 75.143000,36.690000 74.918000,35.970000 74.677000,35.255000 74.421000,34.545000 74.149000,33.841000 73.862000,33.142000 73.561000,32.449000 73.244000,31.763000 72.912000,31.083000 72.566000,30.410000 72.205000,29.744000 71.830000,29.086000 71.440000,28.436000 71.037000,27.795000 70.620000,27.162000 70.189000,26.537000 69.744000,25.922000 69.286000,25.316000 68.815000,24.720000 68.331000,24.134000 67.835000,23.558000 67.326000,22.993000 66.805000,22.438000 66.271000,21.895000 65.726000,21.363000 65.170000,20.843000 64.602000,20.334000 64.023000,19.838000 63.433000,19.354000 62.833000,18.882000 62.222000,18.423000 61.601000,17.978000 60.971000,17.545000 60.332000,17.126000 59.683000,16.721000 59.025000,16.330000 58.359000,15.952000 57.685000,15.589000 57.002000,15.240000 56.312000,14.906000 55.615000,14.587000 54.911000,14.282000 54.200000,13.993000 53.482000,13.719000 52.759000,13.460000 52.030000,13.217000 51.295000,12.989000 50.556000,12.777000 49.812000,12.581000 49.063000,12.401000 48.310000,12.237000 47.554000,12.089000 46.795000,11.957000 46.032000,11.842000 45.267000,11.743000 44.499000,11.660000 43.730000,11.594000 42.959000,11.544000 42.187000,11.511000 41.414000,11.495000 40.640000,11.495000 39.866000,11.512000 39.093000,11.545000 38.320000,11.595000 37.548000,11.662000 36.777000,11.745000 36.008000,11.845000 35.241000,11.961000 34.476000,12.094000 33.714000,12.244000 32.955000,12.410000 32.200000,12.592000 31.448000,12.790000 30.700000,13.005000 29.957000,13.235000 29.219000,13.482000 28.485000,13.745000 27.758000,14.023000 27.036000,14.317000 26.320000,14.627000 25.611000,14.952000 24.908000,15.292000 24.213000,15.648000 23.526000,16.019000 22.846000,16.404000 22.174000,16.804000 21.511000,17.219000 20.857000,17.648000 20.211000,18.091000 19.575000,18.548000 18.949000,19.019000 18.333000,19.503000 17.727000,20.001000 17.132000,20.512000 16.547000,21.036000 15.974000,21.572000 15.412000,22.121000 14.862000,22.682000 14.324000,23.255000 13.797000,23.840000 13.284000,24.436000 12.783000,25.043000 12.295000,25.661000 11.820000,26.289000 11.359000,26.928000 10.911000,27.577000 10.478000,28.236000 10.058000,28.904000 9.652000,29.582000 9.261000,30.268000 8.885000,30.963000 8.524000,31.666000 8.177000,32.376000 7.846000,33.095000 7.530000,33.820000 7.230000,34.553000 6.946000,35.292000 6.677000,36.038000 6.424000,36.789000 6.187000,37.546000 5.967000,38.308000 5.763000,39.075000 5.575000,39.847000 5.404000,40.622000 5.250000,41.402000 5.112000,42.185000 4.991000,42.971000 4.887000,43.760000 4.800000,44.551000 4.729000,45.344000 4.676000,46.139000 4.640000,46.935000 4.621000,47.733000 4.619000,48.530000 4.635000,49.328000 4.667000,50.126000 4.717000,50.923000 4.784000,51.719000 4.868000,52.514000 4.969000,53.307000 5.087000,54.099000 5.222000,54.887000 5.374000,55.673000 5.543000,56.456000 5.729000,57.236000 5.931000,58.011000 6.150000,58.783000 6.386000,59.550000 6.639000,60.312000 6.908000,61.068000 7.193000,61.819000 7.494000,62.564000 7.812000,63.303000 8.145000,64.035000 8.494000,64.760000 8.859000,65.477000 9.239000,66.187000 9.635000,66.889000 10.046000,67.582000 10.471000,68.267000 10.912000,68.942000 11.367000,69.609000 11.837000,70.265000 12.320000,70.912000 12.818000,71.549000 13.330000,72.174000 13.855000,72.789000 14.393000,73.393000 14.944000,73.985000 15.509000,74.566000 16.085000,75.134000 16.674000,75.691000 17.276000,76.234000 17.889000,76.765000 18.513000,77.283000 19.149000,77.787000 19.795000,78.278000 20.453000,78.755000 21.121000,79.218000 21.798000,79.667000 22.486000,80.101000 23.183000,80.521000 23.889000,80.926000 24.604000,81.315000 25.327000,81.690000 26.059000,82.048000 26.798000,82.391000 27.545000,82.719000 28.299000,83.030000 29.060000,83.325000 29.828000,83.604000 30.601000,83.866000 31.381000,84.112000 32.165000,84.341000 32.955000,84.554000 33.750000,84.749000 34.548000,84.927000 35.351000,85.088000 36.158000,85.232000 36.967000,85.359000 37.780000,85.468000 38.595000,85.560000 39.412000,85.634000 40.231000,85.691000 41.051000,85.730000 41.872000,85.752000 42.694000,85.756000 43.516000,85.742000 44.338000,85.711000 45.159000,85.662000 45.979000,85.595000 46.798000,85.511000 47.616000,85.409000 48.431000,85.289000 49.244000,85.152000 50.054000,84.998000 50.861000,84.825000 51.665000,84.636000 52.464000,84.429000 53.259000,84.205000 54.050000,83.964000 54.835000,83.706000 55.615000,83.431000 56.389000,83.140000 57.158000,82.831000 57.919000,82.506000 58.674000,82.165000 59.421000,81.807000 60.161000,81.433000 60.893000,81.043000 61.617000,80.637000 62.332000,80.216000 63.039000,79.780000 63.736000,79.328000 64.423000,78.861000 65.101000,78.379000 65.768000,77.882000 66.425000,77.371000 67.070000,76.846000 67.705000,76.307000 68.328000,75.754000 68.940000,75.188000 69.539000,74.609000 70.126000,74.016000 70.700000,73.411000 71.262000,72.793000 71.810000,72.163000 72.345000,71.522000 72.866000,70.869000 73.373000,70.204000 73.866000,69.528000 74.344000,68.842000 74.808000,68.145000 75.257000,67.439000 75.691000,66.722000 76.109000,65.996000 76.512000,65.261000 76.899000,64.517000 77.271000,63.765000 77.626000,63.004000 77.965000,62.236000 78.287000,61.461000 78.593000,60.678000 78.882000,59.889000 79.154000,59.093000 79.410000,58.291000 79.647000,57.484000 79.868000,56.671000 80.071000,55.854000 80.257000,55.032000 80.425000,54.206000 80.575000,53.376000 80.708000,52.543000 80.822000,51.707000 80.919000,50.868000 80.998000,50.028000 81.058000,49.185000 81.101000,48.341000 81.125000,47.495000 81.131000,46.650000 81.119000,45.803000 81.089000,44.957000 81.041000,44.112000 80.974000,43.267000 80.890000,42.424000 80.787000,41.582000 80.666000,40.743000 80.527000,39.906000 80.370000,39.072000 80.195000,38.241000 80.002000,37.413000 79.791000,36.590000 79.563000,35.771000 79.317000,34.957000 79.054000,34.148000 78.773000,33.344000 78.474000,32.547000 78.159000,31.756000 77.826000,30.971000 77.477000,30.193000 77.111000,29.423000 76.728000,28.661000 76.329000,27.906000 75.913000,27.160000 75.482000,26.423000 75.034000,25.695000 74.571000,24.977000 74.092000,24.268000 73.598000,23.570000 73.089000,22.882000 72.565000,22.205000 72.026000,21.539000 71.473000,20.885000 70.906000,20.242000 70.325000,19.612000 69.730000,18.993000 69.122000,18.388000 68.501000,17.795000 67.867000,17.216000 67.221000,16.650000 66.562000,16.098000 65.891000,15.561000 65.209000,15.037000 64.515000,14.528000 63.810000,14.034000 63.095000,13.555000 62.369000,13.091000 61.633000,12.643000 60.887000,12.211000 60.132000,11.794000 59.367000,11.394000 58.594000,11.010000 57.813000,10.643000 57.024000,10.292000 56.227000,9.958000 55.422000,9.641000 54.611000,9.342000 53.793000,9.060000 52.970000,8.795000 52.140000,8.549000 51.305000,8.320000 50.464000,8.108000 49.619000,7.915000 48.770000,7.740000 47.917000,7.583000 47.061000,7.445000 46.201000,7.325000 45.339000,7.223000 44.474000,7.140000 43.607000,7.076000 42.739000,7.030000 41.870000,7.002000 41.000000,6.994000 40.130000,7.004000 39.259000,7.033000 38.390000,7.080000 37.521000,7.146000 36.653000,7.231000 35.788000,7.335000 34.924000,7.457000 34.063000,7.597000 33.204000,7.757000 32.349000,7.934000 31.498000,8.131000 30.651000,8.345000 29.808000,8.578000 28.970000,8.828000 28.137000,9.097000 27.310000,9.384000 26.490000,9.689000 25.675000,10.011000 24.867000,10.351000 24.067000,10.708000 23.274000,11.083000 22.489000,11.474000 21.712000,11.883000 20.944000,12.308000 20.185000,12.750000 19.435000,13.208000 18.696000,13.682000 17.966000,14.173000 17.246000,14.679000 16.538000,15.200000 15.840000,15.737000 15.154000,16.289000 14.480000,16.856000 13.818000,17.438000 13.168000,18.033000 12.531000,18.643000 11.907000,19.267000 11.296000,19.904000 10.699000,20.554000 10.115000,21.217000 9.546000,21.893000 8.991000,22.581000 8.451000,23.281000 7.926000,23.993000 7.417000,24.716000 6.922000,25.451000 6.444000,26.196000 5.981000,26.951000 5.534000,27.717000 5.104000,28.492000 4.691000,29.276000 4.294000,30.070000 3.914000,30.872000 3.552000,31.682000 3.206000,32.501000 2.879000,33.327000 2.569000,34.160000 2.277000,34.999000 2.003000,35.846000 1.747000,36.698000 1.509000,37.556000 1.290000,38.419000 1.089000,39.287000 0.907000,40.159000 0.743000,41.035000 0.599000,41.915000 0.473000,42.799000 0.366000,43.685000 0.279000,44.573000 0.210000,45.464000 0.160000,46.356000 0.130000,47.249000 0.119000,48.143000 0.127000,49.037000 0.154000,49.932000 0.201000,50.826000 0.266000,51.719000 0.351000,52.610000 0.455000,53.500000 0.579000,54.388000 0.721000,55.274000 0.882000,56.156000 1.063000,57.035000 1.262000,57.911000 1.480000,58.782000 1.717000,59.648000 1.972000,60.510000 2.246000,61.366000 2.539000,62.217000 2.850000,63.061000 3.178000,63.899000 3.526000,64.730000 3.890000,65.553000 4.273000,66.369000 4.673000,67.177000 5.091000,67.976000 5.526000,68.766000 5.978000,69.547000 6.447000,70.319000 6.932000,71.080000 7.434000,71.831000 7.952000,72.572000 8.486000,73.301000 9.036000,74.019000 9.601000,74.725000 10.182000,75.420000 10.777000,76.102000 11.387000,76.771000 12.012000,77.427000 12.651000,78.070000 13.304000,78.699000 13.970000,79.314000 14.650000,79.915000 15.343000,80.502000 16.048000,81.073000 16.766000,81.630000 17.496000,82.171000 18.237000,82.697000 18.990000,83.207000 19.754000,83.700000 20.529000,84.178000 21.314000,84.638000 22.109000,85.082000 22.914000,85.509000 23.728000,85.919000 24.551000,86.311000 25.382000,86.686000 26.222000,87.042000 27.069000,87.381000 27.924000,87.702000 28.786000,88.004000 29.654000,88.288000 30.529000,88.553000 31.409000,88.799000 32.295000,89.027000 33.186000,89.235000 34.081000,89.425000 34.981000,89.595000 35.884000,89.746000 36.791000,89.877000 37.701000,89.989000 38.613000,90.082000 39.527000,90.155000 40.443000,90.208000 41.361000,90.242000 42.279000,90.256000 43.197000,90.250000 44.116000,90.224000 45.034000,90.179000 45.951000,90.114000 46.867000,90.029000 47.781000,89.925000 48.694000,89.800000 49.603000,89.657000 50.510000,89.493000 51.413000,89.311000 52.312000,89.108000 53.208000,88.887000 54.098000,88.646000 54.984000,88.386000 55.864000,88.107000 56.738000,87.809000 57.605000,87.492000 58.467000,87.156000 59.321000,86.802000 60.167000,86.430000 61.006000,86.039000 61.836000,85.630000 62.658000,85.204000 63.470000,84.759000 64.273000,84.297000 65.067000,83.818000 65.850000,83.322000 66.622000,82.809000 67.384000,82.279000 68.134000,81.733000 68.873000,81.170000 69.600000,80.592000 70.314000,79.997000 71.016000,79.388000 71.704000,78.763000 72.379000,78.124000 73.041000,77.470000 73.689000,76.801000 74.322000,76.119000 74.941000,75.422000 75.545000,74.713000 76.134000,73.990000 76.707000,73.255000 77.265000,72.507000 77.806000,71.747000 78.332000,70.976000 78.840000,70.193000 79.332000,69.399000 79.807000,68.594000 80.265000,67.779000 80.706000,66.954000 81.128000,66.120000 81.533000,65.276000 81.920000,64.424000 82.288000,63.563000 82.638000,62.694000 82.970000,61.818000 83.282000,60.934000 83.576000,60.043000 83.850000,59.147000 84.106000,58.244000 84.342000,57.335000 84.558000,56.421000 84.755000,55.503000 84.932000,54.580000 85.089000,53.653000 85.227000,52.723000 85.344000,51.790000 85.442000,50.854000 85.519000,49.915000 85.576000,48.976000 85.613000,48.034000 85.630000,47.092000 85.626000,46.149000 85.602000,45.207000 85.558000,44.264000 85.494000,43.323000 85.410000,42.383000 85.305000,41.444000 85.180000,40.508000 85.035000,39.574000 84.870000,38.643000 84.685000,37.716000 84.480000,36.793000 84.255000,35.873000 84.010000,34.959000 83.746000,34.050000 83.462000,33.146000 83.158000,32.248000 82.835000,31.357000 82.494000,30.472000 82.133000,29.595000 81.753000,28.726000 81.354000,27.864000 80.937000,27.011000 80.501000,26.167000 80.048000,25.332000 79.576000,24.507000 79.086000,23.691000 78.579000,22.887000 78.055000,22.093000 77.513000,21.310000 76.955000,20.538000 76.380000,19.779000 75.788000,19.032000 75.181000,18.297000 74.557000,17.576000 73.918000,16.868000 73.264000,16.173000 72.595000,15.493000 71.911000,14.826000 71.212000,14.175000 70.500000,13.538000 69.774000,12.916000 69.034000,12.310000 68.281000,11.720000 67.515000,11.146000 66.737000,10.589000 65.947000,10.048000 65.146000,9.524000 64.333000,9.017000 63.508000,8.527000 62.674000,8.055000 61.829000,7.601000 60.974000,7.166000 60.110000,6.748000 59.236000,6.349000 58.354000,5.969000 57.464000,5.607000 56.566000,5.265000 55.660000,4.942000 54.748000,4.638000 53.829000,4.354000 52.903000,4.090000 51.972000,3.846000 51.035000,3.621000 50.094000,3.417000 49.148000,3.232000 48.198000,3.069000 47.244000,2.925000 46.287000,2.802000 45.327000,2.700000 44.365000,2.618000 43.401000,2.557000 42.436000,2.516000 41.470000,2.496000 40.503000,2.497000 39.536000,2.519000 38.570000,2.562000 37.604000,2.625000 36.640000,2.709000 35.677000,2.814000 34.716000,2.940000 33.758000,3.086000 32.803000,3.253000 31.852000,3.440000 30.904000,3.648000 29.961000,3.876000 29.023000,4.124000 28.090000,4.393000 27.162000,4.682000 26.241000,4.990000 25.326000,5.319000 24.418000,5.667000 23.517000,6.035000 22.625000,6.422000 21.740000,6.828000 20.864000,7.254000 19.998000,7.698000 19.140000,8.161000 18.293000,8.642000 17.455000,9.142000 16.629000,9.660000 15.813000,10.195000 15.009000,10.749000 14.217000,11.319000 13.437000,11.907000 12.669000,12.511000 11.914000,13.132000 11.173000,13.769000 10.445000,14.422000 9.731000,15.091000 9.031000,15.776000 8.346000,16.475000 7.676000,17.189000 7.022000,17.918000 6.383000,18.661000 5.759000,19.417000 5.152000,20.188000 4.562000,20.971000 3.988000,21.767000 3.431000,22.575000 2.892000,23.396000 2.370000,24.228000 1.866000,25.072000 1.380000,25.926000 0.912000,26.791000 0.463000,27.666000 0.032000,28.551000 -0.379000,29.445000 -0.771000,30.348000 -1.144000,31.260000 -1.498000,32.179000 -1.831000,33.107000 -2.145000,34.041000 -2.439000,34.983000 -2.712000,35.931000 -2.965000,36.885000 -3.198000,37.844000 -3.410000,38.809000 -3.601000,39.778000 -3.772000,40.751000 -3.922000,41.729000 -4.050000,42.709000 -4.158000,43.692000 -4.245000,44.678000 -4.310000,45.666000 -4.354000,46.655000 -4.377000,47.645000 -4.379000,48.636000 -4.359000,49.627000 -4.318000,50.618000 -4.256000,51.608000 -4.172000,52.597000 -4.067000,53.584000 -3.941000,54.568000 -3.794000,55.551000 -3.626000,56.530000 -3.437000,57.505000 -3.226000,58.477000 -2.995000,59.444000 -2.743000,60.407000 -2.470000,61.364000 -2.177000,62.315000 -1.863000,63.260000 -1.529000,64.199000 -1.175000,65.130000 -0.800000,66.054000 -0.406000,66.970000 0.008000,67.877000 0.442000,68.776000 0.894000,69.665000 1.367000,70.545000 1.858000,71.415000 2.367000,72.274000 2.895000,73.123000 3.442000,73.960000 4.007000,74.786000 4.589000,75.599000 5.189000,76.400000 5.806000,77.188000 6.440000,77.963000 7.091000,78.725000 7.758000,79.473000 8.442000,80.206000 9.141000,80.925000 9.856000,81.628000 10.586000,82.317000 11.331000,82.990000 12.090000,83.647000 12.864000,84.287000 13.651000,84.912000 14.452000,85.519000 15.266000,86.109000 16.093000,86.682000 16.932000,87.237000 17.783000,87.774000 18.646000,88.292000 19.520000,88.793000 20.405000,89.274000 21.300000,89.737000 22.205000,90.180000 23.120000,90.604000 24.044000,91.008000 24.977000,91.393000 25.918000,91.758000 26.868000,92.102000 27.824000,92.426000 28.788000,92.729000 29.758000,93.012000 30.735000,93.274000 31.717000,93.515000 32.704000,93.735000 33.697000,93.934000 34.693000,94.111000 35.694000,94.267000 36.698000,94.402000 37.705000,94.515000 38.715000,94.606000 39.726000,94.676000 40.739000,94.724000 41.750000,94.750000 83.500000,94.750000 83.500000,95.250000 41.750000,95.250000 40.721000,95.224000 39.697000,95.175000 38.675000,95.105000 37.655000,95.012000 36.637000,94.898000 35.622000,94.762000 34.611000,94.604000 33.604000,94.425000 32.601000,94.224000 31.603000,94.002000 30.610000,93.758000 29.624000,93.494000 28.643000,93.208000 27.669000,92.901000 26.702000,92.574000 25.743000,92.226000 24.792000,91.857000 23.849000,91.469000 22.915000,91.060000 21.990000,90.631000 21.075000,90.183000 20.170000,89.716000 19.276000,89.229000 18.393000,88.724000 17.521000,88.199000 16.661000,87.657000 15.812000,87.096000 14.977000,86.517000 14.154000,85.920000 13.345000,85.307000 12.549000,84.676000 11.767000,84.028000 11.000000,83.364000 10.247000,82.684000 9.509000,81.988000 8.787000,81.277000 8.080000,80.551000 7.389000,79.810000 6.715000,79.054000 6.057000,78.284000 5.416000,77.501000 4.792000,76.704000 4.186000,75.895000 3.597000,75.072000 3.026000,74.238000 2.474000,73.392000 1.940000,72.534000 1.425000,71.666000 0.928000,70.786000 0.451000,69.897000 -0.006000,68.998000 -0.445000,68.090000 -0.863000,67.172000 -1.262000,66.247000 -1.640000,65.313000 -1.998000,64.371000 -2.336000,63.423000 -2.653000,62.468000 -2.950000,61.506000 -3.225000,60.539000 -3.480000,59.566000 -3.714000,58.588000 -3.926000,57.606000 -4.118000,56.620000 -4.288000,55.630000 -4.437000,54.637000 -4.564000,53.642000 -4.670000,52.644000 -4.754000,51.645000 -4.817000,50.644000 -4.859000,49.643000 -4.879000,48.641000 -4.877000,47.639000 -4.854000,46.638000 -4.809000,45.638000 -4.743000,44.640000 -4.656000,43.643000 -4.547000,42.649000 -4.417000,41.658000 -4.265000,40.670000 -4.093000,39.686000 -3.900000,38.707000 -3.685000,37.732000 -3.450000,36.762000 -3.194000,35.797000 -2.918000,34.839000 -2.621000,33.887000 -2.304000,32.943000 -1.966000,32.005000 -1.609000,31.075000 -1.232000,30.154000 -0.836000,29.241000 -0.420000,28.337000 0.015000,27.442000 0.470000,26.558000 0.942000,25.683000 1.434000,24.820000 1.943000,23.967000 2.471000,23.126000 3.016000,22.296000 3.579000,21.479000 4.159000,20.674000 4.756000,19.882000 5.370000,19.104000 6.000000,18.339000 6.646000,17.588000 7.308000,16.851000 7.985000,16.129000 8.678000,15.422000 9.385000,14.730000 10.107000,14.054000 10.843000,13.393000 11.592000,12.749000 12.355000,12.121000 13.132000,11.510000 13.920000,10.916000 14.721000,10.340000 15.534000,9.780000 16.359000,9.239000 17.195000,8.716000 18.041000,8.210000 18.898000,7.724000 19.765000,7.256000 20.641000,6.806000 21.527000,6.376000 22.421000,5.965000 23.323000,5.574000 24.234000,5.202000 25.152000,4.850000 26.077000,4.518000 27.008000,4.206000 27.946000,3.914000 28.890000,3.642000 29.838000,3.391000 30.792000,3.160000 31.750000,2.950000 32.712000,2.761000 33.678000,2.592000 34.646000,2.445000 35.617000,2.318000 36.591000,2.212000 37.566000,2.127000 38.542000,2.063000 39.520000,2.020000 40.497000,1.998000 41.475000,1.996000 42.452000,2.016000 43.428000,2.057000 44.402000,2.119000 45.375000,2.202000 46.345000,2.306000 47.313000,2.430000 48.277000,2.575000 49.238000,2.741000 50.194000,2.927000 51.147000,3.134000 52.094000,3.361000 53.035000,3.608000 53.971000,3.875000 54.901000,4.162000 55.823000,4.469000 56.739000,4.796000 57.647000,5.142000 58.547000,5.507000 59.439000,5.892000 60.322000,6.295000 61.196000,6.718000 62.061000,7.158000 62.915000,7.617000 63.759000,8.095000 64.593000,8.590000 65.415000,9.102000 66.225000,9.632000 67.024000,10.179000 67.811000,10.743000 68.585000,11.324000 69.347000,11.920000 70.094000,12.533000 70.829000,13.162000 71.549000,13.805000 72.256000,14.464000 72.947000,15.138000 73.624000,15.826000 74.286000,16.529000 74.932000,17.245000 75.563000,17.975000 76.177000,18.717000 76.775000,19.473000 77.357000,20.241000 77.921000,21.021000 78.469000,21.813000 78.999000,22.616000 79.512000,23.429000 80.007000,24.254000 80.484000,25.089000 80.943000,25.933000 81.384000,26.787000 81.806000,27.649000 82.209000,28.521000 82.593000,29.400000 82.958000,30.287000 83.304000,31.182000 83.630000,32.083000 83.937000,32.991000 84.224000,33.905000 84.492000,34.825000 84.739000,35.749000 84.967000,36.679000 85.174000,37.613000 85.361000,38.551000 85.528000,39.492000 85.675000,40.437000 85.801000,41.384000 85.907000,42.333000 85.993000,43.284000 86.058000,44.236000 86.102000,45.189000 86.126000,46.142000 86.130000,47.096000 86.113000,48.049000 86.075000,49.001000 86.018000,49.951000 85.939000,50.900000 85.841000,51.847000 85.722000,52.791000 85.583000,53.732000 85.424000,54.669000 85.245000,55.602000 85.046000,56.531000 84.827000,57.455000 84.588000,58.374000 84.330000,59.288000 84.052000,60.195000 83.755000,61.096000 83.439000,61.990000 83.104000,62.876000 82.750000,63.755000 82.377000,64.626000 81.986000,65.488000 81.577000,66.341000 81.149000,67.185000 80.704000,68.020000 80.241000,68.844000 79.760000,69.658000 79.262000,70.461000 78.748000,71.253000 78.216000,72.033000 77.669000,72.802000 77.105000,73.558000 76.525000,74.302000 75.929000,75.033000 75.318000,75.751000 74.692000,76.455000 74.052000,77.145000 73.396000,77.821000 72.727000,78.483000 72.044000,79.130000 71.347000,79.762000 70.638000,80.378000 69.915000,80.979000 69.180000,81.565000 68.433000,82.134000 67.674000,82.686000 66.903000,83.222000 66.122000,83.741000 65.330000,84.243000 64.527000,84.728000 63.715000,85.195000 62.893000,85.645000 62.062000,86.077000 61.222000,86.490000 60.373000,86.885000 59.517000,87.262000 58.653000,87.620000 57.782000,87.960000 56.904000,88.280000 56.020000,88.582000 55.130000,88.864000 54.234000,89.127000 53.333000,89.371000 52.427000,89.595000 51.517000,89.800000 50.604000,89.984000 49.687000,90.150000 48.766000,90.295000 47.844000,90.421000 46.919000,90.526000 45.992000,90.612000 45.064000,90.678000 44.135000,90.724000 43.206000,90.750000 42.277000,90.756000 41.348000,90.742000 40.420000,90.708000 39.493000,90.654000 38.568000,90.580000 37.645000,90.486000 36.725000,90.373000 35.807000,90.240000 34.893000,90.087000 33.983000,89.915000 33.077000,89.723000 32.176000,89.512000 31.280000,89.282000 30.389000,89.033000 29.504000,88.765000 28.626000,88.478000 27.754000,88.172000 26.889000,87.847000 26.031000,87.505000 25.182000,87.144000 24.341000,86.765000 23.508000,86.368000 22.684000,85.953000 21.870000,85.521000 21.066000,85.072000 20.271000,84.606000 19.487000,84.123000 18.714000,83.624000 17.952000,83.108000 17.202000,82.576000 16.464000,82.028000 15.737000,81.465000 15.024000,80.887000 14.323000,80.293000 13.635000,79.685000 12.961000,79.063000 12.300000,78.426000 11.654000,77.776000 11.021000,77.112000 10.404000,76.435000 9.801000,75.745000 9.214000,75.042000 8.642000,74.327000 8.086000,73.601000 7.545000,72.863000 7.021000,72.113000 6.513000,71.353000 6.022000,70.583000 5.548000,69.802000 5.090000,69.012000 4.650000,68.212000 4.228000,67.404000 3.823000,66.586000 3.436000,65.761000 3.066000,64.927000 2.715000,64.087000 2.382000,63.239000 2.068000,62.385000 1.772000,61.524000 1.494000,60.657000 1.236000,59.785000 0.996000,58.908000 0.775000,58.027000 0.574000,57.141000 0.391000,56.251000 0.228000,55.358000 0.084000,54.462000 -0.041000,53.564000 -0.146000,52.663000 -0.232000,51.761000 -0.298000,50.857000 -0.345000,49.952000 -0.373000,49.047000 -0.381000,48.142000 -0.370000,47.237000 -0.339000,46.333000 -0.289000,45.430000 -0.219000,44.529000 -0.131000,43.630000 -0.023000,42.733000 0.105000,41.840000 0.251000,40.949000 0.416000,40.062000 0.601000,39.179000 0.804000,38.301000 1.026000,37.427000 1.266000,36.559000 1.525000,35.697000 1.803000,34.840000 2.098000,33.990000 2.412000,33.147000 2.744000,32.311000 3.093000,31.483000 3.460000,30.663000 3.844000,29.851000 4.246000,29.048000 4.664000,28.254000 5.100000,27.469000 5.552000,26.695000 6.020000,25.930000 6.504000,25.176000 7.005000,24.433000 7.521000,23.701000 8.052000,22.980000 8.599000,22.271000 9.160000,21.575000 9.736000,20.891000 10.327000,20.220000 10.931000,19.562000 11.549000,18.917000 12.181000,18.286000 12.826000,17.668000 13.484000,17.065000 14.154000,16.477000 14.837000,15.903000 15.531000,15.344000 16.237000,14.801000 16.954000,14.273000 17.682000,13.761000 18.421000,13.264000 19.170000,12.784000 19.929000,12.320000 20.697000,11.873000 21.475000,11.443000 22.261000,11.029000 23.056000,10.633000 23.858000,10.254000 24.668000,9.892000 25.486000,9.548000 26.311000,9.222000 27.142000,8.913000 27.979000,8.623000 28.822000,8.351000 29.670000,8.097000 30.523000,7.862000 31.380000,7.645000 32.242000,7.446000 33.108000,7.266000 33.977000,7.105000 34.849000,6.962000 35.723000,6.839000 36.599000,6.734000 37.478000,6.648000 38.357000,6.581000 39.238000,6.533000 40.118000,6.504000 40.999000,6.494000 41.880000,6.502000 42.760000,6.530000 43.639000,6.577000 44.516000,6.642000 45.392000,6.726000 46.265000,6.829000 47.135000,6.951000 48.002000,7.091000 48.866000,7.249000 49.726000,7.427000 50.581000,7.622000 51.432000,7.836000 52.277000,8.068000 53.117000,8.318000 53.951000,8.586000 54.779000,8.871000 55.601000,9.174000 56.415000,9.495000 57.222000,9.833000 58.021000,10.188000 58.812000,10.560000 59.595000,10.949000 60.368000,11.354000 61.133000,11.776000 61.888000,12.213000 62.633000,12.667000 63.368000,13.137000 64.093000,13.622000 64.806000,14.122000 65.509000,14.637000 66.200000,15.167000 66.879000,15.712000 67.546000,16.271000 68.200000,16.843000 68.842000,17.430000 69.471000,18.030000 70.087000,18.643000 70.689000,19.269000 71.277000,19.907000 71.852000,20.558000 72.412000,21.221000 72.957000,21.895000 73.488000,22.580000 74.003000,23.277000 74.503000,23.984000 74.988000,24.702000 75.457000,25.429000 75.910000,26.166000 76.347000,26.912000 76.768000,27.668000 77.172000,28.432000 77.560000,29.204000 77.931000,29.983000 78.285000,30.771000 78.621000,31.565000 78.941000,32.367000 79.243000,33.174000 79.527000,33.988000 79.794000,34.807000 80.043000,35.632000 80.274000,36.461000 80.488000,37.295000 80.683000,38.132000 80.860000,38.974000 81.019000,39.819000 81.160000,40.666000 81.282000,41.516000 81.386000,42.369000 81.472000,43.223000 81.540000,44.078000 81.589000,44.934000 81.619000,45.791000 81.631000,46.648000 81.625000,47.505000 81.600000,48.360000 81.557000,49.215000 81.496000,50.069000 81.416000,50.920000 81.318000,51.770000 81.202000,52.616000 81.068000,53.460000 80.916000,54.301000 80.746000,55.137000 80.558000,55.969000 80.352000,56.797000 80.129000,57.620000 79.888000,58.438000 79.629000,59.250000 79.354000,60.055000 79.061000,60.855000 78.751000,61.647000 78.424000,62.433000 78.081000,63.211000 77.721000,63.981000 77.345000,64.743000 76.953000,65.497000 76.545000,66.241000 76.121000,66.976000 75.682000,67.702000 75.227000,68.418000 74.757000,69.124000 74.273000,69.819000 73.773000,70.503000 73.260000,71.176000 72.732000,71.838000 72.190000,72.488000 71.635000,73.126000 71.066000,73.751000 70.485000,74.364000 69.890000,74.964000 69.283000,75.551000 68.664000,76.125000 68.033000,76.685000 67.390000,77.231000 66.736000,77.763000 66.071000,78.280000 65.395000,78.783000 64.709000,79.271000 64.012000,79.744000 63.306000,80.202000 62.591000,80.644000 61.866000,81.071000 61.133000,81.482000 60.392000,81.877000 59.642000,82.255000 58.885000,82.618000 58.120000,82.964000 57.349000,83.293000 56.571000,83.606000 55.787000,83.901000 54.996000,84.180000 54.201000,84.441000 53.400000,84.685000 52.594000,84.912000 51.785000,85.121000 50.971000,85.313000 50.153000,85.488000 49.333000,85.644000 48.509000,85.783000 47.683000,85.904000 46.855000,86.008000 46.025000,86.093000 45.194000,86.161000 44.362000,86.210000 43.530000,86.242000 42.697000,86.256000 41.864000,86.252000 41.032000,86.230000 40.201000,86.190000 39.372000,86.133000 38.544000,86.058000 37.718000,85.965000 36.895000,85.854000 36.075000,85.726000 35.258000,85.580000 34.445000,85.416000 33.635000,85.236000 32.831000,85.038000 32.030000,84.823000 31.235000,84.591000 30.446000,84.342000 29.662000,84.076000 28.885000,83.793000 28.114000,83.494000 27.350000,83.179000 26.593000,82.847000 25.844000,82.500000 25.102000,82.136000 24.369000,81.757000 23.645000,81.362000 22.930000,80.952000 22.223000,80.527000 21.527000,80.087000 20.840000,79.632000 20.163000,79.163000 19.497000,78.680000 18.842000,78.182000 18.198000,77.671000 17.565000,77.147000 16.944000,76.609000 16.335000,76.058000 15.738000,75.494000 15.154000,74.918000 14.582000,74.330000 14.023000,73.730000 13.478000,73.118000 12.946000,72.495000 12.428000,71.861000 11.923000,71.216000 11.433000,70.561000 10.957000,69.895000 10.496000,69.220000 10.050000,68.535000 9.618000,67.842000 9.202000,67.139000 8.801000,66.428000 8.416000,65.709000 8.046000,64.981000 7.692000,64.247000 7.355000,63.505000 7.033000,62.757000 6.727000,62.002000 6.438000,61.241000 6.166000,60.474000 5.910000,59.702000 5.671000,58.925000 5.449000,58.143000 5.243000,57.357000 5.055000,56.567000 4.884000,55.774000 4.730000,54.977000 4.593000,54.178000 4.473000,53.376000 4.371000,52.572000 4.286000,51.766000 4.218000,50.959000 4.168000,50.152000 4.135000,49.343000 4.119000,48.535000 4.121000,47.726000 4.141000,46.918000 4.177000,46.111000 4.231000,45.306000 4.302000,44.502000 4.390000,43.700000 4.496000,42.900000 4.618000,42.104000 4.758000,41.310000 4.915000,40.520000 5.088000,39.734000 5.278000,38.952000 5.485000,38.174000 5.709000,37.402000 5.948000,36.635000 6.205000,35.873000 6.477000,35.118000 6.765000,34.368000 7.070000,33.626000 7.390000,32.890000 7.726000,32.162000 8.077000,31.442000 8.443000,30.729000 8.824000,30.025000 9.221000,29.330000 9.632000,28.643000 10.057000,27.966000 10.497000,27.298000 10.951000,26.640000 11.418000,25.992000 11.899000,25.355000 12.394000,24.729000 12.902000,24.113000 13.422000,23.509000 13.955000,22.917000 14.501000,22.336000 15.059000,21.767000 15.628000,21.211000 16.210000,20.667000 16.802000,20.136000 17.406000,19.618000 18.020000,19.114000 18.644000,18.623000 19.279000,18.145000 19.924000,17.682000 20.578000,17.233000 21.241000,16.798000 21.914000,16.378000 22.595000,15.972000 23.284000,15.581000 23.981000,15.205000 24.686000,14.845000 25.398000,14.500000 26.117000,14.170000 26.842000,13.856000 27.574000,13.558000 28.312000,13.276000 29.055000,13.010000 29.804000,12.759000 30.557000,12.526000 31.315000,12.308000 32.077000,12.107000 32.843000,11.922000 33.613000,11.754000 34.385000,11.603000 35.161000,11.468000 35.938000,11.350000 36.718000,11.249000 37.500000,11.164000 38.282000,11.097000 39.066000,11.046000 39.850000,11.012000 40.635000,10.995000 41.419000,10.995000 42.203000,11.012000 42.986000,11.045000 43.767000,11.095000 44.547000,11.163000 45.326000,11.246000 46.102000,11.347000 46.875000,11.464000 47.645000,11.597000 48.412000,11.747000 49.175000,11.914000 49.934000,12.096000 50.688000,12.295000 51.438000,12.510000 52.183000,12.741000 52.922000,12.987000 53.656000,13.250000 54.383000,13.528000 55.104000,13.821000 55.818000,14.130000 56.525000,14.454000 57.225000,14.793000 57.917000,15.146000 58.601000,15.514000 59.276000,15.897000 59.943000,16.294000 60.601000,16.705000 61.250000,17.130000 61.889000,17.568000 62.518000,18.020000 63.137000,18.486000 63.746000,18.964000 64.344000,19.455000 64.931000,19.958000 65.507000,20.474000 66.072000,21.001000 66.624000,21.541000 67.165000,22.092000 67.694000,22.654000 68.210000,23.227000 68.714000,23.811000 69.204000,24.406000 69.682000,25.010000 70.146000,25.625000 70.597000,26.249000 71.034000,26.882000 71.457000,27.524000 71.867000,28.175000 72.262000,28.834000 72.642000,29.501000 73.008000,30.176000 73.359000,30.859000 73.695000,31.548000 74.017000,32.245000 74.323000,32.947000 74.614000,33.656000 74.889000,34.371000 75.149000,35.091000 75.393000,35.816000 75.622000,36.546000 75.834000,37.280000 76.031000,38.018000 76.212000,38.760000 76.377000,39.506000 76.525000,40.255000 76.658000,41.006000 76.774000,41.759000 76.874000,42.515000 76.958000,43.272000 77.025000,44.031000 77.076000,44.790000 77.111000,45.550000 77.129000,46.311000 77.131000,47.071000 77.117000,47.831000 77.086000,48.590000 77.039000,49.347000 76.976000,50.104000 76.897000,50.858000 76.801000,51.610000 76.690000,52.360000 76.562000,53.107000 76.419000,53.850000 76.259000,54.590000 76.084000,55.326000 75.893000,56.058000 75.687000,56.785000 75.465000,57.507000 75.227000,58.224000 74.975000,58.935000 74.707000,59.641000 74.424000,60.340000 74.127000,61.033000 73.815000,61.719000 73.488000,62.398000 73.147000,63.069000 72.792000,63.733000 72.423000,64.388000 72.040000,65.035000 71.643000,65.673000 71.233000,66.303000 70.810000,66.923000 70.373000,67.534000 69.924000,68.135000 69.462000,68.726000 68.988000,69.306000 68.502000,69.876000 68.003000,70.436000 67.493000,70.984000 66.972000,71.520000 66.439000,72.046000 65.896000,72.559000 65.342000,73.061000 64.777000,73.550000 64.203000,74.027000 63.618000,74.491000 63.024000,74.942000 62.421000,75.380000 61.808000,75.805000 61.187000,76.216000 60.558000,76.614000 59.920000,76.998000 59.275000,77.368000 58.622000,77.724000 57.962000,78.066000 57.295000,78.394000 56.621000,78.706000 55.941000,79.004000 55.255000,79.288000 54.564000,79.556000 53.867000,79.810000 53.165000,80.048000 52.459000,80.271000 51.748000,80.479000 51.034000,80.671000 50.316000,80.848000 49.594000,81.009000 48.869000,81.155000 48.142000,81.285000 47.413000,81.399000 46.681000,81.497000 45.948000,81.580000 45.214000,81.647000 44.478000,81.698000 43.743000,81.734000 43.006000,81.753000 42.270000,81.757000 41.535000,81.745000 40.800000,81.717000 40.066000,81.673000 39.334000,81.614000 38.603000,81.539000 37.874000,81.448000 37.148000,81.342000 36.425000,81.220000 35.705000,81.083000 34.988000,80.930000 34.275000,80.762000 33.566000,80.579000 32.862000,80.381000 32.162000,80.168000 31.468000,79.940000 30.778000,79.697000 30.095000,79.439000 29.417000,79.167000 28.746000,78.881000 28.081000,78.580000 27.423000,78.266000 26.773000,77.937000 26.130000,77.595000 25.494000,77.239000 24.867000,76.870000 24.248000,76.487000 23.638000,76.092000 23.037000,75.683000 22.445000,75.262000 21.862000,74.829000 21.289000,74.383000 20.726000,73.926000 20.173000,73.456000 19.631000,72.975000 19.099000,72.483000 18.579000,71.980000 18.069000,71.466000 17.571000,70.941000 17.084000,70.406000 16.610000,69.861000 16.147000,69.306000 15.697000,68.741000 15.259000,68.167000 14.833000,67.584000 14.421000,66.993000 14.021000,66.393000 13.635000,65.785000 13.262000,65.169000 12.902000,64.545000 12.556000,63.914000 12.224000,63.276000 11.906000,62.631000 11.601000,61.980000 11.311000,61.323000 11.036000,60.660000 10.774000,59.992000 10.528000,59.318000 10.296000,58.640000 10.078000,57.957000 9.876000,57.270000 9.688000,56.579000 9.515000,55.885000 9.358000,55.187000 9.215000,54.487000 9.088000,53.783000 8.975000,53.078000 8.878000,52.371000 8.797000,51.662000 8.730000,50.951000 8.679000,50.240000 8.643000,49.529000 8.623000,48.816000 8.617000,48.105000 8.627000,47.393000 8.653000,46.682000 8.693000,45.972000 8.749000,45.264000 8.820000,44.557000 8.906000,43.852000 9.007000,43.150000 9.123000,42.450000 9.255000,41.753000 9.401000,41.060000 9.561000,40.370000 9.737000,39.684000 9.927000,39.002000 10.131000,38.325000 10.350000,37.653000 10.584000,36.986000 10.831000,36.324000 11.093000,35.668000 11.368000,35.019000 11.657000,34.375000 11.960000,33.738000 12.276000,33.109000 12.606000,32.486000 12.948000,31.871000 13.304000,31.264000 13.672000,30.664000 14.053000,30.074000 14.447000,29.491000 14.852000,28.918000 15.270000,28.354000 15.700000,27.799000 16.141000,27.253000 16.593000,26.718000 17.057000,26.192000 17.532000,25.677000 18.017000,25.173000 18.513000,24.679000 19.019000,24.196000 19.535000,23.725000 20.061000,23.265000 20.597000,22.816000 21.142000,22.380000 21.695000,21.955000 22.258000,21.543000 22.828000,21.142000 23.408000,20.755000 23.995000,20.380000 24.589000,20.018000 25.191000,19.669000 25.800000,19.333000 26.416000,19.011000 27.038000,18.702000 27.667000,18.406000 28.301000,18.125000 28.941000,17.857000 29.587000,17.603000 30.237000,17.363000 30.892000,17.137000 31.551000,16.925000 32.215000,16.728000 32.882000,16.545000 33.553000,16.377000 34.227000,16.223000 34.903000,16.084000 35.582000,15.959000 36.264000,15.849000 36.947000,15.754000 37.632000,15.673000 38.318000,15.607000 39.005000,15.556000 39.692000,15.520000 40.380000,15.499000 41.068000,15.492000 41.756000,15.500000 42.442000,15.523000 43.128000,15.561000 43.813000,15.613000 44.496000,15.680000 45.177000,15.761000 45.856000,15.858000 46.532000,15.968000 47.205000,16.093000 47.876000,16.233000 48.542000,16.387000 49.205000,16.555000 49.864000,16.737000 50.519000,16.933000 51.168000,17.143000 51.813000,17.367000 52.453000,17.604000 53.087000,17.855000 53.715000,18.120000 54.337000,18.398000 54.953000,18.689000 55.562000,18.993000 56.164000,19.310000 56.758000,19.639000 57.346000,19.981000 57.925000,20.336000 58.497000,20.702000 59.060000,21.081000 59.614000,21.472000 60.160000,21.874000 60.697000,22.287000 61.225000,22.712000 61.743000,23.148000 62.251000,23.594000 62.749000,24.052000 63.238000,24.519000 63.715000,24.997000 64.183000,25.485000 64.639000,25.982000 65.084000,26.489000 65.519000,27.005000 65.941000,27.530000 66.353000,28.063000 66.752000,28.605000 67.139000,29.156000 67.515000,29.714000 67.878000,30.280000 68.229000,30.853000 68.567000,31.433000 68.892000,32.020000 69.205000,32.614000 69.505000,33.214000 69.791000,33.820000 70.065000,34.432000 70.325000,35.049000 70.571000,35.672000 70.804000,36.299000 71.024000,36.931000 71.229000,37.566000 71.421000,38.206000 71.599000,38.850000 71.763000,39.497000 71.913000,40.147000 72.049000,40.800000 72.171000,41.455000 72.278000,42.112000 72.372000,42.771000 72.451000,43.432000 72.516000,44.094000 72.567000,44.757000 72.603000,45.420000 72.625000,46.084000 72.633000,46.748000 72.627000,47.411000 72.606000,48.074000 72.572000,48.736000 72.523000,49.396000 72.459000,50.056000 72.382000,50.713000 72.291000,51.368000 72.186000,52.021000 72.066000,52.671000 71.933000,53.317000 71.786000,53.961000 71.626000,54.601000 71.451000,55.237000 71.264000,55.869000 71.062000,56.496000 70.848000,57.119000 70.620000,57.736000 70.379000,58.348000 70.125000,58.955000 69.859000,59.556000 69.579000,60.150000 69.287000,60.738000 68.983000,61.319000 68.666000,61.894000 68.338000,62.461000 67.997000,63.021000 67.645000,63.573000 67.281000,64.117000 66.905000,64.652000 66.519000,65.180000 66.121000,65.698000 65.712000,66.208000 65.293000,66.708000 64.864000,67.200000 64.424000,67.681000 63.974000,68.153000 63.514000,68.615000 63.045000,69.066000 62.566000,69.507000 62.079000,69.938000 61.582000,70.358000 61.077000,70.767000 60.563000,71.164000 60.041000,71.550000 59.511000,71.925000 58.974000,72.288000 58.429000,72.640000 57.877000,72.979000 57.319000,73.306000 56.753000,73.621000 56.181000,73.924000 55.604000,74.214000 55.020000,74.492000 54.431000,74.757000 53.836000,75.009000 53.237000,75.247000 52.633000,75.473000 52.024000,75.686000 51.412000,75.886000 50.795000,76.072000 50.175000,76.245000 49.552000,76.404000 48.926000,76.550000 48.297000,76.683000 47.666000,76.802000 47.032000,76.907000 46.397000,76.998000 45.761000,77.076000 45.123000,77.140000 44.484000,77.190000 43.845000,77.227000 43.205000,77.250000 42.566000,77.259000 41.927000,77.254000 41.288000,77.235000 40.650000,77.203000 40.013000,77.157000 39.378000,77.098000 38.744000,77.025000 38.113000,76.938000 37.484000,76.838000 36.857000,76.725000 36.234000,76.598000 35.613000,76.457000 34.997000,76.304000 34.383000,76.137000 33.774000,75.958000 33.169000,75.765000 32.569000,75.560000 31.974000,75.342000 31.384000,75.111000 30.799000,74.868000 30.220000,74.612000 29.646000,74.344000 29.079000,74.064000 28.519000,73.772000 27.965000,73.469000 27.418000,73.153000 26.878000,72.826000 26.346000,72.488000 25.821000,72.138000 25.304000,71.778000 24.796000,71.407000 24.295000,71.025000 23.804000,70.632000 23.321000,70.230000 22.847000,69.817000 22.382000,69.394000 21.927000,68.962000 21.481000,68.520000 21.045000,68.069000 20.620000,67.609000 20.204000,67.141000 19.799000,66.663000 19.404000,66.178000 19.020000,65.684000 18.647000,65.182000 18.285000,64.673000 17.934000,64.156000 17.595000,63.632000 17.267000,63.102000 16.951000,62.564000 16.646000,62.021000 16.354000,61.471000 16.073000,60.915000 15.805000,60.354000 15.549000,59.787000 15.305000,59.215000 15.074000,58.639000 14.855000,58.058000 14.649000,57.473000 14.456000,56.883000 14.275000,56.290000 14.107000,55.694000 13.953000,55.094000 13.811000,54.492000 13.682000,53.887000 13.567000,53.280000 13.464000,52.670000 13.375000,52.059000 13.299000,51.447000 13.236000,50.833000 13.186000,50.219000 13.150000,49.603000 13.126000,48.988000 13.116000,48.372000 13.120000,47.757000 13.136000,47.143000 13.166000,46.529000 13.209000,45.916000 13.264000,45.305000 13.334000,44.695000 13.416000,44.087000 13.511000,43.482000 13.619000,42.879000 13.739000,42.278000 13.873000,41.681000 14.019000,41.087000 14.178000,40.497000 14.350000,39.911000 14.534000,39.329000 14.730000,38.751000 14.939000,38.178000 15.160000,37.609000 15.393000,37.046000 15.637000,36.489000 15.894000,35.937000 16.162000,35.391000 16.442000,34.851000 16.733000,34.318000 17.035000,33.791000 17.349000,33.271000 17.673000,32.758000 18.008000,32.253000 18.354000,31.755000 18.710000,31.265000 19.076000,30.783000 19.452000,30.310000 19.839000,29.845000 20.235000,29.388000 20.640000,28.940000 21.055000,28.502000 21.479000,28.072000 21.911000,27.652000 22.353000,27.242000 22.803000,26.841000 23.261000,26.451000 23.727000,26.070000 24.201000,25.700000 24.683000,25.341000 25.172000,24.992000 25.668000,24.653000 26.170000,24.326000 26.680000,24.010000 27.196000,23.705000 27.718000,23.411000 28.246000,23.129000 28.780000,22.858000 29.319000,22.599000 29.863000,22.352000 30.412000,22.116000 30.966000,21.893000 31.524000,21.681000 32.086000,21.482000 32.652000,21.295000 33.221000,21.120000 33.794000,20.958000 34.370000,20.808000 34.949000,20.671000 35.530000,20.546000 36.113000,20.434000 36.699000,20.334000 37.286000,20.247000 37.874000,20.172000 38.464000,20.111000 39.054000,20.062000 39.645000,20.026000 40.237000,20.002000 40.828000,19.991000 41.419000,19.993000 42.010000,20.008000 42.599000,20.035000 43.188000,20.075000 43.776000,20.128000 44.362000,20.193000 44.946000,20.270000 45.527000,20.361000 46.107000,20.463000 46.684000,20.578000 47.258000,20.705000 47.828000,20.845000 48.396000,20.996000 48.959000,21.160000 49.519000,21.336000 50.074000,21.523000 50.625000,21.722000 51.171000,21.933000 51.712000,22.156000 52.249000,22.390000 52.779000,22.635000 53.304000,22.892000 53.823000,23.159000 54.336000,23.438000 54.842000,23.727000 55.342000,24.027000 55.835000,24.337000 56.321000,24.658000 56.799000,24.989000 57.270000,25.330000 57.734000,25.681000 58.189000,26.041000 58.637000,26.411000 59.076000,26.791000 59.506000,27.179000 59.928000,27.576000 60.341000,27.983000 60.745000,28.397000 61.140000,28.820000 61.526000,29.251000 61.901000,29.690000 62.267000,30.137000 62.624000,30.591000 62.970000,31.053000 63.306000,31.522000 63.631000,31.997000 63.946000,32.479000 64.251000,32.968000 64.545000,33.462000 64.828000,33.963000 65.100000,34.469000 65.360000,34.981000 65.610000,35.497000 65.848000,36.019000 66.075000,36.546000 66.291000,37.077000 66.495000,37.612000 66.687000,38.151000 66.868000,38.693000 67.036000,39.240000 67.193000,39.789000 67.338000,40.341000 67.471000,40.896000 67.592000,41.454000 67.701000,42.013000 67.797000,42.575000 67.882000,43.138000 67.954000,43.702000 68.015000,44.267000 68.063000,44.834000 68.099000,45.401000 68.122000,45.968000 68.134000,46.535000 68.133000,47.102000 68.120000,47.669000 68.095000,48.234000 68.058000,48.799000 68.008000,49.363000 67.947000,49.925000 67.874000,50.485000 67.788000,51.043000 67.691000,51.599000 67.582000,52.153000 67.461000,52.703000 67.328000,53.251000 67.184000,53.795000 67.028000,54.336000 66.861000,54.873000 66.682000,55.406000 66.492000,55.934000 66.290000,56.458000 66.078000,56.978000 65.855000,57.492000 65.621000,58.001000 65.376000,58.505000 65.120000,59.003000 64.854000,59.495000 64.578000,59.981000 64.291000,60.461000 63.994000,60.934000 63.688000,61.400000 63.371000,61.859000 63.045000,62.312000 62.710000,62.757000 62.365000,63.194000 62.011000,63.623000 61.649000,64.045000 61.277000,64.458000 60.897000,64.863000 60.509000,65.260000 60.112000,65.648000 59.707000,66.027000 59.295000,66.397000 58.875000,66.758000 58.447000,67.110000 58.013000,67.452000 57.571000,67.784000 57.123000,68.107000 56.668000,68.420000 56.206000,68.723000 55.739000,69.015000 55.265000,69.298000 54.786000,69.570000 54.302000,69.831000 53.812000,70.082000 53.318000,70.322000 52.818000,70.551000 52.314000,70.770000 51.806000,70.977000 51.294000,71.173000 50.778000,71.358000 50.258000,71.532000 49.735000,71.695000 49.209000,71.846000 48.681000,71.986000 48.149000,72.114000 47.616000,72.231000 47.080000,72.336000 46.543000,72.430000 46.004000,72.512000 45.463000,72.582000 44.922000,72.641000 44.380000,72.688000 43.837000,72.723000 43.294000,72.747000 42.751000,72.759000 42.208000,72.759000 41.665000,72.748000 41.124000,72.725000 40.583000,72.690000 40.043000,72.644000 39.505000,72.586000 38.968000,72.517000 38.434000,72.436000 37.902000,72.344000 37.372000,72.240000 36.844000,72.125000 36.320000,71.999000 35.799000,71.862000 35.281000,71.714000 34.767000,71.555000 34.256000,71.384000 33.750000,71.203000 33.248000,71.012000 32.751000,70.809000 32.258000,70.597000 31.771000,70.373000 31.288000,70.140000 30.811000,69.896000 30.340000,69.642000 29.874000,69.379000 29.415000,69.105000 28.962000,68.822000 28.515000,68.530000 28.075000,68.228000 27.642000,67.917000 27.215000,67.596000 26.796000,67.267000 26.385000,66.930000 25.981000,66.583000 25.585000,66.229000 25.197000,65.866000 24.817000,65.495000 24.445000,65.116000 24.082000,64.730000 23.727000,64.336000 23.381000,63.935000 23.044000,63.526000 22.716000,63.111000 22.397000,62.689000 22.088000,62.261000 21.788000,61.826000 21.498000,61.386000 21.217000,60.939000 20.946000,60.487000 20.685000,60.029000 20.434000,59.567000 20.194000,59.099000 19.963000,58.626000 19.743000,58.149000 19.534000,57.668000 19.335000,57.182000 19.146000,56.693000 18.968000,56.200000 18.801000,55.703000 18.645000,55.204000 18.499000,54.701000 18.365000,54.196000 18.241000,53.688000 18.129000,53.179000 18.027000,52.667000 17.937000,52.153000 17.858000,51.638000 17.790000,51.122000 17.733000,50.604000 17.687000,50.086000 17.652000,49.568000 17.616000,48.530000 17.615000,48.011000 17.625000,47.493000 17.646000,46.975000 17.678000,46.458000 17.722000,45.942000 17.776000,45.428000 17.841000,44.915000 17.918000,44.404000 18.005000,43.896000 18.103000,43.389000 18.212000,42.885000 18.331000,42.384000 18.461000,41.886000 18.602000,41.391000 18.915000,40.412000 19.087000,39.928000 19.270000,39.448000 19.462000,38.973000 19.665000,38.502000 19.877000,38.036000 20.099000,37.575000 20.331000,37.119000 20.573000,36.668000 20.824000,36.223000 21.084000,35.784000 21.632000,34.924000 21.920000,34.503000 22.216000,34.089000 22.521000,33.682000 22.835000,33.281000 23.157000,32.888000 23.487000,32.502000 23.825000,32.123000 24.170000,31.752000 24.524000,31.388000 24.885000,31.033000 25.628000,30.346000 26.400000,29.693000 27.198000,29.075000 27.606000,28.779000 28.020000,28.492000 28.440000,28.214000 28.866000,27.945000 29.297000,27.686000 30.175000,27.197000 30.621000,26.966000 31.071000,26.746000 31.526000,26.535000 31.985000,26.334000 32.448000,26.143000 33.385000,25.792000 33.858000,25.632000 34.334000,25.482000 35.295000,25.214000 35.779000,25.095000 36.265000,24.987000 36.753000,24.890000 37.243000,24.803000 37.734000,24.726000 38.227000,24.660000 38.720000,24.605000 39.214000,24.561000 39.709000,24.527000 40.203000,24.504000 40.698000,24.491000 41.193000,24.489000 42.181000,24.517000 42.674000,24.547000 43.166000,24.588000 43.656000,24.639000 44.145000,24.700000 44.632000,24.772000 45.600000,24.947000 46.081000,25.050000 46.558000,25.163000 47.505000,25.420000 48.439000,25.717000 48.901000,25.880000 49.358000,26.053000 50.260000,26.428000 50.705000,26.630000 51.145000,26.841000 52.009000,27.291000 52.852000,27.777000 53.265000,28.033000 53.673000,28.298000 54.469000,28.853000 54.857000,29.143000 55.615000,29.747000 56.344000,30.382000 57.045000,31.047000 57.384000,31.391000 58.039000,32.098000 58.662000,32.832000 58.961000,33.208000 59.252000,33.591000 59.808000,34.373000 60.330000,35.178000 60.577000,35.588000 60.815000,36.003000 61.044000,36.422000 61.475000,37.275000 61.868000,38.145000 62.223000,39.029000 62.386000,39.476000 62.539000,39.926000 62.682000,40.379000 62.939000,41.293000 63.156000,42.216000 63.250000,42.681000 63.333000,43.146000 63.470000,44.082000 63.523000,44.551000 63.566000,45.021000 63.599000,45.492000 63.621000,45.962000 63.637000,46.904000 63.611000,47.844000 63.546000,48.780000 63.498000,49.247000 63.440000,49.712000 63.372000,50.175000 63.207000,51.096000 63.110000,51.553000 63.003000,52.008000 62.760000,52.908000 62.479000,53.797000 62.324000,54.236000 61.987000,55.102000 61.614000,55.952000 61.205000,56.784000 60.761000,57.596000 60.283000,58.388000 59.773000,59.157000 59.231000,59.902000 58.948000,60.265000 58.360000,60.973000 58.055000,61.316000 57.424000,61.983000 56.766000,62.621000 56.082000,63.229000 55.374000,63.806000 54.643000,64.352000 53.890000,64.865000 53.116000,65.344000 52.324000,65.789000 51.515000,66.199000 50.690000,66.573000 49.851000,66.911000 48.999000,67.212000 48.137000,67.476000 47.265000,67.702000 46.826000,67.801000 45.944000,67.970000 45.056000,68.101000 44.611000,68.152000 44.165000,68.193000 43.272000,68.247000 42.825000,68.259000 41.932000,68.256000 41.042000,68.214000 40.598000,68.178000 39.714000,68.079000 39.275000,68.015000 38.401000,67.860000 37.967000,67.768000 37.108000,67.557000 36.259000,67.310000 35.423000,67.026000 34.601000,66.708000 33.795000,66.355000 33.398000,66.165000 32.618000,65.762000 31.857000,65.326000 31.117000,64.859000 30.398000,64.361000 29.703000,63.833000 29.032000,63.277000 28.706000,62.988000 28.074000,62.391000 27.469000,61.768000 26.892000,61.121000 26.345000,60.451000 25.827000,59.759000 25.341000,59.046000 24.886000,58.314000 24.464000,57.564000 24.075000,56.798000 23.719000,56.018000 23.555000,55.622000 23.251000,54.822000 22.983000,54.011000 22.750000,53.190000 22.553000,52.362000 22.392000,51.527000 22.268000,50.687000 22.179000,49.844000 22.127000,48.999000 22.115000,48.576000 22.118000,47.732000 22.157000,46.889000 22.232000,46.051000 22.342000,45.218000 22.411000,44.804000 22.575000,43.981000 22.774000,43.168000 23.007000,42.365000 23.274000,41.575000 23.574000,40.797000 23.907000,40.035000 24.272000,39.289000 24.668000,38.560000 25.094000,37.850000 25.319000,37.503000 25.789000,36.824000 26.287000,36.166000 26.812000,35.532000 27.362000,34.922000 27.938000,34.337000 28.537000,33.778000 29.159000,33.246000 29.802000,32.743000 30.465000,32.268000 31.147000,31.823000 31.846000,31.408000 32.561000,31.025000 33.291000,30.673000 34.034000,30.353000 34.789000,30.066000 35.554000,29.812000 36.328000,29.592000 37.109000,29.406000 37.897000,29.253000 38.689000,29.135000 39.484000,29.051000 40.281000,29.001000 41.078000,28.986000 41.873000,29.005000 42.666000,29.058000 43.454000,29.145000 44.236000,29.266000 45.012000,29.419000 45.778000,29.606000 46.535000,29.825000 47.280000,30.076000 48.013000,30.359000 48.731000,30.672000 49.434000,31.015000 50.121000,31.388000 50.790000,31.789000 51.440000,32.217000 52.069000,32.673000 52.678000,33.154000 53.264000,33.660000 53.827000,34.190000 54.366000,34.743000 54.879000,35.317000 55.367000,35.912000 55.828000,36.527000 56.261000,37.159000 56.666000,37.808000 57.042000,38.473000 57.388000,39.153000 57.704000,39.845000 57.990000,40.550000 58.245000,41.264000 58.468000,41.988000 58.660000,42.719000 58.819000,43.457000 58.947000,44.199000 59.043000,44.945000 59.106000,45.693000 59.137000,46.442000 59.135000,47.190000 59.102000,47.936000 59.036000,48.679000 58.939000,49.417000 58.811000,50.148000 58.651000,50.873000 58.461000,51.588000 58.240000,52.293000 57.990000,52.987000 57.711000,53.668000 57.403000,54.335000 57.067000,54.988000 56.705000,55.624000 56.316000,56.243000 55.901000,56.843000 55.462000,57.424000 54.999000,57.985000 54.513000,58.524000 54.006000,59.041000 53.477000,59.534000 52.929000,60.004000 52.363000,60.449000 51.778000,60.868000 51.178000,61.261000 50.562000,61.627000 49.932000,61.965000 49.289000,62.276000 48.635000,62.558000 47.970000,62.811000 47.297000,63.035000 46.616000,63.230000 45.928000,63.394000 45.235000,63.529000 44.538000,63.634000 43.839000,63.708000 43.138000,63.752000 42.438000,63.766000 41.739000,63.750000 41.443000,63.744000 41.148000,63.728000 40.848000,63.701000 40.549000,63.662000 40.252000,63.613000 39.956000,63.553000 39.663000,63.482000 39.373000,63.400000 39.086000,63.308000 38.803000,63.206000 38.523000,63.093000 38.248000,62.970000 37.978000,62.837000 37.712000,62.694000 37.452000,62.542000 37.198000,62.380000 36.950000,62.210000 36.708000,62.030000 36.473000,61.841000 36.245000,61.644000 36.024000,61.439000 35.811000,61.226000 35.606000,61.005000 35.409000,60.777000 35.220000,60.542000 35.040000,60.300000 34.708000,59.798000 34.556000,59.538000 34.413000,59.272000 34.280000,59.002000 34.157000,58.727000 34.044000,58.447000 33.942000,58.164000 33.850000,57.877000 33.768000,57.587000 33.697000,57.294000 33.637000,56.999000 33.588000,56.701000 33.549000,56.402000 33.522000,56.102000 33.506000,55.801000 33.500000,55.500000 33.522000,54.898000 33.549000,54.598000 33.588000,54.299000 33.637000,54.002000 33.697000,53.706000 33.768000,53.413000 33.850000,53.123000 33.942000,52.836000 34.044000,52.553000 34.157000,52.273000 34.280000,51.998000 34.413000,51.728000 34.556000,51.462000 34.708000,51.202000 34.870000,50.948000 35.040000,50.700000 35.220000,50.458000 35.409000,50.223000 35.606000,49.995000 35.811000,49.774000 36.024000,49.561000 36.245000,49.356000 36.473000,49.159000 36.708000,48.970000 36.950000,48.790000 37.452000,48.458000 37.712000,48.306000 37.978000,48.163000 38.248000,48.030000 38.523000,47.907000 38.803000,47.794000 39.086000,47.692000 39.373000,47.600000 39.663000,47.518000 39.956000,47.447000 40.252000,47.387000 40.549000,47.338000 40.848000,47.299000 41.148000,47.272000 41.449000,47.256000 41.750000,47.250000 41.761000,47.250000 42.326000,47.229000 42.889000,47.166000 43.168000,47.119000 43.721000,46.995000 43.993000,46.918000 44.528000,46.735000 44.791000,46.629000 45.303000,46.388000 45.796000,46.110000 46.035000,45.958000 46.495000,45.628000 46.930000,45.265000 47.137000,45.072000 47.529000,44.664000 47.891000,44.228000 48.059000,44.001000 48.371000,43.528000 48.514000,43.284000 48.772000,42.780000 48.887000,42.521000 48.992000,42.259000 49.088000,41.992000 49.251000,41.450000 49.317000,41.175000 49.373000,40.897000 49.419000,40.618000 49.455000,40.337000 49.480000,40.055000 49.500000,39.489000 49.479000,38.924000 49.416000,38.361000 49.369000,38.082000 49.245000,37.529000 49.168000,37.257000 48.985000,36.722000 48.879000,36.459000 48.638000,35.947000 48.360000,35.454000 48.208000,35.215000 47.878000,34.755000 47.515000,34.320000 47.322000,34.113000 46.914000,33.721000 46.478000,33.359000 46.251000,33.191000 45.778000,32.879000 45.534000,32.736000 45.030000,32.478000 44.771000,32.363000 44.509000,32.258000 44.242000,32.162000 43.700000,31.999000 43.425000,31.933000 43.147000,31.877000 42.868000,31.831000 42.587000,31.795000 42.305000,31.770000 41.739000,31.750000 41.061000,31.734000 40.382000,31.747000 39.703000,31.790000 39.025000,31.862000 38.350000,31.964000 37.678000,32.094000 37.011000,32.254000 36.351000,32.442000 35.697000,32.660000 35.053000,32.905000 34.419000,33.179000 33.795000,33.480000 33.184000,33.809000 32.587000,34.164000 32.004000,34.545000 31.438000,34.951000 30.888000,35.383000 30.356000,35.838000 29.843000,36.317000 29.351000,36.819000 28.880000,37.342000 28.430000,37.886000 28.004000,38.450000 27.602000,39.032000 27.224000,39.633000 26.872000,40.250000 26.546000,40.884000 26.248000,41.531000 25.977000,42.193000 25.734000,42.866000 25.520000,43.551000 25.335000,44.246000 25.180000,44.949000 25.055000,45.659000 24.961000,46.376000 24.897000,47.097000 24.865000,47.821000 24.863000,48.548000 24.893000,49.275000 24.955000,50.002000 25.047000,50.727000 25.171000,51.448000 25.327000,52.164000 25.513000,52.875000 25.730000,53.578000 25.977000,54.272000 26.255000,54.957000 26.562000,55.630000 26.899000,56.290000 27.264000,56.936000 27.658000,57.567000 28.079000,58.182000 28.526000,58.779000 29.000000,59.358000 29.500000,59.916000 30.023000,60.453000 30.571000,60.969000 31.141000,61.461000 31.732000,61.929000 32.345000,62.371000 32.977000,62.788000 33.627000,63.178000 34.295000,63.540000 34.978000,63.874000 35.677000,64.179000 36.390000,64.453000 37.115000,64.697000 37.850000,64.911000 38.596000,65.092000 39.350000,65.242000 40.111000,65.359000 40.878000,65.444000 41.649000,65.496000 42.423000,65.514000 43.199000,65.499000 43.974000,65.451000 44.748000,65.369000 45.519000,65.254000 46.285000,65.106000 47.046000,64.924000 47.799000,64.710000 48.544000,64.463000 49.279000,64.183000 50.002000,63.872000 50.712000,63.530000 51.408000,63.156000 52.089000,62.753000 52.753000,62.319000 53.398000,61.857000 54.024000,61.367000 54.630000,60.849000 55.213000,60.305000 55.774000,59.735000 56.310000,59.141000 56.821000,58.523000 57.306000,57.883000 57.764000,57.222000 58.194000,56.540000 58.594000,55.839000 58.965000,55.121000 59.305000,54.386000 59.614000,53.636000 59.756000,53.255000 60.016000,52.485000 60.243000,51.703000 60.437000,50.910000 60.597000,50.109000 60.722000,49.301000 60.812000,48.486000 60.868000,47.667000 60.882000,47.256000 60.885000,46.433000 60.852000,45.609000 60.784000,44.787000 60.680000,43.966000 60.541000,43.150000 60.366000,42.339000 60.157000,41.535000 59.913000,40.739000 59.634000,39.954000 59.321000,39.179000 58.975000,38.418000 58.596000,37.672000 58.184000,36.941000 57.741000,36.227000 57.507000,35.877000 57.018000,35.192000 56.761000,34.857000 56.227000,34.203000 55.665000,33.572000 55.075000,32.965000 54.458000,32.383000 53.816000,31.827000 53.150000,31.298000 52.460000,30.798000 51.749000,30.326000 51.016000,29.886000 50.265000,29.476000 49.882000,29.284000 49.104000,28.923000 48.309000,28.595000 47.500000,28.301000 46.678000,28.042000 45.845000,27.818000 45.001000,27.630000 44.575000,27.550000 43.719000,27.416000 43.289000,27.363000 42.424000,27.285000 41.555000,27.244000 41.119000,27.238000 40.248000,27.253000 39.376000,27.305000 38.506000,27.396000 37.640000,27.523000 36.779000,27.688000 35.924000,27.891000 35.077000,28.130000 34.240000,28.405000 33.415000,28.717000 32.602000,29.065000 32.202000,29.252000 31.411000,29.652000 30.638000,30.087000 29.883000,30.555000 29.148000,31.055000 28.433000,31.588000 28.085000,31.866000 27.405000,32.445000 26.749000,33.054000 26.120000,33.691000 25.518000,34.355000 24.943000,35.046000 24.399000,35.762000 23.884000,36.501000 23.639000,36.880000 23.173000,37.653000 22.739000,38.446000 22.535000,38.850000 22.153000,39.672000 21.806000,40.510000 21.495000,41.364000 21.220000,42.232000 21.097000,42.671000 20.878000,43.556000 20.783000,44.003000 20.622000,44.902000 20.556000,45.355000 20.452000,46.265000 20.415000,46.722000 20.388000,47.181000 20.363000,48.099000 20.366000,48.559000 20.400000,49.479000 20.475000,50.398000 20.588000,51.314000 20.660000,51.771000 20.833000,52.680000 20.934000,53.132000 21.045000,53.582000 21.296000,54.475000 21.436000,54.918000 21.745000,55.795000 21.914000,56.229000 22.279000,57.086000 22.476000,57.509000 22.897000,58.343000 23.354000,59.159000 23.846000,59.956000 24.105000,60.346000 24.649000,61.111000 25.226000,61.853000 25.835000,62.570000 26.152000,62.919000 26.807000,63.598000 27.492000,64.248000 27.845000,64.562000 28.572000,65.168000 29.326000,65.743000 30.104000,66.286000 30.503000,66.545000 31.316000,67.037000 32.151000,67.495000 33.007000,67.917000 33.441000,68.114000 34.324000,68.481000 34.771000,68.650000 35.223000,68.810000 35.678000,68.960000 36.597000,69.231000 37.529000,69.462000 37.999000,69.563000 38.946000,69.734000 39.901000,69.865000 40.862000,69.954000 41.344000,69.983000 42.310000,70.011000 43.279000,69.997000 44.247000,69.941000 44.730000,69.897000 45.694000,69.779000 46.175000,69.704000 46.654000,69.619000 47.131000,69.524000 47.607000,69.418000 48.081000,69.302000 49.021000,69.039000 49.950000,68.736000 50.410000,68.569000 51.319000,68.206000 51.769000,68.009000 52.214000,67.803000 52.655000,67.587000 53.091000,67.362000 53.523000,67.127000 54.372000,66.629000 54.788000,66.366000 55.199000,66.094000 55.605000,65.813000 56.004000,65.524000 56.398000,65.225000 57.166000,64.603000 57.908000,63.947000 58.622000,63.259000 58.968000,62.903000 59.306000,62.540000 59.637000,62.169000 59.960000,61.791000 60.275000,61.406000 60.582000,61.014000 60.880000,60.616000 61.452000,59.798000 61.725000,59.380000 62.243000,58.526000 62.489000,58.091000 62.726000,57.650000 62.953000,57.203000 63.170000,56.752000 63.577000,55.834000 63.765000,55.369000 64.112000,54.426000 64.270000,53.948000 64.418000,53.467000 64.556000,52.982000 64.684000,52.495000 64.801000,52.004000 64.907000,51.511000 65.003000,51.015000 65.089000,50.516000 65.163000,50.016000 65.227000,49.514000 65.281000,49.011000 65.323000,48.506000 65.354000,48.000000 65.375000,47.493000 65.385000,46.985000 65.384000,46.477000 65.372000,45.969000 65.349000,45.460000 65.315000,44.952000 65.270000,44.445000 65.214000,43.938000 65.147000,43.433000 65.070000,42.928000 64.981000,42.425000 64.882000,41.924000 64.772000,41.425000 64.651000,40.927000 64.519000,40.433000 64.376000,39.940000 64.223000,39.451000 64.060000,38.965000 63.701000,38.003000 63.506000,37.527000 63.300000,37.055000 63.085000,36.588000 62.859000,36.125000 62.623000,35.667000 62.378000,35.213000 62.122000,34.765000 61.857000,34.322000 61.582000,33.885000 61.298000,33.453000 61.004000,33.027000 60.701000,32.608000 60.388000,32.194000 60.067000,31.788000 59.737000,31.388000 59.398000,30.995000 59.050000,30.609000 58.694000,30.230000 58.330000,29.859000 57.958000,29.496000 57.578000,29.140000 56.794000,28.453000 56.391000,28.123000 55.980000,27.800000 55.563000,27.486000 54.707000,26.886000 54.269000,26.599000 53.825000,26.322000 53.375000,26.054000 52.919000,25.795000 52.457000,25.547000 51.989000,25.308000 51.516000,25.079000 51.039000,24.860000 50.556000,24.652000 50.068000,24.453000 49.576000,24.266000 49.080000,24.088000 48.580000,23.921000 48.076000,23.765000 47.569000,23.620000 47.058000,23.486000 46.544000,23.362000 46.027000,23.249000 45.508000,23.148000 44.986000,23.058000 44.462000,22.979000 43.936000,22.911000 43.409000,22.854000 42.880000,22.809000 42.350000,22.775000 41.819000,22.752000 41.287000,22.741000 40.755000,22.741000 40.222000,22.753000 39.690000,22.776000 39.158000,22.811000 38.627000,22.857000 38.096000,22.915000 37.566000,22.983000 37.038000,23.064000 36.511000,23.156000 35.986000,23.259000 35.463000,23.373000 34.942000,23.499000 34.424000,23.636000 33.908000,23.784000 33.395000,23.944000 32.886000,24.114000 32.380000,24.296000 31.878000,24.488000 31.380000,24.691000 30.886000,24.905000 30.396000,25.130000 29.911000,25.366000 29.431000,25.612000 28.956000,25.868000 28.486000,26.135000 28.022000,26.411000 27.564000,26.698000 27.111000,26.995000 26.665000,27.302000 26.225000,27.619000 25.792000,27.945000 25.366000,28.280000 24.947000,28.625000 24.535000,28.979000 24.131000,29.342000 23.734000,29.713000 23.345000,30.094000 22.964000,30.483000 22.591000,30.880000 22.227000,31.285000 21.871000,31.699000 21.524000,32.120000 21.186000,32.549000 20.857000,32.985000 20.537000,33.429000 20.227000,33.879000 19.926000,34.336000 19.636000,34.800000 19.354000,35.271000 19.083000,35.748000 18.822000,36.230000 18.572000,36.719000 18.331000,37.213000 18.102000,37.712000 17.883000,38.217000 17.674000,38.726000 17.477000,39.240000 17.291000,39.759000 17.115000,40.281000 16.951000,40.808000 16.798000,41.338000 16.656000,41.872000 16.526000,42.409000 16.408000,42.949000 16.301000,43.492000 16.205000,44.038000 16.121000,44.585000 16.049000,45.135000 15.989000,45.686000 15.941000,46.239000 15.904000,46.793000 15.880000,47.348000 15.867000,47.904000 15.866000,48.460000 15.878000,49.017000 15.901000,49.573000 15.936000,50.129000 15.983000,50.685000 16.042000,51.240000 16.113000,51.793000 16.196000,52.346000 16.291000,52.897000 16.398000,53.446000 16.517000,53.992000 16.647000,54.537000 16.789000,55.079000 16.943000,55.618000 17.109000,56.154000 17.286000,56.686000 17.474000,57.215000 17.674000,57.740000 17.886000,58.261000 18.109000,58.778000 18.342000,59.290000 18.587000,59.797000 18.843000,60.299000 19.110000,60.796000 19.388000,61.287000 19.676000,61.772000 19.975000,62.252000 20.284000,62.725000 20.604000,63.191000 20.934000,63.651000 21.273000,64.104000 21.623000,64.550000 21.982000,64.989000 22.351000,65.420000 22.729000,65.843000 23.116000,66.258000 23.513000,66.665000 23.918000,67.063000 24.332000,67.453000 24.755000,67.834000 25.186000,68.207000 25.625000,68.570000 26.072000,68.924000 26.527000,69.268000 26.989000,69.603000 27.459000,69.928000 27.936000,70.242000 28.420000,70.547000 28.911000,70.841000 29.408000,71.125000 29.911000,71.399000 30.420000,71.661000 30.936000,71.913000 31.456000,72.154000 31.983000,72.384000 32.514000,72.602000 33.050000,72.809000 33.591000,73.005000 34.136000,73.189000 34.685000,73.361000 35.239000,73.522000 35.796000,73.671000 36.356000,73.808000 36.919000,73.933000 37.485000,74.045000 38.054000,74.146000 38.626000,74.235000 39.199000,74.311000 39.774000,74.375000 40.351000,74.426000 40.929000,74.466000 41.508000,74.492000 42.088000,74.507000 42.668000,74.509000 43.249000,74.498000 43.830000,74.475000 44.410000,74.439000 44.990000,74.391000 45.568000,74.331000 46.146000,74.258000 46.723000,74.172000 47.297000,74.074000 47.870000,73.964000 48.441000,73.842000 49.009000,73.707000 49.575000,73.559000 50.137000,73.400000 50.696000,73.229000 51.252000,73.045000 51.804000,72.849000 52.352000,72.642000 52.896000,72.422000 53.435000,72.191000 53.970000,71.948000 54.499000,71.694000 55.023000,71.428000 55.541000,71.151000 56.054000,70.862000 56.561000,70.563000 57.061000,70.252000 57.555000,69.930000 58.042000,69.598000 58.523000,69.255000 58.995000,68.902000 59.461000,68.539000 59.919000,68.165000 60.369000,67.782000 60.811000,67.388000 61.244000,66.985000 61.669000,66.573000 62.086000,66.151000 62.493000,65.720000 62.891000,65.280000 63.280000,64.832000 63.660000,64.375000 64.029000,63.910000 64.389000,63.436000 64.739000,62.955000 65.078000,62.466000 65.407000,61.970000 65.726000,61.466000 66.034000,60.956000 66.331000,60.438000 66.617000,59.914000 66.891000,59.384000 67.155000,58.848000 67.407000,58.305000 67.647000,57.758000 67.876000,57.205000 68.093000,56.646000 68.298000,56.083000 68.491000,55.516000 68.672000,54.944000 68.840000,54.368000 68.996000,53.788000 69.140000,53.204000 69.271000,52.618000 69.390000,52.028000 69.496000,51.436000 69.590000,50.841000 69.670000,50.244000 69.738000,49.645000 69.793000,49.044000 69.835000,48.442000 69.864000,47.839000 69.880000,47.235000 69.884000,46.630000 69.874000,46.026000 69.851000,45.421000 69.815000,44.816000 69.766000,44.213000 69.705000,43.610000 69.630000,43.008000 69.542000,42.407000 69.441000,41.809000 69.328000,41.212000 69.201000,40.617000 69.062000,40.025000 68.910000,39.436000 68.745000,38.850000 68.568000,38.268000 68.378000,37.688000 68.175000,37.113000 67.960000,36.542000 67.733000,35.976000 67.493000,35.414000 67.242000,34.857000 66.978000,34.305000 66.702000,33.759000 66.415000,33.219000 66.116000,32.685000 65.805000,32.157000 65.482000,31.635000 65.149000,31.120000 64.804000,30.612000 64.448000,30.112000 64.082000,29.619000 63.705000,29.134000 63.317000,28.656000 62.918000,28.187000 62.510000,27.726000 62.091000,27.274000 61.663000,26.831000 61.225000,26.397000 60.778000,25.972000 60.321000,25.557000 59.855000,25.151000 59.380000,24.755000 58.897000,24.370000 58.405000,23.994000 57.905000,23.629000 57.397000,23.275000 56.882000,22.931000 56.358000,22.599000 55.828000,22.277000 55.290000,21.967000 54.746000,21.669000 54.194000,21.382000 53.637000,21.106000 53.074000,20.843000 52.504000,20.592000 51.929000,20.353000 51.349000,20.126000 50.764000,19.911000 50.174000,19.710000 49.579000,19.520000 48.980000,19.344000 48.378000,19.180000 47.771000,19.029000 47.161000,18.891000 46.548000,18.766000 45.932000,18.655000 45.314000,18.556000 44.693000,18.471000 44.070000,18.399000 43.446000,18.341000 42.820000,18.296000 42.192000,18.264000 41.564000,18.246000 40.936000,18.241000 40.307000,18.250000 39.678000,18.273000 39.050000,18.309000 38.422000,18.358000 37.795000,18.421000 37.169000,18.497000 36.544000,18.587000 35.921000,18.691000 35.301000,18.808000 34.682000,18.938000 34.067000,19.081000 33.454000,19.238000 32.844000,19.408000 32.238000,19.591000 31.636000,19.787000 31.037000,19.997000 30.443000,20.219000 29.854000,20.454000 29.269000,20.702000 28.690000,20.962000 28.116000,21.235000 27.548000,21.520000 26.986000,21.818000 26.429000,22.128000 25.880000,22.450000 25.337000,22.783000 24.801000,23.129000 24.273000,23.486000 23.752000,23.855000 23.239000,24.235000 22.734000,24.626000 22.237000,25.028000 21.748000,25.440000 21.269000,25.864000 20.798000,26.298000 20.336000,26.742000 19.884000,27.196000 19.442000,27.660000 19.009000,28.134000 18.587000,28.617000 18.174000,29.109000 17.773000,29.610000 17.381000,30.120000 17.001000,30.639000 16.632000,31.166000 16.274000,31.701000 15.927000,32.244000 15.592000,32.794000 15.269000,33.352000 14.957000,33.917000 14.658000,34.489000 14.371000,35.067000 14.096000,35.652000 13.834000,36.243000 13.584000,36.840000 13.347000,37.442000 13.123000,38.049000 12.912000,38.662000 12.714000,39.279000 12.529000,39.900000 12.358000,40.526000 12.200000,41.155000 12.055000,41.789000 11.924000,42.425000 11.807000,43.064000 11.704000,43.706000 11.614000,44.351000 11.538000,44.998000 11.476000,45.646000 11.427000,46.296000 11.393000,46.947000 11.373000,47.599000 11.367000,48.252000 11.374000,48.905000 11.396000,49.558000 11.432000,50.210000 11.482000,50.863000 11.546000,51.514000 11.624000,52.164000 11.716000,52.812000 11.822000,53.459000 11.942000,54.104000 12.075000,54.746000 12.223000,55.385000 12.384000,56.022000 12.559000,56.655000 12.748000,57.285000 12.951000,57.911000 13.166000,58.532000 13.396000,59.149000 13.638000,59.762000 13.894000,60.369000 14.163000,60.971000 14.445000,61.567000 14.740000,62.158000 15.047000,62.742000 15.368000,63.320000 15.700000,63.891000 16.046000,64.455000 16.403000,65.012000 16.772000,65.561000 17.154000,66.102000 17.547000,66.636000 17.951000,67.161000 18.367000,67.677000 18.795000,68.185000 19.233000,68.684000 19.682000,69.173000 20.142000,69.653000 20.612000,70.123000 21.093000,70.584000 21.583000,71.034000 22.083000,71.473000 22.593000,71.902000 23.112000,72.320000 23.641000,72.727000 24.178000,73.123000 24.724000,73.507000 25.278000,73.880000 25.840000,74.241000 26.411000,74.589000 26.989000,74.926000 27.574000,75.250000 28.166000,75.562000 28.766000,75.862000 29.372000,76.148000 29.984000,76.421000 30.602000,76.682000 31.226000,76.929000 31.856000,77.163000 32.490000,77.383000 33.130000,77.590000 33.774000,77.783000 34.423000,77.962000 35.075000,78.127000 35.732000,78.279000 36.391000,78.416000 37.054000,78.539000 37.720000,78.648000 38.388000,78.743000 39.058000,78.823000 39.731000,78.889000 40.404000,78.941000 41.080000,78.978000 41.756000,79.000000 42.432000,79.008000 43.110000,79.002000 43.787000,78.980000 44.464000,78.945000 45.140000,78.895000 45.815000,78.830000 46.489000,78.750000 47.162000,78.657000 47.833000,78.548000 48.501000,78.426000 49.167000,78.288000 49.831000,78.137000 50.491000,77.971000 51.148000,77.791000 51.801000,77.597000 52.450000,77.389000 53.095000,77.166000 53.735000,76.930000 54.371000,76.680000 55.001000,76.416000 55.625000,76.139000 56.244000,75.848000 56.857000,75.544000 57.463000,75.226000 58.063000,74.896000 58.655000,74.552000 59.241000,74.196000 59.819000,73.827000 60.389000,73.445000 60.951000,73.051000 61.505000,72.645000 62.050000,72.227000 62.586000,71.797000 63.113000,71.355000 63.631000,70.902000 64.140000,70.438000 64.638000,69.963000 65.126000,69.477000 65.604000,68.980000 66.072000,68.473000 66.528000,67.955000 66.974000,67.428000 67.408000,66.891000 67.831000,66.345000 68.242000,65.789000 68.642000,65.224000 69.029000,64.651000 69.405000,64.069000 69.767000,63.479000 70.118000,62.881000 70.455000,62.275000 70.779000,61.662000 71.091000,61.042000 71.389000,60.415000 71.674000,59.781000 71.945000,59.142000 72.202000,58.496000 72.446000,57.844000 72.676000,57.187000 72.891000,56.525000 73.093000,55.858000 73.280000,55.187000 73.453000,54.511000 73.611000,53.832000 73.755000,53.149000 73.884000,52.463000 73.999000,51.774000 74.098000,51.082000 74.183000,50.388000 74.253000,49.692000 74.308000,48.994000 74.348000,48.295000 74.373000,47.595000 74.383000,46.894000 74.377000,46.193000 74.357000,45.491000 74.322000,44.790000 74.271000,44.090000 74.206000,43.390000 74.125000,42.692000 74.030000,41.995000 73.919000,41.301000 73.794000,40.608000 73.653000,39.918000 73.498000,39.231000 73.328000,38.547000 73.143000,37.866000 72.944000,37.189000 72.730000,36.517000 72.501000,35.849000 72.258000,35.185000 72.001000,34.527000 71.729000,33.874000 71.443000,33.226000 71.144000,32.585000 70.830000,31.950000 70.503000,31.322000 70.162000,30.700000 69.808000,30.086000 69.440000,29.479000 69.060000,28.880000 68.666000,28.289000 68.260000,27.706000 67.841000,27.132000 67.409000,26.567000 66.965000,26.010000 66.510000,25.464000 66.042000,24.927000 65.563000,24.399000 65.072000,23.882000 64.570000,23.376000 64.057000,22.880000 63.533000,22.395000 62.999000,21.921000 62.454000,21.459000 61.900000,21.008000 61.335000,20.569000 60.761000,20.142000 60.178000,19.727000 59.585000,19.325000 58.984000,18.935000 58.374000,18.558000 57.757000,18.195000 57.131000,17.844000 56.497000,17.507000 55.856000,17.183000 55.208000,16.873000 54.553000,16.577000 53.892000,16.295000 53.224000,16.027000 52.550000,15.773000 51.871000,15.534000 51.187000,15.309000 50.497000,15.099000 49.803000,14.904000 49.105000,14.723000 48.402000,14.558000 47.696000,14.407000 46.987000,14.272000 46.274000,14.152000 45.558000,14.047000 44.841000,13.958000 44.121000,13.884000 43.399000,13.825000 42.676000,13.782000 41.952000,13.755000 41.227000,13.743000 40.502000,13.747000 39.776000,13.766000 39.051000,13.801000 38.326000,13.851000 37.603000,13.917000 36.880000,13.999000 36.159000,14.096000 35.441000,14.209000 34.724000,14.337000 34.010000,14.480000 33.299000,14.639000 32.591000,14.813000 31.887000,15.003000 31.186000,15.208000 30.490000,15.427000 29.799000,15.662000 29.112000,15.912000 28.431000,16.176000 27.755000,16.456000 27.085000,16.749000 26.421000,17.058000 25.763000,17.380000 25.113000,17.717000 24.469000,18.068000 23.833000,18.433000 23.205000,18.811000 22.584000,19.203000 21.972000,19.609000 21.369000,20.028000 20.774000,20.460000 20.189000,20.904000 19.612000,21.362000 19.046000,21.832000 18.490000,22.314000 17.943000,22.808000 17.408000,23.314000 16.883000,23.832000 16.369000,24.361000 15.866000,24.901000 15.375000,25.452000 14.896000,26.014000 14.429000,26.586000 13.973000,27.169000 13.531000,27.761000 13.100000,28.363000 12.683000,28.975000 12.279000,29.595000 11.888000,30.224000 11.510000,30.862000 11.146000,31.508000 10.796000,32.162000 10.460000,32.824000 10.138000,33.493000 9.830000,34.169000 9.537000,34.852000 9.258000,35.541000 8.995000,36.237000 8.746000,36.938000 8.512000,37.645000 8.293000,38.357000 8.089000,39.074000 7.901000,39.795000 7.728000,40.521000 7.571000,41.250000 7.430000,41.983000 7.304000,42.719000 7.194000,43.458000 7.100000,44.200000 7.022000,44.943000 6.959000,45.689000 6.913000,46.436000 6.883000,47.184000 6.869000,47.933000 6.871000,48.683000 6.889000,49.432000 6.923000,50.182000 6.973000,50.930000 7.040000,51.678000 7.122000,52.425000 7.221000,53.170000 7.335000,53.913000 7.466000,54.653000 7.613000,55.391000 7.775000,56.126000 7.953000,56.858000 8.147000,57.586000 8.357000,58.310000 8.582000,59.030000 8.823000,59.745000 9.079000,60.455000 9.351000,61.159000 9.638000,61.858000 9.939000,62.551000 10.256000,63.237000 10.588000,63.917000 10.934000,64.590000 11.295000,65.256000 11.670000,65.914000 12.060000,66.564000 12.463000,67.205000 12.880000,67.839000 13.311000,68.463000 13.756000,69.078000 14.214000,69.684000 14.685000,70.280000 15.169000,70.866000 15.665000,71.442000 16.174000,72.007000 16.695000,72.562000 17.229000,73.105000 17.774000,73.637000 18.330000,74.157000 18.898000,74.666000 19.477000,75.162000 20.067000,75.646000 20.667000,76.118000 21.278000,76.577000 21.899000,77.022000 22.529000,77.455000 23.168000,77.874000 23.817000,78.279000 24.475000,78.671000 25.141000,79.048000 25.815000,79.411000 26.498000,79.760000 27.188000,80.094000 27.885000,80.413000 28.589000,80.718000 29.300000,81.007000 30.018000,81.281000 30.741000,81.540000 31.470000,81.783000 32.205000,82.011000 32.944000,82.223000 33.688000,82.419000 34.437000,82.599000 35.190000,82.763000 35.946000,82.911000 36.705000,83.043000 37.468000,83.158000 38.233000,83.257000 39.001000,83.340000 39.770000,83.406000 40.541000,83.456000 41.313000,83.489000 42.086000,83.505000 42.860000,83.505000 43.634000,83.488000 44.407000,83.455000 45.180000,83.405000 45.952000,83.338000 46.723000,83.255000 47.492000,83.155000 48.259000,83.039000 49.024000,82.906000 49.786000,82.756000 50.545000,82.590000 51.300000,82.408000 52.052000,82.210000 52.800000,81.995000 53.543000,81.765000 54.281000,81.518000 55.015000,81.255000 55.742000,80.977000 56.464000,80.683000 57.180000,80.373000 57.889000,80.048000 58.592000,79.708000 59.287000,79.352000 59.974000,78.981000 60.654000,78.596000 61.326000,78.196000 61.989000,77.781000 62.643000,77.352000 63.289000,76.909000 63.925000,76.452000 64.551000,75.981000 65.167000,75.497000 65.773000,74.999000 66.368000,74.488000 66.953000,73.964000 67.526000,73.428000 68.088000,72.879000 68.638000,72.318000 69.176000,71.745000 69.703000,71.160000 70.216000,70.564000 70.717000,69.957000 71.205000,69.339000 71.680000,68.711000 72.141000,68.072000 72.589000,67.423000 73.022000,66.764000 73.442000,66.096000 73.848000,65.418000 74.239000,64.732000 74.615000,64.037000 74.976000,63.334000 75.323000,62.624000 75.654000,61.905000 75.970000,61.180000 76.270000,60.447000 76.554000,59.708000 76.823000,58.962000 77.076000,58.211000 77.313000,57.454000 77.533000,56.692000 77.737000,55.925000 77.925000,55.153000 78.096000,54.378000 78.251000,53.598000 78.388000,52.815000 78.509000,52.029000 78.613000,51.240000 78.700000,50.449000 78.771000,49.656000 78.824000,48.861000 78.860000,48.065000 78.879000,47.267000 78.881000,46.470000 78.865000,45.672000 78.833000,44.874000 78.783000,44.077000 78.716000,43.281000 78.632000,42.486000 78.531000,41.693000 78.413000,40.901000 78.278000,40.113000 78.126000,39.327000 77.957000,38.544000 77.772000,37.764000 77.569000,36.989000 77.350000,36.217000 77.114000,35.450000 76.861000,34.688000 76.592000,33.932000 76.307000,33.181000 76.006000,32.436000 75.688000,31.697000 75.355000,30.965000 75.006000,30.240000 74.641000,29.523000 74.261000,28.813000 73.865000,28.111000 73.454000,27.418000 73.029000,26.733000 72.588000,26.058000 72.133000,25.391000 71.663000,24.735000 71.180000,24.088000 70.682000,23.451000 70.170000,22.826000 69.645000,22.211000 69.107000,21.607000 68.556000,21.015000 67.991000,20.434000 67.415000,19.866000 66.826000,19.309000 66.224000,18.766000 65.611000,18.235000 64.987000,17.717000 64.351000,17.213000 63.705000,16.722000 63.047000,16.245000 62.380000,15.782000 61.702000,15.333000 61.014000,14.899000 60.317000,14.479000 59.611000,14.074000 58.896000,13.685000 58.173000,13.310000 57.441000,12.952000 56.702000,12.609000 55.955000,12.281000 55.201000,11.970000 54.440000,11.675000 53.672000,11.396000 52.899000,11.134000 52.119000,10.888000 51.335000,10.659000 50.545000,10.446000 49.750000,10.251000 48.952000,10.073000 48.149000,9.912000 47.342000,9.768000 46.533000,9.641000 45.720000,9.532000 44.905000,9.440000 44.088000,9.366000 43.269000,9.309000 42.449000,9.270000 41.628000,9.248000 40.806000,9.244000 39.984000,9.258000 39.162000,9.289000 38.341000,9.338000 37.521000,9.405000 36.702000,9.489000 35.884000,9.591000 35.069000,9.711000 34.256000,9.848000 33.446000,10.003000 32.639000,10.175000 31.835000,10.364000 31.036000,10.571000 30.241000,10.795000 29.450000,11.036000 28.665000,11.294000 27.885000,11.569000 27.111000,11.860000 26.342000,12.169000 25.581000,12.494000 24.826000,12.835000 24.079000,13.193000 23.339000,13.567000 22.607000,13.957000 21.883000,14.363000 21.168000,14.784000 20.461000,15.220000 19.764000,15.672000 19.077000,16.139000 18.399000,16.621000 17.732000,17.118000 17.075000,17.629000 16.430000,18.154000 15.795000,18.693000 15.172000,19.246000 14.560000,19.812000 13.961000,20.391000 13.374000,20.984000 12.800000,21.589000 12.238000,22.207000 11.690000,22.837000 11.155000,23.478000 10.634000,24.132000 10.127000,24.796000 9.634000,25.472000 9.156000,26.158000 8.692000,26.855000 8.243000,27.561000 7.809000,28.278000 7.391000,29.004000 6.988000,29.739000 6.601000,30.483000 6.229000,31.235000 5.874000,31.996000 5.535000,32.764000 5.213000,33.539000 4.907000,34.322000 4.618000,35.111000 4.346000,35.907000 4.091000,36.709000 3.853000,37.516000 3.632000,38.329000 3.429000,39.146000 3.243000,39.968000 3.075000,40.794000 2.925000,41.624000 2.792000,42.457000 2.678000,43.293000 2.581000,44.132000 2.502000,44.972000 2.442000,45.815000 2.399000,46.659000 2.375000,47.505000 2.369000,48.350000 2.381000,49.197000 2.411000,50.043000 2.459000,50.888000 2.526000,51.733000 2.610000,52.576000 2.713000,53.418000 2.834000,54.257000 2.973000,55.094000 3.130000,55.928000 3.305000,56.759000 3.498000,57.587000 3.709000,58.410000 3.937000,59.229000 4.183000,60.043000 4.446000,60.852000 4.727000,61.656000 5.026000,62.453000 5.341000,63.244000 5.674000,64.029000 6.023000,64.807000 6.389000,65.577000 6.772000,66.339000 7.171000,67.094000 7.587000,67.840000 8.018000,68.577000 8.466000,69.305000 8.929000,70.023000 9.408000,70.732000 9.902000,71.430000 10.411000,72.118000 10.935000,72.795000 11.474000,73.461000 12.027000,74.115000 12.594000,74.758000 13.175000,75.388000 13.770000,76.007000 14.378000,76.612000 14.999000,77.205000 15.633000,77.784000 16.279000,78.350000 16.938000,78.902000 17.609000,79.439000 18.291000,79.963000 18.985000,80.472000 19.690000,80.966000 20.405000,81.445000 21.131000,81.909000 21.867000,82.357000 22.613000,82.789000 23.368000,83.206000 24.133000,83.606000 24.906000,83.990000 25.687000,84.357000 26.476000,84.708000 27.273000,85.042000 28.078000,85.359000 28.889000,85.658000 29.707000,85.940000 30.530000,86.205000 31.360000,86.451000 32.195000,86.680000 33.036000,86.892000 33.881000,87.085000 34.730000,87.260000 35.583000,87.417000 36.439000,87.555000 37.299000,87.675000 38.161000,87.777000 39.026000,87.860000 39.893000,87.924000 40.761000,87.970000 41.630000,87.998000 42.500000,88.006000 43.370000,87.996000 44.241000,87.967000 45.110000,87.920000 45.979000,87.854000 46.847000,87.769000 47.712000,87.665000 48.576000,87.543000 49.437000,87.403000 50.296000,87.243000 51.151000,87.066000 52.002000,86.869000 52.849000,86.655000 53.692000,86.422000 54.530000,86.172000 55.363000,85.903000 56.190000,85.616000 57.010000,85.311000 57.825000,84.989000 58.633000,84.649000 59.433000,84.292000 60.226000,83.917000 61.011000,83.526000 61.788000,83.117000 62.556000,82.692000 63.315000,82.250000 64.065000,81.792000 64.805000,81.318000 65.534000,80.827000 66.254000,80.321000 66.962000,79.800000 67.660000,79.263000 68.346000,78.711000 69.020000,78.144000 69.682000,77.562000 70.332000,76.967000 70.969000,76.357000 71.593000,75.733000 72.204000,75.096000 72.801000,74.446000 73.385000,73.783000 73.954000,73.107000 74.509000,72.419000 75.049000,71.719000 75.574000,71.007000 76.083000,70.284000 76.578000,69.549000 77.056000,68.804000 77.519000,68.049000 77.966000,67.283000 78.396000,66.508000 78.809000,65.724000 79.206000,64.930000 79.586000,64.128000 79.948000,63.318000 80.294000,62.499000 80.621000,61.673000 80.931000,60.840000 81.223000,60.001000 81.497000,59.154000 81.753000,58.302000 81.991000,57.444000 82.210000,56.581000 82.411000,55.713000 82.593000,54.841000 82.757000,53.965000 82.901000,53.085000 83.027000,52.201000 83.134000,51.315000 83.221000,50.427000 83.290000,49.536000 83.340000,48.644000 83.370000,47.751000 83.381000,46.857000 83.373000,45.963000 83.346000,45.068000 83.299000,44.174000 83.234000,43.281000 83.149000,42.390000 83.045000,41.500000 82.921000,40.612000 82.779000,39.726000 82.618000,38.844000 82.437000,37.965000 82.238000,37.089000 82.020000,36.218000 81.783000,35.352000 81.528000,34.490000 81.254000,33.634000 80.961000,32.783000 80.651000,31.939000 80.322000,31.101000 79.975000,30.270000 79.610000,29.447000 79.227000,28.631000 78.827000,27.823000 78.409000,27.024000 77.974000,26.234000 77.522000,25.453000 77.053000,24.681000 76.568000,23.920000 76.066000,23.169000 75.548000,22.428000 75.014000,21.699000 74.464000,20.981000 73.899000,20.275000 73.319000,19.580000 72.723000,18.898000 72.113000,18.229000 71.488000,17.573000 70.849000,16.930000 70.196000,16.301000 69.530000,15.686000 68.850000,15.085000 68.157000,14.498000 67.452000,13.927000 66.734000,13.370000 66.004000,12.829000 65.263000,12.303000 64.510000,11.793000 63.746000,11.300000 62.971000,10.822000 62.186000,10.362000 61.391000,9.918000 60.586000,9.491000 59.772000,9.081000 58.949000,8.689000 58.118000,8.314000 57.278000,7.958000 56.431000,7.619000 55.576000,7.298000 54.714000,6.996000 53.846000,6.712000 52.971000,6.447000 52.091000,6.201000 51.205000,5.973000 50.314000,5.765000 49.419000,5.575000 48.519000,5.405000 47.616000,5.254000 46.709000,5.123000 45.799000,5.011000 44.887000,4.918000 43.973000,4.845000 43.057000,4.792000 42.139000,4.758000 41.221000,4.744000 40.303000,4.750000 39.384000,4.776000 38.466000,4.821000 37.549000,4.886000 36.633000,4.971000 35.719000,5.075000 34.806000,5.200000 33.897000,5.343000 32.990000,5.507000 32.087000,5.689000 31.188000,5.892000 30.292000,6.113000 29.402000,6.354000 28.516000,6.614000 27.637000,6.893000 26.762000,7.191000 25.895000,7.508000 25.034000,7.844000 24.179000,8.198000 23.333000,8.570000 22.494000,8.961000 21.664000,9.370000 20.842000,9.796000 20.030000,10.241000 19.227000,10.703000 18.433000,11.182000 17.650000,11.678000 16.878000,12.191000 16.116000,12.721000 15.366000,13.267000 14.627000,13.830000 13.900000,14.408000 13.186000,15.003000 12.484000,15.612000 11.796000,16.237000 11.121000,16.876000 10.459000,17.530000 9.811000,18.199000 9.178000,18.881000 8.559000,19.578000 7.955000,20.287000 7.366000,21.010000 6.793000,21.745000 6.235000,22.493000 5.694000,23.253000 5.168000,24.024000 4.660000,24.807000 4.168000,25.601000 3.693000,26.406000 3.235000,27.221000 2.794000,28.046000 2.372000,28.880000 1.967000,29.724000 1.580000,30.576000 1.212000,31.437000 0.862000,32.306000 0.530000,33.182000 0.218000,34.066000 -0.076000,34.957000 -0.350000,35.853000 -0.606000,36.756000 -0.842000,37.665000 -1.058000,38.579000 -1.255000,39.497000 -1.432000,40.420000 -1.589000,41.347000 -1.727000,42.277000 -1.844000,43.210000 -1.942000,44.146000 -2.019000,45.085000 -2.076000,46.024000 -2.113000,46.966000 -2.130000,47.908000 -2.126000,48.851000 -2.102000,49.793000 -2.058000,50.736000 -1.994000,51.677000 -1.910000,52.617000 -1.805000,53.556000 -1.680000,54.492000 -1.535000,55.426000 -1.370000,56.357000 -1.185000,57.284000 -0.980000,58.207000 -0.755000,59.127000 -0.510000,60.041000 -0.246000,60.950000 0.038000,61.854000 0.342000,62.752000 0.665000,63.643000 1.006000,64.528000 1.367000,65.405000 1.747000,66.274000 2.146000,67.136000 2.563000,67.989000 2.999000,68.833000 3.452000,69.668000 3.924000,70.493000 4.414000,71.309000 4.921000,72.113000 5.445000,72.907000 5.987000,73.690000 6.545000,74.462000 7.120000,75.221000 7.712000,75.968000 8.319000,76.703000 8.943000,77.424000 9.582000,78.132000 10.236000,78.827000 10.905000,79.507000 11.589000,80.174000 12.288000,80.825000 13.000000,81.462000 13.727000,82.084000 14.466000,82.690000 15.219000,83.280000 15.985000,83.854000 16.763000,84.411000 17.553000,84.952000 18.354000,85.476000 19.167000,85.983000 19.992000,86.473000 20.826000,86.945000 21.671000,87.399000 22.526000,87.834000 23.390000,88.252000 24.264000,88.651000 25.146000,89.031000 26.036000,89.393000 26.934000,89.735000 27.840000,90.058000 28.752000,90.362000 29.671000,90.646000 30.597000,90.910000 31.528000,91.154000 32.465000,91.379000 33.406000,91.583000 34.352000,91.768000 35.302000,91.931000 36.256000,92.075000 37.213000,92.198000 38.173000,92.300000 39.135000,92.382000 40.099000,92.443000 41.064000,92.484000 42.030000,92.504000 42.997000,92.503000 43.964000,92.481000 44.930000,92.438000 45.896000,92.375000 46.860000,92.291000 47.823000,92.186000 48.784000,92.060000 49.742000,91.914000 50.697000,91.747000 51.648000,91.560000 52.596000,91.352000 53.539000,91.124000 54.477000,90.876000 55.410000,90.607000 56.338000,90.318000 57.259000,90.010000 58.174000,89.681000 59.082000,89.333000 59.983000,88.965000 60.875000,88.578000 61.760000,88.172000 62.636000,87.746000 63.502000,87.302000 64.360000,86.839000 65.207000,86.358000 66.045000,85.858000 66.871000,85.340000 67.687000,84.805000 68.491000,84.252000 69.283000,83.681000 70.063000,83.093000 70.831000,82.489000 71.586000,81.868000 72.327000,81.231000 73.055000,80.578000 73.769000,79.909000 74.469000,79.224000 75.154000,78.525000 75.824000,77.811000 76.478000,77.082000 77.117000,76.339000 77.741000,75.583000 78.348000,74.812000 78.938000,74.029000 79.512000,73.233000 80.069000,72.425000 80.608000,71.604000 81.130000,70.772000 81.634000,69.928000 82.120000,69.074000 82.588000,68.209000 83.037000,67.334000 83.468000,66.449000 83.879000,65.555000 84.271000,64.652000 84.644000,63.740000 84.998000,62.821000 85.331000,61.893000 85.645000,60.959000 85.939000,60.017000 86.212000,59.069000 86.465000,58.115000 86.698000,57.156000 86.910000,56.191000 87.101000,55.222000 87.272000,54.249000 87.422000,53.271000 87.550000,52.291000 87.658000,51.308000 87.745000,50.322000 87.810000,49.334000 87.854000,48.345000 87.877000,47.355000 87.879000,46.364000 87.859000,45.373000 87.818000,44.382000 87.756000,43.392000 87.672000,42.403000 87.567000,41.416000 87.441000,40.432000 87.294000,39.449000 87.126000,38.470000 86.937000,37.495000 86.726000,36.523000 86.495000,35.556000 86.243000,34.593000 85.970000,33.636000 85.677000,32.685000 85.363000,31.740000 85.029000,30.801000 84.675000,29.870000 84.300000,28.946000 83.906000,28.030000 83.492000,27.123000 83.058000,26.224000 82.606000,25.335000 82.133000,24.455000 81.642000,23.585000 81.133000,22.726000 80.605000,21.877000 80.058000,21.040000 79.493000,20.214000 78.911000,19.401000 78.311000,18.600000 77.694000,17.812000 77.060000,17.037000 76.409000,16.275000 75.742000,15.527000 75.058000,14.794000 74.359000,14.075000 73.644000,13.372000 72.914000,12.683000 72.169000,12.010000 71.410000,11.353000 70.636000,10.713000 69.849000,10.088000 69.048000,9.481000 68.234000,8.891000 67.407000,8.318000 66.568000,7.763000 65.717000,7.226000 64.854000,6.708000 63.980000,6.207000 63.095000,5.726000 62.200000,5.263000 61.295000,4.820000 60.380000,4.396000 59.456000,3.992000 58.523000,3.607000 57.582000,3.242000 56.632000,2.898000 55.676000,2.574000 54.712000,2.271000 53.742000,1.988000 52.765000,1.726000 51.783000,1.485000 50.796000,1.265000 49.803000,1.066000 48.807000,0.889000 47.806000,0.733000 46.802000,0.598000 45.795000,0.485000 44.785000,0.394000 43.774000,0.324000 42.761000,0.276000 41.746000,0.250000 0.000000,0.250000 z" /><g transform="translate(83.500000 95.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Arm Length",
                    "name": "arm_length",
                    "tooltip": "Length of a single crossing arm.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Added Width",
                    "name": "added_width",
                    "tooltip": 'Width added to the arm linearly up to the center. An expression or string (with independent variable ``"u"``) can also be used.',
                    "defaults": 0.0,
                    "type": "input",
                    "validates": ["expression"],
                    "validatesArgs": {"expression": [1]},
                    "suffix": "μm",
                },
                {
                    "label": "Extra Length",
                    "name": "extra_length",
                    "tooltip": "Additional length for a straight section at the ports.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.crossing",
            "label": "Crossing",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-5.500000 -5.500000 11.000000 11.000000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}.reference{fill:none;stroke:#221f20;stroke-width:0.038500;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.440000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.055000;}.dashed{stroke-dasharray:0.275000,0.165000;}.port{fill:none;stroke:#805080;stroke-width:0.110000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.082500;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.220000 L 0.330000,0 0,0.220000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.165000 C 0.220000,-0.165000 0.220000,0.165000 0,0.165000" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.099000" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.115500" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 4.000000,1.290000 3.000000,1.330000 2.000000,1.370000 1.394000,1.394000 1.370000,2.000000 1.330000,3.000000 1.290000,4.000000 1.250000,5.000000 -1.250000,5.000000 -1.290000,4.000000 -1.330000,3.000000 -1.370000,2.000000 -1.394000,1.394000 -2.000000,1.370000 -3.000000,1.330000 -4.000000,1.290000 -5.000000,1.250000 -5.000000,-1.250000 -4.000000,-1.290000 -3.000000,-1.330000 -2.000000,-1.370000 -1.394000,-1.394000 -1.370000,-2.000000 -1.330000,-3.000000 -1.290000,-4.000000 -1.250000,-5.000000 1.250000,-5.000000 1.290000,-4.000000 1.330000,-3.000000 1.370000,-2.000000 1.394000,-1.394000 2.000000,-1.370000 3.000000,-1.330000 4.000000,-1.290000 5.000000,-1.250000 5.000000,1.250000 z" /><path class="layer_2_0" d="M 4.000000,0.290000 3.000000,0.330000 2.000000,0.370000 1.000000,0.410000 0.433000,0.433000 0.410000,1.000000 0.370000,2.000000 0.330000,3.000000 0.290000,4.000000 0.250000,5.000000 -0.250000,5.000000 -0.290000,4.000000 -0.330000,3.000000 -0.370000,2.000000 -0.410000,1.000000 -0.433000,0.433000 -1.000000,0.410000 -2.000000,0.370000 -3.000000,0.330000 -4.000000,0.290000 -5.000000,0.250000 -5.000000,-0.250000 -4.000000,-0.290000 -3.000000,-0.330000 -2.000000,-0.370000 -1.000000,-0.410000 -0.433000,-0.433000 -0.410000,-1.000000 -0.370000,-2.000000 -0.330000,-3.000000 -0.290000,-4.000000 -0.250000,-5.000000 0.250000,-5.000000 0.290000,-4.000000 0.330000,-3.000000 0.370000,-2.000000 0.410000,-1.000000 0.433000,-0.433000 1.000000,-0.410000 2.000000,-0.370000 3.000000,-0.330000 4.000000,-0.290000 5.000000,-0.250000 5.000000,0.250000 z" /><g transform="translate(0.000000 5.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(5.000000 0.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 -5.000000) rotate(90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-5.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between bus and ring waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central ring radius.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Port Bends",
                    "name": "port_bends",
                    "tooltip": "Flag controllig whether to set a bend radius for the ports. Not used when ``euler_factor > 0``.",
                    "type": "checkbox",
                    "defaults": False,
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.dual_ring_coupler",
            "label": "Dual Ring Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.175000 -0.925000 20.350000 18.500000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}.reference{fill:none;stroke:#221f20;stroke-width:0.064750;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.740000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.092500;}.dashed{stroke-dasharray:0.462500,0.277500;}.port{fill:none;stroke:#805080;stroke-width:0.185000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.138750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.370000 L 0.555000,0 0,0.370000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.277500 C 0.370000,-0.277500 0.370000,0.277500 0,0.277500" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.166500" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.194250" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M -6.750000,-16.650000 -6.731000,-16.146000 -6.708000,-15.894000 -6.675000,-15.644000 -6.581000,-15.148000 -6.450000,-14.660000 -6.283000,-14.184000 -6.082000,-13.721000 -5.846000,-13.275000 -5.577000,-12.848000 -5.277000,-12.441000 -4.948000,-12.059000 -4.591000,-11.702000 -4.209000,-11.373000 -3.802000,-11.073000 -3.375000,-10.804000 -2.929000,-10.568000 -2.466000,-10.367000 -1.990000,-10.200000 -1.502000,-10.069000 -1.006000,-9.975000 -0.756000,-9.942000 -0.252000,-9.905000 0.000000,-9.900000 0.504000,-9.919000 0.756000,-9.942000 1.006000,-9.975000 1.502000,-10.069000 1.990000,-10.200000 2.466000,-10.367000 2.929000,-10.568000 3.375000,-10.804000 3.802000,-11.073000 4.209000,-11.373000 4.591000,-11.702000 4.948000,-12.059000 5.277000,-12.441000 5.577000,-12.848000 5.846000,-13.275000 6.082000,-13.721000 6.283000,-14.184000 6.450000,-14.660000 6.581000,-15.148000 6.675000,-15.644000 6.708000,-15.894000 6.745000,-16.398000 6.750000,-16.650000 9.250000,-16.650000 9.244000,-16.304000 9.224000,-15.959000 9.192000,-15.614000 9.147000,-15.271000 9.089000,-14.930000 9.018000,-14.592000 8.935000,-14.256000 8.839000,-13.924000 8.731000,-13.595000 8.611000,-13.271000 8.478000,-12.951000 8.334000,-12.637000 8.178000,-12.328000 8.011000,-12.025000 7.832000,-11.729000 7.643000,-11.439000 7.443000,-11.157000 7.232000,-10.883000 7.011000,-10.616000 6.781000,-10.358000 6.541000,-10.109000 6.292000,-9.869000 6.034000,-9.639000 5.767000,-9.418000 5.493000,-9.207000 5.211000,-9.007000 4.921000,-8.818000 4.625000,-8.639000 4.322000,-8.472000 4.013000,-8.316000 3.699000,-8.172000 3.379000,-8.039000 3.055000,-7.919000 2.726000,-7.811000 2.394000,-7.715000 2.058000,-7.632000 1.720000,-7.561000 1.379000,-7.503000 1.036000,-7.458000 0.691000,-7.426000 0.346000,-7.406000 0.000000,-7.400000 -0.346000,-7.406000 -0.691000,-7.426000 -1.036000,-7.458000 -1.379000,-7.503000 -1.720000,-7.561000 -2.058000,-7.632000 -2.394000,-7.715000 -2.726000,-7.811000 -3.055000,-7.919000 -3.379000,-8.039000 -3.699000,-8.172000 -4.013000,-8.316000 -4.322000,-8.472000 -4.625000,-8.639000 -4.921000,-8.818000 -5.211000,-9.007000 -5.493000,-9.207000 -5.767000,-9.418000 -6.034000,-9.639000 -6.292000,-9.869000 -6.541000,-10.109000 -6.781000,-10.358000 -7.011000,-10.616000 -7.232000,-10.883000 -7.443000,-11.157000 -7.643000,-11.439000 -7.832000,-11.729000 -8.011000,-12.025000 -8.178000,-12.328000 -8.334000,-12.637000 -8.478000,-12.951000 -8.611000,-13.271000 -8.731000,-13.595000 -8.839000,-13.924000 -8.935000,-14.256000 -9.018000,-14.592000 -9.089000,-14.930000 -9.147000,-15.271000 -9.192000,-15.614000 -9.224000,-15.959000 -9.244000,-16.304000 -9.250000,-16.650000 z" /><path class="layer_1_0" d="M 6.750000,0.000000 6.731000,-0.504000 6.708000,-0.756000 6.675000,-1.006000 6.581000,-1.502000 6.450000,-1.990000 6.283000,-2.466000 6.082000,-2.929000 5.846000,-3.375000 5.577000,-3.802000 5.277000,-4.209000 4.948000,-4.591000 4.591000,-4.948000 4.209000,-5.277000 3.802000,-5.577000 3.375000,-5.846000 2.929000,-6.082000 2.466000,-6.283000 1.990000,-6.450000 1.502000,-6.581000 1.006000,-6.675000 0.756000,-6.708000 0.252000,-6.745000 0.000000,-6.750000 -0.504000,-6.731000 -0.756000,-6.708000 -1.006000,-6.675000 -1.502000,-6.581000 -1.990000,-6.450000 -2.466000,-6.283000 -2.929000,-6.082000 -3.375000,-5.846000 -3.802000,-5.577000 -4.209000,-5.277000 -4.591000,-4.948000 -4.948000,-4.591000 -5.277000,-4.209000 -5.577000,-3.802000 -5.846000,-3.375000 -6.082000,-2.929000 -6.283000,-2.466000 -6.450000,-1.990000 -6.581000,-1.502000 -6.675000,-1.006000 -6.708000,-0.756000 -6.745000,-0.252000 -6.750000,0.000000 -9.250000,0.000000 -9.244000,-0.346000 -9.224000,-0.691000 -9.192000,-1.036000 -9.147000,-1.379000 -9.089000,-1.720000 -9.018000,-2.058000 -8.935000,-2.394000 -8.839000,-2.726000 -8.731000,-3.055000 -8.611000,-3.379000 -8.478000,-3.699000 -8.334000,-4.013000 -8.178000,-4.322000 -8.011000,-4.625000 -7.832000,-4.921000 -7.643000,-5.211000 -7.443000,-5.493000 -7.232000,-5.767000 -7.011000,-6.034000 -6.781000,-6.292000 -6.541000,-6.541000 -6.292000,-6.781000 -6.034000,-7.011000 -5.767000,-7.232000 -5.493000,-7.443000 -5.211000,-7.643000 -4.921000,-7.832000 -4.625000,-8.011000 -4.322000,-8.178000 -4.013000,-8.334000 -3.699000,-8.478000 -3.379000,-8.611000 -3.055000,-8.731000 -2.726000,-8.839000 -2.394000,-8.935000 -2.058000,-9.018000 -1.720000,-9.089000 -1.379000,-9.147000 -1.036000,-9.192000 -0.691000,-9.224000 -0.346000,-9.244000 0.000000,-9.250000 0.346000,-9.244000 0.691000,-9.224000 1.036000,-9.192000 1.379000,-9.147000 1.720000,-9.089000 2.058000,-9.018000 2.394000,-8.935000 2.726000,-8.839000 3.055000,-8.731000 3.379000,-8.611000 3.699000,-8.478000 4.013000,-8.334000 4.322000,-8.178000 4.625000,-8.011000 4.921000,-7.832000 5.211000,-7.643000 5.493000,-7.443000 5.767000,-7.232000 6.034000,-7.011000 6.292000,-6.781000 6.541000,-6.541000 6.781000,-6.292000 7.011000,-6.034000 7.232000,-5.767000 7.443000,-5.493000 7.643000,-5.211000 7.832000,-4.921000 8.011000,-4.625000 8.178000,-4.322000 8.334000,-4.013000 8.478000,-3.699000 8.611000,-3.379000 8.731000,-3.055000 8.839000,-2.726000 8.935000,-2.394000 9.018000,-2.058000 9.089000,-1.720000 9.147000,-1.379000 9.192000,-1.036000 9.224000,-0.691000 9.244000,-0.346000 9.250000,0.000000 z" /><path class="layer_2_0" d="M -7.750000,-16.650000 -7.745000,-16.360000 -7.701000,-15.782000 -7.663000,-15.495000 -7.615000,-15.209000 -7.556000,-14.925000 -7.486000,-14.644000 -7.406000,-14.366000 -7.315000,-14.090000 -7.214000,-13.819000 -6.983000,-13.287000 -6.712000,-12.775000 -6.562000,-12.527000 -6.403000,-12.284000 -6.236000,-12.048000 -6.059000,-11.818000 -5.874000,-11.595000 -5.681000,-11.379000 -5.480000,-11.170000 -5.271000,-10.969000 -5.055000,-10.776000 -4.832000,-10.591000 -4.602000,-10.414000 -4.366000,-10.247000 -4.123000,-10.088000 -3.875000,-9.938000 -3.363000,-9.667000 -2.831000,-9.436000 -2.560000,-9.335000 -2.284000,-9.244000 -2.006000,-9.164000 -1.725000,-9.094000 -1.441000,-9.035000 -1.155000,-8.987000 -0.868000,-8.949000 -0.579000,-8.922000 -0.290000,-8.905000 0.000000,-8.900000 0.290000,-8.905000 0.868000,-8.949000 1.155000,-8.987000 1.441000,-9.035000 1.725000,-9.094000 2.006000,-9.164000 2.284000,-9.244000 2.560000,-9.335000 2.831000,-9.436000 3.363000,-9.667000 3.875000,-9.938000 4.123000,-10.088000 4.366000,-10.247000 4.602000,-10.414000 4.832000,-10.591000 5.055000,-10.776000 5.271000,-10.969000 5.480000,-11.170000 5.681000,-11.379000 5.874000,-11.595000 6.059000,-11.818000 6.236000,-12.048000 6.403000,-12.284000 6.562000,-12.527000 6.712000,-12.775000 6.983000,-13.287000 7.214000,-13.819000 7.315000,-14.090000 7.406000,-14.366000 7.486000,-14.644000 7.556000,-14.925000 7.615000,-15.209000 7.663000,-15.495000 7.701000,-15.782000 7.728000,-16.071000 7.745000,-16.360000 7.750000,-16.650000 8.250000,-16.650000 8.244000,-16.342000 8.227000,-16.033000 8.198000,-15.726000 8.158000,-15.420000 8.106000,-15.116000 8.043000,-14.814000 7.969000,-14.515000 7.883000,-14.218000 7.787000,-13.925000 7.680000,-13.636000 7.562000,-13.351000 7.433000,-13.070000 7.294000,-12.795000 7.145000,-12.525000 6.985000,-12.261000 6.816000,-12.003000 6.638000,-11.751000 6.450000,-11.506000 6.253000,-11.269000 6.048000,-11.039000 5.834000,-10.816000 5.611000,-10.602000 5.381000,-10.397000 5.144000,-10.200000 4.899000,-10.012000 4.647000,-9.834000 4.389000,-9.665000 4.125000,-9.505000 3.855000,-9.356000 3.580000,-9.217000 3.299000,-9.088000 3.014000,-8.970000 2.725000,-8.863000 2.432000,-8.767000 2.135000,-8.681000 1.836000,-8.607000 1.534000,-8.544000 1.230000,-8.492000 0.924000,-8.452000 0.617000,-8.423000 0.308000,-8.406000 0.000000,-8.400000 -0.308000,-8.406000 -0.617000,-8.423000 -0.924000,-8.452000 -1.230000,-8.492000 -1.534000,-8.544000 -1.836000,-8.607000 -2.135000,-8.681000 -2.432000,-8.767000 -2.725000,-8.863000 -3.014000,-8.970000 -3.299000,-9.088000 -3.580000,-9.217000 -3.855000,-9.356000 -4.125000,-9.505000 -4.389000,-9.665000 -4.647000,-9.834000 -4.899000,-10.012000 -5.144000,-10.200000 -5.381000,-10.397000 -5.611000,-10.602000 -5.834000,-10.816000 -6.048000,-11.039000 -6.253000,-11.269000 -6.450000,-11.506000 -6.638000,-11.751000 -6.816000,-12.003000 -6.985000,-12.261000 -7.145000,-12.525000 -7.294000,-12.795000 -7.433000,-13.070000 -7.562000,-13.351000 -7.680000,-13.636000 -7.787000,-13.925000 -7.883000,-14.218000 -7.969000,-14.515000 -8.043000,-14.814000 -8.106000,-15.116000 -8.158000,-15.420000 -8.198000,-15.726000 -8.227000,-16.033000 -8.244000,-16.342000 -8.250000,-16.650000 z" /><path class="layer_2_0" d="M 7.750000,0.000000 7.745000,-0.290000 7.701000,-0.868000 7.663000,-1.155000 7.615000,-1.441000 7.556000,-1.725000 7.486000,-2.006000 7.406000,-2.284000 7.315000,-2.560000 7.214000,-2.831000 6.983000,-3.363000 6.712000,-3.875000 6.562000,-4.123000 6.403000,-4.366000 6.236000,-4.602000 6.059000,-4.832000 5.874000,-5.055000 5.681000,-5.271000 5.480000,-5.480000 5.271000,-5.681000 5.055000,-5.874000 4.832000,-6.059000 4.602000,-6.236000 4.366000,-6.403000 4.123000,-6.562000 3.875000,-6.712000 3.363000,-6.983000 2.831000,-7.214000 2.560000,-7.315000 2.284000,-7.406000 2.006000,-7.486000 1.725000,-7.556000 1.441000,-7.615000 1.155000,-7.663000 0.868000,-7.701000 0.579000,-7.728000 0.290000,-7.745000 0.000000,-7.750000 -0.290000,-7.745000 -0.868000,-7.701000 -1.155000,-7.663000 -1.441000,-7.615000 -1.725000,-7.556000 -2.006000,-7.486000 -2.284000,-7.406000 -2.560000,-7.315000 -2.831000,-7.214000 -3.363000,-6.983000 -3.875000,-6.712000 -4.123000,-6.562000 -4.366000,-6.403000 -4.602000,-6.236000 -4.832000,-6.059000 -5.055000,-5.874000 -5.271000,-5.681000 -5.480000,-5.480000 -5.681000,-5.271000 -5.874000,-5.055000 -6.059000,-4.832000 -6.236000,-4.602000 -6.403000,-4.366000 -6.562000,-4.123000 -6.712000,-3.875000 -6.983000,-3.363000 -7.214000,-2.831000 -7.315000,-2.560000 -7.406000,-2.284000 -7.486000,-2.006000 -7.556000,-1.725000 -7.615000,-1.441000 -7.663000,-1.155000 -7.701000,-0.868000 -7.728000,-0.579000 -7.745000,-0.290000 -7.750000,0.000000 -8.250000,0.000000 -8.244000,-0.308000 -8.227000,-0.617000 -8.198000,-0.924000 -8.158000,-1.230000 -8.106000,-1.534000 -8.043000,-1.836000 -7.969000,-2.135000 -7.883000,-2.432000 -7.787000,-2.725000 -7.680000,-3.014000 -7.562000,-3.299000 -7.433000,-3.580000 -7.294000,-3.855000 -7.145000,-4.125000 -6.985000,-4.389000 -6.816000,-4.647000 -6.638000,-4.899000 -6.450000,-5.144000 -6.253000,-5.381000 -6.048000,-5.611000 -5.834000,-5.834000 -5.611000,-6.048000 -5.381000,-6.253000 -5.144000,-6.450000 -4.899000,-6.638000 -4.647000,-6.816000 -4.389000,-6.985000 -4.125000,-7.145000 -3.855000,-7.294000 -3.580000,-7.433000 -3.299000,-7.562000 -3.014000,-7.680000 -2.725000,-7.787000 -2.432000,-7.883000 -2.135000,-7.969000 -1.836000,-8.043000 -1.534000,-8.106000 -1.230000,-8.158000 -0.924000,-8.198000 -0.617000,-8.227000 -0.308000,-8.244000 0.000000,-8.250000 0.308000,-8.244000 0.617000,-8.227000 0.924000,-8.198000 1.230000,-8.158000 1.534000,-8.106000 1.836000,-8.043000 2.135000,-7.969000 2.432000,-7.883000 2.725000,-7.787000 3.014000,-7.680000 3.299000,-7.562000 3.580000,-7.433000 3.855000,-7.294000 4.125000,-7.145000 4.389000,-6.985000 4.647000,-6.816000 4.899000,-6.638000 5.144000,-6.450000 5.381000,-6.253000 5.611000,-6.048000 5.834000,-5.834000 6.048000,-5.611000 6.253000,-5.381000 6.450000,-5.144000 6.638000,-4.899000 6.816000,-4.647000 6.985000,-4.389000 7.145000,-4.125000 7.294000,-3.855000 7.433000,-3.580000 7.562000,-3.299000 7.680000,-3.014000 7.787000,-2.725000 7.883000,-2.432000 7.969000,-2.135000 8.043000,-1.836000 8.106000,-1.534000 8.158000,-1.230000 8.198000,-0.924000 8.227000,-0.617000 8.244000,-0.308000 8.250000,0.000000 z" /><g transform="translate(8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(8.000000 -16.650000) rotate(90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 -16.650000) rotate(90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Turns",
                    "name": "turns",
                    "tooltip": "Number of turns in each of the 2 spiral arms.",
                    "validates": ["min", "integer"],
                    "validatesArgs": {"min": [2]},
                    "type": "number",
                    "required": False,
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Bend radius for the spiral turns.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Separation",
                    "name": "separation",
                    "tooltip": "Distance between waveguide centers in parallel sections.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "children": [
                        {
                            "hideLabel": True,
                            "name": "x",
                            "prefix": "x",
                            "suffix": "μm",
                            "type": "number",
                            "validates": ["min"],
                            "validatesArgs": {"min": [0]},
                        },
                        {
                            "hideLabel": True,
                            "name": "y",
                            "prefix": "y",
                            "suffix": "μm",
                            "type": "number",
                            "validates": ["min"],
                            "validatesArgs": {"min": [0]},
                        },
                    ],
                    "itemSpan": 12,
                    "label": "Size",
                    "name": "size",
                    "tooltip": "Spiral dimensions measured from the waveguide centers.",
                    "category": "tuple",
                    "type": "subForm",
                },
                {
                    "label": "Full Length",
                    "name": "full_length",
                    "tooltip": "Desired spiral length. If set to a positive value, 'turns' and 'size[1]' are calculated automatically.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                    "required": False,
                },
                {
                    "label": "Align Ports",
                    "name": "align_ports",
                    "tooltip": 'Optionally align ports to have centers with same ``"x"`` or ``"y"`` coordinates.',
                    "defaults": "none",
                    "options": ["none", "x", "y"],
                    "type": "radioGroup",
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.rectangular_spiral",
            "label": "Rectangular Spiral",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-2.275000 -33.025000 50.050000 36.550000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}.reference{fill:none;stroke:#221f20;stroke-width:0.127925;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:1.462000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.182750;}.dashed{stroke-dasharray:0.913750,0.548250;}.port{fill:none;stroke:#805080;stroke-width:0.365500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.274125;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.731000 L 1.096500,0 0,0.731000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.548250 C 0.731000,-0.548250 0.731000,0.548250 0,0.548250" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.328950" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.383775" /><g id="C1"><path class="layer_1_0" d="M 0.000000,-1.250000 0.504000,-1.269000 0.756000,-1.292000 1.006000,-1.325000 1.502000,-1.419000 1.990000,-1.550000 2.466000,-1.717000 2.929000,-1.918000 3.375000,-2.154000 3.802000,-2.423000 4.209000,-2.723000 4.591000,-3.052000 4.948000,-3.409000 5.277000,-3.791000 5.577000,-4.198000 5.846000,-4.625000 6.082000,-5.071000 6.283000,-5.534000 6.450000,-6.010000 6.581000,-6.498000 6.675000,-6.994000 6.708000,-7.244000 6.745000,-7.748000 6.750000,-8.000000 9.250000,-8.000000 9.244000,-7.654000 9.224000,-7.309000 9.192000,-6.964000 9.147000,-6.621000 9.089000,-6.280000 9.018000,-5.942000 8.935000,-5.606000 8.839000,-5.274000 8.731000,-4.945000 8.611000,-4.621000 8.478000,-4.301000 8.334000,-3.987000 8.178000,-3.678000 8.011000,-3.375000 7.832000,-3.079000 7.643000,-2.789000 7.443000,-2.507000 7.232000,-2.233000 7.011000,-1.966000 6.781000,-1.708000 6.541000,-1.459000 6.292000,-1.219000 6.034000,-0.989000 5.767000,-0.768000 5.493000,-0.557000 5.211000,-0.357000 4.921000,-0.168000 4.625000,0.011000 4.322000,0.178000 4.013000,0.334000 3.699000,0.478000 3.379000,0.611000 3.055000,0.731000 2.726000,0.839000 2.394000,0.935000 2.058000,1.018000 1.720000,1.089000 1.379000,1.147000 1.036000,1.192000 0.691000,1.224000 0.346000,1.244000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.290000,-0.255000 0.868000,-0.299000 1.155000,-0.337000 1.441000,-0.385000 1.725000,-0.444000 2.006000,-0.514000 2.284000,-0.594000 2.560000,-0.685000 2.831000,-0.786000 3.363000,-1.017000 3.875000,-1.288000 4.123000,-1.438000 4.366000,-1.597000 4.602000,-1.764000 4.832000,-1.941000 5.055000,-2.126000 5.271000,-2.319000 5.480000,-2.520000 5.681000,-2.729000 5.874000,-2.945000 6.059000,-3.168000 6.236000,-3.398000 6.403000,-3.634000 6.562000,-3.877000 6.712000,-4.125000 6.983000,-4.637000 7.214000,-5.169000 7.315000,-5.440000 7.406000,-5.716000 7.486000,-5.994000 7.556000,-6.275000 7.615000,-6.559000 7.663000,-6.845000 7.701000,-7.132000 7.728000,-7.421000 7.745000,-7.710000 7.750000,-8.000000 8.250000,-8.000000 8.244000,-7.692000 8.227000,-7.383000 8.198000,-7.076000 8.158000,-6.770000 8.106000,-6.466000 8.043000,-6.164000 7.969000,-5.865000 7.883000,-5.568000 7.787000,-5.275000 7.680000,-4.986000 7.562000,-4.701000 7.433000,-4.420000 7.294000,-4.145000 7.145000,-3.875000 6.985000,-3.611000 6.816000,-3.353000 6.638000,-3.101000 6.450000,-2.856000 6.253000,-2.619000 6.048000,-2.389000 5.834000,-2.166000 5.611000,-1.952000 5.381000,-1.747000 5.144000,-1.550000 4.899000,-1.362000 4.647000,-1.184000 4.389000,-1.015000 4.125000,-0.855000 3.855000,-0.706000 3.580000,-0.567000 3.299000,-0.438000 3.014000,-0.320000 2.725000,-0.213000 2.432000,-0.117000 2.135000,-0.031000 1.836000,0.043000 1.534000,0.106000 1.230000,0.158000 0.924000,0.198000 0.617000,0.227000 0.308000,0.244000 0.000000,0.250000 z" /></g><g id="C4"><path class="layer_1_0" d="M 0.000000,-1.250000 18.250000,-1.250000 18.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 18.250000,-0.250000 18.250000,0.250000 0.000000,0.250000 z" /></g><g id="C2"><path class="layer_1_0" d="M 0.000000,-1.250000 0.346000,-1.244000 0.691000,-1.224000 1.036000,-1.192000 1.379000,-1.147000 1.720000,-1.089000 2.058000,-1.018000 2.394000,-0.935000 2.726000,-0.839000 3.055000,-0.731000 3.379000,-0.611000 3.699000,-0.478000 4.013000,-0.334000 4.322000,-0.178000 4.625000,-0.011000 4.921000,0.168000 5.211000,0.357000 5.493000,0.557000 5.767000,0.768000 6.034000,0.989000 6.292000,1.219000 6.541000,1.459000 6.781000,1.708000 7.011000,1.966000 7.232000,2.233000 7.443000,2.507000 7.643000,2.789000 7.832000,3.079000 8.011000,3.375000 8.178000,3.678000 8.334000,3.987000 8.478000,4.301000 8.611000,4.621000 8.731000,4.945000 8.839000,5.274000 8.935000,5.606000 9.018000,5.942000 9.089000,6.280000 9.147000,6.621000 9.192000,6.964000 9.224000,7.309000 9.244000,7.654000 9.250000,8.000000 6.750000,8.000000 6.745000,7.748000 6.708000,7.244000 6.675000,6.994000 6.581000,6.498000 6.450000,6.010000 6.283000,5.534000 6.082000,5.071000 5.846000,4.625000 5.577000,4.198000 5.277000,3.791000 4.948000,3.409000 4.591000,3.052000 4.209000,2.723000 3.802000,2.423000 3.375000,2.154000 2.929000,1.918000 2.466000,1.717000 1.990000,1.550000 1.502000,1.419000 1.006000,1.325000 0.756000,1.292000 0.504000,1.269000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.308000,-0.244000 0.617000,-0.227000 0.924000,-0.198000 1.230000,-0.158000 1.534000,-0.106000 1.836000,-0.043000 2.135000,0.031000 2.432000,0.117000 2.725000,0.213000 3.014000,0.320000 3.299000,0.438000 3.580000,0.567000 3.855000,0.706000 4.125000,0.855000 4.389000,1.015000 4.647000,1.184000 4.899000,1.362000 5.144000,1.550000 5.381000,1.747000 5.611000,1.952000 5.834000,2.166000 6.048000,2.389000 6.253000,2.619000 6.450000,2.856000 6.638000,3.101000 6.816000,3.353000 6.985000,3.611000 7.145000,3.875000 7.294000,4.145000 7.433000,4.420000 7.562000,4.701000 7.680000,4.986000 7.787000,5.275000 7.883000,5.568000 7.969000,5.865000 8.043000,6.164000 8.106000,6.466000 8.158000,6.770000 8.198000,7.076000 8.227000,7.383000 8.244000,7.692000 8.250000,8.000000 7.750000,8.000000 7.745000,7.710000 7.728000,7.421000 7.701000,7.132000 7.663000,6.845000 7.615000,6.559000 7.556000,6.275000 7.486000,5.994000 7.406000,5.716000 7.315000,5.440000 7.214000,5.169000 6.983000,4.637000 6.712000,4.125000 6.562000,3.877000 6.403000,3.634000 6.236000,3.398000 6.059000,3.168000 5.874000,2.945000 5.681000,2.729000 5.480000,2.520000 5.271000,2.319000 5.055000,2.126000 4.832000,1.941000 4.602000,1.764000 4.366000,1.597000 4.123000,1.438000 3.875000,1.288000 3.363000,1.017000 2.831000,0.786000 2.560000,0.685000 2.284000,0.594000 2.006000,0.514000 1.725000,0.444000 1.441000,0.385000 1.155000,0.337000 0.868000,0.299000 0.290000,0.255000 0.000000,0.250000 z" /></g><g id="C3"><path class="layer_1_0" d="M 0.000000,-1.250000 2.250000,-1.250000 2.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 2.250000,-0.250000 2.250000,0.250000 0.000000,0.250000 z" /></g><g id="C6"><path class="layer_1_0" d="M 0.000000,-1.250000 22.750000,-1.250000 22.750000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 22.750000,-0.250000 22.750000,0.250000 0.000000,0.250000 z" /></g><g id="C5"><path class="layer_1_0" d="M 0.000000,-1.250000 6.750000,-1.250000 6.750000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 6.750000,-0.250000 6.750000,0.250000 0.000000,0.250000 z" /></g><g id="C7"><path class="layer_1_0" d="M 0.000000,-1.250000 11.250000,-1.250000 11.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 11.250000,-0.250000 11.250000,0.250000 0.000000,0.250000 z" /></g><g id="C8"><path class="layer_1_0" d="M 0.000000,-1.250000 35.250000,-1.250000 35.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 35.250000,-0.250000 35.250000,0.250000 0.000000,0.250000 z" /></g></defs><g transform="scale(1 -1)"><g id="C0"><use transform="translate(22.750000 14.750000) rotate(270.000000)" href="#C1" /><use transform="translate(30.750000 22.750000) rotate(180.000000)" href="#C2" /><use transform="translate(14.750000 6.750000) rotate(180.000000)" href="#C1" /><use transform="translate(38.750000 14.750000) rotate(90.000000)" href="#C2" /><use transform="translate(6.750000 14.750000) rotate(90.000000)" href="#C3" /><use transform="translate(38.750000 12.500000) rotate(90.000000)" href="#C3" /><use transform="translate(6.750000 17.000000) rotate(90.000000)" href="#C1" /><use transform="translate(30.750000 4.500000)" href="#C2" /><use transform="translate(14.750000 25.000000)" href="#C4" /><use transform="translate(12.500000 4.500000)" href="#C4" /><use transform="translate(33.000000 25.000000)" href="#C1" /><use transform="translate(4.500000 12.500000) rotate(270.000000)" href="#C2" /><use transform="translate(41.000000 17.000000) rotate(270.000000)" href="#C5" /><use transform="translate(4.500000 19.250000) rotate(270.000000)" href="#C5" /><use transform="translate(41.000000 10.250000) rotate(270.000000)" href="#C1" /><use transform="translate(12.500000 27.250000) rotate(180.000000)" href="#C2" /><use transform="translate(33.000000 2.250000) rotate(180.000000)" href="#C6" /><use transform="translate(35.250000 27.250000) rotate(180.000000)" href="#C6" /><use transform="translate(10.250000 2.250000) rotate(180.000000)" href="#C1" /><use transform="translate(43.250000 19.250000) rotate(90.000000)" href="#C2" /><use transform="translate(2.250000 10.250000) rotate(90.000000)" href="#C7" /><use transform="translate(43.250000 8.000000) rotate(90.000000)" href="#C7" /><use transform="translate(2.250000 21.500000) rotate(90.000000)" href="#C1" /><use transform="translate(35.250000 0.000000)" href="#C2" /><use transform="translate(0.000000 0.000000)" href="#C8" /><use transform="translate(10.250000 29.500000)" href="#C8" /><g transform="translate(45.500000 29.500000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between bus and ring waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central ring radius.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Bus Length",
                    "name": "bus_length",
                    "tooltip": "Length of the bus waveguide added to each side of the straight coupling section. If both ``bus_length`` and ``coupling_length`` are 0, the bus waveguide is not included.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Port Bends",
                    "name": "port_bends",
                    "tooltip": "Flag controllig whether to set a bend radius for the ports. Not used when ``euler_factor > 0``.",
                    "type": "checkbox",
                    "defaults": False,
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.ring_coupler",
            "label": "Ring Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.175000 -0.925000 20.350000 11.750000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}.reference{fill:none;stroke:#221f20;stroke-width:0.041125;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.470000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.058750;}.dashed{stroke-dasharray:0.293750,0.176250;}.port{fill:none;stroke:#805080;stroke-width:0.117500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.088125;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.235000 L 0.352500,0 0,0.235000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.176250 C 0.235000,-0.176250 0.235000,0.176250 0,0.176250" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.105750" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.123375" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M -8.000000,-9.900000 8.000000,-9.900000 8.000000,-7.400000 -8.000000,-7.400000 z" /><path class="layer_1_0" d="M 6.750000,0.000000 6.731000,-0.504000 6.708000,-0.756000 6.675000,-1.006000 6.581000,-1.502000 6.450000,-1.990000 6.283000,-2.466000 6.082000,-2.929000 5.846000,-3.375000 5.577000,-3.802000 5.277000,-4.209000 4.948000,-4.591000 4.591000,-4.948000 4.209000,-5.277000 3.802000,-5.577000 3.375000,-5.846000 2.929000,-6.082000 2.466000,-6.283000 1.990000,-6.450000 1.502000,-6.581000 1.006000,-6.675000 0.756000,-6.708000 0.252000,-6.745000 0.000000,-6.750000 -0.504000,-6.731000 -0.756000,-6.708000 -1.006000,-6.675000 -1.502000,-6.581000 -1.990000,-6.450000 -2.466000,-6.283000 -2.929000,-6.082000 -3.375000,-5.846000 -3.802000,-5.577000 -4.209000,-5.277000 -4.591000,-4.948000 -4.948000,-4.591000 -5.277000,-4.209000 -5.577000,-3.802000 -5.846000,-3.375000 -6.082000,-2.929000 -6.283000,-2.466000 -6.450000,-1.990000 -6.581000,-1.502000 -6.675000,-1.006000 -6.708000,-0.756000 -6.745000,-0.252000 -6.750000,0.000000 -9.250000,0.000000 -9.244000,-0.346000 -9.224000,-0.691000 -9.192000,-1.036000 -9.147000,-1.379000 -9.089000,-1.720000 -9.018000,-2.058000 -8.935000,-2.394000 -8.839000,-2.726000 -8.731000,-3.055000 -8.611000,-3.379000 -8.478000,-3.699000 -8.334000,-4.013000 -8.178000,-4.322000 -8.011000,-4.625000 -7.832000,-4.921000 -7.643000,-5.211000 -7.443000,-5.493000 -7.232000,-5.767000 -7.011000,-6.034000 -6.781000,-6.292000 -6.541000,-6.541000 -6.292000,-6.781000 -6.034000,-7.011000 -5.767000,-7.232000 -5.493000,-7.443000 -5.211000,-7.643000 -4.921000,-7.832000 -4.625000,-8.011000 -4.322000,-8.178000 -4.013000,-8.334000 -3.699000,-8.478000 -3.379000,-8.611000 -3.055000,-8.731000 -2.726000,-8.839000 -2.394000,-8.935000 -2.058000,-9.018000 -1.720000,-9.089000 -1.379000,-9.147000 -1.036000,-9.192000 -0.691000,-9.224000 -0.346000,-9.244000 0.000000,-9.250000 0.346000,-9.244000 0.691000,-9.224000 1.036000,-9.192000 1.379000,-9.147000 1.720000,-9.089000 2.058000,-9.018000 2.394000,-8.935000 2.726000,-8.839000 3.055000,-8.731000 3.379000,-8.611000 3.699000,-8.478000 4.013000,-8.334000 4.322000,-8.178000 4.625000,-8.011000 4.921000,-7.832000 5.211000,-7.643000 5.493000,-7.443000 5.767000,-7.232000 6.034000,-7.011000 6.292000,-6.781000 6.541000,-6.541000 6.781000,-6.292000 7.011000,-6.034000 7.232000,-5.767000 7.443000,-5.493000 7.643000,-5.211000 7.832000,-4.921000 8.011000,-4.625000 8.178000,-4.322000 8.334000,-4.013000 8.478000,-3.699000 8.611000,-3.379000 8.731000,-3.055000 8.839000,-2.726000 8.935000,-2.394000 9.018000,-2.058000 9.089000,-1.720000 9.147000,-1.379000 9.192000,-1.036000 9.224000,-0.691000 9.244000,-0.346000 9.250000,0.000000 z" /><path class="layer_2_0" d="M -8.000000,-8.900000 8.000000,-8.900000 8.000000,-8.400000 -8.000000,-8.400000 z" /><path class="layer_2_0" d="M 7.750000,0.000000 7.745000,-0.290000 7.701000,-0.868000 7.663000,-1.155000 7.615000,-1.441000 7.556000,-1.725000 7.486000,-2.006000 7.406000,-2.284000 7.315000,-2.560000 7.214000,-2.831000 6.983000,-3.363000 6.712000,-3.875000 6.562000,-4.123000 6.403000,-4.366000 6.236000,-4.602000 6.059000,-4.832000 5.874000,-5.055000 5.681000,-5.271000 5.480000,-5.480000 5.271000,-5.681000 5.055000,-5.874000 4.832000,-6.059000 4.602000,-6.236000 4.366000,-6.403000 4.123000,-6.562000 3.875000,-6.712000 3.363000,-6.983000 2.831000,-7.214000 2.560000,-7.315000 2.284000,-7.406000 2.006000,-7.486000 1.725000,-7.556000 1.441000,-7.615000 1.155000,-7.663000 0.868000,-7.701000 0.579000,-7.728000 0.290000,-7.745000 0.000000,-7.750000 -0.290000,-7.745000 -0.868000,-7.701000 -1.155000,-7.663000 -1.441000,-7.615000 -1.725000,-7.556000 -2.006000,-7.486000 -2.284000,-7.406000 -2.560000,-7.315000 -2.831000,-7.214000 -3.363000,-6.983000 -3.875000,-6.712000 -4.123000,-6.562000 -4.366000,-6.403000 -4.602000,-6.236000 -4.832000,-6.059000 -5.055000,-5.874000 -5.271000,-5.681000 -5.480000,-5.480000 -5.681000,-5.271000 -5.874000,-5.055000 -6.059000,-4.832000 -6.236000,-4.602000 -6.403000,-4.366000 -6.562000,-4.123000 -6.712000,-3.875000 -6.983000,-3.363000 -7.214000,-2.831000 -7.315000,-2.560000 -7.406000,-2.284000 -7.486000,-2.006000 -7.556000,-1.725000 -7.615000,-1.441000 -7.663000,-1.155000 -7.701000,-0.868000 -7.728000,-0.579000 -7.745000,-0.290000 -7.750000,0.000000 -8.250000,0.000000 -8.244000,-0.308000 -8.227000,-0.617000 -8.198000,-0.924000 -8.158000,-1.230000 -8.106000,-1.534000 -8.043000,-1.836000 -7.969000,-2.135000 -7.883000,-2.432000 -7.787000,-2.725000 -7.680000,-3.014000 -7.562000,-3.299000 -7.433000,-3.580000 -7.294000,-3.855000 -7.145000,-4.125000 -6.985000,-4.389000 -6.816000,-4.647000 -6.638000,-4.899000 -6.450000,-5.144000 -6.253000,-5.381000 -6.048000,-5.611000 -5.834000,-5.834000 -5.611000,-6.048000 -5.381000,-6.253000 -5.144000,-6.450000 -4.899000,-6.638000 -4.647000,-6.816000 -4.389000,-6.985000 -4.125000,-7.145000 -3.855000,-7.294000 -3.580000,-7.433000 -3.299000,-7.562000 -3.014000,-7.680000 -2.725000,-7.787000 -2.432000,-7.883000 -2.135000,-7.969000 -1.836000,-8.043000 -1.534000,-8.106000 -1.230000,-8.158000 -0.924000,-8.198000 -0.617000,-8.227000 -0.308000,-8.244000 0.000000,-8.250000 0.308000,-8.244000 0.617000,-8.227000 0.924000,-8.198000 1.230000,-8.158000 1.534000,-8.106000 1.836000,-8.043000 2.135000,-7.969000 2.432000,-7.883000 2.725000,-7.787000 3.014000,-7.680000 3.299000,-7.562000 3.580000,-7.433000 3.855000,-7.294000 4.125000,-7.145000 4.389000,-6.985000 4.647000,-6.816000 4.899000,-6.638000 5.144000,-6.450000 5.381000,-6.253000 5.611000,-6.048000 5.834000,-5.834000 6.048000,-5.611000 6.253000,-5.381000 6.450000,-5.144000 6.638000,-4.899000 6.816000,-4.647000 6.985000,-4.389000 7.145000,-4.125000 7.294000,-3.855000 7.433000,-3.580000 7.562000,-3.299000 7.680000,-3.014000 7.787000,-2.725000 7.883000,-2.432000 7.969000,-2.135000 8.043000,-1.836000 8.106000,-1.534000 8.158000,-1.230000 8.198000,-0.924000 8.227000,-0.617000 8.244000,-0.308000 8.250000,0.000000 z" /><g transform="translate(8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(8.000000 -8.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 -8.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Length",
                    "name": "length",
                    "tooltip": "Length of the S bend in the main propagation direction.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                    "required": False,
                },
                {
                    "label": "Offset",
                    "name": "offset",
                    "tooltip": "Side offset of the S bend.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend",
            "label": "S Bend",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.400000 -3.650000 8.800000 5.300000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}.reference{fill:none;stroke:#221f20;stroke-width:0.018550;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.212000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.026500;}.dashed{stroke-dasharray:0.132500,0.079500;}.port{fill:none;stroke:#805080;stroke-width:0.053000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.039750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.106000 L 0.159000,0 0,0.106000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.079500 C 0.106000,-0.079500 0.106000,0.079500 0,0.079500" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.047700" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.055650" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 0.398000,-1.242000 0.795000,-1.218000 1.191000,-1.177000 1.585000,-1.120000 1.977000,-1.048000 2.365000,-0.959000 2.749000,-0.854000 3.128000,-0.734000 3.503000,-0.599000 3.871000,-0.449000 4.233000,-0.283000 4.588000,-0.103000 4.852000,0.031000 5.121000,0.154000 5.395000,0.266000 5.674000,0.367000 5.956000,0.456000 6.242000,0.534000 6.530000,0.599000 6.821000,0.654000 7.114000,0.696000 7.409000,0.726000 7.704000,0.744000 8.000000,0.750000 8.000000,3.250000 7.602000,3.242000 7.205000,3.218000 6.809000,3.177000 6.415000,3.120000 6.023000,3.048000 5.635000,2.959000 5.251000,2.854000 4.872000,2.734000 4.497000,2.599000 4.129000,2.449000 3.767000,2.283000 3.412000,2.103000 3.148000,1.969000 2.879000,1.846000 2.605000,1.734000 2.326000,1.633000 2.044000,1.544000 1.758000,1.466000 1.470000,1.401000 1.179000,1.346000 0.886000,1.304000 0.591000,1.274000 0.296000,1.256000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.357000,-0.243000 0.714000,-0.221000 1.069000,-0.184000 1.423000,-0.134000 1.774000,-0.068000 2.122000,0.011000 2.467000,0.105000 2.808000,0.213000 3.143000,0.334000 3.474000,0.469000 3.799000,0.618000 4.118000,0.779000 4.418000,0.932000 4.724000,1.072000 5.036000,1.199000 5.353000,1.314000 5.674000,1.415000 5.999000,1.504000 6.327000,1.579000 6.659000,1.640000 6.992000,1.688000 7.327000,1.723000 7.663000,1.743000 8.000000,1.750000 8.000000,2.250000 7.643000,2.243000 7.286000,2.221000 6.931000,2.184000 6.577000,2.134000 6.226000,2.068000 5.878000,1.989000 5.533000,1.895000 5.192000,1.787000 4.857000,1.666000 4.526000,1.531000 4.201000,1.382000 3.882000,1.221000 3.582000,1.068000 3.276000,0.928000 2.964000,0.801000 2.647000,0.686000 2.326000,0.585000 2.001000,0.496000 1.673000,0.421000 1.341000,0.360000 1.008000,0.312000 0.673000,0.277000 0.337000,0.257000 0.000000,0.250000 z" /><g transform="translate(8.000000 2.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "S Bend Length",
                    "name": "s_bend_length",
                    "tooltip": "Length of the S bends.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                    "required": False,
                },
                {
                    "label": "S Bend Offset",
                    "name": "s_bend_offset",
                    "tooltip": "Offset of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend_coupler",
            "label": "S Bend Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.774600 -6.674600 17.041200 8.699200"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}.reference{fill:none;stroke:#221f20;stroke-width:0.030447;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.347968px;}.terminal{fill:none;stroke:#805080;stroke-width:0.043496;}.dashed{stroke-dasharray:0.217480,0.130488;}.port{fill:none;stroke:#805080;stroke-width:0.086992;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.065244;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.173984 L 0.260976,0 0,0.173984" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.130488 C 0.173984,-0.130488 0.173984,0.130488 0,0.130488" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.078293" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.091342" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 0.389000,-1.242000 0.778000,-1.217000 1.166000,-1.176000 1.551000,-1.119000 1.933000,-1.046000 2.313000,-0.956000 2.688000,-0.851000 3.058000,-0.730000 3.423000,-0.594000 3.781000,-0.442000 4.133000,-0.275000 4.478000,-0.094000 4.730000,0.039000 4.987000,0.160000 5.248000,0.271000 5.515000,0.371000 5.785000,0.459000 6.058000,0.536000 6.335000,0.601000 6.614000,0.654000 6.895000,0.696000 7.178000,0.726000 7.462000,0.744000 7.746000,0.750000 8.030000,0.744000 8.314000,0.726000 8.597000,0.696000 8.878000,0.654000 9.157000,0.601000 9.434000,0.536000 9.707000,0.459000 9.977000,0.371000 10.244000,0.271000 10.505000,0.160000 10.762000,0.039000 11.014000,-0.094000 11.359000,-0.275000 11.711000,-0.442000 12.069000,-0.594000 12.434000,-0.730000 12.804000,-0.851000 13.179000,-0.956000 13.559000,-1.046000 13.941000,-1.119000 14.326000,-1.176000 14.714000,-1.217000 15.103000,-1.242000 15.492000,-1.250000 15.492000,1.250000 15.208000,1.256000 14.924000,1.274000 14.641000,1.304000 14.360000,1.346000 14.081000,1.399000 13.804000,1.464000 13.531000,1.541000 13.261000,1.629000 12.994000,1.729000 12.733000,1.840000 12.476000,1.961000 12.224000,2.094000 11.879000,2.275000 11.527000,2.442000 11.169000,2.594000 10.804000,2.730000 10.434000,2.851000 10.059000,2.956000 9.679000,3.046000 9.297000,3.119000 8.912000,3.176000 8.524000,3.217000 8.135000,3.242000 7.746000,3.250000 7.357000,3.242000 6.968000,3.217000 6.580000,3.176000 6.195000,3.119000 5.813000,3.046000 5.433000,2.956000 5.058000,2.851000 4.688000,2.730000 4.323000,2.594000 3.965000,2.442000 3.613000,2.275000 3.268000,2.094000 3.016000,1.961000 2.759000,1.840000 2.498000,1.729000 2.231000,1.629000 1.961000,1.541000 1.688000,1.464000 1.411000,1.399000 1.132000,1.346000 0.851000,1.304000 0.568000,1.274000 0.284000,1.256000 0.000000,1.250000 z" /><path class="layer_1_0" d="M 15.492000,5.900000 15.103000,5.892000 14.714000,5.867000 14.326000,5.826000 13.941000,5.769000 13.559000,5.696000 13.179000,5.606000 12.804000,5.501000 12.434000,5.380000 12.069000,5.244000 11.711000,5.092000 11.359000,4.925000 11.014000,4.744000 10.762000,4.611000 10.505000,4.490000 10.244000,4.379000 9.977000,4.279000 9.707000,4.191000 9.434000,4.114000 9.157000,4.049000 8.878000,3.996000 8.597000,3.954000 8.314000,3.924000 8.030000,3.906000 7.746000,3.900000 7.462000,3.906000 7.178000,3.924000 6.895000,3.954000 6.614000,3.996000 6.335000,4.049000 6.058000,4.114000 5.785000,4.191000 5.515000,4.279000 5.248000,4.379000 4.987000,4.490000 4.730000,4.611000 4.478000,4.744000 4.133000,4.925000 3.781000,5.092000 3.423000,5.244000 3.058000,5.380000 2.688000,5.501000 2.313000,5.606000 1.933000,5.696000 1.551000,5.769000 1.166000,5.826000 0.778000,5.867000 0.389000,5.892000 0.000000,5.900000 0.000000,3.400000 0.284000,3.394000 0.568000,3.376000 0.851000,3.346000 1.132000,3.304000 1.411000,3.251000 1.688000,3.186000 1.961000,3.109000 2.231000,3.021000 2.498000,2.921000 2.759000,2.810000 3.016000,2.689000 3.268000,2.556000 3.613000,2.375000 3.965000,2.208000 4.323000,2.056000 4.688000,1.920000 5.058000,1.799000 5.433000,1.694000 5.813000,1.604000 6.195000,1.531000 6.580000,1.474000 6.968000,1.433000 7.357000,1.408000 7.746000,1.400000 8.135000,1.408000 8.524000,1.433000 8.912000,1.474000 9.297000,1.531000 9.679000,1.604000 10.059000,1.694000 10.434000,1.799000 10.804000,1.920000 11.169000,2.056000 11.527000,2.208000 11.879000,2.375000 12.224000,2.556000 12.476000,2.689000 12.733000,2.810000 12.994000,2.921000 13.261000,3.021000 13.531000,3.109000 13.804000,3.186000 14.081000,3.251000 14.360000,3.304000 14.641000,3.346000 14.924000,3.376000 15.208000,3.394000 15.492000,3.400000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.347000,-0.243000 0.694000,-0.221000 1.040000,-0.184000 1.383000,-0.133000 1.724000,-0.068000 2.063000,0.012000 2.397000,0.106000 2.727000,0.214000 3.053000,0.336000 3.373000,0.471000 3.687000,0.620000 3.994000,0.781000 4.283000,0.933000 4.578000,1.073000 4.878000,1.200000 5.184000,1.314000 5.494000,1.416000 5.808000,1.504000 6.126000,1.579000 6.447000,1.640000 6.769000,1.688000 7.094000,1.723000 7.420000,1.743000 7.746000,1.750000 8.072000,1.743000 8.398000,1.723000 8.723000,1.688000 9.045000,1.640000 9.366000,1.579000 9.684000,1.504000 9.998000,1.416000 10.308000,1.314000 10.614000,1.200000 10.914000,1.073000 11.209000,0.933000 11.498000,0.781000 11.805000,0.620000 12.119000,0.471000 12.439000,0.336000 12.765000,0.214000 13.095000,0.106000 13.429000,0.012000 13.768000,-0.068000 14.109000,-0.133000 14.452000,-0.184000 14.798000,-0.221000 15.145000,-0.243000 15.492000,-0.250000 15.492000,0.250000 15.166000,0.257000 14.840000,0.277000 14.515000,0.312000 14.193000,0.360000 13.872000,0.421000 13.554000,0.496000 13.240000,0.584000 12.930000,0.686000 12.624000,0.800000 12.324000,0.927000 12.029000,1.067000 11.740000,1.219000 11.433000,1.381000 11.119000,1.529000 10.799000,1.664000 10.473000,1.786000 10.143000,1.894000 9.809000,1.988000 9.470000,2.068000 9.129000,2.133000 8.786000,2.184000 8.440000,2.221000 8.093000,2.243000 7.746000,2.250000 7.399000,2.243000 7.052000,2.221000 6.706000,2.184000 6.363000,2.133000 6.022000,2.068000 5.683000,1.988000 5.349000,1.894000 5.019000,1.786000 4.693000,1.664000 4.373000,1.529000 4.059000,1.381000 3.752000,1.219000 3.463000,1.067000 3.168000,0.927000 2.868000,0.800000 2.562000,0.686000 2.252000,0.584000 1.938000,0.496000 1.620000,0.421000 1.299000,0.360000 0.977000,0.312000 0.652000,0.277000 0.326000,0.257000 0.000000,0.250000 z" /><path class="layer_2_0" d="M 15.492000,4.900000 15.145000,4.893000 14.798000,4.871000 14.452000,4.834000 14.109000,4.783000 13.768000,4.718000 13.429000,4.638000 13.095000,4.544000 12.765000,4.436000 12.439000,4.314000 12.119000,4.179000 11.805000,4.031000 11.498000,3.869000 11.209000,3.717000 10.914000,3.577000 10.614000,3.450000 10.308000,3.336000 9.998000,3.234000 9.684000,3.146000 9.366000,3.071000 9.045000,3.010000 8.723000,2.962000 8.398000,2.927000 8.072000,2.907000 7.746000,2.900000 7.420000,2.907000 7.094000,2.927000 6.769000,2.962000 6.447000,3.010000 6.126000,3.071000 5.808000,3.146000 5.494000,3.234000 5.184000,3.336000 4.878000,3.450000 4.578000,3.577000 4.283000,3.717000 3.994000,3.869000 3.687000,4.031000 3.373000,4.179000 3.053000,4.314000 2.727000,4.436000 2.397000,4.544000 2.063000,4.638000 1.724000,4.718000 1.383000,4.783000 1.040000,4.834000 0.694000,4.871000 0.347000,4.893000 0.000000,4.900000 0.000000,4.400000 0.326000,4.393000 0.652000,4.373000 0.977000,4.338000 1.299000,4.290000 1.620000,4.229000 1.938000,4.154000 2.252000,4.066000 2.562000,3.964000 2.868000,3.850000 3.168000,3.723000 3.463000,3.583000 3.752000,3.431000 4.059000,3.270000 4.373000,3.121000 4.693000,2.986000 5.019000,2.864000 5.349000,2.756000 5.683000,2.662000 6.022000,2.582000 6.363000,2.517000 6.706000,2.466000 7.052000,2.429000 7.399000,2.407000 7.746000,2.400000 8.093000,2.407000 8.440000,2.429000 8.786000,2.466000 9.129000,2.517000 9.470000,2.582000 9.809000,2.662000 10.143000,2.756000 10.473000,2.864000 10.799000,2.986000 11.119000,3.121000 11.433000,3.270000 11.740000,3.431000 12.029000,3.583000 12.324000,3.723000 12.624000,3.850000 12.930000,3.964000 13.240000,4.066000 13.554000,4.154000 13.872000,4.229000 14.193000,4.290000 14.515000,4.338000 14.840000,4.373000 15.166000,4.393000 15.492000,4.400000 z" /><g transform="translate(15.492000 4.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(15.492000 0.000000) rotate(-180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 4.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between bus and ring waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central ring radius.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "S Bend Length",
                    "name": "s_bend_length",
                    "tooltip": "Length of the S bends.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                    "required": False,
                },
                {
                    "label": "S Bend Offset",
                    "name": "s_bend_offset",
                    "tooltip": "Offset of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Port Bends",
                    "name": "port_bends",
                    "tooltip": "Flag controllig whether to set a bend radius for the ports. Not used when ``euler_factor > 0``.",
                    "type": "checkbox",
                    "defaults": False,
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend_ring_coupler",
            "label": "S Bend Ring Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.175000 -0.925000 20.350000 13.750000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}.reference{fill:none;stroke:#221f20;stroke-width:0.048125;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.550000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.068750;}.dashed{stroke-dasharray:0.343750,0.206250;}.port{fill:none;stroke:#805080;stroke-width:0.137500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.103125;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.275000 L 0.412500,0 0,0.275000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.206250 C 0.275000,-0.206250 0.275000,0.206250 0,0.206250" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.123750" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.144375" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M -7.746000,-11.900000 -7.357000,-11.892000 -6.968000,-11.867000 -6.580000,-11.826000 -6.195000,-11.769000 -5.813000,-11.696000 -5.433000,-11.606000 -5.058000,-11.501000 -4.688000,-11.380000 -4.323000,-11.244000 -3.965000,-11.092000 -3.613000,-10.925000 -3.268000,-10.744000 -3.016000,-10.611000 -2.759000,-10.490000 -2.498000,-10.379000 -2.231000,-10.279000 -1.961000,-10.191000 -1.688000,-10.114000 -1.411000,-10.049000 -1.132000,-9.996000 -0.851000,-9.954000 -0.568000,-9.924000 -0.284000,-9.906000 0.000000,-9.900000 0.284000,-9.906000 0.568000,-9.924000 0.851000,-9.954000 1.132000,-9.996000 1.411000,-10.049000 1.688000,-10.114000 1.961000,-10.191000 2.231000,-10.279000 2.498000,-10.379000 2.759000,-10.490000 3.016000,-10.611000 3.268000,-10.744000 3.613000,-10.925000 3.965000,-11.092000 4.323000,-11.244000 4.688000,-11.380000 5.058000,-11.501000 5.433000,-11.606000 5.813000,-11.696000 6.195000,-11.769000 6.580000,-11.826000 6.968000,-11.867000 7.357000,-11.892000 7.746000,-11.900000 7.746000,-9.400000 7.462000,-9.394000 7.178000,-9.376000 6.895000,-9.346000 6.614000,-9.304000 6.335000,-9.251000 6.058000,-9.186000 5.785000,-9.109000 5.515000,-9.021000 5.248000,-8.921000 4.987000,-8.810000 4.730000,-8.689000 4.478000,-8.556000 4.133000,-8.375000 3.781000,-8.208000 3.423000,-8.056000 3.058000,-7.920000 2.688000,-7.799000 2.313000,-7.694000 1.933000,-7.604000 1.551000,-7.531000 1.166000,-7.474000 0.778000,-7.433000 0.389000,-7.408000 0.000000,-7.400000 -0.389000,-7.408000 -0.778000,-7.433000 -1.166000,-7.474000 -1.551000,-7.531000 -1.933000,-7.604000 -2.313000,-7.694000 -2.688000,-7.799000 -3.058000,-7.920000 -3.423000,-8.056000 -3.781000,-8.208000 -4.133000,-8.375000 -4.478000,-8.556000 -4.730000,-8.689000 -4.987000,-8.810000 -5.248000,-8.921000 -5.515000,-9.021000 -5.785000,-9.109000 -6.058000,-9.186000 -6.335000,-9.251000 -6.614000,-9.304000 -6.895000,-9.346000 -7.178000,-9.376000 -7.462000,-9.394000 -7.746000,-9.400000 z" /><path class="layer_1_0" d="M 6.750000,0.000000 6.731000,-0.504000 6.708000,-0.756000 6.675000,-1.006000 6.581000,-1.502000 6.450000,-1.990000 6.283000,-2.466000 6.082000,-2.929000 5.846000,-3.375000 5.577000,-3.802000 5.277000,-4.209000 4.948000,-4.591000 4.591000,-4.948000 4.209000,-5.277000 3.802000,-5.577000 3.375000,-5.846000 2.929000,-6.082000 2.466000,-6.283000 1.990000,-6.450000 1.502000,-6.581000 1.006000,-6.675000 0.756000,-6.708000 0.252000,-6.745000 0.000000,-6.750000 -0.504000,-6.731000 -0.756000,-6.708000 -1.006000,-6.675000 -1.502000,-6.581000 -1.990000,-6.450000 -2.466000,-6.283000 -2.929000,-6.082000 -3.375000,-5.846000 -3.802000,-5.577000 -4.209000,-5.277000 -4.591000,-4.948000 -4.948000,-4.591000 -5.277000,-4.209000 -5.577000,-3.802000 -5.846000,-3.375000 -6.082000,-2.929000 -6.283000,-2.466000 -6.450000,-1.990000 -6.581000,-1.502000 -6.675000,-1.006000 -6.708000,-0.756000 -6.745000,-0.252000 -6.750000,0.000000 -9.250000,0.000000 -9.244000,-0.346000 -9.224000,-0.691000 -9.192000,-1.036000 -9.147000,-1.379000 -9.089000,-1.720000 -9.018000,-2.058000 -8.935000,-2.394000 -8.839000,-2.726000 -8.731000,-3.055000 -8.611000,-3.379000 -8.478000,-3.699000 -8.334000,-4.013000 -8.178000,-4.322000 -8.011000,-4.625000 -7.832000,-4.921000 -7.643000,-5.211000 -7.443000,-5.493000 -7.232000,-5.767000 -7.011000,-6.034000 -6.781000,-6.292000 -6.541000,-6.541000 -6.292000,-6.781000 -6.034000,-7.011000 -5.767000,-7.232000 -5.493000,-7.443000 -5.211000,-7.643000 -4.921000,-7.832000 -4.625000,-8.011000 -4.322000,-8.178000 -4.013000,-8.334000 -3.699000,-8.478000 -3.379000,-8.611000 -3.055000,-8.731000 -2.726000,-8.839000 -2.394000,-8.935000 -2.058000,-9.018000 -1.720000,-9.089000 -1.379000,-9.147000 -1.036000,-9.192000 -0.691000,-9.224000 -0.346000,-9.244000 0.000000,-9.250000 0.346000,-9.244000 0.691000,-9.224000 1.036000,-9.192000 1.379000,-9.147000 1.720000,-9.089000 2.058000,-9.018000 2.394000,-8.935000 2.726000,-8.839000 3.055000,-8.731000 3.379000,-8.611000 3.699000,-8.478000 4.013000,-8.334000 4.322000,-8.178000 4.625000,-8.011000 4.921000,-7.832000 5.211000,-7.643000 5.493000,-7.443000 5.767000,-7.232000 6.034000,-7.011000 6.292000,-6.781000 6.541000,-6.541000 6.781000,-6.292000 7.011000,-6.034000 7.232000,-5.767000 7.443000,-5.493000 7.643000,-5.211000 7.832000,-4.921000 8.011000,-4.625000 8.178000,-4.322000 8.334000,-4.013000 8.478000,-3.699000 8.611000,-3.379000 8.731000,-3.055000 8.839000,-2.726000 8.935000,-2.394000 9.018000,-2.058000 9.089000,-1.720000 9.147000,-1.379000 9.192000,-1.036000 9.224000,-0.691000 9.244000,-0.346000 9.250000,0.000000 z" /><path class="layer_2_0" d="M -7.746000,-10.900000 -7.399000,-10.893000 -7.052000,-10.871000 -6.706000,-10.834000 -6.363000,-10.783000 -6.022000,-10.718000 -5.683000,-10.638000 -5.349000,-10.544000 -5.019000,-10.436000 -4.693000,-10.314000 -4.373000,-10.179000 -4.059000,-10.030000 -3.752000,-9.869000 -3.463000,-9.717000 -3.168000,-9.577000 -2.868000,-9.450000 -2.562000,-9.336000 -2.252000,-9.234000 -1.938000,-9.146000 -1.620000,-9.071000 -1.299000,-9.010000 -0.977000,-8.962000 -0.652000,-8.927000 -0.326000,-8.907000 0.000000,-8.900000 0.326000,-8.907000 0.652000,-8.927000 0.977000,-8.962000 1.299000,-9.010000 1.620000,-9.071000 1.938000,-9.146000 2.252000,-9.234000 2.562000,-9.336000 2.868000,-9.450000 3.168000,-9.577000 3.463000,-9.717000 3.752000,-9.869000 4.059000,-10.030000 4.373000,-10.179000 4.693000,-10.314000 5.019000,-10.436000 5.349000,-10.544000 5.683000,-10.638000 6.022000,-10.718000 6.363000,-10.783000 6.706000,-10.834000 7.052000,-10.871000 7.399000,-10.893000 7.746000,-10.900000 7.746000,-10.400000 7.420000,-10.393000 7.094000,-10.373000 6.769000,-10.338000 6.447000,-10.290000 6.126000,-10.229000 5.808000,-10.154000 5.494000,-10.066000 5.184000,-9.964000 4.878000,-9.850000 4.578000,-9.723000 4.283000,-9.583000 3.994000,-9.431000 3.687000,-9.269000 3.373000,-9.121000 3.053000,-8.986000 2.727000,-8.864000 2.397000,-8.756000 2.063000,-8.662000 1.724000,-8.582000 1.383000,-8.517000 1.040000,-8.466000 0.694000,-8.429000 0.347000,-8.407000 0.000000,-8.400000 -0.347000,-8.407000 -0.694000,-8.429000 -1.040000,-8.466000 -1.383000,-8.517000 -1.724000,-8.582000 -2.063000,-8.662000 -2.397000,-8.756000 -2.727000,-8.864000 -3.053000,-8.986000 -3.373000,-9.121000 -3.687000,-9.269000 -3.994000,-9.431000 -4.283000,-9.583000 -4.578000,-9.723000 -4.878000,-9.850000 -5.184000,-9.964000 -5.494000,-10.066000 -5.808000,-10.154000 -6.126000,-10.229000 -6.447000,-10.290000 -6.769000,-10.338000 -7.094000,-10.373000 -7.420000,-10.393000 -7.746000,-10.400000 z" /><path class="layer_2_0" d="M 7.750000,0.000000 7.745000,-0.290000 7.701000,-0.868000 7.663000,-1.155000 7.615000,-1.441000 7.556000,-1.725000 7.486000,-2.006000 7.406000,-2.284000 7.315000,-2.560000 7.214000,-2.831000 6.983000,-3.363000 6.712000,-3.875000 6.562000,-4.123000 6.403000,-4.366000 6.236000,-4.602000 6.059000,-4.832000 5.874000,-5.055000 5.681000,-5.271000 5.480000,-5.480000 5.271000,-5.681000 5.055000,-5.874000 4.832000,-6.059000 4.602000,-6.236000 4.366000,-6.403000 4.123000,-6.562000 3.875000,-6.712000 3.363000,-6.983000 2.831000,-7.214000 2.560000,-7.315000 2.284000,-7.406000 2.006000,-7.486000 1.725000,-7.556000 1.441000,-7.615000 1.155000,-7.663000 0.868000,-7.701000 0.579000,-7.728000 0.290000,-7.745000 0.000000,-7.750000 -0.290000,-7.745000 -0.868000,-7.701000 -1.155000,-7.663000 -1.441000,-7.615000 -1.725000,-7.556000 -2.006000,-7.486000 -2.284000,-7.406000 -2.560000,-7.315000 -2.831000,-7.214000 -3.363000,-6.983000 -3.875000,-6.712000 -4.123000,-6.562000 -4.366000,-6.403000 -4.602000,-6.236000 -4.832000,-6.059000 -5.055000,-5.874000 -5.271000,-5.681000 -5.480000,-5.480000 -5.681000,-5.271000 -5.874000,-5.055000 -6.059000,-4.832000 -6.236000,-4.602000 -6.403000,-4.366000 -6.562000,-4.123000 -6.712000,-3.875000 -6.983000,-3.363000 -7.214000,-2.831000 -7.315000,-2.560000 -7.406000,-2.284000 -7.486000,-2.006000 -7.556000,-1.725000 -7.615000,-1.441000 -7.663000,-1.155000 -7.701000,-0.868000 -7.728000,-0.579000 -7.745000,-0.290000 -7.750000,0.000000 -8.250000,0.000000 -8.244000,-0.308000 -8.227000,-0.617000 -8.198000,-0.924000 -8.158000,-1.230000 -8.106000,-1.534000 -8.043000,-1.836000 -7.969000,-2.135000 -7.883000,-2.432000 -7.787000,-2.725000 -7.680000,-3.014000 -7.562000,-3.299000 -7.433000,-3.580000 -7.294000,-3.855000 -7.145000,-4.125000 -6.985000,-4.389000 -6.816000,-4.647000 -6.638000,-4.899000 -6.450000,-5.144000 -6.253000,-5.381000 -6.048000,-5.611000 -5.834000,-5.834000 -5.611000,-6.048000 -5.381000,-6.253000 -5.144000,-6.450000 -4.899000,-6.638000 -4.647000,-6.816000 -4.389000,-6.985000 -4.125000,-7.145000 -3.855000,-7.294000 -3.580000,-7.433000 -3.299000,-7.562000 -3.014000,-7.680000 -2.725000,-7.787000 -2.432000,-7.883000 -2.135000,-7.969000 -1.836000,-8.043000 -1.534000,-8.106000 -1.230000,-8.158000 -0.924000,-8.198000 -0.617000,-8.227000 -0.308000,-8.244000 0.000000,-8.250000 0.308000,-8.244000 0.617000,-8.227000 0.924000,-8.198000 1.230000,-8.158000 1.534000,-8.106000 1.836000,-8.043000 2.135000,-7.969000 2.432000,-7.883000 2.725000,-7.787000 3.014000,-7.680000 3.299000,-7.562000 3.580000,-7.433000 3.855000,-7.294000 4.125000,-7.145000 4.389000,-6.985000 4.647000,-6.816000 4.899000,-6.638000 5.144000,-6.450000 5.381000,-6.253000 5.611000,-6.048000 5.834000,-5.834000 6.048000,-5.611000 6.253000,-5.381000 6.450000,-5.144000 6.638000,-4.899000 6.816000,-4.647000 6.985000,-4.389000 7.145000,-4.125000 7.294000,-3.855000 7.433000,-3.580000 7.562000,-3.299000 7.680000,-3.014000 7.787000,-2.725000 7.883000,-2.432000 7.969000,-2.135000 8.043000,-1.836000 8.106000,-1.534000 8.158000,-1.230000 8.198000,-0.924000 8.227000,-0.617000 8.244000,-0.308000 8.250000,0.000000 z" /><g transform="translate(8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(7.746000 -10.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-7.746000 -10.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "S Bend Length",
                    "name": "s_bend_length",
                    "tooltip": "Length of the S bends.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                    "required": False,
                },
                {
                    "label": "S Bend Offset",
                    "name": "s_bend_offset",
                    "tooltip": "Offset of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                    "type": "number",
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend_straight_coupler",
            "label": "S Bend Straight Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.774600 -4.674600 17.041200 6.699200"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}.reference{fill:none;stroke:#221f20;stroke-width:0.023447;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.267968px;}.terminal{fill:none;stroke:#805080;stroke-width:0.033496;}.dashed{stroke-dasharray:0.167480,0.100488;}.port{fill:none;stroke:#805080;stroke-width:0.066992;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.050244;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.133984 L 0.200976,0 0,0.133984" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.100488 C 0.133984,-0.100488 0.133984,0.100488 0,0.100488" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.060293" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.070342" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 15.492000,-1.250000 15.492000,1.250000 0.000000,1.250000 z" /><path class="layer_1_0" d="M 15.492000,3.900000 15.103000,3.892000 14.714000,3.867000 14.326000,3.826000 13.941000,3.769000 13.559000,3.696000 13.179000,3.606000 12.804000,3.501000 12.434000,3.380000 12.069000,3.244000 11.711000,3.092000 11.359000,2.925000 11.014000,2.744000 10.762000,2.611000 10.505000,2.490000 10.244000,2.379000 9.977000,2.279000 9.707000,2.191000 9.434000,2.114000 9.157000,2.049000 8.878000,1.996000 8.597000,1.954000 8.314000,1.924000 8.030000,1.906000 7.746000,1.900000 7.462000,1.906000 7.178000,1.924000 6.895000,1.954000 6.614000,1.996000 6.335000,2.049000 6.058000,2.114000 5.785000,2.191000 5.515000,2.279000 5.248000,2.379000 4.987000,2.490000 4.730000,2.611000 4.478000,2.744000 4.133000,2.925000 3.781000,3.092000 3.423000,3.244000 3.058000,3.380000 2.688000,3.501000 2.313000,3.606000 1.933000,3.696000 1.551000,3.769000 1.166000,3.826000 0.778000,3.867000 0.389000,3.892000 0.000000,3.900000 0.000000,1.400000 0.284000,1.394000 0.568000,1.376000 0.851000,1.346000 1.132000,1.304000 1.411000,1.251000 1.688000,1.186000 1.961000,1.109000 2.231000,1.021000 2.498000,0.921000 2.759000,0.810000 3.016000,0.689000 3.268000,0.556000 3.613000,0.375000 3.965000,0.208000 4.323000,0.056000 4.688000,-0.080000 5.058000,-0.201000 5.433000,-0.306000 5.813000,-0.396000 6.195000,-0.469000 6.580000,-0.526000 6.968000,-0.567000 7.357000,-0.592000 7.746000,-0.600000 8.135000,-0.592000 8.524000,-0.567000 8.912000,-0.526000 9.297000,-0.469000 9.679000,-0.396000 10.059000,-0.306000 10.434000,-0.201000 10.804000,-0.080000 11.169000,0.056000 11.527000,0.208000 11.879000,0.375000 12.224000,0.556000 12.476000,0.689000 12.733000,0.810000 12.994000,0.921000 13.261000,1.021000 13.531000,1.109000 13.804000,1.186000 14.081000,1.251000 14.360000,1.304000 14.641000,1.346000 14.924000,1.376000 15.208000,1.394000 15.492000,1.400000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 15.492000,-0.250000 15.492000,0.250000 0.000000,0.250000 z" /><path class="layer_2_0" d="M 15.492000,2.900000 15.145000,2.893000 14.798000,2.871000 14.452000,2.834000 14.109000,2.783000 13.768000,2.718000 13.429000,2.638000 13.095000,2.544000 12.765000,2.436000 12.439000,2.314000 12.119000,2.179000 11.805000,2.031000 11.498000,1.869000 11.209000,1.717000 10.914000,1.577000 10.614000,1.450000 10.308000,1.336000 9.998000,1.234000 9.684000,1.146000 9.366000,1.071000 9.045000,1.010000 8.723000,0.962000 8.398000,0.927000 8.072000,0.907000 7.746000,0.900000 7.420000,0.907000 7.094000,0.927000 6.769000,0.962000 6.447000,1.010000 6.126000,1.071000 5.808000,1.146000 5.494000,1.234000 5.184000,1.336000 4.878000,1.450000 4.578000,1.577000 4.283000,1.717000 3.994000,1.869000 3.687000,2.031000 3.373000,2.179000 3.053000,2.314000 2.727000,2.436000 2.397000,2.544000 2.063000,2.638000 1.724000,2.718000 1.383000,2.783000 1.040000,2.834000 0.694000,2.871000 0.347000,2.893000 0.000000,2.900000 0.000000,2.400000 0.326000,2.393000 0.652000,2.373000 0.977000,2.338000 1.299000,2.290000 1.620000,2.229000 1.938000,2.154000 2.252000,2.066000 2.562000,1.964000 2.868000,1.850000 3.168000,1.723000 3.463000,1.583000 3.752000,1.431000 4.059000,1.270000 4.373000,1.121000 4.693000,0.986000 5.019000,0.864000 5.349000,0.756000 5.683000,0.662000 6.022000,0.582000 6.363000,0.517000 6.706000,0.466000 7.052000,0.429000 7.399000,0.407000 7.746000,0.400000 8.093000,0.407000 8.440000,0.429000 8.786000,0.466000 9.129000,0.517000 9.470000,0.582000 9.809000,0.662000 10.143000,0.756000 10.473000,0.864000 10.799000,0.986000 11.119000,1.121000 11.433000,1.270000 11.740000,1.431000 12.029000,1.583000 12.324000,1.723000 12.624000,1.850000 12.930000,1.964000 13.240000,2.066000 13.554000,2.154000 13.872000,2.229000 14.193000,2.290000 14.515000,2.338000 14.840000,2.373000 15.166000,2.393000 15.492000,2.400000 z" /><g transform="translate(15.492000 2.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(15.492000 0.000000) rotate(-180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 2.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Length",
                    "name": "length",
                    "tooltip": "Section length.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Bulge Width",
                    "name": "bulge_width",
                    "tooltip": "Width added to the waveguide cross-section in the central region when ``length`` if enough to fit in 2 tapering sections plus margins.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Bulge Taper Length",
                    "name": "bulge_taper_length",
                    "tooltip": "Length of each tapering region for bulging the central region of the waveguide.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Bulge Margin",
                    "name": "bulge_margin",
                    "tooltip": "Length of the waveguide that must be kept without bulging at both ends.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.straight",
            "label": "Straight",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.400000 -1.650000 8.800000 3.300000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}.reference{fill:none;stroke:#221f20;stroke-width:0.011550;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.132000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.016500;}.dashed{stroke-dasharray:0.082500,0.049500;}.port{fill:none;stroke:#805080;stroke-width:0.033000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.024750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.066000 L 0.099000,0 0,0.066000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.049500 C 0.066000,-0.049500 0.066000,0.049500 0,0.049500" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.029700" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.034650" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 8.000000,-1.250000 8.000000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 8.000000,-0.250000 8.000000,0.250000 0.000000,0.250000 z" /><g transform="translate(8.000000 0.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec1",
                    "name": "port_spec1",
                    "tooltip": "Port specification describing the first cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Port Spec2",
                    "name": "port_spec2",
                    "tooltip": "Port specification describing the second cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Length",
                    "name": "length",
                    "tooltip": "Transition length.",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Constant Length",
                    "name": "constant_length",
                    "tooltip": "Constant cross-section length added to both ends.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Profile",
                    "name": "profile",
                    "tooltip": 'String expression describing the transition shape parametrized by the independent variable ``"u"``, ranging from 0 to 1 along the transition. The expression must evaluate to a float between 0 and 1 representing the weight of the second profile with respect to the first at that position. Alternatively, an :class:`photonforge.Expression` with 1 parameter can be used.',
                    "type": "input",
                    "validates": ["expression"],
                    "validatesArgs": {"expression": [1]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.transition",
            "label": "Transition",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.400000 -1.650000 8.800000 3.300000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}.reference{fill:none;stroke:#221f20;stroke-width:0.011550;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.132000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.016500;}.dashed{stroke-dasharray:0.082500,0.049500;}.port{fill:none;stroke:#805080;stroke-width:0.033000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.024750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.066000 L 0.099000,0 0,0.066000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.049500 C 0.066000,-0.049500 0.066000,0.049500 0,0.049500" /><circle id="port-bend-symbol" style="stroke-width:0;stroke:none;fill:#805080;" cx="0" cy="0" r="0.029700" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.034650" /></defs><g transform="scale(1 -1)"><g id="C0"><path class="layer_1_0" d="M 0.000000,-1.250000 1.600000,-1.240000 3.200000,-1.230000 4.800000,-1.220000 6.400000,-1.210000 8.000000,-1.200000 8.000000,1.200000 6.400000,1.210000 4.800000,1.220000 3.200000,1.230000 1.600000,1.240000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 1.600000,-0.240000 3.200000,-0.230000 4.800000,-0.220000 6.400000,-0.210000 8.000000,-0.200000 8.000000,0.200000 6.400000,0.210000 4.800000,0.220000 3.200000,0.230000 1.600000,0.240000 0.000000,0.250000 z" /><path class="layer_3_0" d="M 0.000000,0.000000 1.600000,-0.240000 3.200000,-0.480000 4.800000,-0.720000 6.400000,-0.960000 8.000000,-1.200000 8.000000,1.200000 6.400000,0.960000 4.800000,0.720000 3.200000,0.480000 1.600000,0.240000 z" /><g transform="translate(8.000000 0.000000) rotate(180.000000)"><path class="port" d="M 0,-1.080000 V 1.080000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
    ],
    "technologies": [
        {
            "arguments": [
                {
                    "itemSpan": 24,
                    "label": "Core Medium",
                    "name": "core_medium",
                    "tooltip": "Medium used for the core layer.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {
                                "type": "material_library",
                                "value": {"path": ["cSi", "Li1993_293K"]},
                            },
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {
                                "type": "constructor",
                                "value": {"permittivity": 12.3, "type": "Medium"},
                            },
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Clad Medium",
                    "name": "clad_medium",
                    "tooltip": "Medium used for cladding.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {
                                "type": "material_library",
                                "value": {"path": ["SiO2", "Palik_Lossless"]},
                            },
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {
                                "type": "constructor",
                                "value": {"permittivity": 4.2, "type": "Medium"},
                            },
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Trench Medium",
                    "name": "trench_medium",
                    "tooltip": "Medium used for trenches.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {"type": "constructor", "value": {"type": "Medium"}},
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {"type": "constructor", "value": {"type": "Medium"}},
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Metal Medium",
                    "name": "metal_medium",
                    "tooltip": "Medium used for the metal layer.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {
                                "type": "material_library",
                                "value": {"path": ["Cu", "JohnsonChristy1972"]},
                            },
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {
                                "type": "constructor",
                                "value": {"name": "PEC", "type": "PECMedium"},
                            },
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Top Medium",
                    "name": "top_medium",
                    "tooltip": "If set, an infinite layer above the clad is added with this medium.",
                    "required": False,
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Substrate Medium",
                    "name": "substrate_medium",
                    "tooltip": "If set, an infinite layer bellow the bottom clad is added with this medium.",
                    "required": False,
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                        },
                    ],
                },
                {
                    "defaults": 0.22,
                    "label": "Core Thickness",
                    "name": "core_thickness",
                    "tooltip": "Thickness of the core layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 0.07,
                    "label": "Slab Thickness",
                    "name": "slab_thickness",
                    "tooltip": "Thickness of the slab region (partially etched core thickness).",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 0.5,
                    "label": "Metal Thickness",
                    "name": "metal_thickness",
                    "tooltip": "Thickness of the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 1.5,
                    "label": "Metal Separation",
                    "name": "metal_separation",
                    "tooltip": "Distance between the top of the silicon layer and the bottom of the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 1.0,
                    "label": "Clad Thickness",
                    "name": "clad_thickness",
                    "tooltip": "Top cladding thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 1.0,
                    "label": "BOX Thickness",
                    "name": "box_thickness",
                    "tooltip": "Bottom cladding thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": (2, 0),
                    "label": "Core Layer",
                    "name": "core_layer",
                    "tooltip": "Layer tuple for the core region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (3, 0),
                    "label": "Slab Layer",
                    "name": "slab_layer",
                    "tooltip": "Layer tuple for the slab region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (1, 0),
                    "label": "Clad Layer",
                    "name": "clad_layer",
                    "tooltip": "Layer tuple for the clad region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (4, 0),
                    "label": "Trench Layer",
                    "name": "trench_layer",
                    "tooltip": "Layer tuple for the trench region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (5, 0),
                    "label": "Metal Layer",
                    "name": "metal_layer",
                    "tooltip": "Layer tuple for the metal region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": 0.5,
                    "label": "Strip Width",
                    "name": "strip_width",
                    "tooltip": "Strip waveguide core width.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 0.4,
                    "label": "Rib Width",
                    "name": "rib_width",
                    "tooltip": "Rib waveguide core width.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 1.0,
                    "label": "Clad Width",
                    "name": "clad_width",
                    "tooltip": "Cladding width to the sides of waveguides.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 3.6,
                    "label": "CPW Width",
                    "name": "cpw_width",
                    "tooltip": "Width of the central conductor for the CPW transmission line in the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 2.5,
                    "label": "CPW Gap",
                    "name": "cpw_gap",
                    "tooltip": "Spacing betwee the central conductor and the ground pads for the CPW transmission line in the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["exclusiveMin"],
                    "validatesArgs": {"exclusiveMin": [0]},
                },
                {
                    "defaults": 0,
                    "label": "Mask Dilation",
                    "name": "mask_dilation",
                    "tooltip": "Dilation appplied to the core extrusion masks.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 0,
                    "label": "Sidewall Angle",
                    "name": "sidewall_angle",
                    "tooltip": "Etching angle in the core (in degrees).",
                    "type": "number",
                    "suffix": "°",
                    "validates": ["exclusiveMin", "exclusiveMax"],
                    "validatesArgs": {"exclusiveMin": [-90], "exclusiveMax": [90]},
                },
                {
                    "defaults": False,
                    "label": "Core Fill",
                    "name": "core_fill",
                    "tooltip": "If set, device bounds will be filled with the core layer and only cladding and slab regions will have it (partially) removed. Otherwise, only core and slab regions will have the core medium.",
                    "type": "checkbox",
                },
                {
                    "defaults": 0.002,
                    "label": "Core Thickness Stdev",
                    "name": "core_thickness_stdev",
                    "tooltip": "Standard deviation for core thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.005,
                    "label": "Slab Thickness Stdev",
                    "name": "slab_thickness_stdev",
                    "tooltip": "Standard deviation for slab thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.05,
                    "label": "Clad Thickness Stdev",
                    "name": "clad_thickness_stdev",
                    "tooltip": "Standard deviation for clad thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.05,
                    "label": "BOX Thickness Stdev",
                    "name": "box_thickness_stdev",
                    "tooltip": "Standard deviation for box thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.005,
                    "label": "Mask Dilation Stdev",
                    "name": "mask_dilation_stdev",
                    "tooltip": "Standard deviation for mask dilation.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 2,
                    "label": "Sidewall Angle Stdev",
                    "name": "sidewall_angle_stdev",
                    "tooltip": "Standard deviation for sidewall angle (in degrees).",
                    "type": "number",
                    "suffix": "°",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
            ],
            "function": "basic_technology",
            "label": "Basic Technology",
        }
    ],
}
